(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    762207,      18848]*)
(*NotebookOutlinePosition[    762915,      18872]*)
(*  CellTagsIndexPosition[    762871,      18868]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Code Here", "Section"],

Cell[BoxData[{
    \(<< Miscellaneous`StandardAtmosphere`\), "\[IndentingNewLine]", 
    \(<< Graphics`Legend`\), "\[IndentingNewLine]", 
    \(\($TextStyle = {FontWeight -> "\<Bold\>", FontSize \[Rule] 16, 
          FontFamily -> "\<Helvetica\>"};\)\)}], "Input"],

Cell[BoxData[{
    \(\(LegendGraphs[{iplots_, legends_}, opts___] := 
        Module[{legopts, gr2}, \[IndentingNewLine]legopts = 
            FilterOptions[Legend, opts]; \[IndentingNewLine]ShowLegend[
            Show[iplots], \[IndentingNewLine]{legends, legopts}, 
            DisplayFunction \[Rule] 
              Identity]\[IndentingNewLine]];\)\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(AtmGraphs[ParameterTextPairs_, opts___] := 
        Module[{paras, txxts, styles, tmp, AtmG, gr, lg, 
            fxstyles}, \[IndentingNewLine]paras = \(Transpose[
                ParameterTextPairs]\)[\([1]\)]; \[IndentingNewLine]txxts = \
\(Transpose[ParameterTextPairs]\)[\([2]\)]; \[IndentingNewLine]AtmG[paras_, 
              opts22___] := 
            Block[{atmgplotopts}, \[IndentingNewLine]atmgplotopts = 
                FilterOptions[Plot, 
                  opts22]; \[IndentingNewLine]AtmosphericPlot[paras, 
                atmgplotopts, 
                DisplayFunction \[Rule] 
                  Identity]\[IndentingNewLine]]; \[IndentingNewLine]styles = \
\(AtmGraphStyles /. {opts}\) /. 
              AtmGraphStyles \[Rule] \ {{Red, AbsoluteThickness[2]}, {Blue, 
                    AbsoluteThickness[2]}, {Green, 
                    AbsoluteThickness[2]}}; \[IndentingNewLine]fxstyles = 
            Take[PadLeft[{}, \(-1\)*Length[paras], styles\ ], 
              Length[paras]]; \[IndentingNewLine]\[IndentingNewLine]tmp = 
            Transpose[{paras, fxstyles}]; \[IndentingNewLine]gr = 
            Map[AtmG[#1[\([1]\)], PlotStyle \[Rule] #1[\([2]\)], 
                  FilterOptions[Plot, opts]] &, tmp]; \[IndentingNewLine]lg = 
            Map[\ {Graphics[
                    Append[#[\([1]\)], 
                      Line[{{0, 0}, {1, 0}}]]], #[\([2]\)]} &, 
              Transpose[{fxstyles, txxts}]]; \[IndentingNewLine]Return[{gr, 
              lg}];\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Section"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        RowBox[{"lst", "=", 
          RowBox[{"AtmGraphs", "[", 
            RowBox[{
              RowBox[{"{", 
                
                RowBox[{\({Pressure, "\<Pressure (hPa)\>"}\), 
                  ",", \({MeanDensity, \*"\"\<Density (kg/\!\(m\^3\)\>\""}\), 
                  ",", 
                  RowBox[{"{", 
                    StyleBox[\(MeanFreePath, "\<M.F.P.L (m)\>"\),
                      GridBoxOptions->{RowSpacings->0.4,
                      RowLines->False}], 
                    StyleBox["}",
                      GridBoxOptions->{RowSpacings->0.4,
                      RowLines->False}]}]}], 
                StyleBox["}",
                  GridBoxOptions->{RowSpacings->0.4,
                  RowLines->False}]}], 
              StyleBox[",",
                GridBoxOptions->{RowSpacings->0.4,
                RowLines->False}], \(PlotRange -> {\(-7\)\ , 500\ }\), 
              ",", \(AtmGraphStyles \[Rule] {{Red, 
                    AbsoluteThickness[2]}, {Yellow, 
                    AbsoluteThickness[2]}, {Green, AbsoluteThickness[2]}}\), 
              ",", "\[IndentingNewLine]", \(FrameLabel \[Rule] \
{"\<Log[10,Value]\>", "\<Altitude, km\>"}\)}], 
            StyleBox["]",
              GridBoxOptions->{RowSpacings->0.4,
              RowLines->False}]}]}], 
        StyleBox[";",
          GridBoxOptions->{RowSpacings->0.4,
          RowLines->False}]}], 
      StyleBox[" ",
        GridBoxOptions->{RowSpacings->0.4,
        RowLines->False}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        LegendGraphs[lst, LegendSize \[Rule] { .8,  .3}, 
          LegendPosition \[Rule] \ {0,  .25}, Foo \[Rule] Bar], 
        DisplayFunction \[Rule] $DisplayFunction, 
        ImageSize \[Rule] 750];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 750 463.525 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.680951 0.0454819 0.00853301 0.001219 [
[.22613 -0.0125 -16.6563 -20.3125 ]
[.22613 -0.0125 16.6563 0 ]
[.45354 -0.0125 -12.2188 -20.3125 ]
[.45354 -0.0125 12.2188 0 ]
[.68095 -0.0125 -6.4375 -20.3125 ]
[.68095 -0.0125 6.4375 0 ]
[.90836 -0.0125 -6.4375 -20.3125 ]
[.90836 -0.0125 6.4375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -54.6563 -40.625 ]
[.5 -0.0125 54.6563 -20.3125 ]
[-0.0125 .00853 -12.875 -10.1563 ]
[-0.0125 .00853 0 10.1563 ]
[-0.0125 .13043 -30.625 -10.1563 ]
[-0.0125 .13043 0 10.1563 ]
[-0.0125 .25233 -30.625 -10.1563 ]
[-0.0125 .25233 0 10.1563 ]
[-0.0125 .37423 -30.625 -10.1563 ]
[-0.0125 .37423 0 10.1563 ]
[-0.0125 .49613 -30.625 -10.1563 ]
[-0.0125 .49613 0 10.1563 ]
[-0.0125 .61803 -30.625 -10.1563 ]
[-0.0125 .61803 0 10.1563 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -50.9375 -47.3125 ]
[-0.01875 .30902 -30.625 47.3125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22613 0 m
.22613 .00625 L
s
gsave
.22613 -0.0125 -77.6563 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.45354 0 m
.45354 .00625 L
s
gsave
.45354 -0.0125 -73.2188 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68095 0 m
.68095 .00625 L
s
gsave
.68095 -0.0125 -67.4375 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.90836 0 m
.90836 .00625 L
s
gsave
.90836 -0.0125 -67.4375 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.0442 0 m
.0442 .00375 L
s
.08969 0 m
.08969 .00375 L
s
.13517 0 m
.13517 .00375 L
s
.18065 0 m
.18065 .00375 L
s
.27161 0 m
.27161 .00375 L
s
.3171 0 m
.3171 .00375 L
s
.36258 0 m
.36258 .00375 L
s
.40806 0 m
.40806 .00375 L
s
.49902 0 m
.49902 .00375 L
s
.54451 0 m
.54451 .00375 L
s
.58999 0 m
.58999 .00375 L
s
.63547 0 m
.63547 .00375 L
s
.72643 0 m
.72643 .00375 L
s
.77191 0 m
.77191 .00375 L
s
.8174 0 m
.8174 .00375 L
s
.86288 0 m
.86288 .00375 L
s
.95384 0 m
.95384 .00375 L
s
.99932 0 m
.99932 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -115.656 -44.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
92.063 19.750 moveto
(@) show
97.813 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
115.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
120.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Value) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
162.563 19.750 moveto
(D) show
168.313 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00853 m
.00625 .00853 L
s
gsave
-0.0125 .00853 -73.875 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13043 m
.00625 .13043 L
s
gsave
-0.0125 .13043 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
0 .25233 m
.00625 .25233 L
s
gsave
-0.0125 .25233 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
0 .37423 m
.00625 .37423 L
s
gsave
-0.0125 .37423 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
0 .49613 m
.00625 .49613 L
s
gsave
-0.0125 .49613 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03291 m
.00375 .03291 L
s
0 .05729 m
.00375 .05729 L
s
0 .08167 m
.00375 .08167 L
s
0 .10605 m
.00375 .10605 L
s
0 .15481 m
.00375 .15481 L
s
0 .17919 m
.00375 .17919 L
s
0 .20357 m
.00375 .20357 L
s
0 .22795 m
.00375 .22795 L
s
0 .27671 m
.00375 .27671 L
s
0 .30109 m
.00375 .30109 L
s
0 .32547 m
.00375 .32547 L
s
0 .34985 m
.00375 .34985 L
s
0 .39861 m
.00375 .39861 L
s
0 .42299 m
.00375 .42299 L
s
0 .44737 m
.00375 .44737 L
s
0 .47175 m
.00375 .47175 L
s
0 .52051 m
.00375 .52051 L
s
0 .54489 m
.00375 .54489 L
s
0 .56927 m
.00375 .56927 L
s
0 .59365 m
.00375 .59365 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -149.094 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
108.313 14.1563 translate
90 rotate
-108.313 -14.1563 translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Altitude) show
121.688 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
130.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(km) show
153.625 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.22613 .61178 m
.22613 .61803 L
s
.45354 .61178 m
.45354 .61803 L
s
.68095 .61178 m
.68095 .61803 L
s
.90836 .61178 m
.90836 .61803 L
s
.125 Mabswid
.0442 .61428 m
.0442 .61803 L
s
.08969 .61428 m
.08969 .61803 L
s
.13517 .61428 m
.13517 .61803 L
s
.18065 .61428 m
.18065 .61803 L
s
.27161 .61428 m
.27161 .61803 L
s
.3171 .61428 m
.3171 .61803 L
s
.36258 .61428 m
.36258 .61803 L
s
.40806 .61428 m
.40806 .61803 L
s
.49902 .61428 m
.49902 .61803 L
s
.54451 .61428 m
.54451 .61803 L
s
.58999 .61428 m
.58999 .61803 L
s
.63547 .61428 m
.63547 .61803 L
s
.72643 .61428 m
.72643 .61803 L
s
.77191 .61428 m
.77191 .61803 L
s
.8174 .61428 m
.8174 .61803 L
s
.86288 .61428 m
.86288 .61803 L
s
.95384 .61428 m
.95384 .61803 L
s
.99932 .61428 m
.99932 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00853 m
1 .00853 L
s
.99375 .13043 m
1 .13043 L
s
.99375 .25233 m
1 .25233 L
s
.99375 .37423 m
1 .37423 L
s
.99375 .49613 m
1 .49613 L
s
.125 Mabswid
.99625 .03291 m
1 .03291 L
s
.99625 .05729 m
1 .05729 L
s
.99625 .08167 m
1 .08167 L
s
.99625 .10605 m
1 .10605 L
s
.99625 .15481 m
1 .15481 L
s
.99625 .17919 m
1 .17919 L
s
.99625 .20357 m
1 .20357 L
s
.99625 .22795 m
1 .22795 L
s
.99625 .27671 m
1 .27671 L
s
.99625 .30109 m
1 .30109 L
s
.99625 .32547 m
1 .32547 L
s
.99625 .34985 m
1 .34985 L
s
.99625 .39861 m
1 .39861 L
s
.99625 .42299 m
1 .42299 L
s
.99625 .44737 m
1 .44737 L
s
.99625 .47175 m
1 .47175 L
s
.99625 .52051 m
1 .52051 L
s
.99625 .54489 m
1 .54489 L
s
.99625 .56927 m
1 .56927 L
s
.99625 .59365 m
1 .59365 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
.82876 .00244 m
.8277 .00305 L
.82663 .00366 L
.82555 .00427 L
.82446 .00488 L
.82335 .00549 L
.82224 .0061 L
.82111 .0067 L
.81997 .00731 L
.81882 .00792 L
.81766 .00853 L
.81648 .00914 L
.81529 .00975 L
.81408 .01036 L
.81287 .01097 L
.81163 .01158 L
.81039 .01219 L
.80912 .0128 L
.80785 .01341 L
.80655 .01402 L
.80524 .01463 L
.80392 .01524 L
.80257 .01585 L
.80121 .01646 L
.79984 .01707 L
.79844 .01768 L
.79702 .01829 L
.79559 .01889 L
.79414 .0195 L
.79266 .02011 L
.79116 .02072 L
.78965 .02133 L
.78811 .02194 L
.78655 .02255 L
.7849 .02316 L
.78345 .02377 L
.7819 .02438 L
.78035 .02499 L
.7788 .0256 L
.77725 .02621 L
.7757 .02682 L
.7726 .02804 L
.7695 .02926 L
.7664 .03048 L
.76331 .03169 L
.76021 .03291 L
.75712 .03413 L
.75405 .03535 L
.75099 .03657 L
.74795 .03779 L
Mistroke
.74492 .03901 L
.7419 .04023 L
.7389 .04145 L
.73591 .04267 L
.73294 .04388 L
.72998 .0451 L
.72704 .04632 L
.72411 .04754 L
.7212 .04876 L
.71833 .04998 L
.71549 .0512 L
.71268 .05242 L
.70717 .05486 L
.70179 .05729 L
.69652 .05973 L
.69137 .06217 L
.68634 .06461 L
.6814 .06705 L
.67649 .06948 L
.67158 .07192 L
.66659 .07436 L
.6615 .0768 L
.65631 .07924 L
.65101 .08167 L
.63722 .08777 L
.62263 .09386 L
.60718 .09996 L
.591 .10605 L
.57402 .11215 L
.57228 .11276 L
.57053 .11337 L
.55651 .11824 L
.53908 .12434 L
.52201 .13043 L
.49227 .14262 L
.47194 .15481 L
.45796 .167 L
.44706 .17919 L
.43795 .19138 L
.43002 .20357 L
.42291 .21576 L
.41643 .22795 L
.41041 .24014 L
.40479 .25233 L
.39948 .26452 L
.39443 .27671 L
.38496 .30109 L
.37616 .32547 L
.36788 .34985 L
.35999 .37423 L
Mistroke
.35242 .39861 L
.34512 .42299 L
.33804 .44737 L
.33116 .47175 L
.32446 .49613 L
.30842 .55708 L
.29347 .61803 L
Mfstroke
.29347 .61803 m
.29347 .61803 L
s
1 1 0 r
.69395 .00244 m
.69309 .00305 L
.69223 .00366 L
.69135 .00427 L
.69047 .00488 L
.68957 .00549 L
.68867 .0061 L
.68776 .0067 L
.68684 .00731 L
.6859 .00792 L
.68496 .00853 L
.68401 .00914 L
.68304 .00975 L
.68207 .01036 L
.68108 .01097 L
.68008 .01158 L
.67907 .01219 L
.67805 .0128 L
.67702 .01341 L
.67597 .01402 L
.67491 .01463 L
.67383 .01524 L
.67275 .01585 L
.67165 .01646 L
.67053 .01707 L
.6694 .01768 L
.66825 .01829 L
.66709 .01889 L
.66591 .0195 L
.66472 .02011 L
.66351 .02072 L
.66228 .02133 L
.66103 .02194 L
.65949 .02255 L
.65794 .02316 L
.65639 .02377 L
.65484 .02438 L
.65329 .02499 L
.65174 .0256 L
.65019 .02621 L
.64864 .02682 L
.64554 .02804 L
.64244 .02926 L
.63934 .03048 L
.63624 .03169 L
.63315 .03291 L
.62997 .03413 L
.62681 .03535 L
.62366 .03657 L
.62053 .03779 L
Mistroke
.61741 .03901 L
.61431 .04023 L
.61122 .04145 L
.60815 .04267 L
.60509 .04388 L
.60204 .0451 L
.59901 .04632 L
.596 .04754 L
.59287 .04876 L
.58976 .04998 L
.58669 .0512 L
.58366 .05242 L
.57769 .05486 L
.57187 .05729 L
.56617 .05973 L
.5606 .06217 L
.55515 .06461 L
.54994 .06705 L
.54503 .06948 L
.54024 .07192 L
.53566 .07436 L
.53099 .0768 L
.52622 .07924 L
.52135 .08167 L
.5087 .08777 L
.4953 .09386 L
.48089 .09996 L
.46565 .10605 L
.44967 .11215 L
.44803 .11276 L
.44638 .11337 L
.43233 .11824 L
.41461 .12434 L
.39662 .13043 L
.36199 .14262 L
.33287 .15481 L
.31306 .167 L
.29814 .17919 L
.28604 .19138 L
.27575 .20357 L
.26674 .21576 L
.25867 .22795 L
.25133 .24014 L
.24455 .25233 L
.23824 .26452 L
.23231 .27671 L
.22137 .30109 L
.21139 .32547 L
.20216 .34985 L
.19349 .37423 L
Mistroke
.18528 .39861 L
.17745 .42299 L
.16991 .44737 L
.16262 .47175 L
.15553 .49613 L
.1385 .55708 L
.12231 .61803 L
Mfstroke
.12231 .61803 m
.12231 .61803 L
s
0 1 0 r
.34548 .00244 m
.34634 .00305 L
.3472 .00366 L
.34808 .00427 L
.34896 .00488 L
.34986 .00549 L
.35058 .0061 L
.35167 .0067 L
.35259 .00731 L
.35353 .00792 L
.35447 .00853 L
.35542 .00914 L
.35639 .00975 L
.35736 .01036 L
.35835 .01097 L
.35935 .01158 L
.36036 .01219 L
.36138 .0128 L
.36241 .01341 L
.36346 .01402 L
.36452 .01463 L
.36559 .01524 L
.36668 .01585 L
.36778 .01646 L
.3689 .01707 L
.37003 .01768 L
.37118 .01829 L
.37234 .01889 L
.37352 .0195 L
.37471 .02011 L
.37592 .02072 L
.37715 .02133 L
.3784 .02194 L
.37994 .02255 L
.38149 .02316 L
.38304 .02377 L
.38459 .02438 L
.38614 .02499 L
.38769 .0256 L
.38924 .02621 L
.39079 .02682 L
.39389 .02804 L
.39699 .02926 L
.40009 .03048 L
.40319 .03169 L
.40628 .03291 L
.40946 .03413 L
.41262 .03535 L
.41577 .03657 L
.4189 .03779 L
Mistroke
.42202 .03901 L
.42512 .04023 L
.42821 .04145 L
.43128 .04267 L
.43434 .04388 L
.43739 .0451 L
.44042 .04632 L
.44343 .04754 L
.44656 .04876 L
.44967 .04998 L
.45274 .0512 L
.45577 .05242 L
.46174 .05486 L
.46756 .05729 L
.47326 .05973 L
.47883 .06217 L
.48428 .06461 L
.48949 .06705 L
.4944 .06948 L
.49919 .07192 L
.50377 .07436 L
.50844 .0768 L
.51321 .07924 L
.51808 .08167 L
.53073 .08777 L
.54413 .09386 L
.55854 .09996 L
.57378 .10605 L
.58976 .11215 L
.5914 .11276 L
.59309 .11337 L
.60703 .11824 L
.62468 .12434 L
.6424 .13043 L
.67624 .14262 L
.70459 .15481 L
.72391 .167 L
.73804 .17919 L
.75002 .19138 L
.75937 .20357 L
.768 .21576 L
.77552 .22795 L
.7824 .24014 L
.78921 .25233 L
.7955 .26452 L
.80026 .27671 L
.81035 .30109 L
.81928 .32547 L
.82788 .34985 L
.83627 .37423 L
Mistroke
.84377 .39861 L
.85143 .42299 L
.85847 .44737 L
.86476 .47175 L
.87216 .49613 L
.88818 .55708 L
.9032 .61803 L
Mfstroke
.9032 .61803 m
.9032 .61803 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.52381 .40426 m
.52381 .54711 L
.90476 .54711 L
.90476 .40426 L
F
1 g
.5 .42806 m
.5 .57092 L
.88095 .57092 L
.88095 .42806 L
F
0 g
.001 w
[ ] 0 setdash
.5 .42806 m
.88095 .42806 L
.88095 .57092 L
.5 .57092 L
.5 .42806 L
s
% Start of sub-graphic
p
0.5 0.428065 0.880952 0.570922 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0101902 0.101902 [
[ 0 0 0 0 ]
[ 1 .375 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .375 L
0 .375 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0183424 0.35119 0.120245 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .06929 -61 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
76.313 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
80.750 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
90.438 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
94.875 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
105.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
110.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
124.125 19.750 moveto
(H) show
129.625 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.813 19.750 moveto
(L) show
149.313 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.136549 0.35119 0.238451 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 1 0 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .1875 -61 -14.5313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 20.500 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.500 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Density) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
124.563 20.500 moveto
(H) show
130.063 20.500 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(kg) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
148.625 20.500 moveto
(\\220) show
154.500 20.500 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
168.688 13.125 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 11.375 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
175.563 20.500 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.254755 0.35119 0.356658 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .30571 -61 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Pressure) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.813 19.750 moveto
(H) show
141.313 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(hPa) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
170.563 19.750 moveto
(L) show
176.063 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{750, 463.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001cb000`400?l00000o`00003oo`3ooooo
0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo
003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0
ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool0
0?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooM`3o
ool00`3oojX0E@00000000030000000405FZo`3oool0oooo0=B0:`<0000000<0EJ[o0?ooo`3oool0
3`3oool00`3oojX0E@0[083Do`0/0?ooo`050?nZE@00000000000000000[P=@0o`3ooolV0?ooo`00
o`3ooomf0?ooo`030?ooe020:`00000000D0000000D0EJ[o0?ooo`3DP2/0000002^0e00D0?ooo`03
0=B0:`00:h00e?oo02d0oooo00<0e80[0000000[P=@0o`3ooolV0?ooo`00o`3oooml0?ooo`070:YE
0000000005FZ0?ooo`3DP2/0000002^0e00D0?ooo`030?ooZP1E02/0P=Co02d0oooo00<0e80[0000
000[P=@0o`3ooolV0?ooo`00o`3ooomR0?ooo`030?ooZP1E0000000000H0000000D0:h3D0?ooo`3o
ool0oonZ05D00002000000030000:`20e?l0oooo00<0oooo00/0e80[000000000000:h3D0=B0:`00
000005FZ0?ooo`3DP2/0000002^0e0040?ooo`040?ooe020:`00000002^0e0@0oooo00D0ojYE0000
00000000000005FZo`020?ooo`040?oDP00[0000000[083Do`@0oooo00D0omB002/000000000001E
0:[oo`040?ooo`0<0=B0:`0000000000000[P03DojX0E@000000:`20e?l0oonZ05D000000000EJ[o
0P3oool01`2ZE@00000000000000:h00ZX0[00000000EJX00`3oool01@2ZE@000000000000000000
:h3D00<0oooo00<0e80[0000000[P=@0o`3ooolV0?ooo`00o`3ooomR0?ooo`030?ooZP1E00000000
00H0000000<0:h3D0?ooo`3oZUD01P000000101EZ_l0oooo0?ooo`3DP2/40000000702/[:`000000
05FZ0?ooo`3DP2/0000002^0e0040?ooo`040?ooe020:`00000002^0e0<0oooo00<0ojYE00000000
00000`0000001P1EZ_l0oooo0?oDP00[0000000[083Do`@0oooo00D0e80[000000000000000005FZ
o`030?ooo`030?nZE@000000000000@0000000P002^00=Coo`3oojX0E@000000001EZ_l0oooo0?nZ
E@H0000000@005FZ0?ooo`3oool0ZUD01@0000001P0[P=@0oooo0?ooo`3DP2/0000002^0e?l0oooo
9P3oool00?l0ooooHP3oool0103oojX0E@000000001EZ_l60?ooo`0G0?ooe020:`000000000[P03D
ool0oooo0:YE0000000002^00=Coo`3oojX0E@0000000000EJX0oooo0?oDP00[00000000001EZP3o
ool0e80[0000000[P=@0103oool0103oom@0P2/00000000[P=@20?ooo`090?ooe020:`00000002^0
e03oool0e80[00000000:h00e?oo00L0oooo00H0oooD080[00000000EEEE00000000EJX30?ooo`0T
0=B0:`00000002^00=Coo`3oom@0P2/000000000:h00e?oo0?ooZP1E0000000005FZo`3oool0ZUD0
00000000:h00e?oo0?ooZP1E00000000001EZP3oool0omB002/000000000EJ[o0?ooo`3oZUD00000
0000E@2Zool0oooo0=B0:`000000:h3Do`3ooolV0?ooo`00o`3ooomR0?ooo`040?ooZP1E00000000
05FZo`H0oooo00@0omB002/0000002/0P=Co0P3oool0203oojX0E@000000:`20e?l0omB002/00000
02/0P=Co0P3oool01`3DP2/00000001EZP3oool0e80[0000000[P=@0103oool0103oom@0P2/00000
000[P=@20?ooo`090?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo00L0oooo00L0omB0
02/0000005D0Z_nZ05D0000005D0Z_oo0080oooo0140ojYE000000000000EJ[o0?ooo`3DP2/00000
000[P03Dool0oonZ05D000000000EJ[o0?ooo`2ZE@000000001EZP020?ooo`080:YE0000000005FZ
0?ooo`3DP2/00000000[P03Dool60?ooo`030=B0:`000000:h3D0?l0oooo9P3oool00?l0ooooHP3o
ool0103oojX0E@000000001EZ_l60?ooo`040?oDP00[0000001E0:[oo`80oooo00P0oonZ05D00000
0000EJ[o0?oDP00[0000001E0:[oo`80oooo00L0e80[00000000EJX0oooo0=B0:`000000:h3D00@0
oooo00@0oooD080[00000000:h3D0P3oool02@3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[
083Do`070?ooo`070=B0:`00000002^00=Coo`2ZE@00000005FZo`020?ooo`030?ooe020:`000000
00@0000000X002^00=Coo`3oojX0E@000000001EZ_l0oooo0:YE0000000005FZ0P3oool01@3DP2/0
0000001EZP3oool0e80[00L0000000D0EJ[o0?ooo`3DP2/0000002^0e03o0?ooobH0oooo003o0?oo
of80oooo00@0oonZ05D000000000EJ[o1P3oool0103oe800:`000000:`20e?l20?ooo`080?ooZP1E
0000000[083Do`3oe800:`000000:`20e?l20?ooo`070=B0:`00000005FZ0?ooo`3DP2/0000002^0
e0040?ooo`040?ooe020:`00000002^0e080oooo00T0ojYE0000000005D0Z_oo0?ooo`3oojX0E@00
0000001EZ_l01P3oool0203oom@0P2/00000000[P=@0oooo0=B0:`00000005FZ1@3oool03P3oe800
:`0000000000000002^00=Coo`3oojX0E@000000001EZ_l0oooo0:YE0000000005FZ0P3oool01@3D
P2/00000001EZP3oool0ojYE00H0000000H0000[083Do`3oool0e80[0000000[P=Co0?ooobH0oooo
003o0?ooof80oooo00@0oonZ05D000000000EJ[o1P3oool05`3oom@0P2/000000000:h00e?oo0?oo
o`2ZE@0000000000E@2Zool0oonZ05D00000000005FZ0?ooo`3oojX0E@0000000000EJX0oooo0=B0
:`000000:h3D00@0oooo00@0oooD080[00000000:h3D0P3oool02@3oZUD000000000E@2Zool0oooo
0?ooZP1E0000000005FZo`060?ooo`0K0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo
0?ooo`3oojX0E@000000E@2Zool0oooo0=B0:`00000002^00=Coo`3oojX0E@000000001EZ_l0oooo
0:YE0000000005FZ0080oooo0140e80[00000000EJX0oooo0?oDP00[0000001E0:[oo`3oool0omB0
02/0000005D0Z_oo0?ooo`3DP2/0000002^0e03o0?ooobH0oooo003o0?ooof80oooo00@0oonZ05D0
00000000EJ[o1`3oool00`3oe800:`00000000040000000405FZo`3oool0oooo0=B0:`H0000000d0
05FZ0?ooo`3DP2/0000002^0e03oool0oooD080[000[P=@0oooD080[00000000:h3D0080oooo00T0
omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l01P3oool02@3DP2/00000000[P03Dool0
oooo0?ooe020:`00000005FZo`020?ooo`030:YE00000000000000<0000000X005FZ0?ooo`3oojX0
E@000000001EZ_l0oooo0:YE0000000005FZ0P3oool00`3DP2/00000001EZP020?ooo`030:YE0000
0000000000<0000000H0:h3D0?ooo`3oool0e80[0000000[P=Co0?ooobH0oooo003o0?ooof80oooo
00@0oonZ05D000000000EJ[o203oool01P3oojX0E@00000000000000000[083Do`@0oooo01<0e80[
000000000000:h3D0=B0:`00000005FZ0?ooo`3DP2/0000002^0e03oool0oooD080[00000000000[
02/[00000000:h3D0080oooo00T0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool01@3o
ool0103oom@0P2/00000000[P=@30?ooo`040=B0:`00000002^00=Coo`80oooo00l0ZUD000000000
00000000000[P03Dool0oooo0?ooZP1E0000000005FZo`3oool0ZUD000000000EJX00P3oool00`3D
P2/00000001EZP030?ooo`050=B0:`00000000000000000[P=@00`3oool00`3DP2/0000002^0e03o
0?ooobH0oooo003o0?ooof80oooo00@0oonZ05D000000000EJ[o6P3oool00`3DP2/0000002^0e003
0?ooo`050:YE0000000000000000000[P=@00P3oool02@3oom@0P2/00000000[P=@0oooo0=B0:`00
000002^00=Coo`050?ooo`040?oDP00[0000000005FZo`<0oooo00@0omB002/0000002/0P=Co2@3o
ool0103oojX0E@000000001EZ_lD0?ooo`030=B0:`000000:h3D0?l0oooo9P3oool00?l0ooooHP3o
ool0103oojX0E@000000001EZ_lJ0?ooo`050=B0:`00000000000000001EZ_l00P3oool0103oZUD0
00000000000[P=@30?ooo`030?nZE@000000000000<0000000<0EJ[o0?ooo`3oool0103oool0103D
P2/000000000E@2Zool30?ooo`040?ooe020:`00000002^0e0T0oooo00@0oonZ05D000000000EJ[o
4P3oool01@3oZUD00000000000000000:h3D0?l0oooo9P3oool00?l0ooooHP3oool0103oojX0E@00
0000001EZ_lR0?ooo`030:YE00000000:h3D00@0oooo00D0ojYE000000000000000005FZo`060?oo
o`040?ooe020:`000000001EZPD0oooo00@0ZUD000000000:h00e?oo203oool0103oojX0E@000000
001EZ_oo0?ooocd0oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oo
oo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o
0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00k03oool0103oom@0P2/00000000[P=@40?oo
o`050?nZE@00000000000000001EZ_l0P`3oool01@3DP2/00000000000000000:h3D0880oooo00D0
ojYE000000000000000005FZo`270?ooo`050=B0:`00000000000000000[P=@0FP3oool00>`0oooo
00@0oooD080[00000000:h3D0`3oool00`3oZUD00000000000030000000305FZo`3oool0oooo07l0
oooo00<0e80[0000000000000`0000000`00EJX0oooo0?ooo`1n0?ooo`030?nZE@000000000000<0
000000<0EJ[o0?ooo`3oool0P`3oool00`3DP2/000000000000300000003001EZP3oool0oooo05L0
oooo003/0?ooo`040?ooe020:`00000002^0e080oooo00T0oooD080[00000000:h3D0?ooo`3DP2/0
0000000[P03Dool0O`3oool02@3oojX0E@000000000[P=@0oooo0?nZE@000000000[083Do`1n0?oo
o`090?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo08<0oooo00T0oonZ05D000000000
:h3D0?ooo`3oZUD000000000:`20e?l0F03oool00=d0oooo00<0oonZ05D0000000001P0000000`00
:h00e?oo0?ooo`030?ooo`040?ooe020:`00000002^0e080oooo00T0omB002/0000002/0P=Co0?oo
o`3oe800:`000000E@2Zool0L`3oool00`3oojX0E@00000000060000000<000[P03Dool0oooo0?nZ
E@000000001E0:[oo`3oool0oooD080[00000000EJ[oOP3oool02@3oe800:`000000:`20e?l0oooo
0?oDP00[0000001E0:[oo`230?ooo`090?nZE@000000001E0:[oo`3oool0oooD080[00000000EJ[o
05P0oooo003M0?ooo`030?ooZP1E0000000000H0000000<002^00=Coo`3oool00`3oool0103oom@0
P2/00000000[P=@20?ooo`090?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co07<0oooo
00<0oonZ05D0000000001P0000000`00:h00e?oo0?ooo`050?ooo`040?ooe020:`00000002^0e7h0
oooo00T0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0R03oool0103oom@0P2/00000
000[P=AH0?ooo`00k03oool0103oom@0P2/00000000[P=@20?ooo`090?nZE@000000001E0:[oo`3o
ool0oonZ05D000000000EJ[o07l0oooo00H0oonZ05D0000002/0P=Co0?ooo`3oZUD20000000305FZ
o`3oool0oooo07`0oooo00T0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0P`3oool0
1P3oojX0E@000000:`20e?l0oooo0?nZE@80000000<0EJ[o0?ooo`3oool0EP3oool00>`0oooo00@0
oooD080[00000000:h3D0P3oool02@3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`1o
0?ooo`030?ooe020:`00000000@0000000<002^00=Coo`3oool0O@3oool02@3oZUD000000000E@2Z
ool0oooo0?ooZP1E0000000005FZo`230?ooo`030?ooe020:`00000000@0000000<002^00=Coo`3o
ool0E`3oool00>T0oooo00L0oooD080[000[P=@0oooD080[00000000:h3D0080oooo00T0omB002/0
000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0P03oool00`2ZE@0000000000000200000003001E
ZP3oool0oooo07h0oooo00T0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0Q03oool0
0`2ZE@0000000000000200000003001EZP3oool0oooo05P0oooo003Y0?ooo`070?ooe020:`000000
0000:`0[:`00000002^0e0020?ooo`090?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo
0800oooo00<0e80[00000000EJX0P`3oool02@3oe800:`000000:`20e?l0oooo0?oDP00[0000001E
0:[oo`240?ooo`030=B0:`00000005FZ05d0oooo003[0?ooo`050:YE0000000000000000000[P=@0
0P3oool02@3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`200?ooo`040?oDP00[0000
02^00=Cooh80oooo00T0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0Q03oool0103o
e800:`00000[P03DoomL0?ooo`00k03oool0103oZUD000000000000[P=@30?ooo`030?nZE@000000
000000<0000000<0EJ[o0?ooo`3oool0O`3oool00`3oojX0E@0000000003000000030000E@2Zool0
oooo07h0oooo00<0ojYE0000000000000`0000000`1EZ_l0oooo0?ooo`230?ooo`030?ooZP1E0000
000000<0000000<0001E0:[oo`3oool0E`3oool00>d0oooo00<0ZUD00000000[P=@0103oool01@3o
ZUD00000000000000000EJ[o0880oooo00<0oooD080[000000000`0000000`0005D0Z_oo0?ooo`1o
0?ooo`050?nZE@00000000000000001EZ_l0QP3oool00`3oom@0P2/000000003000000030000E@2Z
ool0oooo05L0oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00
oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?oo
ool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03o
ool00600ooooo`00003o000006d000008`3oool00500oooo00D0ojYE000000000000000005FZo`0;
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool00`00o`00oooo0?ooo`07
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0B
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo0240oooo001?0?ooo`030?nZE@000000000000<0000000<0EJ[o0?oo
o`3oool0203oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo0`00o`080?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool30?oo01<0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo0`3o000C0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0240oooo001>0?ooo`090?ooe020:`00000002^0e03oool0e80[00000000
:h00e?oo00T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`<00?l01`3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo103oo`0C0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`3oool40?l001@0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool08@3oool004h0oooo00T0omB002/0000002/0P=Co0?ooo`3oe800:`000000
E@2Zool02@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo04P0oooo1000o`0m0?oo
o`030000003oool0oooo08X0oooo00@000000?ooo`3oool0oooo103oo`1>0?ooo`D0o`00<P3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0240oooo001>0?ooo`090?oDP00[0000001E
0:[oo`3oool0oonZ05D0000002/0P=Co00T0oooo00<000000?ooo`3oool0e03oool5003o0</0oooo
103oo`1>0?ooo`D0o`00K03oool00`000000oooo0?ooo`0Q0?ooo`00CP3oool02@3oZUD000000000
E@2Zool0oooo0?ooZP1E0000000005FZo`090?ooo`D00000e@3oool4003o0<L0oooo1@3oo`1=0?oo
o`H0o`00J@3oool5000002<0oooo001>0?ooo`090?nZE@000000001E0:[oo`3oool0oonZ05D00000
0000EJ[o00T0oooo00<000000?ooo`3oool0e`3oool5003o0<D0oooo103oo`1>0?ooo`@0o`00L03o
ool00`000000oooo0?ooo`0Q0?ooo`00CP3oool02@3oe800:`000000E@2Zool0oooo0?ooZP1E0000
000[083Do`090?ooo`030000003oool0oooo0=X0oooo1000o`310?ooo`D0ool0C03oool50?l00780
oooo00<000000?ooo`3oool08@3oool004h0oooo00T0omB002/0000002/0P=Co0?ooo`3oe800:`00
0000E@2Zool02@3oool00`000000oooo0?ooo`3J0?ooo`H00?l0_@3oool50?oo04`0oooo1P3o001c
0?ooo`030000003oool0oooo0240oooo001>0?ooo`090?ooe020:`00000002^0e03oool0e80[0000
0000:h00e?oo00T0oooo00<000000?ooo`3oool0g03oool5003o0;/0oooo1@3oo`1;0?ooo`D0o`00
MP3oool00`000000oooo0?ooo`0Q0?ooo`00C`3oool00`3oZUD00000000000030000000305FZo`3o
ool0oooo00P0oooo00<000000?ooo`3oool0g`3oool5003o0;H0oooo1@3oo`1;0?ooo`D0o`00N03o
ool00`000000oooo0?ooo`0Q0?ooo`00D03oool01@3oZUD00000000000000000EJ[o00/0oooo00<0
00000?ooo`3oool0g`3oool7003o0;80oooo1@3oo`1:0?ooo`H0o`00NP3oool00`000000oooo0?oo
o`0Q0?ooo`00H03oool00`000000oooo0?ooo`3S0?ooo`@00?l0[`3oool50?oo04X0oooo1P3o001l
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0>D0oooo1@00o`2Z0?oo
o`D0ool0B@3oool60?l007l0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3o
ool0iP3oool7003o0:@0oooo1P3oo`180?ooo`L0o`00P@3oool00`000000oooo0?ooo`0Q0?ooo`00
H03oool00`000000oooo0?ooo`3Y0?ooo`H00?l0X03oool60?oo04P0oooo1P3o00240?ooo`030000
003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0>`0oooo1P00o`2J0?ooo`H0ool0B@3o
ool50?l008L0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0kP3oool7
003o09<0oooo203oo`170?ooo`P0o`00R03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`00
0000oooo0?ooo`3a0?ooo`H00?l0S`3oool70?oo04P0oooo1`3o002;0?ooo`030000003oool0oooo
0240oooo001P0?ooo`030000003oool0oooo0?@0oooo1@00o`2;0?ooo`D0ool0BP3oool50?l008l0
oooo00<000000?ooo`3oool08@3oool00600oooo0`00003f0?ooo`D00?l0Q`3oool50?oo04X0oooo
1@3o002?0?ooo`<000008`3oool00600oooo00<000000?ooo`3oool0n03oool7003o0800oooo1P3o
o`180?ooo`L0o`00T`3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3j
0?ooo`L00?l0O03oool60?oo04P0oooo1`3o002E0?ooo`030000003oool0oooo0240oooo001P0?oo
o`030000003oool0oooo0?h0oooo1@00o`1h0?ooo`D0ool0BP3oool40?l009T0oooo00<000000?oo
o`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3oool10?ooo`L00?l0L03oool70?oo04P0
oooo1P3o002K0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo
0`3oool7003o06`0oooo1`3oo`180?ooo`L0o`00W03oool00`000000oooo0?ooo`0Q0?ooo`00H03o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo1@00o`1X0?ooo`D0ool0BP3oool50?l00:00oooo00<0
00000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3oool90?ooo`H00?l0H@3oool7
0?oo04P0oooo1`3o002R0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo
0?l0oooo2`3oool6003o05d0oooo1`3oo`190?ooo`H0o`00Y03oool00`000000oooo0?ooo`0Q0?oo
o`00H03oool00`000000oooo0?ooo`3o0?ooo`h0oooo1@00o`1J0?ooo`@0ool0B`3oool40?l00:P0
oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3oool@0?ooo`L00?l0
DP3oool60?oo04T0oooo1`3o002Y0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003o
ool0oooo0?l0oooo4P3oool7003o04h0oooo1`3oo`190?ooo`H0o`00Z`3oool00`000000oooo0?oo
o`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?oooaH0oooo1P00o`170?ooo`L0ool0B@3oool6
0?l00:l0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooolH0?oo
o`H00?l0@`3oool60?oo04X0oooo1P3o002a0?ooo`030000003oool0oooo0240oooo001P0?ooo`03
0000003oool0oooo0?l0oooo703oool4003o0400oooo103oo`1<0?ooo`@0o`00]03oool00`000000
oooo0?ooo`0Q0?ooo`00H03oool300000?l0oooo7@3oool6003o03T0oooo1P3oo`1;0?ooo`D0o`00
]03oool3000002<0oooo001P0?ooo`030000003oool0oooo0?l0oooo7`3oool6003o03D0oooo1P3o
o`1;0?ooo`H0o`00]`3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o
0?ooob<0oooo1000o`0b0?ooo`@0ool0C03oool50?l00;X0oooo00<000000?ooo`3oool08@3oool0
0600oooo00<000000?ooo`3oool0o`3ooolT0?ooo`H00?l0:`3oool60?oo04/0oooo1P3o002l0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo9P3oool6003o02L0
oooo1P3oo`1;0?ooo`H0o`00_P3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo
0?ooo`3o0?ooobT0oooo1@00o`0T0?ooo`@0ool0C@3oool40?l00<40oooo00<000000?ooo`3oool0
8@3oool00600oooo00<000000?ooo`3oool0o`3oool[0?ooo`H00?l07P3oool50?oo04`0oooo1@3o
00330?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo;@3oool5
003o01/0oooo1P3oo`1;0?ooo`H0o`00a03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`00
0000oooo0?ooo`3o0?oooc00oooo1000o`0H0?ooo`@0ool0C@3oool40?l00<L0oooo00<000000?oo
o`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooola0?ooo`H00?l04P3oool50?oo04`0
oooo1@3o00390?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo
<`3oool5003o00l0oooo1P3oo`1;0?ooo`H0o`00bP3oool00`000000oooo0?ooo`0Q0?ooo`00H03o
ool00`000000oooo0?ooo`3o0?ooocH0oooo0`00o`0=0?ooo`@0ool0C@3oool40?l00<d0oooo00<0
00000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooolg0?ooo`D00?l01`3oool5
0?oo04`0oooo1@3o003?0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo
0?l0oooo>03oool5003o00@0oooo1P3oo`1;0?ooo`H0o`00d03oool00`000000oooo0?ooo`0Q0?oo
o`00H03oool00`000000oooo0?ooo`3o0?oooc/0oooo1000o`000`3oool0ool00?oo00020?oo04`0
oooo1@3o003C0?ooo`030000003oool0oooo0240oooo001P0?ooo`<00000o`3oooll0?ooo`D00?l0
00<0ool00?ooo`3oool0BP3oool50?l00=<0oooo0`00000S0?ooo`00H03oool00`000000oooo0?oo
o`3o0?oooc`0oooo0P3oo`05003o04T0oooo1@3o003G0?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo0?l0oooo>`3oool40?oo00030?ooo`00o`000?l000<00?l0A@3oool5
0?l00=T0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3oooli0?oo
o`@0ool01@3oool5003o0440oooo1@3o003K0?ooo`030000003oool0oooo0240oooo001P0?ooo`03
0000003oool0oooo0?l0oooo=P3oool60?oo00P0oooo1P00o`0k0?ooo`H0o`00g@3oool00`000000
oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?oooc<0oooo1`3oo`0<0?ooo`H00?l0
=P3oool70?l00=l0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3o
ool`0?ooo`L0ool04P3oool6003o0300oooo1`3o003R0?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo0?l0oooo;P3oool60?oo01L0oooo1P00o`0[0?ooo`L0o`00i@3oool0
0`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooob/0oooo1P3oo`0M0?oo
o`D00?l09`3oool60?l00>P0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3o
ool0o`3ooolY0?ooo`H0ool08@3oool6003o0240oooo1P3o003[0?ooo`030000003oool0oooo0240
oooo001P0?ooo`030000003oool0oooo0?l0oooo9`3oool50?oo02H0oooo1P00o`0M0?ooo`H0o`00
k@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooobD0oooo1@3o
o`0[0?ooo`D00?l0603oool60?l00?00oooo00<000000?ooo`3oool08@3oool00600oooo00<00000
0?ooo`3oool0o`3ooolR0?ooo`H0ool0;`3oool6003o01<0oooo1P3o003b0?ooo`030000003oool0
oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo803oool60?oo03<0oooo1P00o`0>0?oo
o`H0o`00m@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?oooah0
oooo1@3oo`0i0?ooo`H00?l02@3oool60?l00?L0oooo00<000000?ooo`3oool08@3oool00600oooo
0`00003o0?oooa/0oooo1P3oo`0m0?ooo`H00?l0103oool60?l00?P0oooo0`00000S0?ooo`00H03o
ool00`000000oooo0?ooo`3o0?oooaT0oooo1P3oo`120?ooo`H00?l01@3o003l0?ooo`030000003o
ool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo5P3oool60?oo04L0oooo1P00o`3o
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo503oool60?oo
04L0oooo1@3o0006003o0?`0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3o
ool0o`3oool?0?ooo`P0ool0A@3oool80?l000@0oooo2@00o`3g0?ooo`030000003oool0oooo0240
oooo001P0?ooo`030000003oool0oooo0?l0oooo303oool90?oo04@0oooo2@3o00090?ooo`P00?l0
m@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooo`T0oooo1`3o
o`160?ooo`L0o`004`3oool6003o0?80oooo00<000000?ooo`3oool08@3oool00600oooo00<00000
0?ooo`3oool0o`3oool60?ooo`L0ool0AP3oool70?l001P0oooo1`00o`3_0?ooo`030000003oool0
oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo0`3oool70?oo04H0oooo1`3o000N0?oo
o`H00?l0k@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooo`40
oooo1P3oo`170?ooo`H0o`00903oool6003o0>X0oooo00<000000?ooo`3oool08@3oool003l0oooo
00@0oooD080[00000000:h3D103oool01@3oZUD00000000000000000EJ[o00@0oooo00D0ojYE0000
00000000000005FZo`0;0?ooo`030000003oool0oooo0?d0oooo1P3oo`170?ooo`H0o`00:@3oool7
003o0>L0oooo00<000000?ooo`3oool08@3oool003l0oooo00@0oooD080[00000000:h3D0`3oool0
0`3oZUD00000000000030000000405FZo`3oool0oooo0?nZE@D0000000<0EJ[o0?ooo`3oool0203o
ool00`000000oooo0?ooo`3j0?ooo`L0ool0AP3oool70?l002h0oooo1`00o`3T0?ooo`030000003o
ool0oooo0240oooo000o0?ooo`040?ooe020:`00000002^0e080oooo0180oooD080[00000000:h3D
0?ooo`3DP2/00000000[P03Dool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool90?oo
o`030000003oool0oooo0?L0oooo1`3oo`170?ooo`H0o`00=03oool6003o0>80oooo00<000000?oo
o`3oool08@3oool003l0oooo00@0oooD080[00000000:h3D0P3oool04P3oe800:`000000:`20e?l0
oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`T0oooo
00<000000?ooo`3oool0m@3oool60?oo04L0oooo1P3o000j0?ooo`H00?l0g`3oool00`000000oooo
0?ooo`0Q0?ooo`00?`3oool0103oom@0P2/00000000[P=@20?ooo`0B0?oDP00[0000001E0:[oo`3o
ool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co2@3oool0
0`000000oooo0?ooo`3b0?ooo`H0ool0B03oool60?l003h0oooo1`00o`3L0?ooo`030000003oool0
oooo0240oooo000o0?ooo`040?ooe020:`00000002^0e080oooo0180ojYE0000000005D0Z_oo0?oo
o`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l90?ooo`D0
0000k@3oool70?oo04P0oooo1@3o00140?ooo`L00?l0e@3oool5000002<0oooo000o0?ooo`040?oo
e020:`00000002^0e080oooo0180ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE
0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l90?ooo`030000003oool0oooo0>d0oooo1P3o
o`180?ooo`H0o`00B@3oool6003o0=L0oooo00<000000?ooo`3oool08@3oool003`0oooo00L0oooD
080[000[P=@0oooD080[00000000:h3D0080oooo0180omB002/0000005D0Z_oo0?ooo`3oojX0E@00
0000:`20e?l0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l90?ooo`030000003oool0
oooo0>X0oooo1P3oo`190?ooo`H0o`00CP3oool6003o0=@0oooo00<000000?ooo`3oool08@3oool0
03`0oooo00L0oooD080[00000000000[02/[00000000:h3D0080oooo0180omB002/0000002/0P=Co
0?ooo`3oe800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool90?oo
o`030000003oool0oooo0>L0oooo1`3oo`180?ooo`H0o`00D`3oool6003o0=80oooo00<000000?oo
o`3oool08@3oool003h0oooo00D0ZUD0000000000000000002^0e0020?ooo`0B0?ooe020:`000000
02^0e03oool0e80[00000000:h00e?oo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo
2@3oool00`000000oooo0?ooo`3U0?ooo`H0ool0B@3oool60?l005P0oooo1P00o`3?0?ooo`030000
003oool0oooo0240oooo000o0?ooo`040?nZE@000000000002^0e0<0oooo00<0ojYE000000000000
0`000000101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo00P0oooo00<000000?ooo`3o
ool0hP3oool60?oo04X0oooo1@3o001M0?ooo`L00?l0c03oool00`000000oooo0?ooo`0Q0?ooo`00
@03oool00`2ZE@00000002^0e0040?ooo`050?nZE@00000000000000001EZ_l0103oool01@3oZUD0
0000000000000000EJ[o00/0oooo00<000000?ooo`3oool0h03oool60?oo04T0oooo1P3o001R0?oo
o`H00?l0bP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3M0?ooo`H0
ool0BP3oool60?l006L0oooo1P00o`370?ooo`030000003oool0oooo0240oooo001P0?ooo`030000
003oool0oooo0=X0oooo1`3oo`1:0?ooo`D0o`00K03oool7003o0<@0oooo00<000000?ooo`3oool0
8@3oool00600oooo00<000000?ooo`3oool0f03oool60?oo04`0oooo103o001a0?ooo`H00?l0`P3o
ool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3E0?ooo`H0ool0C@3oool4
0?l007H0oooo1P00o`2o0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo
0=<0oooo1P3oo`1=0?ooo`D0o`00N@3oool6003o0;d0oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0d03oool60?oo04h0oooo1@3o001n0?ooo`H00?l0^P3oool00`000000
oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3>0?ooo`H0ool0C`3oool40?l00880oooo
1P00o`2h0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0</0oooo1P3o
o`1@0?ooo`@0o`00Q`3oool6003o0;D0oooo00<000000?ooo`3oool08@3oool00600oooo0`000039
0?ooo`H0ool0D@3oool40?l008X0oooo1@00o`2b0?ooo`<000008`3oool00600oooo00<000000?oo
o`3oool0b03oool40?oo05<0oooo0`3o002?0?ooo`@00?l0/P3oool00`000000oooo0?ooo`0Q0?oo
o`00H03oool00`000000oooo0?ooo`360?ooo`@0ool0E03oool30?l00940oooo1000o`2a0?ooo`03
0000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0<D0oooo103oo`1C0?ooo`@0o`00
U03oool4003o0:l0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0``3o
ool40?oo05@0oooo103o002F0?ooo`@00?l0[P3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool0
0`000000oooo0?ooo`320?ooo`@0ool0E03oool30?l009X0oooo1000o`2/0?ooo`030000003oool0
oooo0240oooo001P0?ooo`030000003oool0oooo0<00oooo103oo`1E0?ooo`<0o`00W03oool4003o
0:/0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0_`3oool40?oo05D0
oooo0`3o002O0?ooo`@00?l0Z@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo
0?ooo`2n0?ooo`<0ool0EP3oool30?l00:40oooo1000o`2X0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo0;`0oooo103oo`1F0?ooo`<0o`00Y03oool3003o0:L0oooo00<0
00000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0^`3oool40?oo05H0oooo0`3o002V
0?ooo`<00?l0YP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2i0?oo
o`@0ool0E`3oool30?l00:P0oooo1000o`2T0?ooo`030000003oool0oooo0240oooo001P0?ooo`03
0000003oool0oooo0;P0oooo103oo`1G0?ooo`<0o`00ZP3oool4003o0:<0oooo00<000000?ooo`3o
ool08@3oool00600oooo00<000000?ooo`3oool0]P3oool40?oo05P0oooo0`3o002]0?ooo`<00?l0
XP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2e0?ooo`@0ool0F03o
ool30?l00:l0oooo0`00o`2Q0?ooo`030000003oool0oooo0240oooo001P0?ooo`<00000]03oool3
0?oo05X0oooo0P3o002a0?ooo`<00?l0WP3oool3000002<0oooo001P0?ooo`030000003oool0oooo
0;<0oooo0`3oo`1J0?ooo`80o`00/`3oool3003o09l0oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0/P3oool30?oo05X0oooo0P3o002e0?ooo`<00?l0WP3oool00`000000
oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2a0?ooo`<0ool0F`3oool00`3o0000oooo
0?ooo`2e0?ooo`<00?l0W@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?oo
o`2a0?ooo`80ool0F`3oool20?l00;P0oooo0`00o`2L0?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo0;00oooo0P3oo`1L0?ooo`030?l0003oool0oooo0;P0oooo0`00o`2K
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0:l0oooo0`3oo`1K0?oo
o`80o`00^`3oool3003o09X0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3o
ool0[P3oool30?oo05/0oooo0P3o002m0?ooo`<00?l0V@3oool00`000000oooo0?ooo`0Q0?ooo`00
H03oool00`000000oooo0?ooo`2]0?ooo`<0ool0G03oool00`3o0000oooo0?ooo`2m0?ooo`800?l0
V@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2/0?ooo`<0ool0G03o
ool20?l00<00oooo0P00o`2H0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo0:/0oooo0`3oo`1L0?ooo`80o`00`P3oool2003o09L0oooo00<000000?ooo`3oool08@3oool0
0600oooo00<000000?ooo`3oool0Z`3oool20?oo05`0oooo0P3o00340?ooo`03003o003oool0oooo
09D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0ZP3oool20?oo05d0
oooo00<0o`000?ooo`3oool0``3oool2003o09H0oooo00<000000?ooo`3oool08@3oool00600oooo
00<000000?ooo`3oool0Z@3oool30?oo05`0oooo0P3o00360?ooo`800?l0U@3oool00`000000oooo
0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2X0?ooo`<0ool0G03oool20?l00<P0oooo0P00
o`2D0?ooo`030000003oool0oooo0240oooo001P0?ooo`<00000Z03oool20?oo05d0oooo00<0o`00
0?ooo`3oool0b03oool00`00o`00oooo0?ooo`2@0?ooo`<000008`3oool00600oooo00<000000?oo
o`3oool0Y`3oool20?oo05d0oooo0P3o003:0?ooo`800?l0T`3oool00`000000oooo0?ooo`0Q0?oo
o`00H03oool00`000000oooo0?ooo`2V0?ooo`80ool0GP3oool00`3o0000oooo0?ooo`3:0?ooo`80
0?l0TP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2U0?ooo`80ool0
GP3oool20?l00<d0oooo0P00o`2A0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003o
ool0oooo0:D0oooo00<0ool00?ooo`3oool0G@3oool00`3o0000oooo0?ooo`3=0?ooo`03003o003o
ool0oooo08l0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0Y03oool2
0?oo05h0oooo0P3o003?0?ooo`800?l0T03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`00
0000oooo0?ooo`2S0?ooo`80ool0G`3oool00`3o0000oooo0?ooo`3?0?ooo`800?l0S`3oool00`00
0000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2R0?ooo`80ool0G`3oool20?l00=80
oooo0P00o`2>0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0:80oooo
00<0ool00?ooo`3oool0GP3oool00`3o0000oooo0?ooo`3B0?ooo`03003o003oool0oooo08`0oooo
00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0X@3oool20?oo05l0oooo0P3o
003D0?ooo`800?l0S@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2P
0?ooo`80ool0H03oool00`3o0000oooo0?ooo`3D0?ooo`03003o003oool0oooo08/0oooo00<00000
0?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0W`3oool20?oo0600oooo0P3o003F0?oo
o`800?l0S03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2O0?ooo`03
0?oo003oool0oooo05h0oooo0P3o003H0?ooo`800?l0R`3oool00`000000oooo0?ooo`0Q0?ooo`00
H03oool00`000000oooo0?ooo`2N0?ooo`80ool0H03oool00`3o0000oooo0?ooo`3H0?ooo`03003o
003oool0oooo08T0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0W@3o
ool20?oo0600oooo0P3o003J0?ooo`800?l0RP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool3
000009d0oooo00<0ool00?ooo`3oool0G`3oool00`3o0000oooo0?ooo`3J0?ooo`03003o003oool0
oooo08H0oooo0`00000S0?ooo`00H03oool00`000000oooo0?ooo`2L0?ooo`80ool0H03oool20?l0
0=`0oooo0P00o`290?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo09/0
oooo0P3oo`1Q0?ooo`030?l0003oool0oooo0=`0oooo0P00o`280?ooo`030000003oool0oooo0240
oooo001P0?ooo`030000003oool0oooo09/0oooo00<0ool00?ooo`3oool0G`3oool20?l00=l0oooo
00<00?l00?ooo`3oool0QP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?oo
o`2J0?ooo`80ool0H@3oool00`3o0000oooo0?ooo`3N0?ooo`800?l0Q`3oool00`000000oooo0?oo
o`0Q0?ooo`00H03oool00`000000oooo0?ooo`2J0?ooo`030?oo003oool0oooo05l0oooo0P3o003Q
0?ooo`03003o003oool0oooo08D0oooo00<000000?ooo`3oool08@3oool002l0oooo00<0ojYE0000
E@2Zool0;P3oool00`000000oooo0?ooo`2I0?ooo`80ool0H@3oool00`3o0000oooo0?ooo`3P0?oo
o`800?l0QP3oool00`000000oooo0?ooo`0Q0?ooo`00;03oool01P3oe800:`00000000000000001E
0:[oobh0oooo00<000000?ooo`3oool0V03oool20?oo0640oooo0P3o003S0?ooo`800?l0Q@3oool0
0`000000oooo0?ooo`0Q0?ooo`00:@3oool00`3oojX0E@000000000400000003000[P03Dool0oooo
02d0oooo00<000000?ooo`3oool0V03oool00`3oo`00oooo0?ooo`1P0?ooo`030?l0003oool0oooo
0><0oooo00<00?l00?ooo`3oool0P`3oool00`000000oooo0?ooo`0Q0?ooo`009P3oool00`3oom@0
P2/0000000050000000305FZo`3oool0oooo02l0oooo00<000000?ooo`3oool0U`3oool20?oo0640
oooo0P3o003U0?ooo`800?l0Q03oool00`000000oooo0?ooo`0Q0?ooo`00903oool00`3oojX0E@00
0000000300000005001EZP3oool0ZUD00000001EZ_l0<@3oool00`000000oooo0?ooo`2G0?ooo`03
0?oo003oool0oooo0600oooo00<0o`000?ooo`3oool0i@3oool00`00o`00oooo0?ooo`220?ooo`03
0000003oool0oooo0240oooo000T0?ooo`040?ooZP1E00000000001EZP@0oooo00<0ZUD00000001E
Z_l03@3oool00`3DP2/00000000000050000000405FZo`3oool0oooo0?nZE@<0000000<0EJ[o0?oo
o`3oool00P3oool01@3oZUD00000000000000000EJ[o00/0oooo00<000000?ooo`3oool0UP3oool2
0?oo0640oooo0P3o003W0?ooo`800?l0P`3oool00`000000oooo0?ooo`0Q0?ooo`00903oool00`3o
ojX0E@000000000300000005001EZP3oool0ZUD00000001EZ_l03@3oool00`3oe800:`0000000005
0000000305FZo`3oool0ojYE00D0000000@0EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?oo
o`080?ooo`030000003oool0oooo09D0oooo0P3oo`1Q0?ooo`80o`00j@3oool2003o0880oooo00<0
00000?ooo`3oool08@3oool002H0oooo00<0oonZ05D0000000001@0000000`1EZ_l0oooo0?ooo`0<
0?ooo`040:YE00000000001E0:[oo`@0oooo0180oooD080[00000000:h3D0?ooo`3DP2/00000000[
P03Dool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool90?ooo`030000003oool0oooo
09D0oooo00<0ool00?ooo`3oool0H03oool00`3o0000oooo0?ooo`3Y0?ooo`03003o003oool0oooo
0800oooo00<000000?ooo`3oool08@3oool002T0oooo00<0omB002/000000000100000000`00:h00
e?oo0?ooo`0:0?ooo`050?ooe020:`0000000000E@2Zool00`3oool04P3oe800:`000000:`20e?l0
oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`T0oooo
00<000000?ooo`3oool0U03oool20?oo0640oooo0P3o003[0?ooo`800?l0P@3oool00`000000oooo
0?ooo`0Q0?ooo`00;03oool01P3oZUD00000000000000000001E0:[oo``0oooo00D0oooD080[0000
0000001E0:[oo`020?ooo`0B0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[
0000001E0:[oo`3oool0oonZ05D0000002/0P=Co2@3oool500000980oooo00<0ool00?ooo`3oool0
H03oool00`3o0000oooo0?ooo`3[0?ooo`03003o003oool0oooo07/0oooo1@00000S0?ooo`00;`3o
ool00`3DP2/0001E0:[oo`0=0?ooo`0H0?ooe020:`0000000000E@2Zool0oooo0?nZE@000000001E
0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o
2@3oool00`000000oooo0?ooo`2C0?ooo`80ool0H@3oool20?l00>d0oooo0P00o`200?ooo`030000
003oool0oooo0240oooo00100?ooo`0G0?ooe020:`000000001EZP3oool0ojYE0000000005D0Z_oo
0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l02@3o
ool00`000000oooo0?ooo`2C0?ooo`030?oo003oool0oooo0600oooo0P3o003^0?ooo`03003o003o
ool0oooo07h0oooo00<000000?ooo`3oool08@3oool00440oooo01H0omB002/0000002/0P=Co0?oD
P00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0
000002/0P=Co2@3oool00`000000oooo0?ooo`2B0?ooo`80ool0H@3oool30?l00>h0oooo0P00o`1o
0?ooo`030000003oool0oooo0240oooo000T0?ooo`030?ooZP1E0000000000T0000000<0001E0:[o
o`3oool02@3oool06`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`3oe800:`000000
:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[o
o`090?ooo`030000003oool0oooo0980oooo00<0ool00?ooo`3oool0H03oool20?l00?00oooo00<0
0?l00?ooo`3oool0O@3oool00`000000oooo0?ooo`0Q0?ooo`00903oool00`3oojX0E@0000000009
000000030000E@2Zool0oooo00T0oooo01/0oonZ05D000000000EJ[o0?ooo`3oZUD000000000:`20
e?l0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0oooD080[00000000:h3D0?ooo`3D
P2/00000000[P03Dool02@3oool00`000000oooo0?ooo`2A0?ooo`80ool0H@3oool30?l00?00oooo
0P00o`1n0?ooo`030000003oool0oooo0240oooo000m0?ooo`030:YE00000000000000<0000000@0
05FZ0?ooo`3oool0ojYE1@000000101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo00P0
oooo00<000000?ooo`3oool0T@3oool00`3oo`00oooo0?ooo`1P0?ooo`80o`00lP3oool00`00o`00
oooo0?ooo`1l0?ooo`030000003oool0oooo0240oooo000W0?ooo`040?ooZP1E000002^00=Cooa<0
oooo00D0e80[0000000000000000001EZP040?ooo`050?nZE@00000000000000001EZ_l0103oool0
1@3oZUD00000000000000000EJ[o00/0oooo00<000000?ooo`3oool0T03oool20?oo0680oooo0P3o
003b0?ooo`800?l0O@3oool00`000000oooo0?ooo`0Q0?ooo`009@3oool00`3oom@0P2/000000008
0000000305FZo`3oool0oooo02d0oooo00<000000?ooo`3oool0T03oool00`3oo`00oooo0?ooo`1P
0?ooo`<0o`00l`3oool00`00o`00oooo0?ooo`1k0?ooo`030000003oool0oooo0240oooo000U0?oo
o`030=B0:`000000000000P0000000<002^00=Coo`3oool0;@3oool00`000000oooo0?ooo`2?0?oo
o`80ool0HP3oool20?l00?@0oooo0P00o`1l0?ooo`030000003oool0oooo0240oooo000W0?ooo`04
0?ooZP1E000002^00=Coo`<0oooo00@0oooD080[000005D0Z_oo;P3oool00`000000oooo0?ooo`2?
0?ooo`80ool0H@3oool30?l00?@0oooo0P00o`1l0?ooo`030000003oool0oooo0240oooo000W0?oo
o`040?ooZP1E000002^00=Coo`<0oooo00@0oonZ05D00000:h00e?oo;P3oool00`000000oooo0?oo
o`2>0?ooo`80ool0HP3oool20?l00?H0oooo0P00o`1k0?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo08h0oooo0P3oo`1R0?ooo`80o`00mP3oool2003o07/0oooo00<00000
0?ooo`3oool08@3oool002@0oooo00D0oonZ05D0000005D0Z_nZ05D00007000000030000E@2Zool0
oooo02d0oooo00<000000?ooo`3oool0S@3oool30?oo0640oooo0`3o003f0?ooo`<00?l0NP3oool0
0`000000oooo0?ooo`0Q0?ooo`00903oool01@3oojX0E@000000E@2ZojX0E@0000L0000000<0001E
0:[oo`3oool0;@3oool00`000000oooo0?ooo`2=0?ooo`80ool0HP3oool20?l00?P0oooo0P00o`1j
0?ooo`030000003oool0oooo0240oooo001P0?ooo`<00000S@3oool20?oo0640oooo0`3o003h0?oo
o`<00?l0M`3oool3000002<0oooo000W0?ooo`040?ooZP1E000002^00=CoocD0oooo00<000000?oo
o`3oool0S03oool20?oo0680oooo0P3o003j0?ooo`800?l0N@3oool00`000000oooo0?ooo`0Q0?oo
o`009@3oool00`3oom@0P2/0000000080000000305FZo`3oool0oooo02d0oooo00<000000?ooo`3o
ool0S03oool00`3oo`00oooo0?ooo`1P0?ooo`<0o`00nP3oool2003o07T0oooo00<000000?ooo`3o
ool08@3oool002D0oooo00<0e80[000000000000200000000`00:h00e?oo0?ooo`0]0?ooo`030000
003oool0oooo08/0oooo0P3oo`1R0?ooo`80o`00n`3oool3003o07P0oooo00<000000?ooo`3oool0
8@3oool002L0oooo00@0oonZ05D00000:h00e?oo0`3oool0103oom@0P2/00000E@2Zool^0?ooo`03
0000003oool0oooo08/0oooo00<0ool00?ooo`3oool0H@3oool20?l00?`0oooo0P00o`1h0?ooo`03
0000003oool0oooo0240oooo000W0?ooo`040?ooZP1E000002^00=Coo`<0oooo00@0oonZ05D00000
:h00e?oo;P3oool00`000000oooo0?ooo`2:0?ooo`80ool0HP3oool30?l00?`0oooo0`00o`1g0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo08X0oooo00<0ool00?ooo`3o
ool0H@3oool20?l00?h0oooo0P00o`1g0?ooo`030000003oool0oooo0240oooo000W0?ooo`030?oo
ZP1E0000000000D0000000<002^00=Coo`3oool0;P3oool00`000000oooo0?ooo`290?ooo`80ool0
HP3oool30?l00?h0oooo0P00o`1g0?ooo`030000003oool0oooo0240oooo000W0?ooo`030?ooZP1E
0000000000H0000000<005FZ0?ooo`3oool0;@3oool00`000000oooo0?ooo`290?ooo`030?oo003o
ool0oooo0640oooo0P3o003o0?ooo`<00?l0MP3oool00`000000oooo0?ooo`0Q0?ooo`00;P3oool0
103oe800:`000000E@2Zool^0?ooo`030000003oool0oooo08T0oooo00<0ool00?ooo`3oool0H@3o
ool20?l00?l0oooo0@3oool2003o07H0oooo00<000000?ooo`3oool08@3oool002l0oooo00<0ZUD0
0000E@2Zool0;P3oool00`000000oooo0?ooo`280?ooo`80ool0HP3oool30?l00?l0oooo0@3oool3
003o07D0oooo00<000000?ooo`3oool08@3oool002h0oooo00@0oooD080[0000:h00e?oo;P3oool0
0`000000oooo0?ooo`280?ooo`030?oo003oool0oooo0640oooo0P3o003o0?ooo`<0oooo0P00o`1e
0?ooo`030000003oool0oooo0240oooo000^0?ooo`030?nZE@000000EJ[o02l0oooo00<000000?oo
o`3oool0Q`3oool20?oo0680oooo0`3o003o0?ooo`<0oooo0P00o`1e0?ooo`030000003oool0oooo
0240oooo000W0?ooo`030?ooZP1E0000000000H0000000<0001E0:[oo`3oool0;@3oool00`000000
oooo0?ooo`270?ooo`030?oo003oool0oooo0640oooo0P3o003o0?ooo`@0oooo0`00o`1d0?ooo`03
0000003oool0oooo0240oooo000W0?ooo`030?ooZP1E0000000000H0000000<0001E0:[oo`3oool0
;@3oool00`000000oooo0?ooo`260?ooo`80ool0H`3oool20?l00?l0oooo1@3oool2003o07@0oooo
00<000000?ooo`3oool08@3oool00600oooo0`0000260?ooo`030?oo003oool0oooo0640oooo0`3o
003o0?ooo`D0oooo0`00o`1a0?ooo`<000008`3oool00600oooo00<000000?ooo`3oool0Q@3oool2
0?oo06<0oooo0P3o003o0?ooo`L0oooo0P00o`1c0?ooo`030000003oool0oooo0240oooo000Y0?oo
o`030?ooZP1E000000000080000000<0001E0:[oo`3oool0;`3oool00`000000oooo0?ooo`250?oo
o`80ool0H`3oool20?l00?l0oooo1`3oool2003o07<0oooo00<000000?ooo`3oool08@3oool002P0
oooo00<0ojYE0000000000001@0000000`1EZ_l0oooo0?ooo`0]0?ooo`030000003oool0oooo08@0
oooo0`3oo`1R0?ooo`<0o`00o`3oool70?ooo`<00?l0LP3oool00`000000oooo0?ooo`0Q0?ooo`00
9`3oool0103oom@0P2/00000000[P=@30?ooo`040=B0:`00000002^00=Coobh0oooo00<000000?oo
o`3oool0Q03oool20?oo06<0oooo0P3o003o0?ooo`T0oooo0P00o`1b0?ooo`030000003oool0oooo
0240oooo000W0?ooo`040?ooZP1E000002^00=Coo`<0oooo00@0oooD080[000005D0Z_oo;P3oool0
0`000000oooo0?ooo`230?ooo`<0ool0H`3oool20?l00?l0oooo2@3oool2003o0780oooo00<00000
0?ooo`3oool08@3oool002L0oooo00@0oooD080[0000:h00e?oo0`3oool0103oom@0P2/0000[P03D
ool^0?ooo`030000003oool0oooo08<0oooo0P3oo`1S0?ooo`<0o`00o`3oool90?ooo`<00?l0L@3o
ool00`000000oooo0?ooo`0Q0?ooo`00:03oool00`3oZUD0000002^0e0030?ooo`030=B0:`000000
EJ[o02l0oooo00<000000?ooo`3oool0P`3oool20?oo06<0oooo0P3o003o0?ooo`/0oooo0P00o`1a
0?ooo`030000003oool0oooo0240oooo000T0?ooo`030?ooZP1E0000000000T0000000<0001E0:[o
o`3oool0;@3oool00`000000oooo0?ooo`220?ooo`<0ool0H`3oool20?l00?l0oooo2`3oool2003o
0740oooo00<000000?ooo`3oool08@3oool002@0oooo00<0oonZ05D0000000002@0000000`0005D0
Z_oo0?ooo`0]0?ooo`030000003oool0oooo0880oooo0P3oo`1T0?ooo`80o`00o`3oool;0?ooo`80
0?l0L@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`220?ooo`80ool0
H`3oool30?l00?l0oooo2`3oool3003o0700oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool0P@3oool30?oo06<0oooo0P3o003o0?ooo`d0oooo0P00o`1`0?ooo`030000003o
ool0oooo0240oooo000Y0?ooo`030?ooZP1E000000000080000000<0000[083Do`3oool0;`3oool0
0`000000oooo0?ooo`210?ooo`80ool0I03oool20?l00?l0oooo3@3oool2003o0700oooo00<00000
0?ooo`3oool08@3oool002P0oooo00<0ojYE0000000000001@0000000`1EZ_l0oooo0?ooo`0]0?oo
o`030000003oool0oooo0800oooo0`3oo`1S0?ooo`<0o`00o`3oool=0?ooo`<00?l0K`3oool00`00
0000oooo0?ooo`0Q0?ooo`009`3oool02`3oom@0P2/00000001EZ_l0omB002/0:`20e?l0omB002/0
0000:h00e?oo02h0oooo00<000000?ooo`3oool0P03oool20?oo06@0oooo0P3o003o0?ooo`l0oooo
0P00o`1_0?ooo`030000003oool0oooo0240oooo000W0?ooo`0;0?ooZP1E000002^00=Coo`3oe800
:`0[083Do`3oool0ZUD00000E@2Zool0;P3oool00`000000oooo0?ooo`200?ooo`80ool0I03oool2
0?l00?l0oooo3`3oool2003o06l0oooo00<000000?ooo`3oool08@3oool002L0oooo00/0oooD080[
000002/0P=Co0?oDP00[02/0P=Co0?ooe020:`00001E0:[oo`0^0?ooo`<00000O`3oool30?oo06<0
oooo0`3o003o0?ooo`l0oooo0`00o`1/0?ooo`<000008`3oool002P0oooo00T0ojYE000000000000
00000000:`20e?l0ZUD00000000[P=@0;`3oool00`000000oooo0?ooo`1o0?ooo`80ool0I03oool2
0?l00?l0oooo4@3oool2003o06h0oooo00<000000?ooo`3oool08@3oool002T0oooo00L0oonZ05D0
00000000000[083Do`3DP2/0:h3D0300oooo00<000000?ooo`3oool0OP3oool30?oo06@0oooo0P3o
003o0?oooa40oooo0P00o`1^0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo07h0oooo0P3oo`1T0?ooo`<0o`00o`3ooolA0?ooo`<00?l0K@3oool00`000000oooo0?ooo`0Q
0?ooo`00H03oool00`000000oooo0?ooo`1n0?ooo`80ool0I03oool20?l00?l0oooo4`3oool2003o
06d0oooo00<000000?ooo`3oool08@3oool002h0oooo00H0ojYE0000000005D0Z_oo0:YE000[P=@/
0?ooo`030000003oool0oooo07d0oooo0`3oo`1T0?ooo`80o`00o`3ooolC0?ooo`<00?l0K03oool0
0`000000oooo0?ooo`0Q0?ooo`00;P3oool01@3oZUD0000000000000000005FZ02d0oooo00<00000
0?ooo`3oool0O@3oool20?oo06@0oooo0`3o003o0?oooa@0oooo0P00o`1/0?ooo`030000003oool0
oooo0240oooo001P0?ooo`030000003oool0oooo07`0oooo0`3oo`1T0?ooo`80o`00o`3ooolE0?oo
o`800?l0K03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1l0?ooo`80
ool0I@3oool20?l00?l0oooo5@3oool3003o06/0oooo00<000000?ooo`3oool08@3oool00600oooo
00<000000?ooo`3oool0O03oool20?oo06@0oooo0`3o003o0?oooaH0oooo0P00o`1[0?ooo`030000
003oool0oooo0240oooo001P0?ooo`030000003oool0oooo07/0oooo0`3oo`1T0?ooo`80o`00o`3o
oolG0?ooo`<00?l0JP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1k
0?ooo`80ool0I@3oool20?l00?l0oooo603oool2003o06X0oooo00<000000?ooo`3oool08@3oool0
0600oooo00<000000?ooo`3oool0NP3oool30?oo06@0oooo0`3o003o0?oooaP0oooo0P00o`1Z0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo07X0oooo0P3oo`1U0?ooo`80
o`00o`3ooolI0?ooo`<00?l0J@3oool00`000000oooo0?ooo`0Q0?ooo`00903oool00`3oojX0E@00
00000009000000030000E@2Zool0oooo02d0oooo00<000000?ooo`3oool0NP3oool20?oo06D0oooo
0P3o003o0?oooaX0oooo0P00o`1Y0?ooo`030000003oool0oooo0240oooo000T0?ooo`030?ooZP1E
0000000000T0000000<0001E0:[oo`3oool0;@3oool3000007T0oooo0`3oo`1T0?ooo`<0o`00o`3o
oolJ0?ooo`<00?l0IP3oool3000002<0oooo000Z0?ooo`040=B0:`0000000000001EZS80oooo00<0
00000?ooo`3oool0N@3oool20?oo06D0oooo0P3o003o0?oooa`0oooo0P00o`1X0?ooo`030000003o
ool0oooo0240oooo000Y0?ooo`050:YE0000000000000000001EZ_l0<P3oool00`000000oooo0?oo
o`1i0?ooo`80ool0I@3oool20?l00?l0oooo703oool2003o06P0oooo00<000000?ooo`3oool08@3o
ool002L0oooo00<0oonZ05D000000000100000000`0002/0P=Co0?ooo`0_0?ooo`030000003oool0
oooo07P0oooo0`3oo`1T0?ooo`<0o`00o`3ooolL0?ooo`<00?l0I`3oool00`000000oooo0?ooo`0Q
0?ooo`009`3oool01`3oojX0E@000000001EZ_l0oooo0?ooZP1E00000P0000000`0005D0Z_oo0?oo
o`0]0?ooo`030000003oool0oooo07P0oooo0P3oo`1U0?ooo`80o`00o`3ooolN0?ooo`800?l0I`3o
ool00`000000oooo0?ooo`0Q0?ooo`009`3oool00`3oojX0E@0[083Do`040?ooo`040?ooZP1E0000
001E0:[oobh0oooo00<000000?ooo`3oool0N03oool20?oo06D0oooo0P3o003o0?oooah0oooo0P00
o`1W0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo07L0oooo0`3oo`1T
0?ooo`<0o`00o`3ooolN0?ooo`<00?l0IP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`00
0000oooo0?ooo`1g0?ooo`80ool0I@3oool20?l00?l0oooo803oool2003o06H0oooo00<000000?oo
o`3oool08@3oool002L0oooo00<0oonZ05D0000000001P0000000`0005D0Z_oo0?ooo`0]0?ooo`03
0000003oool0oooo07L0oooo0P3oo`1U0?ooo`80o`00o`3ooolP0?ooo`800?l0IP3oool00`000000
oooo0?ooo`0Q0?ooo`009`3oool00`3oojX0E@0000000006000000030000E@2Zool0oooo02d0oooo
00<000000?ooo`3oool0MP3oool30?oo06@0oooo0`3o003o0?ooob00oooo0`00o`1U0?ooo`030000
003oool0oooo0240oooo000X0?ooo`030?nZE@000000EJ[o01<0oooo00D0e80[0000000000000000
05FZo`040?ooo`050?nZE@00000000000000001EZ_l0103oool01@3oZUD00000000000000000EJ[o
00/0oooo00<000000?ooo`3oool0MP3oool20?oo06D0oooo0P3o003o0?ooob80oooo0P00o`1U0?oo
o`030000003oool0oooo0240oooo000W0?ooo`040?ooe020:`0002^00=Cooa80oooo00<0e80[0000
000000000`000000100[P=@0oooo0?ooo`3oZUD50000000405FZo`3oool0oooo0?nZE@D0000000<0
EJ[o0?ooo`3oool0203oool00`000000oooo0?ooo`1f0?ooo`80ool0I@3oool20?l00?l0oooo8P3o
ool2003o06D0oooo00<000000?ooo`3oool08@3oool002L0oooo00@0oonZ05D0000005D0Z_oo4@3o
ool06`3oe800:`000000000[P=@0oooo0=B0:`000000001E0:[oo`3oom@0P2/00000000[P=@0oooo
0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`090?ooo`03
0000003oool0oooo07D0oooo0`3oo`1T0?ooo`<0o`00o`3ooolR0?ooo`<00?l0I03oool00`000000
oooo0?ooo`0Q0?ooo`009`3oool00`3oom@0P2/000000006000000030000E@2Zool0oooo00T0oooo
01/0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB002/0000002/0P=Co0?ooo`3o
e800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool02@3oool00`00
0000oooo0?ooo`1e0?ooo`80ool0I@3oool20?l00?l0oooo903oool2003o06@0oooo00<000000?oo
o`3oool08@3oool002P0oooo00<0oonZ05D0000000001@0000000`0005D0Z_oo0?ooo`0>0?ooo`0F
0?ooZP1E0000000[083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`3oe800:`00
0000E@2Zool0oooo0?ooZP1E0000000[083Do`T0oooo00<000000?ooo`3oool0M@3oool20?oo06D0
oooo0P3o003o0?ooob@0oooo0P00o`1T0?ooo`030000003oool0oooo0240oooo000X0?ooo`030?nZ
E@000000EJ[o01H0oooo01H0ojYE0000000005D0Z_oo0?nZE@000000001E0:[oo`3oool0oonZ05D0
00000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o2@3oool500000780oooo
0`3oo`1T0?ooo`<0o`00o`3ooolT0?ooo`<00?l0G`3oool5000002<0oooo000W0?ooo`040?ooe020
:`0002^00=Cooa@0oooo01P0omB002/000000000000[083Do`3oool0ojYE0000000005D0Z_oo0?oo
o`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l90?ooo`03
0000003oool0oooo07@0oooo0P3oo`1U0?ooo`80o`00o`3ooolV0?ooo`800?l0H`3oool00`000000
oooo0?ooo`0Q0?ooo`009`3oool0103oojX0E@000000E@2ZoolD0?ooo`0H0?oDP00[00000000000[
P03Dool0oooo0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[o
o`3oool0oonZ05D0000002/0P=Co2@3oool00`000000oooo0?ooo`1d0?ooo`80ool0I@3oool20?l0
0?l0oooo9P3oool2003o06<0oooo00<000000?ooo`3oool08@3oool002P0oooo00<0ZUD000000000
00001@0000000`0005D0Z_oo0?ooo`0>0?ooo`0F0:YE0000000005FZ0?ooo`3oe800:`000000:`20
e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`T0
oooo00<000000?ooo`3oool0L`3oool30?oo06@0oooo0`3o003o0?ooobH0oooo0`00o`1R0?ooo`03
0000003oool0oooo0240oooo000X0?ooo`030?ooZP1E0000000000D0000000<0001E0:[oo`3oool0
2@3oool06`3oojX0E@000000001EZ_l0oooo0:YE0000000005FZ0?ooo`3oom@0P2/00000000[P=@0
oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`090?oo
o`030000003oool0oooo07<0oooo0P3oo`1U0?ooo`80o`00o`3ooolX0?ooo`800?l0HP3oool00`00
0000oooo0?ooo`0Q0?ooo`00?@3oool00`2ZE@000000000000030000000405FZo`3oool0oooo0?nZ
E@D0000000@0EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?ooo`080?ooo`030000003oool0
oooo07<0oooo0P3oo`1U0?ooo`80o`00o`3ooolX0?ooo`800?l0HP3oool00`000000oooo0?ooo`0Q
0?ooo`00?P3oool01@2ZE@000000000000000000EJ[o00@0oooo00D0ojYE000000000000000005FZ
o`040?ooo`050?nZE@00000000000000001EZ_l02`3oool00`000000oooo0?ooo`1b0?ooo`<0ool0
I03oool30?l00?l0oooo:03oool3003o0640oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool0LP3oool20?oo06D0oooo0P3o003o0?ooobX0oooo0P00o`1Q0?ooo`030000003o
ool0oooo0240oooo001P0?ooo`030000003oool0oooo0780oooo0P3oo`1U0?ooo`80o`00o`3ooolZ
0?ooo`800?l0H@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1a0?oo
o`<0ool0I03oool30?l00?l0oooo:P3oool3003o0600oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0L@3oool20?oo06D0oooo0P3o003o0?ooob`0oooo0P00o`1P0?ooo`03
0000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0740oooo0P3oo`1U0?ooo`80o`00
o`3oool/0?ooo`800?l0H03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?oo
o`1`0?ooo`<0ool0I03oool30?l00?l0oooo;03oool3003o05l0oooo00<000000?ooo`3oool08@3o
ool00600oooo00<000000?ooo`3oool0L03oool20?oo06D0oooo0P3o001<0?ooool000007P00000U
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0700oooo0P3oo`1U0?oo
o`80o`00C03ooooo000001h000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool3000006l0
oooo0`3oo`1T0?ooo`<0o`00C03ooooo000001h000008`3oool3000002<0oooo001P0?ooo`030000
003oool0oooo06l0oooo0P3oo`1U0?ooo`80o`00C@3ooooo000001h000009@3oool00`000000oooo
0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1_0?ooo`80ool0I@3oool20?l004d0ooooo`00
000N000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0KP3oool3
0?oo06@0oooo0`3o001=0?ooool000007P00000U0?ooo`030000003oool0oooo0240oooo001P0?oo
o`030000003oool0oooo06h0oooo0P3oo`1U0?ooo`80o`00CP3ooooo000001h000009@3oool00`00
0000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1^0?ooo`80ool0I@3oool20?l004h0
ooooo`00000N000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0
K@3oool30?oo06@0oooo0`3o001>0?ooool000007P00000U0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo06d0oooo0P3oo`1U0?ooo`80o`00C`3ooooo000001h000009@3o
ool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1]0?ooo`80ool0I@3oool2
0?l004l0ooooo`00000N000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?oo
o`3oool0K03oool30?oo06@0oooo0`3o001?0?ooool000007P00000U0?ooo`030000003oool0oooo
0240oooo001P0?ooo`030000003oool0oooo06`0oooo0P3oo`1U0?ooo`80o`00D03ooooo000001h0
00009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1/0?ooo`80ool0
I@3oool20?l00500ooooo`00000N000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool0J`3oool30?oo06@0oooo0`3o001@0?ooool000007P00000U0?ooo`030000003o
ool0oooo0240oooo001P0?ooo`030000003oool0oooo06/0oooo0P3oo`1U0?ooo`80o`00D@3ooooo
000001h000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1[0?oo
o`80ool0I@3oool20?l003l0ooooo`00000`000002D0oooo00<000000?ooo`3oool08@3oool00600
oooo0`00001Z0?ooo`<0ool0I03oool30?l003l0oooo00<000000?ooo`3oool0o`3ooolK0?oooa80
00008`3oool3000002<0oooo001P0?ooo`030000003oool0oooo06X0oooo0P3oo`1U0?ooo`80o`00
@03oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo06X0oooo0P3oo`1U0?ooo`80o`00@03oool00`000000oooo0?oo
o`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo06T0oooo0`3oo`1U0?ooo`80o`00@03oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo06T0oooo0P3oo`1U0?oo
o`<0o`00@03oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo
0240oooo001P0?ooo`030000003oool0oooo06T0oooo0P3oo`1U0?ooo`80o`00@@3oool00`000000
oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000
003oool0oooo06P0oooo0`3oo`1U0?ooo`80o`00@@3oool00`000000oooo0?ooo`3o0?oooa/0oooo
4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo06P0oooo0P3o
o`1U0?ooo`<0o`00@@3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003o
ool0oooo0240oooo001P0?ooo`030000003oool0oooo06P0oooo0P3oo`1U0?ooo`80o`00@P3oool0
0`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?oo
o`030000003oool0oooo06L0oooo0`3oo`1U0?ooo`80o`00@P3oool00`000000oooo0?ooo`3o0?oo
oa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo06L0
oooo0P3oo`1V0?ooo`80o`00@P3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`03
0000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo06L0oooo0P3oo`1U0?ooo`<0o`00
@P3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo06H0oooo0`3oo`1U0?ooo`80o`00@`3oool00`000000oooo0?oo
o`2^0?ooo`030?ooe020:b/0P=Co00h0oooo00<0oonZ05D[P03Dool0F03ooolB000002D0oooo00<0
00000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0IP3oool20?oo06H0oooo0P3o0013
0?ooo`030000003oool0oooo0:d0oooo00<0oooD080[:`20e?l0403oool00`3oe800:b^00=Coo`1G
0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1V0?oo
o`80ool0IP3oool20?l004<0oooo00<000000?ooo`3oool0[@3oool00`2ZE@0005FZ0?ooo`0A0?oo
o`030=B0:`00EJX0oooo05H0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`<0
0000I@3oool30?oo06D0oooo0`3o00130?ooo`030000003oool0oooo06h0oooo01H0oonZ05D00000
0000EJ[o0?ooo`2ZE@000000001EZP3oool0ojYE0000000005D0Z_oo0?oDP00[0000000[083Do`3o
ool0oonZ05D000000000EJ[o1P3oool0203oe800:`000000:`20e?l0oonZ05D000000000EJ[o1`3o
ool01P3oe800:`000000:`20e?l0oonZ05D000L0000000<0:h3D0?ooo`3oool00`3oool00`3oZUD0
000[083Do`020?ooo`0>0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?ooo`3oZUD0
00000000E@2Zool20?ooo`030?oDP00[0000EJ[o05H0oooo4P00000S0?ooo`<000008`3oool00600
oooo00<000000?ooo`3oool0I@3oool20?oo06H0oooo0P3o00140?ooo`030000003oool0oooo06h0
oooo01H0oonZ05D000000000EJ[o0?ooe020:`000000000[P03Dool0ojYE0000000005D0Z_oo0?oD
P00[0000000[083Do`3oool0oonZ05D000000000EJ[o1P3oool0203oe800:`000000:`20e?l0oonZ
05D000000000EJ[o1`3oool01P3oe800:`000000:`20e?l0oonZ05D000L0000000<0:h3D0?ooo`3o
ool00`3oool00`2ZE@00001E0:[oo`020?ooo`0>0?oDP00[0000000[083Do`3oool0omB002/00000
05D0Z_oo0?ooo`3oZUD000000000E@2Zool20?ooo`030?ooZP1E000005FZ05H0oooo4P00000U0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo06D0oooo0P3oo`1V0?ooo`80
o`00A03oool00`000000oooo0?ooo`1^0?ooo`0=0?ooZP1E0000000005FZo`3oojX0E@0000000000
05D0Z_oo0?nZE@000000001E0:[oo`050?ooo`040?ooZP1E0000000005FZo`X0oooo00@0oonZ05D0
00000000EJ[o2`3oool0103oojX0E@000000001EZ_l:0?ooo`040?ooZP1E000002^00=Coo`80oooo
00h0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0oooo0?nZE@000000001E0:[oo`80
oooo00@0oooD080[000005D0Z_ooE@3ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0I@3oool20?oo06H0oooo0P3o00140?ooo`030000003oool0oooo06h0
oooo00d0oonZ05D000000000EJ[o0?nZE@0002/0P81E0000001EZ_l0ojYE0000000005D0Z_oo00D0
oooo00@0oonZ05D000000000EJ[o2P3oool0103oojX0E@000000001EZ_l;0?ooo`040?ooZP1E0000
000005FZo`X0oooo00@0oonZ05D00000:h00e?oo0P3oool03P3oe800:`000000:`20e?l0oooo0?oD
P00[0000001E0:[oo`3oool0ojYE0000000005D0Z_oo0P3oool0103oom@0P2/00000E@2ZoomE0?oo
oa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1T0?ooo`<0
ool0I@3oool30?l004@0oooo00<000000?ooo`3oool07`3oool_003o0200oooo00d0oonZ05D00000
0000EJ[o0=B0:`0005D0Z_nZ05D0000[P=@0ojYE0000000005D0Z_oo00D0oooo00@0oonZ05D00000
0000EJ[o2P3oool0103oojX0E@000000001EZ_l;0?ooo`040?ooZP1E0000000005FZo`X0oooo00@0
oonZ05D00000:h00e?oo0P3oool03P3oe800:`000000:`20e?l0oooo0?oDP00[0000000[083Do`3o
ool0ojYE0000000005D0Z_oo0P3oool0103oom@0P2/00000E@2ZoomE0?oooa8000009@3oool00`00
0000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1T0?ooo`80ool0IP3oool20?l004D0
oooo00<000000?ooo`3oool07`3oool_003o0200oooo00d0oonZ05D000000000EJ[o0:YE0000:h00
e?oD080[0000EJX0ojYE0000000005D0Z_oo00D0oooo00<0oonZ05D0000000001@0000000`0[P=@0
oooo0?ooo`030?ooo`030?ooZP1E0000000000D0000000<0:h3D0?ooo`3oool0103oool0103oojX0
E@000000001EZ_l:0?ooo`040?ooZP1E0000001E0:[oo`80oooo00h0omB002/0000002/0P=Co0?oo
o`3oe800:`000000:`20e?l0oooo0?nZE@000000001E0:[oo`80oooo00@0oooD080[000005D0Z_oo
E@3ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0I03o
ool20?oo06H0oooo0P3o00150?ooo`030000003oool0oooo06h0oooo00d0oonZ05D000000000EJ[D
080[0000EJX0oooo0:YE0000:h00e:YE0000000005D0Z_oo00D0oooo00<0oonZ05D0000000001@00
00000`0[P=@0oooo0?ooo`030?ooo`030?ooZP1E0000000000H0000000<005FZ0?ooo`3oool00`3o
ool0103oojX0E@000000001EZ_l;0?ooo`030:YE000005D0Z_oo0080oooo00H0omB002/000000000
05FZ0?ooo`3oZUD20000000602^0e03oool0e80[0000000005D0Z_oo0P3oool00`3oojX0E@00001E
ZP1F0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1S
0?ooo`<0ool0I@3oool30?l004D0oooo00<000000?ooo`3oool0KP3oool03@3oojX0E@000000001E
ZZX0E@0002^0e03oool0e80[0000E@2ZZUD000000000E@2Zool01@3oool0103oojX0E@000000001E
Z_l:0?ooo`040?ooZP1E0000000005FZo`<0oooo00@0e80[0000000002/0P=Co103oool0103oojX0
E@000000001EZ_l;0?ooo`030?nZE@0002/0P=Co0080oooo00<0omB002/0000000002@0000001`00
EJX0oooo0?ooo`3oool0omB002/0001EZ_l0EP3ooolB000002D0oooo00<000000?ooo`3oool08@3o
ool00600oooo00<000000?ooo`3oool0H`3oool20?oo06H0oooo0P3o00160?ooo`030000003oool0
oooo06h0oooo00d0oonZ05D000000000EEEE0000:`20e?l0oooo0?nZE@000000EEEE0000000005D0
Z_oo00D0oooo00@0oonZ05D000000000EJ[o2P3oool0103oojX0E@000000001EZ_l30?ooo`040?oo
ZP1E0000000005FZo`@0oooo00@0oonZ05D000000000EJ[o303oool04@2ZE@0005FZ0?ooo`3oool0
omB002/0000002/0P:Z002/000000000001E0:[oo`3oe800:`000000000005D0Z_oo00<0oooo00<0
e80[001EZP3oool0EP3ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<00000
0?ooo`3oool0H`3oool20?oo06H0oooo0P3o00160?ooo`030000003oool0oooo06h0oooo00d0oonZ
05D000000000:b/[0000E@2Zool0oooo0?ooZP1E0000:b/[0000000005D0Z_oo00D0oooo00@0oonZ
05D000000000EJ[o2P3oool0103oojX0E@000000001EZ_l30?ooo`040=B0:`000000000[083Do`@0
oooo00@0oonZ05D000000000EJ[o303oool00`3oom@0P2/005FZo`0@0?ooo`030?nZE@00:h00e?oo
05L0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo06<0
oooo0P3oo`1V0?ooo`80o`00AP3oool00`000000oooo0?ooo`1^0?ooo`090?ooZP1E000000000000
0000:h00e?oo0?ooo`3oom@0P2/00080000000<0001E0:[oo`3oool0103oool00`3oojX0E@000000
0005000000030000:`20e?l0oooo00<0oooo00<0oonZ05D0000000001P0000000`00EJX0oooo0?oo
o`030?ooo`040?ooZP1E0000000005FZo`h0oooo00<0ZUD[083Do`3oool03@3oool00`3oojX0EEFZ
0?ooo`1H0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?oo
o`1R0?ooo`<0ool0I@3oool30?l004H0oooo00<000000?ooo`3oool0KP3oool01@3oojX0E@000000
0000000005FZ00<0oooo00D0ZUD0000000000000001E0:[oo`050?ooo`030?ooZP1E0000000000D0
000000<0000[083Do`3oool00`3oool00`3oojX0E@000000000500000003001EZP3oool0oooo00@0
oooo00@0oonZ05D000000000EJ[oN@3ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0HP3oool20?oo06H0oooo0P3o00170?ooo`030000003oool0oooo0?l0
oooo6`3ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0
HP3oool20?oo06H0oooo0P3o00170?ooo`030000003oool0oooo0?l0oooo6`3ooolB000002D0oooo
00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0HP3oool20?oo06H0oooo0P3o
00170?ooo`030000003oool0oooo0?l0oooo6`3ooolB000002D0oooo00<000000?ooo`3oool08@3o
ool00600oooo0`00001Q0?ooo`<0ool0I@3oool30?l004L0oooo00<000000?ooo`3oool0o`3ooolK
0?oooa8000008`3oool3000002<0oooo001P0?ooo`030000003oool0oooo0640oooo0P3oo`1V0?oo
o`80o`00B03oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo
0240oooo001P0?ooo`030000003oool0oooo0640oooo0P3oo`1V0?ooo`80o`00B03oool00`000000
oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000
003oool0oooo0600oooo0`3oo`1V0?ooo`80o`00B03oool00`000000oooo0?ooo`3o0?oooa/0oooo
4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0600oooo0P3o
o`1V0?ooo`<0o`00B03oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003o
ool0oooo0240oooo001P0?ooo`030000003oool0oooo0600oooo0P3oo`1V0?ooo`80o`00B@3oool0
0`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?oo
o`030000003oool0oooo05l0oooo0`3oo`1V0?ooo`80o`00B@3oool00`000000oooo0?ooo`3o0?oo
oa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo05l0
oooo0P3oo`1V0?ooo`<0o`00B@3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`03
0000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo05l0oooo0P3oo`1V0?ooo`80o`00
BP3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo05h0oooo0`3oo`1V0?ooo`80o`00BP3oool00`000000oooo0?oo
o`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo00100?ooo`040?ooZP1E0000
000[083Do`<0oooo00D0ojYE000000000000000005FZo`040?ooo`050?nZE@00000000000000001E
Z_l02`3oool00`000000oooo0?ooo`1N0?ooo`80ool0I`3oool20?l004X0oooo00<000000?ooo`3o
ool0o`3ooolK0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool0103oojX0E@00
0000:`20e?l20?ooo`030?nZE@000000000000<0000000@0EJ[o0?ooo`3oool0ojYE1@0000000`1E
Z_l0oooo0?ooo`080?ooo`030000003oool0oooo05h0oooo0P3oo`1V0?ooo`<0o`00BP3oool00`00
0000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo000l0?ooo`03
0:YE00000000000000D0000001<005FZ0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo
0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo00T0oooo00<000000?ooo`3oool0G@3o
ool30?oo06H0oooo0P3o001;0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000002D0oooo00<0
00000?ooo`3oool08@3oool003`0oooo00<0ZUD00000000000001@0000004`00EJX0omB002/00000
02/0P=Co0?ooo`3oe800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Z
ool02@3oool00`000000oooo0?ooo`1M0?ooo`80ool0I`3oool20?l004/0oooo00<000000?ooo`3o
ool0o`3ooolK0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00?03oool06`3oZUD00000
001EZP3oool0oonZ05D0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[
083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`090?ooo`030000003oool0oooo
05d0oooo0P3oo`1W0?ooo`80o`00B`3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?oo
o`030000003oool0oooo0240oooo000l0?ooo`0K0?ooe020:`00000005FZo`3oojX0E@000000:`20
e?l0oooo0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[oo`3o
ool0oonZ05D000000000EJ[o00T0oooo1@00001J0?ooo`<0ool0IP3oool30?l004/0oooo00<00000
0?ooo`3oool0W`3oool01@3oe800:`000000000005D0Z_oo00/0oooo00<0oooD080[:`20e?l02@3o
ool00`3oojX0E@00000000030000000505FZo`3oool0oooD080[000[P=@0E03ooolB00000240oooo
1@00000S0?ooo`00?@3oool06P3oe800:`00000[P03DojX0E@000000:`20e?l0oooo0?nZE@000000
001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D000000000
EJ[o2@3oool00`000000oooo0?ooo`1L0?ooo`80ool0I`3oool20?l004`0oooo00<000000?ooo`3o
ool0W`3oool01@3oe800:`0000000000000005FZ00X0oooo00<0oooD080[:`20e?l02@3oool00`3o
om@0P2/0000000050000000505FZo`3oool0e80[000[P03Dool0D`3ooolB000002D0oooo00<00000
0?ooo`3oool08@3oool003h0oooo01T0e80[0000000[P800E@000000:`20e?l0oooo0?oDP00[0000
001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0
P=Co00T0oooo00<000000?ooo`3oool0G03oool20?oo06L0oooo0P3o001<0?ooo`030000003oool0
oooo0:40oooo00@0omB002/0000002/0P=Co2@3oool00`2ZE@0005FZ0?ooo`0?0?ooo`070:YE0000
000005FZ0?ooo`3oe800:`0[083Do`1C0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00
?P3oool06@3oom@0P2/0000000000000000[083Do`3oool0omB002/0000002/0P=Co0?ooo`3oe800
:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool02@3oool00`000000
oooo0?ooo`1L0?ooo`80ool0I`3oool20?l004`0oooo00<000000?ooo`3oool0KP3oool00`3oojX0
E@00000000050000000302^0e03oool0oooo00<0oooo00D0ZUD0000000000000000002^0e0030?oo
o`030:YE0000000005FZ0080oooo00<0e80[00000000EJX00P3oool00`3oom@0P2/0000000020000
000B000[P03Dool0oooo0?ooZP1E0000000005FZo`3oool0omB002/000000000000[083Do`3oool0
oonZ05D000000000:h3D203oool00`3oZUD0000[083Do`020?ooo`030:YE0000000005FZ0080oooo
00<0ZUD000000000EJX00P3oool02`3DP2/000000000000[P=@0e80[00000000EJX0oooo0?ooe020
:`00:h3D00<0oooo00h0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0oooo0?nZE@00
0000001E0:[ood80oooo4P00000U0?ooo`030000003oool0oooo0240oooo000o0?ooo`0H0?nZE@00
000000000000:`20e?l0oooo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo0?ooe020
:`00000002^0e03oool0e80[00000000:h00e?oo2@3oool00`000000oooo0?ooo`1K0?ooo`<0ool0
IP3oool30?l004`0oooo00<000000?ooo`3oool0KP3oool00`3oojX0E@000000000600000005000[
P03Dool0oooo0?ooo`2ZE@001@0000001P0[P=@0oooo0?ooo`2ZE@000000001EZP80oooo00H0e80[
00000000EJX0oooo0?ooe020:`0500000008000[P03Dool0oonZ05D000000000EJ[o0?ooo`2ZE@02
000000040000:`20e?l0oooo0?nZE@80000000<002^00=Coo`3oool01P3oool00`2ZE@00001E0:[o
o`020?ooo`0:0:YE0000000005FZ0?ooo`3oe800:`000000E@2Zool0oooo0=B0:`@0000000<0:b/[
00000000EJX00P3oool00`3DP2/002^00=Coo`020?ooo`0>0?oDP00[0000000[083Do`3oool0omB0
02/0000005D0Z_oo0?ooo`3oZUD000000000E@2Zoom20?oooa8000009@3oool00`000000oooo0?oo
o`0Q0?ooo`00@03oool0102ZE@0000000000:`20e?l20?ooo`030?nZE@000000000000<0000000@0
EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?ooo`080?ooo`030000003oool0oooo05/0oooo
0P3oo`1W0?ooo`80o`00C@3oool00`000000oooo0?ooo`1^0?ooo`040?ooZP1E0000000005FZo`<0
oooo0180omB002/000000000:h3D0?ooo`3oe800:`000000001EZ_l0oooo0?nZE@000000001E0:[o
o`3oool0ZUD000000000EJX20?ooo`0E0=B0:`00000005FZ0?ooo`3oZUD000000000:`20e?l0oooo
0?ooZP1E0000000[083Do`3oojX0E@000000001EZ_l0oooD080[00000000:h3D00<0oooo00D0ZUD0
000000000000000[083Do`060?ooo`040?ooZP1E000002^00=Coo`80oooo0140ZUD000000000EJX0
oooD080[00000000:h3D0?ooo`3oojX0E@0000000000EJX0oooo0?oDP00[00000000001EZP020?oo
o`030?oDP00[02/0P=Co0080oooo00h0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0
oooo0?nZE@000000001E0:[ood80oooo4P00000U0?ooo`030000003oool0oooo0240oooo00100?oo
o`040?ooZP1E0000000[083Do`<0oooo00D0ojYE000000000000000005FZo`040?ooo`050?nZE@00
000000000000001EZ_l02`3oool00`000000oooo0?ooo`1K0?ooo`80ool0I`3oool20?l004d0oooo
00<000000?ooo`3oool0KP3oool0103oojX0E@000000001EZ_l40?ooo`080?nZE@000000001E0:[o
o`3DP2/00000000[P03Dool60?ooo`030:YE0000000005FZ0080oooo00<0e80[00000000EJX0103o
ool03P3oZUD00000000000000000000[083Do`3oojX0E@000000001EZ_l0oooD080[00000000EJ[o
0P3oool01P3oe800:`000000E@2ZZUD00000001EZPH0oooo00@0oonZ05D00000:h00e?oo0P3oool0
302ZE@0000000000:`20P5D000000000E@2Zool0oooo0?oDP00[0000000[083Do`80oooo00<0e80[
00000000EJX00P3oool00`3oom@0P2/002^0e0020?ooo`0>0?oDP00[0000000[083Do`3oool0omB0
02/0000005D0Z_oo0?ooo`3oZUD000000000E@2Zoom20?oooa8000009@3oool00`000000oooo0?oo
o`0Q0?ooo`00H03oool00`000000oooo0?ooo`1K0?ooo`80ool0I`3oool20?l004d0oooo00<00000
0?ooo`3oool0KP3oool0103oojX0E@000000001EZ_l40?ooo`050?oDP00[0000000[083Do`3DP2/0
1`0000001@1EZ_l0oooo0:YE0000000005FZ0080oooo00<0e80[00000000EJX00P3oool00`3DP2/0
0000000000030000000:001EZP3oool0oonZ05D000000000EJ[o0?ooe020:`00000005FZo`80oooo
00L0e80[00000000EJX0oonZ05D0000005D0Z_oo00D0oooo00@0oonZ05D00000:h00e?oo0P3oool0
0`2ZE@000000000000020000000705FZo`3oool0oooo0?oDP00[0000001E0:[oo`020?ooo`030=B0
:`00000005FZ00<0oooo0180e80[000[P03Dool0oooo0?oDP00[0000000[083Do`3oool0omB002/0
000002/0P=Co0?ooo`3oZUD000000000E@2Zoom20?oooa8000009@3oool00`000000oooo0?ooo`0Q
0?ooo`00H03oool00`000000oooo0?ooo`1J0?ooo`<0ool0IP3oool30?l004d0oooo00<000000?oo
o`3oool07`3oool_0?oo0200oooo00@0oonZ05D000000000EJ[o103oool01@3oojX0E@000000:`20
e?l0ojYE00H0000000H0000[083Do`3oool0ZUD000000000EJX20?ooo`060=B0:`00000005FZ0?oo
o`3oojX0E@000`0000005@00EJX0oooo0?ooo`3oool0oonZ05D000000000EJ[o0?ooe020:`000000
05FZo`3oool0oooD080[00000000EJ[o0?ooo`2ZE@00000005FZo`050?ooo`040?ooZP1E0000001E
0:[oo`80oooo00H0ZUD000000000EED0E@00000[P03Dool20?ooo`040?oDP00[0000000[083Do`80
oooo00<0e80[00000000EJX00`3oool04P3oe800:`0[083Do`3oool0omB002/0000002/0P=Co0?oo
o`3oe800:`000000:`20e?l0oooo0?nZE@000000001E0:[ood80oooo4P00000U0?ooo`030000003o
ool0oooo0240oooo001P0?ooo`030000003oool0oooo05X0oooo0P3oo`1W0?ooo`80o`00CP3oool0
0`000000oooo0?ooo`0O0?ooobl0ool0803oool0103oojX0E@000000001EZ_l40?ooo`0b0?ooZP1E
0000000[083Do`3oe800:`000000E@2Zool0oooo0?oDP00[0000001E0:[oo`3oool0ZUD000000000
02/0P=Co0?ooe020:`000000001EZP3oool0omB002/0000005D0Z_oo0?ooo`3DP2/00000001EZP3o
ool0oonZ05D000000000EJ[o0?ooe020:`00000005FZo`3oool0omB002/0000005D0Z_oo0?ooo`3o
ZUD00000000[P03Dool50?ooo`030:YE000005D0Z_oo0080oooo00H0ZUD000000000EJX0e80[0000
0000EJX20?ooo`090?ooZP1E00000000001EZP3oool0oonZ05D00000000005FZ00<0oooo00X0oooD
080[000[P=@0oooo0?oDP00[00000000001EZP3oool0ojYE0P0000001P0[P=@0oooo0=B0:`000000
001E0:[ood80oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo05X0oooo0P3oo`1W0?ooo`80o`00CP3oool00`000000oooo0?ooo`1^0?ooo`040?ooZP1E0000
000005FZo`@0oooo00H0omB002/0000002/0P=Co0?ooo`2ZE@050000000402^0e03oool0oooo0:YE
00H0000000@0:h3D0?ooo`3oom@0P2/01@0000001`0[P=@0oooo0?ooZP1E0000000005FZe020:`00
0`000000100005D0P80[00000000EJX20?ooo`040?ooZP1E0000000[083Do`D0oooo00<0ojYE0000
:`20e?l00P3oool01`2ZE@000000001EZP3oom@0P2/00000000[P=@00P3oool00`3DP2/000000000
000400000003001EZP3oool0oooo0080oooo00D0e80[000[P03Dool0omB002/0000:00000004001E
ZP3oool0oooD080[0080000000<0:h3D0?ooo`3oool0>`3ooolB000002D0oooo00<000000?ooo`3o
ool08@3oool00600oooo00<000000?ooo`3oool0F@3oool30?oo06H0oooo0`3o001>0?ooo`030000
003oool0oooo06h0oooo00@0oonZ05D000000000EJ[o103oool0103DP2/000000000E@2Zool20?oo
o`050=B0:`00000000000000000[P=@00`3oool0102ZE@000000001EZP2ZE@0200000006001EZP3o
ool0oooo0?ooo`3oojX0E@000`0000002000EJX0oooo0?ooo`3oojX0E@000000001EZ]@0P2/01P00
00001`1EZ_l0oooo0?ooo`3oool0ZUD00000000[P=@01P3oool0302ZE@0005FZ0?ooo`3oool0ZUD0
00000000EJX0oooo0?oDP00[0000000005FZo`80oooo00L0e80[000000000000:h3D0=B0:`000000
05FZ00@0oooo01L0omB002/0:`20e?l0omB002/0000002/0P:Z002/000000000001E0:[oo`3oe800
:`000000000005D0Z_oo0?ooo`3DP2/0000[083Do`3oZUD0000005FZo`0l0?oooa8000009@3oool0
0`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1I0?ooo`80ool0I`3oool20?l0
04l0oooo00<000000?ooo`3oool0KP3oool0103oojX0E@000000001EZ_l30?ooo`040?nZE@000000
000002^0e240oooo00@0oooD080[00000000EJ[o403oool01`3oom@0P2/005FZo`3oool0ZUD00000
0000EJX04P3oool00`3oom@0P2/002^0e00A0?ooo`030?ooZP1E0000:h3D03`0oooo4P00000U0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo05T0oooo0P3oo`1W0?ooo`80
o`00C`3oool00`000000oooo0?ooo`1^0?ooo`030?ooZP1E0000000000H0000000<002^00=Coo`3o
ool0703oool0203oojX0E@000000001EZ_l0oooD080[00000000EJ[o4P3oool01@2ZEB/0P=Co0:YE
0000000005FZ01<0oooo00<0e80[000[P03Dool0403oool00`3oe800:`0005FZo`0l0?oooa800000
9@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1I0?ooo`80ool0I`3o
ool20?l004l0oooo00<000000?ooo`3oool0KP3oool00`3oojX0E@00000000050000000302^0e03o
ool0oooo01d0oooo00@0oonZ05D000000000EJ[o0P3oool00`2ZE@00EJ[o0?ooo`0C0?ooo`030:YE
0000000005FZ02D0oooo00<0ojYE0000E@2Zool0?@3ooolB000002D0oooo00<000000?ooo`3oool0
8@3oool00600oooo0`00001H0?ooo`<0ool0IP3oool30?l004l0oooo00<000000?ooo`3oool0f`3o
ool00`3DP2/0001E0:[oo`0l0?oooa8000008`3oool3000002<0oooo001P0?ooo`030000003oool0
oooo05P0oooo0P3oo`1W0?ooo`80o`00D03oool00`000000oooo0?ooo`3H0?ooo`060?nZE@000000
EJ[o0=B0:`0002/0P=Co?03ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool0F03oool20?oo06L0oooo0P3o001@0?ooo`030000003oool0oooo0=T0oooo00@0
ZUD0000000000000:h3D?@3ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool0F03oool20?oo06L0oooo0P3o001@0?ooo`030000003oool0oooo0?l0oooo6`3o
oolB000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0E`3oool3
0?oo06H0oooo0`3o001@0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000002D0oooo00<00000
0?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0E`3oool20?oo06L0oooo0P3o001A0?oo
o`030000003oool0oooo0?l0oooo6`3ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0E`3oool20?oo06L0oooo0P3o001A0?ooo`030000003oool0oooo0?l0
oooo6`3ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0
E`3oool20?oo06L0oooo0P3o001A0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000002D0oooo
00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0EP3oool30?oo06H0oooo0`3o
001A0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000002D0oooo00<000000?ooo`3oool08@3o
ool00600oooo00<000000?ooo`3oool0EP3oool20?oo06L0oooo0P3o001B0?ooo`030000003oool0
oooo0?l0oooo6`3ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?oo
o`3oool0EP3oool20?oo06L0oooo0P3o001B0?ooo`030000003oool0oooo0?l0oooo6`3ooolB0000
02D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0EP3oool20?oo06L0
oooo0P3o001B0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000002D0oooo00<000000?ooo`3o
ool08@3oool00600oooo00<000000?ooo`3oool0E@3oool30?oo06H0oooo0`3o001B0?ooo`030000
003oool0oooo0?l0oooo6`3ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool0E@3oool20?oo06L0oooo0P3o001C0?ooo`030000003oool0oooo0?l0oooo6`3o
oolB000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0E@3oool2
0?oo06L0oooo0P3o001C0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000002D0oooo00<00000
0?ooo`3oool08@3oool00600oooo0`00001D0?ooo`<0ool0IP3oool30?l005<0oooo00<000000?oo
o`3oool0o`3ooolK0?oooa8000008`3oool3000002<0oooo001P0?ooo`030000003oool0oooo05@0
oooo0P3oo`1W0?ooo`80o`00E03oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`03
0000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo05@0oooo0P3oo`1W0?ooo`80o`00
E03oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo05@0oooo0P3oo`1W0?ooo`80o`00E03oool00`000000oooo0?oo
o`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo05<0oooo0`3oo`1V0?ooo`<0o`00E03oool00`000000oooo0?ooo`2j0?ooo`030?ooe020:b/0
P=Co01d0oooo00<0oonZ05D[P03Dool0?@3ooolB000002D0oooo00<000000?ooo`3oool08@3oool0
0600oooo00<000000?ooo`3oool0D`3oool20?oo06L0oooo0P3o001E0?ooo`030000003oool0oooo
0;T0oooo00<0oooD080[:`20e?l07`3oool00`3oe800:b^00=Coo`0l0?oooa8000009@3oool00`00
0000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1C0?ooo`80ool0I`3oool20?l005D0
oooo00<000000?ooo`3oool0^@3oool00`2ZE@0005FZ0?ooo`0P0?ooo`030=B0:`00EJX0oooo03/0
oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo05<0oooo
0P3oo`1W0?ooo`80o`00E@3oool00`000000oooo0?ooo`1^0?ooo`040?ooZP1E0000000005FZo`L0
oooo00@0oonZ05D0000002/0P=Co103oool01@2ZE@000000000000000000:h3D00<0oooo00<0oooD
080[000000000P0000001P00:h00e?oo0?ooo`3oool0oooD080[00<0000000<002^00=Coo`3oool0
0P3oool0302ZE@00000000000000:h00ZX0[00000000EJX0oooo0?ooZP1E0000000[083Do`@0oooo
00D0ZUD0000000000000000002^0e0070?ooo`030?nZE@0002/0P=Co0080oooo00<0ZUD000000000
EJX00P3oool0203DP2/00000001EZP3oool0oonZ05D000000000EJ[o203oool0203DP2/000000000
0000:h00e?nZ05D0000002/0P=Co0P3oool00`3oe800:`0005FZo`0k0?oooa8000009@3oool00`00
0000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1B0?ooo`<0ool0IP3oool30?l005D0
oooo00<000000?ooo`3oool0KP3oool0103oojX0E@000000001EZ_l70?ooo`040?ooZP1E0000000[
083Do`<0oooo00<0ZUD00000000000000`000000100[P=@0oooo0?ooe020:`0500000004000[P03D
ool0oooD080[00D0000000@002^00=Coo`3oool0ojYE1P0000001P00EJX0oooo0?ooZP1E0000000[
083Do`<0oooo00<0ZUD00000000000000`0000000`0[P=@0oooo0?ooo`040?ooo`030:YE000005D0
Z_oo0080oooo00<0ZUD000000000EJX00P3oool0203DP2/00000001EZP3oool0oonZ05D000000000
EJ[o1`3oool00`3oZUD000000000000400000007000[P03Dool0oooo0?ooo`3oojX0E@00001EZP0k
0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1B0?oo
o`80ool0I`3oool20?l005H0oooo00<000000?ooo`3oool0KP3oool0103oojX0E@000000001EZ_l7
0?ooo`040?ooZP1E0000000[083Do`80oooo02T0omB002/000000000EJ[o0?ooo`3oZUD000000000
E@2Zool0ojYE0000000002/0P=Co0?ooo`3oojX0E@000000:`20e?l0ojYE0000000002/0P=Co0?oo
o`3oojX0E@000000:`20e?l0oooo0:YE0000000002^00=Coo`3oojX0E@0000000000EJX0oooo0?oo
ZP1E0000000[083Do`020?ooo`090?oDP00[0000000005FZo`3oool0ojYE0000000005D0Z_oo00@0
oooo00@0oonZ05D00000:h00e?oo0P3oool00`2ZE@000000001EZP020?ooo`080=B0:`00000005FZ
0?ooo`3oojX0E@000000001EZ_l70?ooo`090=B0:`00000002^00=Coo`3oom@0P2/000000000:h00
e?oo0080oooo00@0oooD080[000005D0Z_oo>P3ooolB000002D0oooo00<000000?ooo`3oool08@3o
ool00600oooo00<000000?ooo`3oool0DP3oool20?oo06L0oooo0P3o001F0?ooo`030000003oool0
oooo06h0oooo00@0oonZ05D000000000EJ[o1`3oool0103oojX0E@000000:`20e?l20?ooo`040=B0
:`00000002^00=Coo`P0oooo00H0ojYE00000000000000000000:`20e?l30?ooo`0:0?nZE@000000
00000000000002/0P=Co0?ooo`2ZE@000000001EZP80oooo00P0ZUD000000000EJX0oooo0?ooZP1E
0000000[083Do`80oooo00@0e80[00000000:h00e?oo2@3oool0103oojX0E@00000[P03Dool20?oo
o`030:YE0000000005FZ0080oooo00P0e80[00000000EJX0oooo0?ooZP1E0000000005FZo`L0oooo
00T0ojYE000000000000EJ[o0?ooo`3DP2/00000000[P03Dool00P3oool0103oom@0P2/00000E@2Z
oolj0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1B
0?ooo`80ool0I`3oool20?l005H0oooo00<000000?ooo`3oool0KP3oool0103oojX0E@000000001E
Z_l70?ooo`040?ooZP1E0000000005FZo`80oooo00<0e80[0000000000001@0000000`1EZ_l0oooo
0=B0:`0500000004001EZP3oool0oooo0=B0:`D0000000H005FZ0?ooo`3oool0ZUD000000000EJX2
0?ooo`080=B0:`00000005FZ0?ooo`3oojX0E@000000001EZ_l20?ooo`030=B0:`000000000000D0
000000<0EJ[o0?ooo`3oool00P3oool0103oojX0E@00000[P03Dool20?ooo`030:YE0000000005FZ
0080oooo00P0e80[00000000EJX0oooo0?ooZP1E0000000005FZo`L0oooo00<0oooD080[00000000
100000002000:h00e?oo0?ooo`3oool0oooD080[000005D0Z_oo>P3ooolB000002D0oooo00<00000
0?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0D@3oool30?oo06H0oooo0`3o001F0?oo
o`030000003oool0oooo01l0oooo;`3o000P0?ooo`030?ooZP1E0000000000D0000000L0:h3D0?oo
o`3oool0oonZ05D000000000EJ[o0080oooo00<0ojYE00000000000010000000100002/0P=Co0?oo
ZP1E000300000006001EZP3oool0oooo0?ooo`3oojX0E@000`0000000`00EJX0oooo0?ooo`020?oo
o`030:YE0000000005FZ0080oooo00P0e80[00000000EJX0oooo0?ooZP1E0000000005FZo`80oooo
00<0ojYE000000000000100000000`0002/0P=Co0?ooo`030?ooo`040?ooZP1E0000001E0:[oo`80
oooo00<0ZUD000000000EJX00P3oool01P3DP2/00000001EZP3oool0oonZ05D000H0000000<0:h3D
0?ooo`3oool00`3oool01P3oe800:`0000000000000002^00=Coo`80oooo00@0oooD080[000005D0
Z_oo>P3ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0
D@3oool20?oo06L0oooo0P3o001G0?ooo`030000003oool0oooo01l0oooo;`3o000P0?ooo`030?oo
ZP1E0000000000H0000000H005FZ0?ooo`3oojX0E@0000000000EJX20?ooo`0J0?oDP00[0000001E
0:[oo`3oool0omB002/0000005D0Z_oo0?oDP00[0000001E0:[oo`3oool0e80[00000000EJX0oooo
0?oDP00[0000001E0:[oo`3oool0e80[00000000EJX20?ooo`030:YE0000000005FZ0080oooo00P0
e80[00000000EJX0oooo0?ooZP1E00000000001EZP80oooo00T0omB002/0000005D0Z_oo0?ooo`3o
e800:`000000E@2Zool01@3oool00`2ZE@00001E0:[oo`020?ooo`0;0:YE00000000000[083Do`3o
om@0P2/000000000EJX0oooo0?ooZP1E00001`0000002`00EJX0oooo0?ooZP1E0000001E0:[oo`3o
ool0e80[00000000:h00e?oo0080oooo00<0oonZ05D00000EJX0>`3ooolB000002D0oooo00<00000
0?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0D@3oool20?oo06L0oooo0P3o001G0?oo
o`030000003oool0oooo06h0oooo00@0oonZ05D000000000EJ[o0`3oool01P3DP2/000000000:`20
e?l0oonZ05D000<0000000<002^00=Coo`2ZE@001@000000100[P=@0oooo0?ooe020:`0500000004
02^0e03oool0oooD080[00D0000000H0:h3D0?ooo`3oool0ZUD000000000EJX20?ooo`060=B0:`00
000005FZ0?ooo`3oojX0E@000`0000000`00:h00e?oo0:YE00050000000302^0e03oool0oooo00@0
oooo00<0ojYE0000:`20e?l00P3oool00`2ZE@000000000000040000000602^0e03oool0oonZ05D0
00000000EJ[o0`3oool01P3DP2/000000000:`20e?l0oooo0:YE00D0000000L005FZ0?ooo`3oool0
oooo0?oDP00[0000EJ[o03/0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Q0?oo
o`00H03oool300000500oooo0`3oo`1W0?ooo`80o`00E`3oool00`000000oooo0?ooo`1^0?ooo`04
0?ooZP1E0000000005FZo`<0oooo00d0oonZ05D000000000EJ[o0?ooZP1E0000000[0820E@000000
000[083Do`3oool0e80[00<0000000H0:h3D0?ooo`3oool0oooo0?ooZP1E000300000006001EZP3o
ool0oooo0?ooo`3oojX0E@000`0000001`00EJX0oooo0?ooo`3oool0ZUD000000000EJX00P3oool0
3@3DP2/00000001EZP3oool0oonZ05D0000002/0P81E0000000002/0P=Co0?ooo`3DP2/00`000000
0`0[P=@0oooo0?ooo`060?ooo`080:YE0000EJX0oooo0?ooo`2ZE@000000001EZP2ZE@0200000007
001EZP3oool0oooo0?ooZP1E0000000005FZo`030?ooo`040?ooZP1E0000000005FZo`80oooo00H0
ZUD00000000000000000000[P03Dool30?ooo`030=B0:`00EJX0oooo03/0oooo00<000000?ooo`3o
ool0<P3oool3000002<0oooo001P0?ooo`030000003oool0oooo0500oooo0P3oo`1W0?ooo`<0o`00
E`3oool00`000000oooo0?ooo`1^0?ooo`040?ooZP1E0000000005FZo`<0oooo00@0e80[00000000
02/0P=Co@03oool01`3oom@0P2/005FZo`3oool0ZUD000000000EJX01P3oool0103oojX0E@000000
001EZ_l30?ooo`040=B0:`000000000[083Do`X0oooo00<0ojYE000[P03Dool0?03oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0500oooo
0P3oo`1W0?ooo`80o`00F03oool00`000000oooo0?ooo`1^0?ooo`030?ooZP1E0000000000H00000
00<005FZ0?ooo`3oool0@@3oool01@2ZEB/0P=Co0:YE0000000005FZ00H0oooo00<0oonZ05D00000
00001P0000000`00EJX0oooo0?ooo`080?ooo`030?ooZP1EEJX0oooo03d0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1@0?ooo`80ool0
I`3oool20?l005P0oooo00<000000?ooo`3oool0KP3oool00`3oojX0E@000000000500000003001E
ZP3oool0oooo04@0oooo00<0ZUD000000000EJX01P3oool00`3oojX0E@000000000500000003001E
ZP3oool0oooo04T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Q0?ooo`00H03o
ool00`000000oooo0?ooo`1?0?ooo`<0ool0I`3oool20?l005P0oooo00<000000?ooo`3oool0o`3o
oolK0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool08@3oool00600oooo00<00000
0?ooo`3oool0C`3oool20?oo06L0oooo0`3o001H0?ooo`030000003oool0oooo0?l0oooo6`3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo
04l0oooo0P3oo`1W0?ooo`80o`00F@3oool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1?0?ooo`80
ool0I`3oool20?l005T0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0CP3oool30?oo06L0oooo
0P3o001I0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0240oooo001P0?ooo`030000003oool0oooo04h0oooo0P3oo`1W0?ooo`<0o`00F@3o
ool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0Q0?ooo`00H03oool00`000000oooo0?ooo`1>0?ooo`80ool0I`3oool20?l005X0oooo00<00000
0?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool08@3oool0
0600oooo00<000000?ooo`3oool0CP3oool20?oo06L0oooo0P3o001J0?ooo`030000003oool0oooo
0?l0oooo6`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo001P0?ooo`03
0000003oool0oooo04d0oooo0`3oo`1W0?ooo`80o`00FP3oool00`000000oooo0?ooo`3o0?oooa/0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo
0?ooo`1=0?ooo`80ool0J03oool20?l005X0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0C@3o
ool20?oo06L0oooo0`3o001J0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0240oooo001P0?ooo`<00000C03oool30?oo06L0oooo0P3o001K
0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0b0?ooo`<000008`3oool0
0600oooo00<000000?ooo`3oool0C03oool20?oo06P0oooo0P3o001K0?ooool000007`00000f0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo04`0oooo0P3oo`1X0?ooo`80
o`00o`3ooom`0?ooo`800?l0?P3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo
0?ooo`1<0?ooo`80ool0I`3oool30?l00?l0ooooL03oool3003o03d0oooo00<000000?ooo`3oool0
8@3oool00600oooo00<000000?ooo`3oool0B`3oool30?oo06L0oooo0P3o003o0?ooog80oooo0P00
o`0m0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo04/0oooo0P3oo`1X
0?ooo`80o`00o`3ooomb0?ooo`800?l0?@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`00
0000oooo0?ooo`1;0?ooo`80ool0J03oool20?l00?l0ooooLP3oool2003o03d0oooo00<000000?oo
o`3oool08@3oool00600oooo00<000000?ooo`3oool0B`3oool20?oo06L0oooo0`3o003o0?ooog80
oooo0`00o`0l0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo04X0oooo
0`3oo`1W0?ooo`80o`00o`3ooomd0?ooo`800?l0?03oool00`000000oooo0?ooo`0Q0?ooo`00H03o
ool00`000000oooo0?ooo`1:0?ooo`80ool0J03oool20?l00?l0ooooM03oool2003o03`0oooo00<0
00000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0BP3oool20?oo06P0oooo0P3o003o
0?ooog@0oooo0P00o`0l0?ooo`030000003oool0oooo0240oooo000n0?ooo`050=B0:`0000000000
0000000[P=@0103oool01@3oZUD00000000000000000EJ[o00@0oooo00D0ojYE0000000000000000
05FZo`0;0?ooo`030000003oool0oooo04T0oooo0`3oo`0m0?ooo`030000003oool0oooo02L0oooo
0`3o001O0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0Q03oool3003o00<0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0Q0?ooo`00?@3oool00`3DP2/000000000
000300000004001EZP3oool0oooo0?nZE@D0000000@0EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0
oooo0?ooo`080?ooo`030000003oool0oooo04T0oooo0P3oo`0n0?ooo`030000003oool0oooo02L0
oooo0P3o001P0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0Q@3oool2003o00<0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0Q0?ooo`00?03oool06`3oojX0E@00
0000000[P=@0oooo0?nZE@000000000[083Do`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^0
0=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`090?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0A0?ooo`80ool01P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0;0?ooo`80o`00303oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0E0?ooo`800?l00`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool08@3oool003`0
oooo01/0ojYE0000000005D0Z_oo0?ooo`3oom@0P2/00000001EZ_l0omB002/0000002/0P=Co0?oo
o`3oe800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool02@3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04@3oool2
0?oo00H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool02`3oool20?l000`0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool05@3oool2
003o00<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0240oooo00110?ooo`0F0?ooe020:`00000002^0e03oe800:`000000E@2Zool0oooo0?ooZP1E
0000000[083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`T0ooooB`0000030?oo
06L000000`3o003o000007H000000`00o`0k000002<0oooo000l0?ooo`060?ooZP1E0000000[083D
o`3oool0ojYE0P0000004`1EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE
0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0o`3ooooo0?oooiT0oooo000l0?ooo`030?oo
e020:`00000000@0000001@002^00=Coo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZ
o`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZool0ooooo`3ooonI0?ooo`00?@3oool0
0`2ZE@000000000000020000000E001EZP3oool0oooo0?oDP00[0000001E0:[oo`3oool0oonZ05D0
000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?l0ooooo`3ooonI0?oo
o`00?@3oool00`3DP2/00000001EZP050?ooo`0B0?oDP00[0000000[083Do`3oool0omB002/00000
05D0Z_oo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_ooo`3ooooo0?oooiT0oooo000m
0?ooo`040?oDP00[000002^00=Coo`@0oooo0180oooD080[00000000:h3D0?ooo`3DP2/00000000[
P03Dool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Doooo0?ooool0ooooV@3oool003d0
oooo00<0oonZ05D0000000000`000000100005D0Z_oo0?ooo`3oZUD50000000405FZo`3oool0oooo
0?nZE@D0000000<0EJ[o0?ooo`3oool0o`3ooooo0?oooiP0oooo000m0?ooo`030?ooe020:`000000
00<0000000D0001E0:[oo`3oool0oooo0?nZE@030000000305FZo`3oool0oooo0080oooo00D0ojYE
000000000000000005FZo`3o0?ooool0ooooV`3oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oo
oo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o
0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0oooo
l03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0
ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo0000\
\>"],
  ImageRangeCache->{{{0, 749}, {462.5, 0}} -> {-1.05093, -0.648943, \
0.00280622, 0.00280622}, {{18.125, 730.813}, {451.438, 11}} -> {-18.4117, \
-85.8705, 0.0355787, 1.32747}, {{374.5, 659.563}, {142.125, 35.25}} -> \
{-4.51559, -11.1315, 0.0117896, 0.0344332}, {{389.75, 474.563}, {136.875, \
107.813}} -> {-9.14964, -24.5791, 0.022329, 0.0722583}, {{389.75, 474.563}, \
{103.188, 74.125}} -> {-9.14964, -27.0133, 0.022329, 0.0722583}, {{389.75, \
474.563}, {69.5, 40.4375}} -> {-9.14964, -29.4475, 0.022329, 0.0722583}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Try it Here", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"lst", "=", 
        RowBox[{"AtmGraphs", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["GravityAcceleration",
                    GridBoxOptions->{RowSpacings->0.4,
                    RowLines->False}], ",", 
                  "\"\<Gravity (m/\!\(s\^\(-2\)\))\>\""}], "}"}], 
              StyleBox["}",
                GridBoxOptions->{RowSpacings->0.4,
                RowLines->False}]}], 
            StyleBox[",",
              GridBoxOptions->{RowSpacings->0.4,
              RowLines->False}], \(PlotRange -> {\(-7\)\ , 500\ }\)}], 
          StyleBox["]",
            GridBoxOptions->{RowSpacings->0.4,
            RowLines->False}]}]}], 
      StyleBox[";",
        GridBoxOptions->{RowSpacings->0.4,
        RowLines->False}]}], "\[IndentingNewLine]", \(Show[
        LegendGraphs[lst, LegendSize \[Rule] { .8,  .2}, 
          LegendPosition \[Rule] \ {0,  .35}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        ImageSize \[Rule] 750];\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 750 463.525 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-4.36999 0.543891 0.00853301 0.001219 [
[.11711 -0.0125 -17.5313 -20.3125 ]
[.11711 -0.0125 17.5313 0 ]
[.25309 -0.0125 -13.0938 -20.3125 ]
[.25309 -0.0125 13.0938 0 ]
[.38906 -0.0125 -17.5313 -20.3125 ]
[.38906 -0.0125 17.5313 0 ]
[.52503 -0.0125 -6.4375 -20.3125 ]
[.52503 -0.0125 6.4375 0 ]
[.66101 -0.0125 -17.5313 -20.3125 ]
[.66101 -0.0125 17.5313 0 ]
[.79698 -0.0125 -13.0938 -20.3125 ]
[.79698 -0.0125 13.0938 0 ]
[.93295 -0.0125 -17.5313 -20.3125 ]
[.93295 -0.0125 17.5313 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -104.719 -40.625 ]
[.5 -0.0125 104.719 -20.3125 ]
[-0.0125 .00853 -12.875 -10.1563 ]
[-0.0125 .00853 0 10.1563 ]
[-0.0125 .13043 -30.625 -10.1563 ]
[-0.0125 .13043 0 10.1563 ]
[-0.0125 .25233 -30.625 -10.1563 ]
[-0.0125 .25233 0 10.1563 ]
[-0.0125 .37423 -30.625 -10.1563 ]
[-0.0125 .37423 0 10.1563 ]
[-0.0125 .49613 -30.625 -10.1563 ]
[-0.0125 .49613 0 10.1563 ]
[-0.0125 .61803 -30.625 -10.1563 ]
[-0.0125 .61803 0 10.1563 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -50.9375 -48.625 ]
[-0.01875 .30902 -30.625 48.625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11711 0 m
.11711 .00625 L
s
gsave
.11711 -0.0125 -78.5313 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.25) show
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -74.0938 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.5) show
1.000 setlinewidth
grestore
.38906 0 m
.38906 .00625 L
s
gsave
.38906 -0.0125 -78.5313 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.75) show
1.000 setlinewidth
grestore
.52503 0 m
.52503 .00625 L
s
gsave
.52503 -0.0125 -67.4375 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
.66101 0 m
.66101 .00625 L
s
gsave
.66101 -0.0125 -78.5313 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.25) show
1.000 setlinewidth
grestore
.79698 0 m
.79698 .00625 L
s
gsave
.79698 -0.0125 -74.0938 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.5) show
1.000 setlinewidth
grestore
.93295 0 m
.93295 .00625 L
s
gsave
.93295 -0.0125 -78.5313 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.75) show
1.000 setlinewidth
grestore
.125 Mabswid
.14431 0 m
.14431 .00375 L
s
.1715 0 m
.1715 .00375 L
s
.1987 0 m
.1987 .00375 L
s
.22589 0 m
.22589 .00375 L
s
.28028 0 m
.28028 .00375 L
s
.30748 0 m
.30748 .00375 L
s
.33467 0 m
.33467 .00375 L
s
.36187 0 m
.36187 .00375 L
s
.41625 0 m
.41625 .00375 L
s
.44345 0 m
.44345 .00375 L
s
.47064 0 m
.47064 .00375 L
s
.49784 0 m
.49784 .00375 L
s
.55223 0 m
.55223 .00375 L
s
.57942 0 m
.57942 .00375 L
s
.60662 0 m
.60662 .00375 L
s
.63381 0 m
.63381 .00375 L
s
.6882 0 m
.6882 .00375 L
s
.71539 0 m
.71539 .00375 L
s
.74259 0 m
.74259 .00375 L
s
.76978 0 m
.76978 .00375 L
s
.82417 0 m
.82417 .00375 L
s
.85137 0 m
.85137 .00375 L
s
.87856 0 m
.87856 .00375 L
s
.90576 0 m
.90576 .00375 L
s
.08992 0 m
.08992 .00375 L
s
.06272 0 m
.06272 .00375 L
s
.03553 0 m
.03553 .00375 L
s
.00834 0 m
.00834 .00375 L
s
.96015 0 m
.96015 .00375 L
s
.98734 0 m
.98734 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -165.719 -44.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(GravityAcceleration) show
212.375 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
221.250 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
235.438 19.750 moveto
(\\220) show
241.313 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
250.188 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
259.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
268.438 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00853 m
.00625 .00853 L
s
gsave
-0.0125 .00853 -73.875 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13043 m
.00625 .13043 L
s
gsave
-0.0125 .13043 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
0 .25233 m
.00625 .25233 L
s
gsave
-0.0125 .25233 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
0 .37423 m
.00625 .37423 L
s
gsave
-0.0125 .37423 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
0 .49613 m
.00625 .49613 L
s
gsave
-0.0125 .49613 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03291 m
.00375 .03291 L
s
0 .05729 m
.00375 .05729 L
s
0 .08167 m
.00375 .08167 L
s
0 .10605 m
.00375 .10605 L
s
0 .15481 m
.00375 .15481 L
s
0 .17919 m
.00375 .17919 L
s
0 .20357 m
.00375 .20357 L
s
0 .22795 m
.00375 .22795 L
s
0 .27671 m
.00375 .27671 L
s
0 .30109 m
.00375 .30109 L
s
0 .32547 m
.00375 .32547 L
s
0 .34985 m
.00375 .34985 L
s
0 .39861 m
.00375 .39861 L
s
0 .42299 m
.00375 .42299 L
s
0 .44737 m
.00375 .44737 L
s
0 .47175 m
.00375 .47175 L
s
0 .52051 m
.00375 .52051 L
s
0 .54489 m
.00375 .54489 L
s
0 .56927 m
.00375 .56927 L
s
0 .59365 m
.00375 .59365 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -150.406 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
109.625 14.1563 translate
90 rotate
-109.625 -14.1563 translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Altitude) show
121.688 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
130.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Km) show
156.250 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11711 .61178 m
.11711 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.38906 .61178 m
.38906 .61803 L
s
.52503 .61178 m
.52503 .61803 L
s
.66101 .61178 m
.66101 .61803 L
s
.79698 .61178 m
.79698 .61803 L
s
.93295 .61178 m
.93295 .61803 L
s
.125 Mabswid
.14431 .61428 m
.14431 .61803 L
s
.1715 .61428 m
.1715 .61803 L
s
.1987 .61428 m
.1987 .61803 L
s
.22589 .61428 m
.22589 .61803 L
s
.28028 .61428 m
.28028 .61803 L
s
.30748 .61428 m
.30748 .61803 L
s
.33467 .61428 m
.33467 .61803 L
s
.36187 .61428 m
.36187 .61803 L
s
.41625 .61428 m
.41625 .61803 L
s
.44345 .61428 m
.44345 .61803 L
s
.47064 .61428 m
.47064 .61803 L
s
.49784 .61428 m
.49784 .61803 L
s
.55223 .61428 m
.55223 .61803 L
s
.57942 .61428 m
.57942 .61803 L
s
.60662 .61428 m
.60662 .61803 L
s
.63381 .61428 m
.63381 .61803 L
s
.6882 .61428 m
.6882 .61803 L
s
.71539 .61428 m
.71539 .61803 L
s
.74259 .61428 m
.74259 .61803 L
s
.76978 .61428 m
.76978 .61803 L
s
.82417 .61428 m
.82417 .61803 L
s
.85137 .61428 m
.85137 .61803 L
s
.87856 .61428 m
.87856 .61803 L
s
.90576 .61428 m
.90576 .61803 L
s
.08992 .61428 m
.08992 .61803 L
s
.06272 .61428 m
.06272 .61803 L
s
.03553 .61428 m
.03553 .61803 L
s
.00834 .61428 m
.00834 .61803 L
s
.96015 .61428 m
.96015 .61803 L
s
.98734 .61428 m
.98734 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00853 m
1 .00853 L
s
.99375 .13043 m
1 .13043 L
s
.99375 .25233 m
1 .25233 L
s
.99375 .37423 m
1 .37423 L
s
.99375 .49613 m
1 .49613 L
s
.125 Mabswid
.99625 .03291 m
1 .03291 L
s
.99625 .05729 m
1 .05729 L
s
.99625 .08167 m
1 .08167 L
s
.99625 .10605 m
1 .10605 L
s
.99625 .15481 m
1 .15481 L
s
.99625 .17919 m
1 .17919 L
s
.99625 .20357 m
1 .20357 L
s
.99625 .22795 m
1 .22795 L
s
.99625 .27671 m
1 .27671 L
s
.99625 .30109 m
1 .30109 L
s
.99625 .32547 m
1 .32547 L
s
.99625 .34985 m
1 .34985 L
s
.99625 .39861 m
1 .39861 L
s
.99625 .42299 m
1 .42299 L
s
.99625 .44737 m
1 .44737 L
s
.99625 .47175 m
1 .47175 L
s
.99625 .52051 m
1 .52051 L
s
.99625 .54489 m
1 .54489 L
s
.99625 .56927 m
1 .56927 L
s
.99625 .59365 m
1 .59365 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
.97217 .00244 m
.97619 .00305 L
.97048 .00366 L
.96966 .00427 L
.96879 .00488 L
.96798 .00549 L
.96711 .0061 L
.96629 .0067 L
.96542 .00731 L
.96461 .00792 L
.96374 .00853 L
.96292 .00914 L
.9621 .00975 L
.96123 .01036 L
.96042 .01097 L
.95955 .01158 L
.95873 .01219 L
.95792 .0128 L
.95705 .01341 L
.95623 .01402 L
.95536 .01463 L
.95454 .01524 L
.95373 .01585 L
.95286 .01646 L
.95204 .01707 L
.95123 .01768 L
.95036 .01829 L
.94954 .01889 L
.94867 .0195 L
.94785 .02011 L
.94704 .02072 L
.94617 .02133 L
.94535 .02194 L
.94454 .02255 L
.94367 .02316 L
.94285 .02377 L
.94203 .02438 L
.94116 .02499 L
.94035 .0256 L
.93953 .02621 L
.93866 .02682 L
.93703 .02804 L
.93534 .02926 L
.93366 .03048 L
.93203 .03169 L
.93034 .03291 L
.92871 .03413 L
.92702 .03535 L
.92539 .03657 L
.9237 .03779 L
Mistroke
.92207 .03901 L
.92039 .04023 L
.91876 .04145 L
.91707 .04267 L
.91544 .04388 L
.91375 .0451 L
.91212 .04632 L
.91049 .04754 L
.9088 .04876 L
.90717 .04998 L
.90548 .0512 L
.90385 .05242 L
.90054 .05486 L
.89727 .05729 L
.89395 .05973 L
.89069 .06217 L
.88737 .06461 L
.88411 .06705 L
.88085 .06948 L
.87758 .07192 L
.87427 .07436 L
.871 .0768 L
.86855 .07924 L
.86448 .08167 L
.85632 .08777 L
.84821 .09386 L
.84011 .09996 L
.832 .10605 L
.82396 .11215 L
.82314 .11276 L
.82232 .11337 L
.81591 .11824 L
.80786 .12434 L
.79981 .13043 L
.78387 .14262 L
.76793 .15481 L
.75211 .167 L
.73639 .17919 L
.72067 .19138 L
.70506 .20357 L
.68951 .21576 L
.67406 .22795 L
.65867 .24014 L
.64333 .25233 L
.6281 .26452 L
.61287 .27671 L
.58274 .30109 L
.55283 .32547 L
.52318 .34985 L
.49387 .37423 L
Mistroke
.46477 .39861 L
.43589 .42299 L
.40733 .44737 L
.379 .47175 L
.35093 .49613 L
.28186 .55708 L
.21425 .61803 L
Mfstroke
.21425 .61803 m
.21425 .61803 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.52381 .45187 m
.52381 .54711 L
.90476 .54711 L
.90476 .45187 L
F
1 g
.5 .47568 m
.5 .57092 L
.88095 .57092 L
.88095 .47568 L
F
0 g
.001 w
[ ] 0 setdash
.5 .47568 m
.88095 .47568 L
.88095 .57092 L
.5 .57092 L
.5 .47568 L
s
% Start of sub-graphic
p
0.5 0.475684 0.880952 0.570922 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0183824 0.183824 [
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0330882 0.35119 0.216912 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .125 -61 -14.5313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 20.500 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.500 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Gravity) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
121.625 20.500 moveto
(H) show
127.125 20.500 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.313 20.500 moveto
(\\220) show
147.188 20.500 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
156.063 13.125 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 11.375 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.750 13.125 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 11.375 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
170.625 20.500 moveto
(L) show
176.125 20.500 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{750, 463.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001cb000`400?l00000o`00003oo`3ooooo
0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo
003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0
ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool0
0?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooG03o
ool01@3oe800:`000000000005D0Z_oo06@0oooo00<0oonZ05D0:`20e?l04`3oool00`3oom@0P2/0
02^0e03o0?oooa80oooo003o0?oooe`0oooo00D0omB002/0000000000000001EZP1U0?ooo`030=B0
:`00:h00e?oo01<0oooo00<0e80[000[P03Dool0o`3ooolA0?ooo`00o`3ooomN0?ooo`040?oDP00[
0000000[083Dof@0oooo00<0oonZ05D0:`20e?l04`3oool00`3oe800:`0[083Do`3o0?oooa40oooo
003o0?oooc80oooo00<0ojYE0000000000000P0000002000:h00e?oo0?ooo`3oool0oonZ05D00000
02/0P=Co0`3oool0203DP2/0000000000000:h00e?nZ05D0000002/0P=Co0`3oool00`2ZE@000000
001EZP030?ooo`0?0?ooZP1E0000000005FZo`3oool0omB002/000000000000[083Do`3oool0oonZ
05D000000000:h3D0080oooo00@0oooD080[00000000:h3D1@3oool00`2ZE@000000001EZP020?oo
o`060?nZE@000000000000000000:h00e?oo0`3oool01P3oZUD0000000000000000002^00=Coo`<0
oooo00D0ZUD0000000000000000002^0e0020?ooo`040?ooZP1E0000000005FZo`80oooo00D0ZUD0
000000000000000002^0e0020?ooo`040?ooZP1E0000000[083Do`<0oooo0140e80[000000000000
02^00=CoZP1E0000000[083Do`3oool0omB002/000000000000[083DZP1E0000000005FZo`020?oo
o`060?ooZP1E000000000000000002/0P=Co0`3oool00`2ZE@000000001EZP020?ooo`030=B0:`00
000005FZ0080oooo00@0omB002/0000002/0P=Co1@3oool04@3oe800:`000000:`20e?l0oooo0?oD
P00[0000001E0:[oo`3oool0ojYE0000000005D0Z_oo0?ooe020:`00:h3D00@0oooo00<0oooD080[
000000000P0000000`00:h00e?oo0?ooo`090?ooo`030=B0:`000000000000D0000000<0EJ[o0?oo
o`3oool0l03oool00?l0oooo<@3oool00`2ZE@0000000000000500000006001EZP3oool0oonZ05D0
000002/0P=Co0P3oool00`3oZUD000000000000400000009000[P03Dool0oooo0?ooo`3oojX0E@00
0000000005D0Z_oo0080oooo00H0oonZ05D000000000EJ[o0?ooo`2ZE@02000000040000:`20e?l0
oooo0?nZE@80000000P002^00=Coo`3oool0oooo0=B0:`00000002^00=Coo`<0oooo00H0oonZ05D0
00000000EJ[o0?ooo`3oZUD5000000040000E@2Zool0oooo0?nZE@D0000000@0001E0:[oo`3oool0
ZUD01@000000200[P=@0oooo0?ooZP1E0000000005FZo`3oool0ZUD01@0000001P0[P=@0oooo0?oo
ZP1E0000000[083Do`80oooo00<0ojYE000000000000100000001000:h00e?oo0?ooo`2ZE@020000
00070000:`20e:X0E@000000001EZ_l0oooo0?nZE@060000000605FZo`3oool0oooo0:YE00000000
05FZ0P3oool00`3DP2/00000001EZP020?ooo`040?oDP00[0000000[083Do`D0oooo0180omB002/0
000002/0P=Co0?ooo`3oe800:`000000E@2Zool0oooo0?nZE@000000001E0:[oo`3oool0e80[000[
P03Dool20?ooo`030?ooe020:`00000000@0000000<002^00=Coo`3oool0203oool00`3oe800:`00
000000050000000305FZo`3oool0oooo0?00oooo003o0?oooc00oooo00@0e80[000000000000EJ[o
0P3oool02@3oom@0P2/00000000005D0Z_oo0?ooZP1E0000000[083Do`020?ooo`090=B0:`000000
02^00=Coo`3oom@0P2/000000000:h00e?oo0080oooo00D0e80[0000001EEED0000005FZo`020?oo
o`080?ooZP1E0000000005FZo`3oom@0P2/00000000[P=@30?ooo`050:YE0000000000000000:`20
e?l00P3oool0103oe800:`000000:`20e?l30?ooo`0`0?nZE@000000001E0:[oo`3oojX0E@000000
000[P=@0oooo0?ooe020:`00000002^0e03oojX0E@000000000[P=@0oooo0?ooe020:`00000002^0
e03oe800:`000000001EZ_l0oooo0?nZE@000000001E0:[oo`3oojX0E@000000001EZ_l0omB002/0
00000000EJ[o0?ooo`3oZUD000000000E@2Zool0oonZ05D0000002/0P=Co0P3oool0803DP2/00000
000[P03Dool0oooD080[0000000002^00=Coo`3oom@0P2/00000000[P=@0oooo0?ooZP1E00000000
05FZo`3oom@0P2/000000000:h00e?oo0?ooo`2ZE@000000000[P03Dool0oooo0:YE0000000005FZ
0P3oool00`3DP2/00000001EZP0;0?ooo`0B0?oDP00[0000000[083Do`3oool0omB002/0000005D0
Z_oo0?ooo`3oZUD000000000E@2Zool0oooo0?oDP00[02/0P=Co0P3oool02@3oZUD000000000:`20
e?l0oooo0?ooZP1E0000000[083Do`0:0?ooo`040:YE00000000001E0:[oooH0oooo003o0?ooobl0
oooo00@0oonZ05D000000000:h3D103oool0203oZUD000000000E@2Zool0oonZ05D0000002/0P=Co
0P3oool06P3oZUD000000000001EZ_l0oooo0=B0:`00000002^00=Coo`3oool0oooD080[000005D0
Z]B002/00000:h00e?oo0?ooo`3oojX0E@000000001EZ_l0oooD080[00000000EJ[o0P3oool01P3o
e800:`000000E@2ZZUD00000001EZP80oooo00<0oooD080[000000001P0000001P00EJX0oooo0?oD
P00[0000000[083Do`D0oooo00@0omB002/0000002/0P=Co1@3oool0103DP2/00000000[P03Dool5
0?ooo`080?ooZP1E0000000005FZo`3DP2/00000000[P03Dool50?ooo`040?ooZP1E0000000[083D
o`80oooo01H0ojYE000000000000EJ[o0?ooo`3DP2/00000000[P03Dool0oooD080[00000000EJ[o
0?ooo`3oojX0E@000000001EZ_l0omB002/0000002/0P=Co0P3oool0203oojX0E@000000:`20e?l0
oooo0:YE0000000005FZ0P3oool00`3DP2/00000001EZP0;0?ooo`0B0?oDP00[0000000[083Do`3o
ool0omB002/0000005D0Z_oo0?ooo`3oZUD000000000E@2Zool0oooo0?ooe020:`00:h3D1@3oool0
1P3oZUD00000000000000000000[083Do`X0oooo00D0oooD080[00000000001E0:[oo`3e0?ooo`00
o`3oool_0?ooo`070?oDP00[0000001E0:[oo`3oool0oooD080[0003000000060000E@2Zool0oonZ
05D000000000EJ[o0P3oool00`3oom@0P2/0000000040000000C000[P03Dool0oooo0?oDP00[0000
02^00=Coe020:`00000[083Do`3oool0oonZ05D000000000EJ[o0?ooe020:`00000005FZo`020?oo
o`070=B0:`00000005FZ0?ooZP1E0000001E0:[oo`020?ooo`030=B0:`000000000000D0000000H0
EJ[o0?ooo`3oe800:`000000E@2Zool50?ooo`040?oDP00[0000001E0:[oo`D0oooo00<0e80[0000
000000001@0000001P1EZ_l0oonZ05D000000000EJ[o0=B0:`L0000000D0EJ[o0?ooZP1E00000000
05FZo`020?ooo`030?ooe020:`00000000@0000000l002^00=Coo`3oom@0P2/00000001EZ_l0oooo
0?ooZP1E0000000005FZo`3oe800:`000000E@2Zool00P3oool0203oojX0E@000000001EZ_l0oooo
0:YE0000000005FZ0P3oool00`3DP2/00000001EZP0;0?ooo`0>0?oDP00[0000000[083Do`3oool0
omB002/0000002/0P=Co0?ooo`3oZUD000000000E@2Zool20?ooo`030=B0:`00:h00e?oo0080oooo
00<0e80[0000000000000`0000000`00EJX0oooo0?ooo`0:0?ooo`050?ooe020:`0000000000E@2Z
ool0m03oool00?l0oooo;`3oool01`3oZUD00000000[P03Dool0oooo0?ooe020:`000`0000001P00
05D0Z_oo0?ooZP1E0000000005FZo`D0oooo0200omB002/0000000000000000[P03Dool0oooo0:YE
00000000:h3D0?ooo`3DP2/0000002^0e03oool0oonZ05D000000000EJ[o0?ooe020:`00000005FZ
o`3oool0oooD080[00000000EJ[o0?ooo`2ZE@00000005FZo`80oooo00h0omB002/0000005D0Z_oo
0?ooo`3oe800:`000000E@2Zool0oooo0?oDP00[0000000[083Do`D0oooo00@0omB002/0000002/0
P=Co1@3oool00`3oZUD0000000000004000000070000:`20e?l0oonZ05D000000000EJ[o0?nZE@06
000000060000:`20e?l0oonZ05D000000000EJ[o1@3oool04`3oe800:`0000000000000002^00=Co
o`3oom@0P2/00000001EZ_l0oooo0?ooZP1E0000000005FZo`3oe800:`000000:`20e?l00P3oool0
203oojX0E@000000:`20e?l0oooo0:YE0000000005FZ0P3oool00`3DP2/00000001EZP0;0?ooo`0>
0?oDP00[0000000[083Do`3oool0omB002/0000002/0P=Co0?ooo`3oZUD000000000E@2Zool20?oo
o`060?oDP00[02/0P=Co0?ooo`3oojX0E@000`0000000`00EJX0oooo0?ooo`0=0?ooo`050?ooe020
:`0000000000E@2Zool0l`3oool00?l0oooo;`3oool0103oZUD00000000[P03Dool80?ooo`040?oo
ZP1E00000000001EZP80oooo02d0oonZ05D0000005D0Z_oo0?ooo`3DP2/00000000[P03Dool0oonZ
05D0000002/0P=Co0?ooo`3oe800:`00000[P03Dool0oonZ05D000000000EJ[o0?ooe020:`000000
05FZo`3oool0omB002/0000005D0Z_oo0?ooo`3oZUD00000000[P03Dool0oooo0?ooe020:`000000
05FZo`3oool0e80[00000000EJX00P3oool0;03oojX0E@000000000[P=@0oooo0?ooZP1E0000000[
083Do`3oojX0E@000000000[P=@0oooo0?ooZP1E0000000[083Do`3oe800:`000000E@2Zool0oooo
0?oDP00[0000001E0:[oo`3oojX0E@000000001EZ_l0omB002/0000005D0Z_oo0?ooo`3oe800:`00
0000E@2Zool0oonZ05D00000000005FZ0P3oool09@3oojX0E@000000E@2Zool0oooo0=B0:`000000
02^00=Coo`3oom@0P2/00000001EZ_l0oooo0?ooZP1E0000000005FZo`3oom@0P2/000000000:h00
e?oo0?ooo`2ZE@0000000000E@2Zool0oooo0:YE00000000000[083Do`3oom@0P2/000000000EJX0
2`3oool01P3oe800:`0000000000EJX0oooo0?nZE@80000000H0:h3D0?ooo`3DP2/000000000E@2Z
ool20?ooo`0F0?ooe020:`00:h3D0?ooo`3oe800:`000000E@2Zool0oooo0=B0:`00000005FZ0?oo
o`3oojX0E@000000:`20e?l0oooo0?nZE@00000002^00=Coo`@0oooo00@0oooD080[0000000005FZ
l`3oool00?l0oooo;`3oool0103oe800:`000000E@2Zool80?ooo`030?ooZP1E0000000000800000
00<002^00=Coo`2ZE@001@0000004000EJX0oooo0?nZE@00000002^00=Coo`3oool0oooD080[0000
0000EJ[o0?ooZP1E0000000005FZe020:`03000000040000E@20P2/00000001EZP80oooo00@0oonZ
05D0000002/0P=Co0P3oool01`3DP2/00000001EZP3oom@0P2/00000001EZ_l00`3oool00`3oZUD0
00000000000300000004000[P03Dool0oooo0?nZE@D0000000@002^00=Coo`3oool0ZUD01@000000
200[P=@0oooo0?ooZP1E0000000005FZo`3oool0ZUD01@000000100[P=@0oooo0?ooZP1E00030000
0003000[P03Dool0ZUD000D0000000<005FZ0?ooe020:`000`000000200005D0Z_nZ05D000000000
EJ[o0?ooo`3oe800:`001@000000101EZ_l0oooo0?ooo`2ZE@060000000302^0e03oool0oooo00T0
oooo00<0omB002/0000000002@0000000`00EJX0oooo0?ooo`020?ooo`050=B0:`00:h00e?oo0?oo
e020:`001@0000002P0[P=@0oooo0?ooo`3DP2/0000002^0e03oool0ZUD00000001EZ_l60?ooo`04
0?oDP00[0000000[083Doo80oooo003o0?ooobl0oooo00@0oonZ05D000000000EJ[o103oool03@3D
P2/002^00=Coo`3oool0oonZ05D0000002/0P81E0000000002/0P=Co0?ooo`2ZE@000`0000001P00
:h00e?oo0?ooo`2ZE@00000002^0e0<0oooo00P0ZUD000000000EJX0oonZ05D000000000EJ[D080[
00H0000000L0EJ[o0?ooo`3oool0oooo0:YE00000000:h3D0080oooo00L0omB002/00000:h00e=B0
02/0000005D0Z_oo00@0oooo00H0ojYE0000000000000000000[P03Dool30?ooo`060?nZE@000000
000000000000:h00e?oo0`3oool01@3DP2/00000000000000000:h3D0080oooo00@0oonZ05D00000
0000EJ[o0P3oool01@3DP2/00000000000000000:h3D0080oooo00T0oonZ05D0000002/0P81E0000
000002/0P=Co0?ooo`2ZE@000`0000001000:h00e?oo0?ooe020:`03000000050000E@2ZojX0E@00
0000001EZ_l00P3oool01P3oojX0E@00000000000000000[083Do`<0oooo00@0ZUD000000000EJX0
ZUD00P0000000`00EJX0oooo0?ooo`0:0?ooo`0=0?oDP00[0000000[082ZP00[000000000000E@2Z
ool0omB002/000000000001E0:[oo`040?ooo`060?oDP00[02/0P=Co0?ooo`3oojX0E@000`000000
5@00EJX0oooo0?ooo`3oool0omB002/0000005D0Z]B002/00000:h00e?oo0?ooo`3oZUD000000000
E@2Zool0oooo0?ooZP1E0000000005FZo`3b0?ooo`00o`3oool`0?ooo`040=B0:`000000000005FZ
o`80oooo00@0ojYE00000000000005FZ7@3oool0103oom@0P2/00000001EZ_l<0?ooo`060?ooe020
:`00000[05EE:`00000005FZ7P3oool0103oojX0E@000000001EZ_lH0?ooo`040?ooe020:`000000
05FZoc@0oooo00<0oooD080[000[P=@02`3oool01@2ZE@00000002/[:`000000:h3D0080oooo00T0
oonZ05D000000000EJ[o0?ooo`3oZUD000000000:`20e?l0lP3oool00?l0oooo<03oool00`3oom@0
P2/000000005000000030000:`20e?l0oooo01P0oooo00P0oonZ05D000000000EJ[o0?ooe020:`00
000005FZo`d0oooo00D0e80[000000000000000005FZo`0N0?ooo`040?ooZP1E0000000005FZoaP0
oooo00T0oooD080[00000000EJ[o0?ooo`3oojX0E@000000001EZ_l0<03oool00`3DP2/002^00=Co
o`0:0?ooo`050?oDP00[000000000000E@2Zool00`3oool00`2ZE@0000000000000300000003001E
ZP3oool0oooo0?40oooo003o0?oooc80oooo00<0ojYE0000000000000P0000000`00:h00e?oo0?oo
o`0I0?ooo`040?ooZP1E0000000005FZo`80oooo00<0ZUD005FZo`3oool0303oool01@3oe800:`00
0000000005D0Z_oo01h0oooo00@0oonZ05D000000000EJ[o6P3oool01`2ZE@00EJ[o0?ooo`3oojX0
E@000000001EZ_l0?P3oool00`2ZE@00000002^0e0050?ooo`050=B0:`000000000000000000EJX0
m03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0
ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`
0?ooo`00o`3ooooo0?oooo00oooo002K0?ooo`050:YE00000000000000000000EJX00P3oool01@3o
e800:`000000:`20e?l0e80[00L0000000@0EJ[o0?ooo`3oool0e80[0`0000000`0[P=@0oooo0?oo
o`0k0?ooo`050:YE00000000000000000000EJX00P3oool0103oe800:`000000:`20e?l20?ooo`05
0=B0:`00000000000000000[P=@0?P3oool01@2ZE@00000000000000000005FZ0080oooo00T0omB0
02/0000002/0P=Co0?ooo`3oom@0P2/00000001EZ_l01P3oool01@3DP2/00000000000000000:h3D
04<0oooo00H0oooD080[0000000000000000E@2Zoom30?ooo`060?ooe020:`0000000000000005D0
Z_oo0P3oool01@3oe800:`000000:`20e?l0e80[00L0000000@0EJ[o0?ooo`3oool0e80[0`000000
0`0[P=@0oooo0?ooo`0k0?ooo`060?ooe020:`0000000000000005D0Z_oo0P3oool0103oe800:`00
0000:`20e?l20?ooo`050=B0:`00000000000000000[P=@0?03oool01P3oom@0P2/0000000000000
001E0:[oo`80oooo00T0omB002/0000002/0P=Co0?ooo`3oom@0P2/00000001EZ_l01P3oool01@3D
P2/00000000000000000:h3D0400oooo002I0?ooo`030?ooe020:`00000000@0000000P005FZ0?oo
o`3oe800:`000000:`20e?l0omB002/000H0000000<0EJ[o0?ooo`3DP2/01@0000000`00EJX0oooo
0?ooo`0h0?ooo`030?ooe020:`00000000@0000000P005FZ0?ooo`3oe800:`000000:`20e?l0oooo
0=B0:`D0000000<005FZ0?ooo`3oool0>@3oool00`3oom@0P2/0000000040000000;001EZP3oool0
omB002/0000002/0P=Co0?ooo`3oom@0P2/00000000[P=@01@3oool00`3DP2/00000000000030000
0003001EZP3oool0oooo03l0oooo00<0oooD080[000000000`0000000`0002/0P=Co0?ooo`100?oo
o`030?ooe020:`00000000<0000000T0000[083Do`3oool0omB002/0000002/0P=Co0?oDP00[0000
1P0000000`1EZ_l0oooo0=B0:`0500000003001EZP3oool0oooo03T0oooo00<0oooD080[00000000
0`0000002@0002/0P=Co0?ooo`3oe800:`000000:`20e?l0oooo0=B0:`0500000003001EZP3oool0
oooo03P0oooo00<0oooD080[000000000`000000300002/0P=Co0?ooo`3oe800:`000000:`20e?l0
oooo0?ooe020:`00000002^0e0D0oooo00<0e80[0000000000000`0000000`00EJX0oooo0?ooo`0m
0?ooo`00V@3oool02@3oe800:`000000001EZ_l0oooo0?nZE@000000000[083Do`050?ooo`040:YE
00000000001E0:[oo`@0oooo00T0oonZ05D000000000:h3D0?ooo`3oZUD000000000:`20e?l0>@3o
ool02@3oe800:`000000001EZ_l0oooo0?nZE@000000000[083Do`040?ooo`090?ooZP1E00000000
02^0e03oool0ojYE0000000002/0P=Co03X0oooo00T0omB002/000000000EJ[o0?ooo`3oZUD00000
0000:`20e?l01P3oool00`2ZE@000000001EZP040?ooo`090?ooZP1E0000000002^0e03oool0ojYE
0000000002/0P=Co0400oooo00P0omB002/0000002/0P=Co0?ooo`3DP2/00000001EZT40oooo00P0
omB002/0000002/0P=Co0?ooo`3DP2/00000001EZPH0oooo00@0ZUD00000000005D0Z_oo103oool0
2@3oojX0E@000000000[P=@0oooo0?nZE@000000000[083Do`0j0?ooo`080?oDP00[0000000[083D
o`3oool0e80[00000000EJX50?ooo`090?ooZP1E0000000002^0e03oool0ojYE0000000002/0P=Co
03T0oooo00P0omB002/0000002/0P=Co0?ooo`3DP2/00000001EZPL0oooo00<0ZUD000000000EJX0
103oool02@3oojX0E@000000000[P=@0oooo0?nZE@000000000[083Do`0n0?ooo`00V@3oool02@3o
ZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`050?ooo`050?ooe020:`0000000000E@2Z
ool00`3oool02@3oZUD000000000E@2Zool0oooo0?ooe020:`00000005FZo`0i0?ooo`090?nZE@00
0000001E0:[oo`3oool0oonZ05D000000000EJ[o00@0oooo00T0ojYE0000000005D0Z_oo0?ooo`3o
om@0P2/00000001EZ_l0>P3oool02@3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`06
0?ooo`040?nZE@00000002^00=Coo`<0oooo00T0ojYE0000000005D0Z_oo0?ooo`3oom@0P2/00000
001EZ_l0A@3oool0103oojX0E@000000E@2Zoom50?ooo`040?ooZP1E0000001E0:[oo`D0oooo00D0
oooD080[00000000001E0:[oo`030?ooo`090?nZE@000000001E0:[oo`3oool0oooD080[00000000
EJ[o03l0oooo00@0oonZ05D0000005D0Z_oo103oool02@3oZUD000000000E@2Zool0oooo0?ooe020
:`00000005FZo`0n0?ooo`040?ooZP1E0000001E0:[oo`H0oooo00@0ojYE00000000:h00e?oo0`3o
ool02@3oZUD000000000E@2Zool0oooo0?ooe020:`00000005FZo`0n0?ooo`00V@3oool02@3oojX0
E@000000001EZ_l0oooo0?nZE@000000001E0:[oo`060?ooo`050?ooe020:`0000000000E@2Zool0
1`3oool0103oom@0P2/00000000[P=@i0?ooo`090?ooZP1E0000000005FZo`3oool0ojYE00000000
05D0Z_oo00T0oooo00@0oooD080[00000000:h3D>P3oool02@3oojX0E@000000001EZ_l0oooo0?nZ
E@000000001E0:[oo`060?ooo`040?oDP00[0000000[083Do`P0oooo00@0oooD080[00000000:h3D
@P3oool01`2ZE@00000000000000EH00P2/00000:`20e?l0@P3oool01`2ZE@00000000000000EH00
P2/00000:`20e?l01P3oool01@3oom@0P2/00000000005D0Z_oo00L0oooo00@0oooD080[00000000
:h3D?03oool01`2ZE@00000000000000EH00P2/00000:`20e?l02@3oool0103oom@0P2/00000000[
P=@k0?ooo`070:YE000000000000001EP020:`00000[083Do`060?ooo`040?oDP00[0000000[083D
o`P0oooo00@0oooD080[00000000:h3D?P3oool009X0oooo00<0ojYE0000000000000`0000000`1E
Z_l0oooo0?ooo`060?ooo`0<0?ooe020:`0000000000E@2Zool0oooo0?ooZP1E0000000[083Do`3o
ool0ojYE0P0000000`1EZ_l0oooo0?ooo`0h0?ooo`030?nZE@000000000000<0000000<0EJ[o0?oo
o`3oool00`3oool01P3oojX0E@000000:`20e?l0oooo0?nZE@80000000<0EJ[o0?ooo`3oool0>@3o
ool00`3oZUD00000000000030000000305FZo`3oool0oooo00D0oooo00@0oooD080[00000000:h3D
0`3oool01P3oojX0E@000000:`20e?l0oooo0?nZE@80000000<0EJ[o0?ooo`3oool0?P3oool00`3o
om@0P2/0000000050000000305FZo`3oool0oooo03h0oooo00<0oooD080[000000001@0000000`1E
Z_l0oooo0?ooo`050?ooo`0<0?ooe020:`0000000000E@2Zool0oooo0?ooZP1E0000000[083Do`3o
ool0ojYE0P0000000`1EZ_l0oooo0?ooo`0h0?ooo`030?ooe020:`00000000D0000000<0EJ[o0?oo
o`3oool00P3oool01P3oojX0E@000000:`20e?l0oooo0?nZE@80000000<0EJ[o0?ooo`3oool0=`3o
ool00`3oom@0P2/0000000050000000305FZo`3oool0oooo00@0oooo00@0oooD080[00000000:h3D
0`3oool01P3oojX0E@000000:`20e?l0oooo0?nZE@80000000<0EJ[o0?ooo`3oool0?03oool009X0
oooo00<0oonZ05D0000000000P0000000`0005D0Z_oo0?ooo`080?ooo`070?ooe020:`000000001E
ZP3oool0oooD080[000500000003000[P03Dool0oooo03T0oooo00<0oonZ05D0000000000P000000
0`0005D0Z_oo0?ooo`040?ooo`030?ooe020:`00000000@0000000<002^00=Coo`3oool0>P3oool0
0`3oojX0E@0000000002000000030000E@2Zool0oooo00L0oooo00@0ojYE0000000005D0Z_oo0P3o
ool00`3oom@0P2/00000000400000003000[P03Dool0oooo03l0oooo00H0ojYE0000000002/0P=Co
0?ooo`3DP2/20000000305FZo`3oool0oooo03h0oooo00H0ojYE0000000002/0P=Co0?ooo`3DP2/2
0000000305FZo`3oool0oooo00H0oooo00L0oooD080[0000000005FZ0?ooo`3oom@0P2/000D00000
00<002^00=Coo`3oool0>@3oool01P3oZUD000000000:`20e?l0oooo0=B0:`80000000<0EJ[o0?oo
o`3oool00P3oool00`3oom@0P2/00000000400000003000[P03Dool0oooo03P0oooo00H0ojYE0000
000002/0P=Co0?ooo`3DP2/20000000305FZo`3oool0oooo00D0oooo00@0ojYE0000000005D0Z_oo
0P3oool00`3oom@0P2/00000000400000003000[P03Dool0oooo03d0oooo002I0?ooo`090?ooe020
:`00000002^0e03oool0e80[00000000:h00e?oo00T0oooo00H0omB002/0000002/0P=Co0?ooo`2Z
E@0400000003001EZP3oool0oooo03T0oooo00T0oooD080[00000000:h3D0?ooo`3DP2/00000000[
P03Dool01@3oool00`2ZE@0000000000000200000003001EZP3oool0oooo03X0oooo00T0oooD080[
00000000:h3D0?ooo`3DP2/00000000[P03Dool01`3oool0103oom@0P2/00000000[P=@30?ooo`03
0:YE0000000000000080000000<005FZ0?ooo`3oool0@03oool02@3DP2/00000000[P03Dool0oooo
0?ooZP1E0000000[083Do`100?ooo`090=B0:`00000002^00=Coo`3oool0oonZ05D0000002/0P=Co
00T0oooo00H0omB002/0000002/0P=Co0?ooo`2ZE@0400000003001EZP3oool0oooo03X0oooo00T0
e80[00000000:h00e?oo0?ooo`3oojX0E@000000:`20e?l01@3oool00`2ZE@000000000000020000
0003001EZP3oool0oooo03T0oooo00T0e80[00000000:h00e?oo0?ooo`3oojX0E@000000:`20e?l0
1`3oool0103oom@0P2/00000000[P=@30?ooo`030:YE0000000000000080000000<005FZ0?ooo`3o
ool0?P3oool009T0oooo00T0oonZ05D0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0103oool0
3@3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`3oool0e80[00000000EJX0?P3oool0
2@3oojX0E@000000:`20e?l0oooo0?oDP00[0000001E0:[oo`050?ooo`030=B0:`00000005FZ03l0
oooo00T0oonZ05D0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0203oool0103oZUD000000000
E@2Zool20?ooo`030=B0:`00000005FZ04D0oooo00T0e80[00000000:h00e?oo0?ooo`3oojX0E@00
0000E@2Zool0@03oool02@3DP2/00000000[P03Dool0oooo0?ooZP1E0000001E0:[oo`040?ooo`0=
0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?ooo`3DP2/00000001EZP0o0?ooo`09
0=B0:`00000002^00=Coo`3oool0oonZ05D0000005D0Z_oo00D0oooo00<0e80[00000000EJX0?P3o
ool02@3DP2/00000000[P03Dool0oooo0?ooZP1E0000001E0:[oo`080?ooo`040?nZE@000000001E
0:[oo`80oooo00<0e80[00000000EJX0@`3oool009T0oooo00T0oonZ05D000000000:h3D0?ooo`3D
P2/000000000E@2Zool0103oool03P3oojX0E@000000001EZ_l0oooo0?nZE@000000000[083Do`3o
ool0omB002/00000:h00e?oo?@3oool02@3oojX0E@000000000[P=@0oooo0=B0:`000000001E0:[o
o`050?ooo`040?oDP00[000002^00=Cooch0oooo00T0oonZ05D000000000:h3D0?ooo`3DP2/00000
0000E@2Zool02@3oool02@2ZE@000000000[P03Dool0oooo0?oDP00[000002^00=Coo`140?ooo`09
0?nZE@000000000[083Do`3oool0e80[00000000:h00e?oo0400oooo00T0ojYE0000000002/0P=Co
0?ooo`3DP2/00000000[P03Dool0103oool03P3oojX0E@000000001EZ_l0oooo0?nZE@000000000[
083Do`3oool0omB002/00000:h00e?oo?P3oool02@3oZUD000000000:`20e?l0oooo0=B0:`000000
02^00=Coo`050?ooo`040?oDP00[000002^00=Coocd0oooo00T0ojYE0000000002/0P=Co0?ooo`3D
P2/00000000[P03Dool02@3oool02@2ZE@000000000[P03Dool0oooo0?oDP00[000002^00=Coo`12
0?ooo`00VP3oool00`3DP2/00000000000030000000302^0e03oool0oooo00@0oooo00<0ZUD00000
000000000`0000001@00EJX0oooo0?ooo`3oojX0E@0000@0000000<0001E0:[oo`3oool0>@3oool0
0`3DP2/00000000000030000000302^0e03oool0oooo00@0oooo00<0oonZ05D0000000000`000000
0`0005D0Z_oo0?ooo`0j0?ooo`030=B0:`000000000000<0000000<0:h3D0?ooo`3oool00`3oool0
0`3oZUD00000000000050000000405FZo`3oool0oonZ05D000@0000000<0001E0:[oo`3oool0?`3o
ool00`3oom@0P2/000000003000000030000:`20e?l0oooo0400oooo00<0oooD080[000000000`00
00000`0002/0P=Co0?ooo`050?ooo`030:YE00000000000000<0000000D005FZ0?ooo`3oool0oonZ
05D00004000000030000E@2Zool0oooo03T0oooo00<0oooD080[000000000`0000000`0002/0P=Co
0?ooo`050?ooo`030?ooZP1E0000000000<0000000<0001E0:[oo`3oool0>03oool00`3oom@0P2/0
00000003000000030000:`20e?l0oooo00@0oooo00<0ojYE0000000000001@000000101EZ_l0oooo
0?ooZP1E0004000000030000E@2Zool0oooo03d0oooo002K0?ooo`050:YE0000000000000000000[
P=@0203oool01@3DP2/0000000000000000005FZ00<0oooo00<0oooD080[000000000`0000000`00
05D0Z_oo0?ooo`0j0?ooo`050:YE0000000000000000000[P=@01`3oool00`3oom@0P2/000000003
000000030000E@2Zool0oooo03/0oooo00D0ZUD0000000000000000002^0e0060?ooo`030?nZE@00
0000000000D0000000@0EJ[o0?ooo`3oom@0P2/0100000000`0005D0Z_oo0?ooo`110?ooo`050:YE
0000000000000000:`20e?l0A03oool01@2ZE@0000000000000002/0P=Co00P0oooo00D0e80[0000
000000000000001EZP030?ooo`030?ooe020:`00000000<0000000<0001E0:[oo`3oool0>`3oool0
1@2ZE@0000000000000002/0P=Co00L0oooo00<0oooD080[000000000`0000000`0005D0Z_oo0?oo
o`0j0?ooo`050:YE0000000000000000:`20e?l01P3oool00`3oZUD00000000000050000000405FZ
o`3oool0oooD080[00@0000000<0001E0:[oo`3oool0?@3oool00?l0ooooo`3oooo`0?ooo`00o`3o
oooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00
oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?oo
ool0ooool03oool00?l0ooooo`3oooo`0?ooo`00H03ooooo00000?l00000K@00000S0?ooo`00D03o
ool01@3oZUD00000000000000000EJ[o00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0240oooo001?0?ooo`030?nZE@000000000000<0000000<0
EJ[o0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`L0o`000`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0240oooo001>0?ooo`090?ooe020:`00000002^0e03oool0e80[
00000000:h00e?oo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00@000000?ooo`3oool0oooo1P3o00060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool08@3oool004h0oooo00T0omB002/0000002/0P=Co0?ooo`3oe800
:`000000E@2Zool02@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo103o
000A0?ooo`030000003oool0oooo0240oooo001>0?ooo`090?oDP00[0000001E0:[oo`3oool0oonZ
05D0000002/0P=Co00T0oooo00<000000?ooo`3oool0o`3ooooo0?oooe80oooo103o000C0?ooo`03
0000003oool0oooo0240oooo001>0?ooo`090?nZE@000000001E0:[oo`3oool0oonZ05D000000000
EJ[o00T0oooo1@00003o0?ooool0ooooC`3oool40?l00100oooo1@00000S0?ooo`00CP3oool02@3o
ZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`090?ooo`030000003oool0oooo0?l0oooo
o`3ooom@0?ooo`@0o`005@3oool00`000000oooo0?ooo`0Q0?ooo`00CP3oool02@3oe800:`000000
E@2Zool0oooo0?ooZP1E0000000[083Do`090?ooo`030000003oool0oooo0?l0ooooo`3ooom>0?oo
o`@0o`005`3oool00`000000oooo0?ooo`0Q0?ooo`00CP3oool02@3oe800:`000000:`20e?l0oooo
0?oDP00[0000001E0:[oo`090?ooo`030000003oool0oooo0?l0ooooo`3ooom=0?ooo`@0o`00603o
ool00`000000oooo0?ooo`0Q0?ooo`00CP3oool02@3oom@0P2/00000000[P=@0oooo0=B0:`000000
02^00=Coo`090?ooo`030000003oool0oooo0?l0ooooo`3ooom<0?ooo`@0o`006@3oool00`000000
oooo0?ooo`0Q0?ooo`00C`3oool00`3oZUD00000000000030000000305FZo`3oool0oooo00P0oooo
00<000000?ooo`3oool0o`3ooooo0?ooodX0oooo103o000K0?ooo`030000003oool0oooo0240oooo
001@0?ooo`050?nZE@00000000000000001EZ_l02`3oool00`000000oooo0?ooo`3o0?ooool0oooo
B03oool50?l001`0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3o
oooo0?ooodL0oooo103o000N0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo0?l0ooooo`3ooom60?ooo`@0o`007`3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`00
0000oooo0?ooo`3o0?ooool0ooooA03oool50?l00200oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0o`3ooooo0?oood<0oooo103o000R0?ooo`030000003oool0oooo0240
oooo001P0?ooo`030000003oool0oooo0?l0ooooo`3ooom20?ooo`@0o`008`3oool00`000000oooo
0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooool0oooo@03oool50?l002@0oooo00<0
00000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooooo0?ooocl0oooo103o000V
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0ooooo`3oooln0?oo
o`<0o`00:03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool300000?l0ooooo`3ooolm0?ooo`<0
o`009`3oool3000002<0oooo001P0?ooo`030000003oool0oooo0?l0ooooo`3ooolk0?ooo`@0o`00
:P3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooool0oooo>P3o
ool40?l002/0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooooo
0?ooocT0oooo0`3o000]0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo
0?l0ooooo`3ooolg0?ooo`@0o`00;P3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000
oooo0?ooo`3o0?ooool0oooo=P3oool40?l002l0oooo00<000000?ooo`3oool08@3oool00600oooo
00<000000?ooo`3oool0o`3ooooo0?ooocD0oooo0`3o000a0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo0?l0ooooo`3ooolc0?ooo`@0o`00<P3oool00`000000oooo0?oo
o`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooool0oooo<P3oool40?l003<0oooo00<00000
0?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooooo0?oooc40oooo0`3o000e0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0ooooo`3oool_0?ooo`@0
o`00=P3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooool0oooo
;P3oool40?l003L0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3o
oooo0?ooob`0oooo103o000i0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo0?l0ooooo`3oool[0?ooo`@0o`00>P3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`00
0000oooo0?ooo`3o0?ooool0oooo:P3oool30?l003`0oooo00<000000?ooo`3oool08@3oool00600
oooo0`00003o0?ooool0oooo:03oool40?l003/0oooo0`00000S0?ooo`00H03oool00`000000oooo
0?ooo`3o0?ooool0oooo9`3oool40?l003h0oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool0o`3ooooo0?ooobH0oooo0`3o00100?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo0?l0ooooo`3ooolT0?ooo`@0o`00@@3oool00`000000oooo0?ooo`0Q
0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooool0oooo8`3oool40?l00480oooo00<000000?oo
o`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooooo0?ooob80oooo0`3o00140?ooo`03
0000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0ooooo`3ooolP0?ooo`@0o`00
A@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooool0oooo7`3o
ool40?l004H0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooooo
0?oooah0oooo0`3o00180?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo
0?l0ooooo`3ooolK0?ooo`D0o`00B@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000
oooo0?ooo`3o0?ooool0oooo6P3oool50?l004X0oooo00<000000?ooo`3oool08@3oool00600oooo
00<000000?ooo`3oool0o`3ooooo0?oooaT0oooo0`3o001=0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo0?l0ooooo`3ooolH0?ooo`<0o`00CP3oool00`000000oooo0?oo
o`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooool0oooo5P3oool40?l004l0oooo00<00000
0?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooooo0?oooaD0oooo103o001@0?oo
o`030000003oool0oooo0240oooo001P0?ooo`<00000o`3ooooo0?oooa@0oooo0`3o001@0?ooo`<0
00008`3oool00600oooo00<000000?ooo`3oool0o`3ooooo0?oooa80oooo103o001C0?ooo`030000
003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0ooooo`3ooolA0?ooo`@0o`00E03o
ool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooool0oooo403oool3
0?l005H0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`h0oooo103o001G0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0
ooooo`3oool=0?ooo`@0o`00F03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo
0?ooo`3o0?ooool0oooo2`3oool40?l005X0oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`X0oooo103o001K0?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo0?l0ooooo`3oool80?ooo`@0o`00G@3oool00`000000oooo0?ooo`0Q
0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooool0oooo1`3oool40?l005h0oooo00<000000?oo
o`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooooo0?ooo`H0oooo0`3o001P0?ooo`03
0000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0ooooo`3oool50?ooo`<0o`00
H@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooool0oooo0`3o
ool40?l00680oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooooo
0?ooo`80oooo103o001S0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo
0?l0ooooo`3oool10?ooo`<0o`00I@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool300000?l0
ooooo`3oool30?l006@0oooo0`00000S0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooood0oooo
103o001W0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0ooooo03o
ool40?l006P0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooook
0?ooo`<0o`00JP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?oo
ooT0oooo103o001[0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0
oooom`3oool50?l006`0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0
o`3oooof0?ooo`@0o`00KP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?oo
o`3o0?ooooD0oooo0`3o001`0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo0?l0ooool`3oool40?l00740oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?oo
o`3oool0o`3oooob0?ooo`@0o`00LP3oool00`000000oooo0?ooo`0Q0?ooo`00?`3oool0103oom@0
P2/00000000[P=@40?ooo`050?nZE@00000000000000001EZ_l0103oool01@3oZUD0000000000000
0000EJ[o00/0oooo00<000000?ooo`3oool0o`3ooooa0?ooo`<0o`00M03oool00`000000oooo0?oo
o`0Q0?ooo`00?`3oool0103oom@0P2/00000000[P=@30?ooo`030?nZE@000000000000<0000000@0
EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo
l03oool30?l007D0oooo00<000000?ooo`3oool08@3oool003l0oooo00@0oooD080[00000000:h3D
0P3oool04P3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0
oooo0=B0:`00000002^00=Coo`T0oooo00<000000?ooo`3oool0o`3oooo^0?ooo`@0o`00MP3oool0
0`000000oooo0?ooo`0Q0?ooo`00?`3oool0103oom@0P2/00000000[P=@20?ooo`0B0?oDP00[0000
000[083Do`3oool0omB002/0000005D0Z_oo0?oDP00[0000000[083Do`3oool0omB002/0000005D0
Z_oo2@3oool00`000000oooo0?ooo`3o0?ooond0oooo103o001g0?ooo`030000003oool0oooo0240
oooo000o0?ooo`040?ooe020:`00000002^0e080oooo0180omB002/0000005D0Z_oo0?ooo`3oojX0
E@000000:`20e?l0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l90?ooo`030000003o
ool0oooo0?l0ooook03oool30?l007T0oooo00<000000?ooo`3oool08@3oool003l0oooo00@0oooD
080[00000000:h3D0P3oool04P3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`3oZUD0
00000000E@2Zool0oooo0?ooZP1E0000000005FZo`T0oooo1@00003o0?ooonT0oooo0`3o001f0?oo
o`D000008`3oool003l0oooo00@0oooD080[00000000:h3D0P3oool04P3oZUD000000000E@2Zool0
oooo0?ooZP1E0000000005FZo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`T0oooo
00<000000?ooo`3oool0o`3ooooZ0?ooo`<0o`00N`3oool00`000000oooo0?ooo`0Q0?ooo`00?03o
ool01`3oom@0P2/002^0e03oom@0P2/00000000[P=@00P3oool04P3oe800:`000000E@2Zool0oooo
0?ooZP1E0000000[083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`T0oooo00<0
00000?ooo`3oool0o`3ooooY0?ooo`<0o`00O03oool00`000000oooo0?ooo`0Q0?ooo`00?03oool0
1`3oom@0P2/00000000002/0:b/00000000[P=@00P3oool04P3oe800:`000000:`20e?l0oooo0?oD
P00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`T0oooo00<00000
0?ooo`3oool0o`3ooooW0?ooo`@0o`00O@3oool00`000000oooo0?ooo`0Q0?ooo`00?P3oool01@2Z
E@000000000000000000:h3D0080oooo0180oooD080[00000000:h3D0?ooo`3DP2/00000000[P03D
ool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool90?ooo`030000003oool0oooo0?l0
ooooiP3oool40?l007h0oooo00<000000?ooo`3oool08@3oool003l0oooo00@0ojYE000000000000
:h3D0`3oool00`3oZUD00000000000030000000405FZo`3oool0oooo0?nZE@D0000000<0EJ[o0?oo
o`3oool0203oool00`000000oooo0?ooo`3o0?ooonD0oooo0`3o00200?ooo`030000003oool0oooo
0240oooo00100?ooo`030:YE00000000:h3D00@0oooo00D0ojYE000000000000000005FZo`040?oo
o`050?nZE@00000000000000001EZ_l02`3oool00`000000oooo0?ooo`3o0?ooon@0oooo0`3o0021
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0ooooh`3oool30?l0
0880oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooooR0?ooo`<0
o`00P`3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooon00oooo
103o00240?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooog`3o
ool40?l008D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooooM
0?ooo`@0o`00Q`3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?oo
om`0oooo103o00280?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0
oooofP3oool40?l008X0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0
o`3ooooI0?ooo`@0o`00R`3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool300000?l0oooof03o
ool30?l008/0oooo0`00000S0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooomH0oooo103o002>
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0ooooe@3oool40?l0
08l0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooooD0?ooo`<0
o`00T@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooom<0oooo
0`3o002B0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0ooood@3o
ool40?l009<0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3oooo@
0?ooo`@0o`00U03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?oo
oll0oooo0`3o002F0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0
oooocP3oool30?l009L0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0
o`3oooo<0?ooo`@0o`00V03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?oo
o`3o0?oool/0oooo103o002I0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo0?l0oooob@3oool40?l009/0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?oo
o`3oool0o`3oooo80?ooo`@0o`00W03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000
oooo0?ooo`3o0?ooolH0oooo103o002N0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000
003oool0oooo0?l0ooooa@3oool40?l009l0oooo00<000000?ooo`3oool08@3oool00600oooo0`00
003o0?oool@0oooo0`3o002O0?ooo`<000008`3oool00600oooo00<000000?ooo`3oool0o`3oooo3
0?ooo`<0o`00XP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?oo
ol80oooo0`3o002S0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0
oooo`03oool40?l00:@0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0
o`3ooono0?ooo`@0o`00Y@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?oo
o`3o0?oookh0oooo0`3o002W0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo0?l0oooo_@3oool30?l00:P0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?oo
o`3oool0o`3ooonl0?ooo`<0o`00Z@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000
oooo0?ooo`3o0?oook/0oooo0`3o002Z0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000
003oool0oooo0?l0oooo^@3oool40?l00:/0oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool0o`3ooonh0?ooo`@0o`00[03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool0
0`000000oooo0?ooo`3o0?oookH0oooo103o002^0?ooo`030000003oool0oooo0240oooo001P0?oo
o`030000003oool0oooo0?l0oooo]@3oool40?l00:l0oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0o`3ooonc0?ooo`@0o`00/@3oool00`000000oooo0?ooo`0Q0?ooo`00
H03oool00`000000oooo0?ooo`3o0?oook80oooo103o002b0?ooo`030000003oool0oooo0240oooo
001P0?ooo`<00000o`3ooona0?ooo`<0o`00/P3oool3000002<0oooo001P0?ooo`030000003oool0
oooo0?l0oooo[`3oool40?l00;D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?oo
o`3oool0o`3ooon^0?ooo`@0o`00]P3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000
oooo0?ooo`3o0?ooojd0oooo0`3o002h0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000
003oool0oooo0?l0oooo[03oool30?l00;T0oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool0o`3ooonZ0?ooo`@0o`00^P3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool0
0`000000oooo0?ooo`3o0?ooojT0oooo103o002k0?ooo`030000003oool0oooo0240oooo001P0?oo
o`030000003oool0oooo0?l0ooooZ03oool30?l00;d0oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0o`3ooonW0?ooo`<0o`00_P3oool00`000000oooo0?ooo`0Q0?ooo`00
H03oool00`000000oooo0?ooo`3o0?ooojD0oooo103o002o0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo0?l0ooooY03oool40?l00<00oooo00<000000?ooo`3oool08@3o
ool00600oooo00<000000?ooo`3oool0o`3ooonS0?ooo`<0o`00`P3oool00`000000oooo0?ooo`0Q
0?ooo`00H03oool00`000000oooo0?ooo`3o0?oooj80oooo0`3o00330?ooo`030000003oool0oooo
0240oooo001P0?ooo`030000003oool0oooo0?l0ooooX03oool40?l00<@0oooo00<000000?ooo`3o
ool08@3oool00600oooo00<000000?ooo`3oool0o`3ooonO0?ooo`@0o`00a@3oool00`000000oooo
0?ooo`0Q0?ooo`00H03oool300000?l0ooooWP3oool30?l00<D0oooo0`00000S0?ooo`00H03oool0
0`000000oooo0?ooo`3o0?oooi`0oooo103o00380?ooo`030000003oool0oooo0240oooo001P0?oo
o`030000003oool0oooo0?l0ooooV`3oool40?l00<T0oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0o`3ooonJ0?ooo`<0o`00b`3oool00`000000oooo0?ooo`0Q0?ooo`00
H03oool00`000000oooo0?ooo`3o0?oooiT0oooo0`3o003<0?ooo`030000003oool0oooo0240oooo
000_0?ooo`030?nZE@0005D0Z_oo02h0oooo00<000000?ooo`3oool0o`3ooonG0?ooo`@0o`00c@3o
ool00`000000oooo0?ooo`0Q0?ooo`00;03oool01P3oe800:`00000000000000001E0:[oobh0oooo
00<000000?ooo`3oool0o`3ooonF0?ooo`@0o`00cP3oool00`000000oooo0?ooo`0Q0?ooo`00:@3o
ool00`3oojX0E@000000000400000003000[P03Dool0oooo02d0oooo00<000000?ooo`3oool0o`3o
oonE0?ooo`<0o`00d03oool00`000000oooo0?ooo`0Q0?ooo`009P3oool00`3oom@0P2/000000005
0000000305FZo`3oool0oooo02l0oooo00<000000?ooo`3oool0o`3ooonD0?ooo`<0o`00d@3oool0
0`000000oooo0?ooo`0Q0?ooo`00903oool00`3oojX0E@000000000300000005001EZP3oool0ZUD0
0000001EZ_l0<@3oool00`000000oooo0?ooo`3o0?oooi80oooo103o003B0?ooo`030000003oool0
oooo0240oooo000T0?ooo`040?ooZP1E00000000001EZP@0oooo00<0ZUD00000001EZ_l0<@3oool0
0`000000oooo0?ooo`3o0?oooi40oooo103o003C0?ooo`030000003oool0oooo0240oooo000T0?oo
o`030?ooZP1E0000000000<0000000D005FZ0?ooo`2ZE@00000005FZo`0=0?ooo`030=B0:`000000
000000D0000000@0EJ[o0?ooo`3oool0ojYE0`0000000`1EZ_l0oooo0?ooo`020?ooo`050?nZE@00
000000000000001EZ_l02`3oool00`000000oooo0?ooo`3o0?oooi00oooo0`3o003E0?ooo`030000
003oool0oooo0240oooo000V0?ooo`030?ooZP1E0000000000D0000000<0EJ[o0?ooo`3oool02`3o
ool00`3oe800:`00000000050000000305FZo`3oool0ojYE00D0000000@0EJ[o0?ooo`3oool0ojYE
1@0000000`1EZ_l0oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooS`3oool30?l00=H0oooo
00<000000?ooo`3oool08@3oool002T0oooo00<0omB002/000000000100000000`00:h00e?oo0?oo
o`0:0?ooo`040:YE00000000001E0:[oo`@0oooo0180oooD080[00000000:h3D0?ooo`3DP2/00000
000[P03Dool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool90?ooo`030000003oool0
oooo0?l0ooooS@3oool40?l00=L0oooo00<000000?ooo`3oool08@3oool002`0oooo00H0ojYE0000
0000000000000000E@2Zool;0?ooo`050?ooe020:`0000000000E@2Zool00`3oool04P3oe800:`00
0000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E
0:[oo`T0oooo00<000000?ooo`3oool0o`3ooon<0?ooo`@0o`00f03oool00`000000oooo0?ooo`0Q
0?ooo`00;`3oool00`3DP2/0001E0:[oo`0<0?ooo`050?ooe020:`0000000000E@2Zool00P3oool0
4P3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`3oe800:`000000E@2Zool0oooo0?oo
ZP1E0000000[083Do`T0oooo1@00003o0?ooohT0oooo0`3o003F0?ooo`D000008`3oool003l0oooo
01P0oooD080[00000000001E0:[oo`3oool0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001E
Z_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l90?ooo`030000003oool0oooo0?l0
ooooR@3oool40?l00=/0oooo00<000000?ooo`3oool08@3oool00400oooo01L0oooD080[00000000
05FZ0?ooo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`3oZUD000000000E@2Zool0
oooo0?ooZP1E0000000005FZo`090?ooo`030000003oool0oooo0?l0ooooR03oool40?l00=`0oooo
00<000000?ooo`3oool08@3oool002@0oooo00<0oonZ05D0000000002@0000000`0005D0Z_oo0?oo
o`0>0?ooo`0F0?oDP00[0000000[083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083D
o`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`T0oooo00<000000?ooo`3oool0o`3o
oon70?ooo`<0o`00gP3oool00`000000oooo0?ooo`0Q0?ooo`00903oool00`3oojX0E@0000000009
000000030000E@2Zool0oooo00T0oooo01/0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001E
Z_l0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3o
e800:`000000E@2Zool02@3oool00`000000oooo0?ooo`3o0?ooohH0oooo0`3o003O0?ooo`030000
003oool0oooo0240oooo000l0?ooo`0K0?ooZP1E0000000005FZo`3oool0ojYE0000000002/0P=Co
0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo0?ooe020:`00000002^0e03oool0e80[
00000000:h00e?oo00T0oooo00<000000?ooo`3oool0o`3ooon40?ooo`@0o`00h03oool00`000000
oooo0?ooo`0Q0?ooo`009`3oool0103oojX0E@00000[P03DoolB0?ooo`030:YE00000000000000<0
000000@005FZ0?ooo`3oool0ojYE1@000000101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0
oooo00P0oooo00<000000?ooo`3oool0o`3ooon30?ooo`@0o`00h@3oool00`000000oooo0?ooo`0Q
0?ooo`009@3oool00`3oom@0P2/0000000080000000305FZo`3oool0oooo00/0oooo00D0e80[0000
000000000000001EZP040?ooo`050?nZE@00000000000000001EZ_l0103oool01@3oZUD000000000
00000000EJ[o00/0oooo00<000000?ooo`3oool0o`3ooon20?ooo`<0o`00h`3oool00`000000oooo
0?ooo`0Q0?ooo`009@3oool00`3DP2/000000000000800000003000[P03Dool0oooo02d0oooo00<0
00000?ooo`3oool0o`3ooon10?ooo`<0o`00i03oool00`000000oooo0?ooo`0Q0?ooo`009`3oool0
103oojX0E@00000[P03Dool30?ooo`040?ooe020:`00001E0:[oobh0oooo00<000000?ooo`3oool0
o`3ooomo0?ooo`@0o`00i@3oool00`000000oooo0?ooo`0Q0?ooo`009`3oool0103oojX0E@00000[
P03Dool30?ooo`040?ooZP1E000002^00=Coobh0oooo00<000000?ooo`3oool0o`3ooomn0?ooo`@0
o`00iP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooogd0oooo
0`3o003X0?ooo`030000003oool0oooo0240oooo000T0?ooo`050?ooZP1E0000001E0:[oZP1E0000
1`0000000`0005D0Z_oo0?ooo`0]0?ooo`030000003oool0oooo0?l0ooooO03oool30?l00>T0oooo
00<000000?ooo`3oool08@3oool002@0oooo00D0oonZ05D0000005D0Z_nZ05D00007000000030000
E@2Zool0oooo02d0oooo00<000000?ooo`3oool0o`3ooomj0?ooo`@0o`00jP3oool00`000000oooo
0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooogT0oooo103o003[0?ooo`030000003o
ool0oooo0240oooo000W0?ooo`040?ooZP1E000002^00=CoocD0oooo0`00003o0?ooogP0oooo0`3o
003[0?ooo`<000008`3oool002D0oooo00<0oooD080[00000000200000000`1EZ_l0oooo0?ooo`0]
0?ooo`030000003oool0oooo0?l0ooooMP3oool40?l00>h0oooo00<000000?ooo`3oool08@3oool0
02D0oooo00<0e80[000000000000200000000`00:h00e?oo0?ooo`0]0?ooo`030000003oool0oooo
0?l0ooooM@3oool40?l00>l0oooo00<000000?ooo`3oool08@3oool002L0oooo00@0oonZ05D00000
:h00e?oo0`3oool0103oom@0P2/00000E@2Zool^0?ooo`030000003oool0oooo0?l0ooooM03oool3
0?l00?40oooo00<000000?ooo`3oool08@3oool002L0oooo00@0oonZ05D00000:h00e?oo0`3oool0
103oojX0E@00000[P03Dool^0?ooo`030000003oool0oooo0?l0ooooL`3oool30?l00?80oooo00<0
00000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3oooma0?ooo`@0o`00l`3oool0
0`000000oooo0?ooo`0Q0?ooo`009`3oool00`3oojX0E@000000000500000003000[P03Dool0oooo
02h0oooo00<000000?ooo`3oool0o`3ooom`0?ooo`@0o`00m03oool00`000000oooo0?ooo`0Q0?oo
o`009`3oool00`3oojX0E@000000000600000003001EZP3oool0oooo02d0oooo00<000000?ooo`3o
ool0o`3ooom_0?ooo`<0o`00mP3oool00`000000oooo0?ooo`0Q0?ooo`00;P3oool0103oe800:`00
0000E@2Zool^0?ooo`030000003oool0oooo0?l0ooooKP3oool30?l00?L0oooo00<000000?ooo`3o
ool08@3oool002l0oooo00<0ZUD00000E@2Zool0;P3oool00`000000oooo0?ooo`3o0?ooof`0oooo
103o003h0?ooo`030000003oool0oooo0240oooo000^0?ooo`040?ooe020:`0002^00=Coobh0oooo
00<000000?ooo`3oool0o`3ooom[0?ooo`@0o`00n@3oool00`000000oooo0?ooo`0Q0?ooo`00;P3o
ool00`3oZUD0000005FZo`0_0?ooo`030000003oool0oooo0?l0ooooJP3oool30?l00?/0oooo00<0
00000?ooo`3oool08@3oool002L0oooo00<0oonZ05D0000000001P0000000`0005D0Z_oo0?ooo`0]
0?ooo`030000003oool0oooo0?l0ooooJ@3oool30?l00?`0oooo00<000000?ooo`3oool08@3oool0
02L0oooo00<0oonZ05D0000000001P0000000`0005D0Z_oo0?ooo`0]0?ooo`030000003oool0oooo
0?l0ooooI`3oool40?l00?d0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3o
ool0o`3ooomV0?ooo`@0o`00oP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool300000?l0oooo
I@3oool30?l00?h0oooo0`00000S0?ooo`00:@3oool00`3oojX0E@0000000002000000030000E@2Z
ool0oooo02l0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`<0o`00o`3oool20?ooo`030000003o
ool0oooo0240oooo000X0?ooo`030?nZE@000000000000D0000000<0EJ[o0?ooo`3oool0;@3oool0
0`000000oooo0?ooo`3o0?ooof<0oooo0`3o003o0?ooo`<0oooo00<000000?ooo`3oool08@3oool0
02L0oooo00@0oooD080[00000000:h3D0`3oool0103DP2/00000000[P03Dool^0?ooo`030000003o
ool0oooo0?l0ooooH@3oool40?l00?l0oooo103oool00`000000oooo0?ooo`0Q0?ooo`009`3oool0
103oojX0E@00000[P03Dool30?ooo`040?ooe020:`00001E0:[oobh0oooo00<000000?ooo`3oool0
o`3ooomP0?ooo`@0o`00o`3oool50?ooo`030000003oool0oooo0240oooo000W0?ooo`040?ooe020
:`0002^00=Coo`<0oooo00@0oooD080[0000:h00e?oo;P3oool00`000000oooo0?ooo`3o0?oooel0
oooo0`3o003o0?ooo`L0oooo00<000000?ooo`3oool08@3oool002P0oooo00<0ojYE0000000[P=@0
0`3oool00`3DP2/0000005FZo`0_0?ooo`030000003oool0oooo0?l0ooooGP3oool30?l00?l0oooo
203oool00`000000oooo0?ooo`0Q0?ooo`00903oool00`3oojX0E@0000000009000000030000E@2Z
ool0oooo02d0oooo00<000000?ooo`3oool0o`3ooomM0?ooo`<0o`00o`3oool90?ooo`030000003o
ool0oooo0240oooo000T0?ooo`030?ooZP1E0000000000T0000000<0001E0:[oo`3oool0;@3oool0
0`000000oooo0?ooo`3o0?oooe`0oooo0`3o003o0?ooo`X0oooo00<000000?ooo`3oool08@3oool0
0600oooo00<000000?ooo`3oool0o`3ooomK0?ooo`<0o`00o`3oool;0?ooo`030000003oool0oooo
0240oooo001P0?ooo`030000003oool0oooo0?l0ooooFP3oool30?l00?l0oooo303oool00`000000
oooo0?ooo`0Q0?ooo`00:@3oool00`3oojX0E@0000000002000000030000:`20e?l0oooo02l0oooo
00<000000?ooo`3oool0o`3ooomH0?ooo`@0o`00o`3oool=0?ooo`030000003oool0oooo0240oooo
000X0?ooo`030?nZE@000000000000D0000000<0EJ[o0?ooo`3oool0;@3oool00`000000oooo0?oo
o`3o0?oooeL0oooo103o003o0?ooo`h0oooo00<000000?ooo`3oool08@3oool002L0oooo00/0oooD
080[00000000EJ[o0?oDP00[02/0P=Co0?oDP00[000002^00=Coo`0^0?ooo`030000003oool0oooo
0?l0ooooEP3oool30?l00?l0oooo403oool00`000000oooo0?ooo`0Q0?ooo`009`3oool02`3oojX0
E@00000[P03Dool0omB002/0:`20e?l0oooo0:YE000005D0Z_oo02h0oooo00<000000?ooo`3oool0
o`3ooomE0?ooo`<0o`00o`3ooolA0?ooo`030000003oool0oooo0240oooo000W0?ooo`0;0?ooe020
:`00000[083Do`3oe800:`0[083Do`3oom@0P2/00000E@2Zool0;P3oool00`000000oooo0?ooo`3o
0?oooe@0oooo0`3o003o0?oooa80oooo00<000000?ooo`3oool08@3oool002P0oooo00T0ojYE0000
0000000000000000:`20e?l0ZUD00000000[P=@0;`3oool300000?l0ooooD`3oool30?l00?l0oooo
4@3oool3000002<0oooo000Y0?ooo`070?ooZP1E000000000000:`20e?l0e80[02^0e00`0?ooo`03
0000003oool0oooo0?l0ooooD@3oool40?l00?l0oooo503oool00`000000oooo0?ooo`0Q0?ooo`00
H03oool00`000000oooo0?ooo`3o0?oooe00oooo103o003o0?oooaD0oooo00<000000?ooo`3oool0
8@3oool002h0oooo00H0ojYE0000000005D0Z_oo0:YE000[P=@/0?ooo`030000003oool0oooo0?l0
ooooC`3oool30?l00?l0oooo5`3oool00`000000oooo0?ooo`0Q0?ooo`00;P3oool01@3oZUD00000
00000000000005FZ02d0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`<0o`00o`3ooolH0?ooo`03
0000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0ooooC03oool40?l00?l0oooo
6@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?oood/0oooo103o
003o0?oooaX0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooom:
0?ooo`<0o`00o`3ooolL0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo
0?l0ooooB@3oool30?l00?l0oooo7@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000
oooo0?ooo`3o0?ooodL0oooo103o003o0?oooah0oooo00<000000?ooo`3oool08@3oool00600oooo
00<000000?ooo`3oool0o`3ooom60?ooo`@0o`00o`3ooolO0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo0?l0ooooA@3oool30?l00?l0oooo8@3oool00`000000oooo0?oo
o`0Q0?ooo`00903oool00`3oojX0E@0000000009000000030000E@2Zool0oooo02d0oooo00<00000
0?ooo`3oool0o`3ooom40?ooo`<0o`00o`3ooolR0?ooo`030000003oool0oooo0240oooo000T0?oo
o`030?ooZP1E0000000000T0000000<0001E0:[oo`3oool0;@3oool00`000000oooo0?ooo`3o0?oo
od80oooo103o003o0?ooob<0oooo00<000000?ooo`3oool08@3oool002T0oooo00D0oonZ05D00000
000002^00=Coo`0b0?ooo`030000003oool0oooo0?l0oooo@@3oool40?l00?l0oooo903oool00`00
0000oooo0?ooo`0Q0?ooo`00:03oool01@3oojX0E@0000000000:h00e?oo03<0oooo0`00003o0?oo
od00oooo0`3o003o0?ooob@0oooo0`00000S0?ooo`009`3oool01@3oojX0E@00000000000000:h3D
03@0oooo00<000000?ooo`3oool0o`3ooolo0?ooo`<0o`00o`3ooolW0?ooo`030000003oool0oooo
0240oooo000V0?ooo`030?oDP00[0000000000@0000000<0EJ[o0?ooo`3oool0<03oool00`000000
oooo0?ooo`3o0?ooocd0oooo103o003o0?ooobP0oooo00<000000?ooo`3oool08@3oool002D0oooo
00H0omB002/000000000001E0:[oo`3DP2/3000000030000:`20e?l0oooo02l0oooo00<000000?oo
o`3oool0o`3oooll0?ooo`@0o`00o`3ooolY0?ooo`030000003oool0oooo0240oooo000T0?ooo`05
0?ooZP1E000000000000E@2Zool00P3oool00`3oom@0P2/00000000200000003000[P03Dool0oooo
02d0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`<0o`00o`3oool[0?ooo`030000003oool0oooo
0240oooo000T0?ooo`040?ooZP1E0000001E0:[oo`D0oooo00D0ojYE000000000000001E0:[oo`0^
0?ooo`030000003oool0oooo0?l0oooo>P3oool30?l00?l0oooo;03oool00`000000oooo0?ooo`0Q
0?ooo`00903oool00`3oojX0E@1E0:[oo`080?ooo`030:YE000005D0Z_oo02h0oooo00<000000?oo
o`3oool0o`3oooli0?ooo`<0o`00o`3oool]0?ooo`030000003oool0oooo0240oooo001P0?ooo`03
0000003oool0oooo0?l0oooo=`3oool40?l00?l0oooo;P3oool00`000000oooo0?ooo`0Q0?ooo`00
H03oool00`000000oooo0?ooo`3o0?ooocH0oooo103o003o0?ooobl0oooo00<000000?ooo`3oool0
8@3oool002L0oooo00<0oonZ05D0000000001P0000000`0005D0Z_oo0?ooo`0]0?ooo`030000003o
ool0oooo0?l0oooo=@3oool30?l00?l0oooo<@3oool00`000000oooo0?ooo`0Q0?ooo`009`3oool0
0`3oojX0E@0000000006000000030000E@2Zool0oooo00/0oooo00D0e80[000000000000000005FZ
o`040?ooo`050?nZE@00000000000000001EZ_l0103oool01@3oZUD00000000000000000EJ[o00/0
oooo00<000000?ooo`3oool0o`3ooold0?ooo`<0o`00o`3ooolb0?ooo`030000003oool0oooo0240
oooo000X0?ooo`030?nZE@000000EJ[o0180oooo00<0e80[0000000000000`000000100[P=@0oooo
0?ooo`3oZUD50000000405FZo`3oool0oooo0?nZE@D0000000<0EJ[o0?ooo`3oool0203oool00`00
0000oooo0?ooo`3o0?oooc<0oooo0`3o003o0?oooc<0oooo00<000000?ooo`3oool08@3oool002L0
oooo00@0oooD080[0000:h00e?oo4@3oool06`3oe800:`000000000[P=@0oooo0=B0:`000000001E
0:[oo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo
0=B0:`00000002^00=Coo`090?ooo`030000003oool0oooo0?l0oooo<@3oool40?l00?l0oooo=03o
ool00`000000oooo0?ooo`0Q0?ooo`009`3oool0103oojX0E@000000E@2ZoolA0?ooo`0K0?nZE@00
0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000000[083Do`3oool0omB002/00000
05D0Z_oo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo00T0oooo00<000000?ooo`3o
ool0o`3oool`0?ooo`@0o`00o`3ooole0?ooo`030000003oool0oooo0240oooo000W0?ooo`030?oo
e020:`00000000H0000000<0001E0:[oo`3oool03P3oool05P3oojX0E@000000:`20e?l0omB002/0
000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000
:`20e?l90?ooo`030000003oool0oooo0?l0oooo;`3oool30?l00?l0oooo=`3oool00`000000oooo
0?ooo`0Q0?ooo`00:03oool00`3oojX0E@0000000005000000030000E@2Zool0oooo00h0oooo01H0
ojYE0000000005D0Z_oo0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000
001E0:[oo`3oool0oonZ05D000000000EJ[o2@3oool500000?l0oooo;03oool30?l00?l0oooo=03o
ool5000002<0oooo000X0?ooo`030?nZE@000000EJ[o01@0oooo01P0omB002/000000000000[083D
o`3oool0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?oo
o`3oojX0E@000000001EZ_l90?ooo`030000003oool0oooo0?l0oooo;@3oool30?l00?l0oooo>@3o
ool00`000000oooo0?ooo`0Q0?ooo`009`3oool0103oom@0P2/0000[P03DoolD0?ooo`0H0?oDP00[
00000000000[P03Dool0oooo0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[
0000001E0:[oo`3oool0oonZ05D0000002/0P=Co2@3oool00`000000oooo0?ooo`3o0?ooob/0oooo
103o003o0?ooocX0oooo00<000000?ooo`3oool08@3oool002L0oooo00@0oonZ05D0000005D0Z_oo
5P3oool05P2ZE@000000001EZP3oool0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0
omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool90?ooo`030000003oool0oooo0?l0oooo
:P3oool40?l00?l0oooo>`3oool00`000000oooo0?ooo`0Q0?ooo`00:03oool00`2ZE@0000000000
0005000000030000E@2Zool0oooo00T0oooo01/0oonZ05D000000000EJ[o0?ooo`2ZE@000000001E
ZP3oool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0oooD080[00000000:h3D0?oo
o`3DP2/00000000[P03Dool02@3oool00`000000oooo0?ooo`3o0?ooobT0oooo0`3o003o0?ooocd0
oooo00<000000?ooo`3oool08@3oool002P0oooo00<0oonZ05D0000000001@0000000`0005D0Z_oo
0?ooo`0:0?ooo`030:YE00000000000000<0000000@0EJ[o0?ooo`3oool0ojYE1@000000101EZ_l0
oooo0?ooo`3oZUD50000000305FZo`3oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolX0?oo
o`<0o`00o`3oooln0?ooo`030000003oool0oooo0240oooo000n0?ooo`050:YE0000000000000000
001EZ_l0103oool01@3oZUD00000000000000000EJ[o00@0oooo00D0ojYE000000000000000005FZ
o`0;0?ooo`030000003oool0oooo0?l0oooo9`3oool30?l00?l0oooo?`3oool00`000000oooo0?oo
o`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooobD0oooo103o003o0?oood00oooo00<00000
0?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooolT0?ooo`@0o`00o`3ooom10?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo8`3oool30?l00?l0
oooo@`3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooob80oooo
0`3o003o0?oood@0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3o
oolQ0?ooo`<0o`00o`3ooom50?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo0?l0oooo7`3oool40?l00?l0ooooAP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`00
0000oooo0?ooo`3o0?oooah0oooo103o003o0?ooodL0oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0o`3ooolM0?ooo`<0o`00o`3ooom90?ooo`030000003oool0oooo0240
oooo001P0?ooo`<00000o`3ooolL0?ooo`<0o`00o`3ooom80?ooo`<000008`3oool00600oooo00<0
00000?ooo`3oool0o`3ooolK0?ooo`<0o`00o`3ooom;0?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo0?l0oooo6P3oool30?l00?l0ooooC03oool00`000000oooo0?ooo`0Q
0?ooo`00H03oool00`000000oooo0?ooo`3o0?oooaP0oooo103o003o0?ooodd0oooo00<000000?oo
o`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooolG0?ooo`@0o`00o`3ooom>0?ooo`03
0000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo5P3oool30?l00?l0oooo
D03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?oooaD0oooo0`3o
003o0?oooe40oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooolD
0?ooo`<0o`00o`3ooomB0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo
0?l0oooo4`3oool30?l00?l0ooooD`3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000
oooo0?ooo`3o0?oooa80oooo0`3o003o0?oooe@0oooo00<000000?ooo`3oool08@3oool00600oooo
00<000000?ooo`3oool0o`3ooolA0?ooo`<0o`00o`3ooomE0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo0?l0oooo3`3oool40?l00?l0ooooEP3oool00`000000oooo0?oo
o`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooo`h0oooo103o003o0?oooeL0oooo00<00000
0?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3oool=0?ooo`<0o`00o`3ooomI0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo303oool30?l00?l0
ooooFP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool300000?l0oooo2`3oool30?l00?l0oooo
F@3oool3000002<0oooo001P0?ooo`030000003oool0oooo0?l0oooo2P3oool30?l00?l0ooooG03o
ool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooo`P0oooo103o003o
0?oooed0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3oool70?oo
o`@0o`00o`3ooomN0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0
oooo1P3oool30?l00?l0ooooH03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo
0?ooo`3o0?ooo`D0oooo0`3o003o0?ooof40oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool0o`3oool40?ooo`<0o`00o`3ooomR0?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo0?l0oooo0P3oool40?l00?l0ooooH`3oool00`000000oooo0?ooo`0Q
0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooo`40oooo103o003o0?ooof@0oooo00<000000?oo
o`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3oool30?l00?l0ooooIP3oool00`000000
oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3n0?ooo`<0o`00o`3ooomW0?ooo`030000
003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?d0oooo0`3o003o0?ooofP0oooo00<0
00000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0n`3oool40?l00?l0ooooJ@3oool0
0`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3j0?ooo`@0o`00o`3ooomZ0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?T0oooo0`3o003o0?ooof`0
oooo00<000000?ooo`3oool08@3oool00600oooo0`00003h0?ooo`<0o`00o`3ooom[0?ooo`<00000
8`3oool00600oooo00<000000?ooo`3oool0m`3oool30?l00?l0ooooKP3oool00`000000oooo0?oo
o`0Q0?ooo`00H03oool00`000000oooo0?ooo`3e0?ooo`@0o`00o`3ooom_0?ooo`030000003oool0
oooo0240oooo001P0?ooo`030000003oool0oooo0?@0oooo103o000]0?ooool000007P00000U0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?<0oooo0`3o000_0?ooool0
00007P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?80oooo
0`3o000`0?ooool000007P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003o
ool0oooo0?40oooo0`3o000a0?ooool000007P00000U0?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo0>l0oooo103o000b0?ooool000007P00000U0?ooo`030000003oool0
oooo0240oooo001P0?ooo`030000003oool0oooo0>h0oooo103o000c0?ooool000007P00000U0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0>d0oooo0`3o000e0?ooool0
00007P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0>`0oooo
0`3o000f0?ooool000007P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003o
ool0oooo0>/0oooo0`3o000g0?ooool000007P00000U0?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo0>T0oooo103o000h0?ooool000007P00000U0?ooo`030000003oool0
oooo0240oooo001P0?ooo`030000003oool0oooo0>P0oooo103o000i0?ooool000007P00000U0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0>L0oooo0`3o000k0?ooool0
00007P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`<00000iP3oool30?l003`0oooo
o`00000N000002<0oooo0`00000S0?ooo`00H03oool00`000000oooo0?ooo`3U0?ooo`<0o`00?@3o
oooo000001h000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3T
0?ooo`<0o`00?P3ooooo000001h000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`00
0000oooo0?ooo`3R0?ooo`@0o`00?`3ooooo000001h000009@3oool00`000000oooo0?ooo`0Q0?oo
o`00H03oool00`000000oooo0?ooo`3Q0?ooo`@0o`00@03ooooo000001h000009@3oool00`000000
oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3P0?ooo`<0o`00<03ooooo000003000000
9@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3O0?ooo`<0o`00<@3o
ool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo0=h0oooo0`3o000b0?ooo`030000003oool0oooo0?l0oooo6`3ooolB
000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0g@3oool30?l0
03<0oooo00<000000?ooo`3oool0o`3ooolK0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?oo
o`00H03oool00`000000oooo0?ooo`3L0?ooo`<0o`00=03oool00`000000oooo0?ooo`3o0?oooa/0
oooo4P00000U0?ooo`030000003oool0oooo0240oooo00100?ooo`040?ooZP1E0000000[083Do`<0
oooo00D0ojYE000000000000000005FZo`040?ooo`050?nZE@00000000000000001EZ_l02`3oool0
0`000000oooo0?ooo`3K0?ooo`<0o`00=@3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U
0?ooo`030000003oool0oooo0240oooo00100?ooo`040?ooZP1E0000000[083Do`80oooo00<0ojYE
0000000000000`000000101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo00P0oooo00<0
00000?ooo`3oool0f@3oool40?l003H0oooo00<000000?ooo`3oool0o`3ooolK0?oooa8000009@3o
ool00`000000oooo0?ooo`0Q0?ooo`00?03oool00`2ZE@000000000000050000000C001EZP3oom@0
P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`000000
02^00=Coo`090?ooo`030000003oool0oooo0=P0oooo103o000g0?ooo`030000003oool0oooo0?l0
oooo6`3ooolB000002D0oooo00<000000?ooo`3oool08@3oool003`0oooo00<0ZUD0000000000000
1@0000004`00EJX0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0omB002/0000002/0
P=Co0?ooo`3oe800:`000000E@2Zool02@3oool00`000000oooo0?ooo`3G0?ooo`<0o`00>@3oool0
0`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo000l0?oo
o`0K0?nZE@00000005FZ0?ooo`3oojX0E@000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oool0
oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co00T0oooo00<0
00000?ooo`3oool0eP3oool30?l003X0oooo00<000000?ooo`3oool0o`3ooolK0?oooa8000009@3o
ool00`000000oooo0?ooo`0Q0?ooo`00?03oool06`3oom@0P2/00000001EZ_l0oonZ05D0000002/0
P=Co0?ooo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`3oZUD000000000E@2Zool0
oooo0?ooZP1E0000000005FZo`090?ooo`D00000d`3oool30?l003/0oooo00<000000?ooo`3oool0
o`3ooolK0?oooa8000008@3oool5000002<0oooo000m0?ooo`0J0?oDP00[000002^00=CoZP1E0000
000[083Do`3oool0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0
Z_oo0?ooo`3oojX0E@000000001EZ_l90?ooo`030000003oool0oooo0=@0oooo0`3o000l0?ooo`03
0000003oool0oooo0?l0oooo6`3ooolB000002D0oooo00<000000?ooo`3oool08@3oool003h0oooo
01T0e80[0000000[P800E@000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oool0oonZ05D00000
02/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co00T0oooo00<000000?ooo`3o
ool0d`3oool30?l003d0oooo00<000000?ooo`3oool0o`3ooolK0?oooa8000009@3oool00`000000
oooo0?ooo`0Q0?ooo`00?P3oool06@3oom@0P2/0000000000000000[083Do`3oool0omB002/00000
02/0P=Co0?ooo`3oe800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Z
ool02@3oool00`000000oooo0?ooo`3A0?ooo`@0o`00?P3oool00`000000oooo0?ooo`3o0?oooa/0
oooo4P00000U0?ooo`030000003oool0oooo0240oooo000o0?ooo`0H0?nZE@00000000000000:`20
e?l0oooo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo0?ooe020:`00000002^0e03o
ool0e80[00000000:h00e?oo2@3oool00`000000oooo0?ooo`3@0?ooo`@0o`00?`3oool00`000000
oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo00100?ooo`040:YE
00000000000[083Do`80oooo00<0ojYE0000000000000`000000101EZ_l0oooo0?ooo`3oZUD50000
000305FZo`3oool0oooo00P0oooo00<000000?ooo`3oool0c`3oool30?l00440oooo00<000000?oo
o`3oool0o`3ooolK0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00@03oool0103oojX0
E@000000:`20e?l30?ooo`050?nZE@00000000000000001EZ_l0103oool01@3oZUD0000000000000
0000EJ[o00/0oooo00<000000?ooo`3oool0cP3oool30?l00480oooo00<000000?ooo`3oool0o`3o
oolK0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3=
0?ooo`<0o`00@`3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0
oooo0240oooo001P0?ooo`030000003oool0oooo0<`0oooo0`3o00140?ooo`030000003oool0oooo
0?l0oooo6`3ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3o
ool0b`3oool30?l004D0oooo00<000000?ooo`3oool0o`3ooolK0?oooa8000009@3oool00`000000
oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3:0?ooo`<0o`00AP3oool00`000000oooo
0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003o
ool0oooo0<P0oooo103o00170?ooo`030000003oool0oooo0?l0oooo6`3ooolB000002D0oooo00<0
00000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0a`3oool40?l004P0oooo00<00000
0?ooo`3oool0o`3ooolK0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`00
0000oooo0?ooo`360?ooo`<0o`00BP3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0<D0oooo0`3o001;0?ooo`03
0000003oool0oooo0?l0oooo6`3ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600oooo
0`0000340?ooo`<0o`00C03oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000S0?ooo`<00000
8`3oool00600oooo00<000000?ooo`3oool0``3oool30?l004d0oooo00<000000?ooo`3oool0o`3o
oolK0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`32
0?ooo`<0o`00CP3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0
oooo0240oooo001P0?ooo`030000003oool0oooo0<00oooo103o001?0?ooo`030000003oool0oooo
09/0oooo00D0omB002/000000000001E0:[oo`0<0?ooo`030?ooe020:b/0P=Co00`0oooo00<0oooD
080[000[P=@0703oool00`3oojX0EB^00=Coo`0m0?oooa8000009@3oool00`000000oooo0?ooo`0Q
0?ooo`00H03oool00`000000oooo0?ooo`2o0?ooo`@0o`00D03oool00`000000oooo0?ooo`2K0?oo
o`050?oDP00[0000000000000000EJX02`3oool00`3oom@0P2/[083Do`0>0?ooo`030=B0:`00:h00
e?oo01`0oooo00<0omB002/[P03Dool0?03ooolB000002D0oooo00<000000?ooo`3oool08@3oool0
0600oooo00<000000?ooo`3oool0_P3oool30?l00580oooo00<000000?ooo`3oool0W@3oool0103o
e800:`000000:`20e?l:0?ooo`030:YE0000EJX0oooo00h0oooo00<0omB002/0:`20e?l07@3oool0
0`3DP2/005FZ0?ooo`0k0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`00
0000oooo0?ooo`2m0?ooo`<0o`00D`3oool00`000000oooo0?ooo`1a0?ooo`030?nZE@0000000000
0080000000P002^00=Coo`3oool0oooo0?ooZP1E0000000[083Do`<0oooo00P0e80[000000000000
02^00=CoZP1E0000000[083Do`<0oooo00<0ZUD000000000EJX00`3oool03`3oojX0E@000000001E
Z_l0oooo0?oDP00[000000000000:`20e?l0oooo0?ooZP1E0000000002^0e0090?ooo`0E0?nZE@00
02/0P=Co0?ooo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oool0ojYE00000000
05D0Z_oo0?ooe020:`00:h3D00@0oooo00<0oooD080[000000000P0000000`00:h00e?oo0?ooo`0A
0?ooo`030?oDP00[0000EJ[o03/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?oo
o`030000003oool0oooo0;`0oooo0`3o001D0?ooo`030000003oool0oooo0700oooo00<0ZUD00000
000000001@0000001P00EJX0oooo0?ooZP1E0000000[083Do`80oooo00<0ojYE0000000000001000
00002@00:h00e?oo0?ooo`3oool0oonZ05D000000000001E0:[oo`020?ooo`060?ooZP1E00000000
05FZo`3oool0ZUD00P000000100002/0P=Co0?ooo`3oZUD200000003000[P03Dool0oooo00L0oooo
01H0ZUD00000E@2Zool0oooo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?ooo`3o
ZUD000000000E@2Zool0oooo0=B0:`00:h00e?oo0P3oool00`3oom@0P2/00000000400000003000[
P03Dool0oooo0100oooo00<0oonZ05D00000EJX0>`3ooolB000002D0oooo00<000000?ooo`3oool0
8@3oool00600oooo00<000000?ooo`3oool0^`3oool30?l005D0oooo00<000000?ooo`3oool0K`3o
ool0103DP2/000000000001EZ_l20?ooo`090?ooe020:`0000000000E@2Zool0oonZ05D0000002/0
P=Co0080oooo00T0e80[00000000:h00e?oo0?ooe020:`000000000[P03Dool00P3oool01@3DP2/0
000005EEE@000000EJ[o0080oooo00P0oonZ05D000000000EJ[o0?ooe020:`00000002^0e0<0oooo
00D0ZUD0000000000000000[083Do`070?ooo`0G0?ooZP1E000002^00=Coo`3oool0omB002/00000
02/0P=Co0?ooo`3oe800:`000000E@2Zool0oooo0?nZE@000000001E0:[oo`3oool0omB002/0:`20
e?l00P3oool02@3oZUD000000000:`20e?l0oooo0?ooZP1E0000000[083Do`0A0?ooo`040?ooe020
:`00001E0:[oocX0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003o
ool0oooo0;X0oooo0`3o001F0?ooo`030000003oool0oooo06h0oooo00@0oonZ05D000000000:h3D
103oool0203oZUD000000000E@2Zool0oonZ05D0000002/0P=Co0P3oool06P3oZUD000000000001E
Z_l0oooo0=B0:`00000002^00=Coo`3oool0oooD080[000005D0Z]B002/00000:h00e?oo0?ooo`3o
ojX0E@000000001EZ_l0oooD080[00000000EJ[o0P3oool01P3oe800:`000000E@2ZZUD00000001E
ZPL0oooo01L0oonZ05D00000:h00e?oo0?ooo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E
0:[oo`3oool0ojYE0000000005D0Z_oo0?ooo`3oom@0P2/002^0e0050?ooo`060?nZE@0000000000
0000000002/0P=Co4@3oool0103oom@0P2/00000E@2Zoolj0?oooa8000009@3oool00`000000oooo
0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2i0?ooo`<0o`00E`3oool00`000000oooo0?oo
o`1^0?ooo`070?oDP00[0000001E0:[oo`3oool0oooD080[0003000000060000E@2Zool0oonZ05D0
00000000EJ[o0P3oool00`3oom@0P2/0000000040000000C000[P03Dool0oooo0?oDP00[000002^0
0=Coe020:`00000[083Do`3oool0oonZ05D000000000EJ[o0?ooe020:`00000005FZo`020?ooo`07
0=B0:`00000005FZ0?ooZP1E0000001E0:[oo`060?ooo`0C0?ooZP1E000002^00=Coo`3oool0omB0
02/0000002/0P=Co0?ooo`3oe800:`000000:`20e?l0oooo0?nZE@000000001E0:[oo`020?ooo`03
0=B0:`00:h00e?oo0080oooo00<0e80[0000000000000`0000000`00EJX0oooo0?ooo`0@0?ooo`04
0?ooe020:`00001E0:[oocX0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`03
0000003oool0oooo0;L0oooo103o001H0?ooo`030000003oool0oooo00d0ooooD`3o000>0?ooo`07
0?nZE@00000002^00=Coo`3oool0oooD080[0003000000060000E@2Zool0oonZ05D000000000EJ[o
1@3oool0803oe800:`0000000000000002^00=Coo`3oool0ZUD00000000[P=@0oooo0=B0:`000000
:h3D0?ooo`3oojX0E@000000001EZ_l0oooD080[00000000EJ[o0?ooo`3oom@0P2/00000001EZ_l0
oooo0:YE00000000EJ[o1P3oool04`3oojX0E@000000E@2Zool0oooo0?oDP00[0000000[083Do`3o
ool0omB002/0000002/0P=Co0?ooo`3oZUD000000000E@2Zool00P3oool01P3oe800:`0[083Do`3o
ool0oonZ05D000<0000000<005FZ0?ooo`3oool04P3oool0103oom@0P2/00000E@2Zoolj0?oooa80
00009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2f0?ooo`@0o`00
F@3oool00`000000oooo0?ooo`0=0?oooe<0o`003P3oool0103oZUD00000000[P03Dool80?ooo`04
0?ooZP1E00000000001EZP80oooo02@0oonZ05D0000005D0Z_oo0?ooo`3DP2/00000000[P03Dool0
oonZ05D0000002/0P=Co0?ooo`3oe800:`00000[P03Dool0oonZ05D000000000EJ[o0?ooe020:`00
000005FZo`3oool0omB002/0000005D0Z_oo0?ooo`3oZUD00000000[P03Dool60?ooo`0:0:YE0000
05D0Z_oo0?ooo`3oe800:`0000000000EJX0oooo0?nZE@80000000H0:h3D0?ooo`3DP2/000000000
E@2Zool20?ooo`0<0?ooe020:`00:h3D0?ooo`3oe800:`000000E@2Zool0oooo0=B0:`00000005FZ
4P3oool00`3oojX0E@00001EZP0k0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03o
ool00`000000oooo0?ooo`2e0?ooo`<0o`00F`3oool00`000000oooo0?ooo`1^0?ooo`040?oDP00[
0000001E0:[oo`P0oooo00<0oonZ05D0000000000P0000000`00:h00e?oo0:YE00050000000@001E
ZP3oool0ojYE00000000:h00e?oo0?ooo`3oom@0P2/00000001EZ_l0oonZ05D000000000EJ[D080[
00<0000000@0001E0820:`00000005FZ0P3oool0103oojX0E@000000:`20e?l60?ooo`060?nZE@00
02/0P=Co0?ooo`3oe800:`002P0000000`00EJX0oooo0?ooo`020?ooo`050=B0:`00:h00e?oo0?oo
e020:`001@0000000`0[P=@0oooo0?ooo`070?ooo`030=B0:`00000000000080000000L0:h3D0?oo
o`3oool0oooo0?oDP00[0000EJ[o03/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo0;@0oooo0`3o001L0?ooo`030000003oool0oooo06h0oooo00@0oonZ
05D000000000EJ[o103oool03@3DP2/002^00=Coo`3oool0oonZ05D0000002/0P81E0000000002/0
P=Co0?ooo`2ZE@000`0000001P00:h00e?oo0?ooo`2ZE@00000002^0e0<0oooo00P0ZUD000000000
EJX0oonZ05D000000000EJ[D080[00H0000000L0EJ[o0?ooo`3oool0oooo0:YE00000000:h3D00L0
oooo0100ZUD0001EZP3oool0omB002/0000002/0P:Z002/000000000001E0:[oo`3oe800:`000000
000005D0Z_oo103oool01P3oe800:`0[083Do`3oool0oonZ05D000<0000000<005FZ0?ooo`3oool0
203oool0103oojX0E@00000[P03Dool50?ooo`030=B0:`00EJX0oooo03/0oooo4P00000U0?ooo`03
0000003oool0oooo0240oooo001P0?ooo`<00000/`3oool30?l005d0oooo00<000000?ooo`3oool0
K`3oool0103DP2/000000000001EZ_l20?ooo`040?nZE@0000000000001EZQd0oooo00@0oooD080[
00000000EJ[o4@3oool00`3oom@0P2/005FZo`0A0?ooo`030?ooe020:`00:h3D00T0oooo00<0ojYE
0000000000000`0000001P00:h00e?oo0?ooo`3oe800:`00001EZP@0oooo00<0ojYE000[P03Dool0
?03ooolB000002<0oooo0`00000S0?ooo`00H03oool00`000000oooo0?ooo`2b0?ooo`<0o`00GP3o
ool00`000000oooo0?ooo`1_0?ooo`030?ooe020:`00000000D0000000<0000[083Do`3oool0603o
ool0203oojX0E@000000001EZ_l0oooD080[00000000EJ[o4`3oool00`2ZEB/0P=Co0?ooo`0@0?oo
o`030=B0:`00:h00e?oo0180oooo00<0ojYE0000000[P=@00P3oool00`3oojX0EEFZ0?ooo`0m0?oo
oa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2a0?ooo`<0
o`00G`3oool00`000000oooo0?ooo`1a0?ooo`030?nZE@00000000000080000000<002^00=Coo`3o
ool06@3oool0103oojX0E@000000001EZ_l20?ooo`030:YE001EZ_l0oooo03/0oooo00<0e80[0000
:`20e?l0@@3ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3o
ool0/03oool30?l00600oooo00<000000?ooo`3oool0eP3oool00`3oe800:`0002^0e0110?oooa80
00009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2^0?ooo`@0o`00
H@3oool00`000000oooo0?ooo`3C0?ooo`060?nZE@000000EJ[o0?oDP00[0000EJ[o@@3ooolB0000
02D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0[@3oool40?l00680
oooo00<000000?ooo`3oool0e03oool0102ZE@00000000000000EJY20?oooa8000009@3oool00`00
0000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2/0?ooo`<0o`00I03oool00`000000
oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000
003oool0oooo0:/0oooo0`3o001U0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000002D0oooo
00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0ZP3oool30?l006H0oooo00<0
00000?ooo`3oool0o`3ooolK0?oooa8000009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool0
0`000000oooo0?ooo`2Y0?ooo`<0o`00I`3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0:P0oooo0`3o001X0?oo
o`030000003oool0oooo0?l0oooo6`3ooolB000002D0oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0Y`3oool30?l006T0oooo00<000000?ooo`3oool0o`3ooolK0?oooa80
00009@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2U0?ooo`@0o`00
JP3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000U0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo0:@0oooo103o001[0?ooo`030000003oool0oooo0?l0oooo6`3o
oolB000002D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0X`3oool3
0?l006d0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool08@3oool00600oooo0`00002R0?ooo`<0o`00KP3oool00`000000oooo0?ooo`3o0?oo
oa/0oooo00<000000?ooo`3oool0<P3oool3000002<0oooo001P0?ooo`030000003oool0oooo0:40
oooo0`3o001_0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0:00oooo0`3o001`0?ooo`030000
003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo09l0oooo0`3o001a0?ooo`030000003oool0oooo0?l0oooo6`3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo09h0oooo0`3o001b0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo09d0oooo0`3o001c0?oo
o`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
0240oooo001P0?ooo`030000003oool0oooo09/0oooo103o001d0?ooo`030000003oool0oooo0?l0
oooo6`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000
003oool0oooo09X0oooo103o001e0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo09T0oooo0`3o
001g0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0240oooo001P0?ooo`030000003oool0oooo09P0oooo0`3o001h0?ooo`030000003oool0
oooo0?l0oooo6`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo001P0?oo
o`030000003oool0oooo09L0oooo0`3o001i0?ooo`030000003oool0oooo0?l0oooo6`3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo09H0
oooo0`3o001j0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo09D0oooo0`3o001k0?ooo`030000
003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo09@0oooo0`3o001l0?ooo`030000003oool0oooo0?l0oooo6`3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo09<0oooo0`3o001m0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0240oooo001P0?ooo`<00000TP3oool30?l007h0oooo00<000000?oo
o`3oool0o`3ooolK0?ooo`030000003oool0oooo0380oooo0`00000S0?ooo`00H03oool00`000000
oooo0?ooo`2@0?ooo`@0o`00O`3ooooo000001l00000=P3oool00`000000oooo0?ooo`0Q0?ooo`00
H03oool00`000000oooo0?ooo`2?0?ooo`@0o`00o`3ooooE0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo08h0oooo0`3o003o0?ooomL0oooo00<000000?ooo`3oool08@3o
ool00600oooo00<000000?ooo`3oool0S@3oool30?l00?l0oooof03oool00`000000oooo0?ooo`0Q
0?ooo`00H03oool00`000000oooo0?ooo`2<0?ooo`<0o`00o`3ooooI0?ooo`030000003oool0oooo
0240oooo001P0?ooo`030000003oool0oooo08/0oooo0`3o003o0?ooomX0oooo00<000000?ooo`3o
ool08@3oool00600oooo00<000000?ooo`3oool0RP3oool30?l00?l0oooof`3oool00`000000oooo
0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`290?ooo`<0o`00o`3ooooL0?ooo`030000003o
ool0oooo0240oooo001P0?ooo`030000003oool0oooo08P0oooo0`3o003o0?ooomd0oooo00<00000
0?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0QP3oool40?l00?l0oooogP3oool00`00
0000oooo0?ooo`0Q0?ooo`00?P3oool01@3DP2/00000000000000000:h3D00@0oooo00D0ojYE0000
00000000000005FZo`040?ooo`050?nZE@00000000000000001EZ_l02`3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo03`0oooo103o000A0?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0240oooo000m
0?ooo`030=B0:`000000000000<0000000@005FZ0?ooo`3oool0ojYE1@000000101EZ_l0oooo0?oo
o`3oZUD50000000305FZo`3oool0oooo00P0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0k0?ooo`<0o`004`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Q0?ooo`00?03oool06`3oojX0E@000000
000[P=@0oooo0?nZE@000000000[083Do`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Co
o`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`090?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`<0o`000`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool003`0oooo
01/0ojYE0000000005D0Z_oo0?ooo`3oom@0P2/00000001EZ_l0omB002/0000002/0P=Co0?ooo`3o
e800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool02@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool30?l0
00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0240oooo00110?ooo`0F0?ooe020:`00000002^0e03oe800:`000000E@2Zool0oooo0?ooZP1E0000
000[083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`T0ooooQ00000030?l00?l0
0000i@00000S0?ooo`00?03oool01P3oojX0E@000000:`20e?l0oooo0?nZE@80000001<0EJ[o0?nZ
E@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D0
00000000EJ[o0?l0ooooo`3ooonI0?ooo`00?03oool00`3oom@0P2/0000000040000000D000[P03D
ool0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3o
ojX0E@000000001EZ_oo0?ooool0ooooV@3oool003d0oooo00<0ZUD00000000000000P0000005@00
EJX0oooo0?ooo`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`3oe800:`000000E@2Z
ool0oooo0?ooZP1E0000000[083Do`3o0?ooool0ooooV@3oool003d0oooo00<0e80[00000000EJX0
1@3oool04P3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0
oooo0?oDP00[0000001E0:[oool0ooooo`3ooonI0?ooo`00?@3oool0103oe800:`00000[P03Dool4
0?ooo`0B0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo0?ooe020:`00000002^0e03o
ool0e80[00000000:h00e?ooo`3ooooo0?oooiT0oooo000m0?ooo`030?ooZP1E0000000000<00000
00@0001E0:[oo`3oool0ojYE1@000000101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo
0?l0ooooo`3ooonH0?ooo`00?@3oool00`3oom@0P2/000000003000000050000E@2Zool0oooo0?oo
o`3oZUD00`0000000`1EZ_l0oooo0?ooo`020?ooo`050?nZE@00000000000000001EZ_l0o`3ooooo
0?oooi/0oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo
003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0
ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool0
0?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3o
ooo`0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 749}, {462.5, 0}} -> {-1.05093, -0.648943, \
0.00280622, 0.00280622}, {{18.125, 730.813}, {451.438, 11}} -> {7.74704, \
-85.8705, 0.0029752, 1.32747}, {{374.5, 659.563}, {106.5, 35.25}} -> \
{-4.51559, -6.89529, 0.0117896, 0.0190879}, {{389.75, 474.563}, {97.0625, \
44.625}} -> {-4.85026, -15.6912, 0.0123804, 0.0400637}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"lst", "=", 
        RowBox[{"AtmGraphs", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["KineticTemperature",
                    GridBoxOptions->{RowSpacings->0.4,
                    RowLines->False}], ",", "\"\<\!\(\*
StyleBox[\"Kinetic\",\nGridBoxOptions->{RowSpacings->0.4,\n\
RowLines->False}]\)\!\(\*
StyleBox[\" \",\nGridBoxOptions->{RowSpacings->0.4,\n\
RowLines->False}]\)\!\(\*
StyleBox[\"Temperature\",\nGridBoxOptions->{RowSpacings->0.4,\n\
RowLines->False}]\) (K)\>\""}], "}"}], 
              StyleBox["}",
                GridBoxOptions->{RowSpacings->0.4,
                RowLines->False}]}], 
            StyleBox[",",
              GridBoxOptions->{RowSpacings->0.4,
              RowLines->False}], \(PlotRange -> {\(-7\)\ , 250\ }\)}], 
          StyleBox["]",
            GridBoxOptions->{RowSpacings->0.4,
            RowLines->False}]}]}], 
      StyleBox[";",
        GridBoxOptions->{RowSpacings->0.4,
        RowLines->False}]}], "\[IndentingNewLine]", \(Show[
        LegendGraphs[lst, LegendSize \[Rule] {1.2,  .2}, 
          LegendPosition \[Rule] \ {\(- .4\), \(- .35\)}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        ImageSize \[Rule] 750];\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 750 463.525 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.195063 0.00117125 0.0168336 0.0024048 [
[.03919 -0.0125 -15.3125 -20.3125 ]
[.03919 -0.0125 15.3125 0 ]
[.27344 -0.0125 -15.3125 -20.3125 ]
[.27344 -0.0125 15.3125 0 ]
[.50769 -0.0125 -15.3125 -20.3125 ]
[.50769 -0.0125 15.3125 0 ]
[.74194 -0.0125 -15.3125 -20.3125 ]
[.74194 -0.0125 15.3125 0 ]
[.97619 -0.0125 -19.75 -20.3125 ]
[.97619 -0.0125 19.75 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -86.9688 -40.625 ]
[.5 -0.0125 86.9688 -20.3125 ]
[-0.0125 .01683 -12.875 -10.1563 ]
[-0.0125 .01683 0 10.1563 ]
[-0.0125 .13707 -21.75 -10.1563 ]
[-0.0125 .13707 0 10.1563 ]
[-0.0125 .25731 -30.625 -10.1563 ]
[-0.0125 .25731 0 10.1563 ]
[-0.0125 .37755 -30.625 -10.1563 ]
[-0.0125 .37755 0 10.1563 ]
[-0.0125 .49779 -30.625 -10.1563 ]
[-0.0125 .49779 0 10.1563 ]
[-0.0125 .61803 -30.625 -10.1563 ]
[-0.0125 .61803 0 10.1563 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -50.9375 -48.625 ]
[-0.01875 .30902 -30.625 48.625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03919 0 m
.03919 .00625 L
s
gsave
.03919 -0.0125 -76.3125 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.27344 0 m
.27344 .00625 L
s
gsave
.27344 -0.0125 -76.3125 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
.50769 0 m
.50769 .00625 L
s
gsave
.50769 -0.0125 -76.3125 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(600) show
1.000 setlinewidth
grestore
.74194 0 m
.74194 .00625 L
s
gsave
.74194 -0.0125 -76.3125 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(800) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -80.75 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
.125 Mabswid
.09775 0 m
.09775 .00375 L
s
.15631 0 m
.15631 .00375 L
s
.21488 0 m
.21488 .00375 L
s
.332 0 m
.332 .00375 L
s
.39056 0 m
.39056 .00375 L
s
.44913 0 m
.44913 .00375 L
s
.56625 0 m
.56625 .00375 L
s
.62481 0 m
.62481 .00375 L
s
.68338 0 m
.68338 .00375 L
s
.8005 0 m
.8005 .00375 L
s
.85907 0 m
.85907 .00375 L
s
.91763 0 m
.91763 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -147.969 -44.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(KineticTemperature) show
212.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
221.438 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
232.938 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01683 m
.00625 .01683 L
s
gsave
-0.0125 .01683 -73.875 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13707 m
.00625 .13707 L
s
gsave
-0.0125 .13707 -82.75 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
0 .25731 m
.00625 .25731 L
s
gsave
-0.0125 .25731 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
0 .37755 m
.00625 .37755 L
s
gsave
-0.0125 .37755 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
0 .49779 m
.00625 .49779 L
s
gsave
-0.0125 .49779 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(250) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04088 m
.00375 .04088 L
s
0 .06493 m
.00375 .06493 L
s
0 .08898 m
.00375 .08898 L
s
0 .11303 m
.00375 .11303 L
s
0 .16112 m
.00375 .16112 L
s
0 .18517 m
.00375 .18517 L
s
0 .20922 m
.00375 .20922 L
s
0 .23327 m
.00375 .23327 L
s
0 .28136 m
.00375 .28136 L
s
0 .30541 m
.00375 .30541 L
s
0 .32946 m
.00375 .32946 L
s
0 .35351 m
.00375 .35351 L
s
0 .4016 m
.00375 .4016 L
s
0 .42565 m
.00375 .42565 L
s
0 .4497 m
.00375 .4497 L
s
0 .47375 m
.00375 .47375 L
s
0 .52184 m
.00375 .52184 L
s
0 .54589 m
.00375 .54589 L
s
0 .56994 m
.00375 .56994 L
s
0 .59399 m
.00375 .59399 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -150.406 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
109.625 14.1563 translate
90 rotate
-109.625 -14.1563 translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Altitude) show
121.688 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
130.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Km) show
156.250 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.03919 .61178 m
.03919 .61803 L
s
.27344 .61178 m
.27344 .61803 L
s
.50769 .61178 m
.50769 .61803 L
s
.74194 .61178 m
.74194 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.09775 .61428 m
.09775 .61803 L
s
.15631 .61428 m
.15631 .61803 L
s
.21488 .61428 m
.21488 .61803 L
s
.332 .61428 m
.332 .61803 L
s
.39056 .61428 m
.39056 .61803 L
s
.44913 .61428 m
.44913 .61803 L
s
.56625 .61428 m
.56625 .61803 L
s
.62481 .61428 m
.62481 .61803 L
s
.68338 .61428 m
.68338 .61803 L
s
.8005 .61428 m
.8005 .61803 L
s
.85907 .61428 m
.85907 .61803 L
s
.91763 .61428 m
.91763 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01683 m
1 .01683 L
s
.99375 .13707 m
1 .13707 L
s
.99375 .25731 m
1 .25731 L
s
.99375 .37755 m
1 .37755 L
s
.99375 .49779 m
1 .49779 L
s
.125 Mabswid
.99625 .04088 m
1 .04088 L
s
.99625 .06493 m
1 .06493 L
s
.99625 .08898 m
1 .08898 L
s
.99625 .11303 m
1 .11303 L
s
.99625 .16112 m
1 .16112 L
s
.99625 .18517 m
1 .18517 L
s
.99625 .20922 m
1 .20922 L
s
.99625 .23327 m
1 .23327 L
s
.99625 .28136 m
1 .28136 L
s
.99625 .30541 m
1 .30541 L
s
.99625 .32946 m
1 .32946 L
s
.99625 .35351 m
1 .35351 L
s
.99625 .4016 m
1 .4016 L
s
.99625 .42565 m
1 .42565 L
s
.99625 .4497 m
1 .4497 L
s
.99625 .47375 m
1 .47375 L
s
.99625 .52184 m
1 .52184 L
s
.99625 .54589 m
1 .54589 L
s
.99625 .56994 m
1 .56994 L
s
.99625 .59399 m
1 .59399 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
.18053 .00481 m
.17672 .00601 L
.17291 .00721 L
.1691 .00842 L
.16528 .00962 L
.16147 .01082 L
.15767 .01202 L
.15386 .01323 L
.15005 .01443 L
.14624 .01563 L
.14243 .01683 L
.13863 .01804 L
.13482 .01924 L
.13102 .02044 L
.12721 .02164 L
.12341 .02285 L
.11961 .02405 L
.1158 .02525 L
.112 .02645 L
.1082 .02766 L
.1044 .02886 L
.1006 .03006 L
.0968 .03126 L
.093 .03246 L
.0892 .03367 L
.0854 .03487 L
.08161 .03607 L
.07781 .03727 L
.07401 .03848 L
.07022 .03968 L
.06642 .04088 L
.06263 .04208 L
.05883 .04329 L
.05869 .04449 L
.05869 .04569 L
.05869 .04689 L
.05869 .0481 L
.05869 .0493 L
.05869 .0505 L
.05869 .0517 L
.05869 .05291 L
.05869 .05531 L
.05869 .05772 L
.05869 .06012 L
.05869 .06252 L
.05869 .06493 L
.05978 .06733 L
.06094 .06974 L
.06211 .07214 L
.06327 .07455 L
Mistroke
.06443 .07695 L
.06559 .07936 L
.06675 .08176 L
.06792 .08417 L
.06908 .08657 L
.07024 .08898 L
.0714 .09138 L
.07256 .09379 L
.07547 .09619 L
.07839 .0986 L
.08195 .101 L
.0852 .10341 L
.09168 .10822 L
.09816 .11303 L
.10464 .11784 L
.11111 .12264 L
.11757 .12745 L
.12194 .13226 L
.12194 .13707 L
.12004 .14188 L
.11359 .14669 L
.10714 .1515 L
.1007 .15631 L
.09426 .16112 L
.07818 .17315 L
.06213 .18517 L
.04903 .19719 L
.03759 .20922 L
.02618 .22124 L
.02504 .22244 L
.02381 .22365 L
.02381 .23327 L
.02562 .24529 L
.03343 .25731 L
.08604 .28136 L
.22659 .30541 L
.35457 .32946 L
.46041 .35351 L
.54797 .37755 L
.62047 .4016 L
.68053 .42565 L
.73031 .4497 L
.77141 .47375 L
.80584 .49779 L
.83428 .52184 L
.85791 .54589 L
.89389 .59399 L
Mfstroke
.89389 .59399 m
.90634 .61803 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.33333 .11854 m
.33333 .21378 L
.90476 .21378 L
.90476 .11854 L
F
1 g
.30952 .14235 m
.30952 .23759 L
.88095 .23759 L
.88095 .14235 L
F
0 g
.001 w
[ ] 0 setdash
.30952 .14235 m
.88095 .14235 L
.88095 .23759 L
.30952 .23759 L
.30952 .14235 L
s
% Start of sub-graphic
p
0.309524 0.14235 0.880952 0.237588 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0122549 0.122549 [
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0220588 0.35119 0.144608 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .08333 -61 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Kinetic) show
120.500 19.750 moveto
(Temperature) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
221.438 19.750 moveto
(H) show
226.938 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(K) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
238.438 19.750 moveto
(L) show
243.938 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{750, 463.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001cb000`400?l00000o`00003oo`3ooooo
0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo
003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0
ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool0
0?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooUP3o
ool00`2ZE@000000001EZP0k0?ooo`030?ooZP1E02/0P=Co0?l0oooo6@3oool00?l0ooooUP3oool0
0`2ZE@000000001EZP0l0?ooo`030=B0:`00:h00e?oo0?l0oooo603oool00?l0ooooUP3oool00`2Z
E@000000001EZP0l0?ooo`030?ooZP1E02/0P=Co0?l0oooo603oool00?l0oooo?`3oool0103oojX0
E@000000001EZ_l40?ooo`0<0?nZE@000000000002^0e03oojX0E@000000001EZ_l0oooo0:YE0000
000005FZ0P3oool00`3DP2/00000001EZP030?ooo`050:YE0000000000000000000[P=@00`3oool0
203oe800:`000000000002/0P=BZ05D000000000EJ[o0P3oool01P3oZUD0000000000000000002^0
0=Coo`D0oooo00@0omB002/0000002/0P=Co103oool01@2ZE@000000000000000000:h3D0080oooo
01<0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0oooo0?nZE@000000001E0:[oo`3o
ool0ZUD000000000EJX0ZUD00080000000<0:h3D0?ooo`3oool00P3oool01@2ZE@00000000000000
0000:h3D0080oooo00@0oonZ05D0000002/0P=Co0`3oool0403DP2/0000000000000:h00e?nZ05D0
000002/0P=Co0?ooo`3oe800:`000000000002/0P=Co0?ooo`2ZE@0200000009000[P02ZP2/00000
001EZP3oool0oonZ05D0000002/0P=Co00@0oooo00X0ZUD0000000000000000002^0e03oool0omB0
02/0000002/0P=Co1@3oool0103oojX0E@000000001EZ_l40?ooo`040?nZE@000000000002^0e?l0
oooo1`3oool00?l0oooo?`3oool0103oojX0E@000000001EZ_l30?ooo`0=0?ooZP1E00000000000[
P03Dool0oonZ05D000000000EJ[o0?ooo`2ZE@000000001EZP020?ooo`030=B0:`00000005FZ0080
oooo00<0ZUD00000000000000`000000100[P=@0oooo0?ooo`2ZE@02000000070000:`20e:X0E@00
0000001EZ_l0oooo0?nZE@05000000030000E@2Zool0oooo00<0oooo00@0omB002/0000002/0P=Co
0`3oool00`2ZE@000000000000030000000B02^0e03oool0omB002/0000002/0P=Co0?ooo`3oe800
:`000000E@2Zool0oooo0?nZE@000000001E0:[oo`3oool0ZUD01P000000100[P=@0oooo0?ooo`2Z
E@050000000602^0e03oool0oonZ05D0000002/0P=Co0P3oool00`3oZUD000000000000400000004
000[P03Dool0oooo0:YE0080000000<0000[083Do`3oZUD01P0000001P00EJX0oooo0?ooZP1E0000
000[083Do`<0oooo00<0ZUD00000000000000`0000001@0[P=@0omB002/0000002/0P=Co00D0oooo
00@0oonZ05D000000000EJ[o0`3oool01@3oojX0E@0000000000:h00e?oo0?l0oooo1`3oool00?l0
oooo?`3oool0103oojX0E@000000001EZ_l30?ooo`0=0=B0:`000000000005FZo`3oool0oonZ05D0
00000000EJ[o0?ooo`2ZE@000000001EZP020?ooo`0O0=B0:`00000005FZ0?ooo`3oe800:`000000
001EZ_l0oooo0?nZE@000000001E0:[oo`3oom@0P2/00000000[P=@0oooo0?ooZP1E0000000005FZ
o`3oojX0E@000000000[P=@0oooo0?ooe020:`00000002^0e0040?ooo`040?oDP00[0000000[083D
o`80oooo02h0omB002/000000000EJ[o0?ooo`3oZUD000000000E@2Zool0omB002/0000002/0P=Co
0?ooo`3oe800:`000000E@2Zool0oooo0?nZE@000000001E0:[oo`3oool0ZUD00000000002/0P=Co
0?ooo`3DP2/000000000E@2Zool0omB002/000000000EJ[o0?ooo`3oZUD000000000E@2Zool0oonZ
05D0000002/0P=Co0P3oool03@3DP2/00000000[P03Dool0oooD080[0000000002^00=Coo`3oom@0
P2/00000000[P=@00P3oool03@2ZE@000000000[P03Dool0oonZ05D00000000005FZ0?ooo`3oojX0
E@000000:`20e?l00P3oool02@3oe800:`000000001EZ_l0oooo0?nZE@000000001E0:[oo`080?oo
o`040?ooZP1E0000000005FZo`<0oooo00@0e80[000000000000EJ[oo`3oool80?ooo`00o`3ooolo
0?ooo`040?ooZP1E0000000005FZo`80oooo00@0omB002/00000000005FZ0P3oool0203oojX0E@00
0000001EZ_l0oooo0:YE0000000005FZ0P3oool0203DP2/00000001EZP3oool0e80[00000000:h00
e?oo1@3oool03@3oom@0P2/00000001EZ_l0oooo0?ooZP1E0000000005FZo`3oe800:`000000:`20
e?l02@3oool0103oe800:`000000:`20e?l20?ooo`040=B0:`00000002^00=Coo`D0oooo0180omB0
02/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0oooo0?nZE@000000001E0:[oo`3oool0ZUD0
00000000EJX20?ooo`080?ooZP1E0000000[083Do`3DP2/00000000[P03Dool50?ooo`040?ooZP1E
0000000[083Do`80oooo00d0ojYE000000000000EJ[o0?ooo`3DP2/00000000[P03Dool0oooD080[
00000000EJ[o0080oooo00<0ZUD000000000EJX00P3oool0202ZE@000000001EZP3oool0oonZ05D0
000002/0P=Co0P3oool0103DP2/00000000[P03Dool=0?ooo`040?ooZP1E0000000005FZo`80oooo
00@0omB002/00000000005FZo`3oool90?ooo`00o`3ooolo0?ooo`0:0?ooZP1E000000000000:`20
e?l0oooo0:YE00000000001E0:[oo`80oooo00P0oonZ05D000000000EJ[o0?ooo`2ZE@000000001E
ZP80oooo00D0e80[00000000EJX0oooo0=B0:`070000000>05FZo`3oom@0P2/00000001EZ_l0oooo
0?ooZP1E0000000005FZo`3oe800:`000000E@2Zool90?ooo`040?oDP00[0000000[083Do`80oooo
00<0e80[0000000000001@0000004`1EZ_l0omB002/0000002/0P=Co0?ooo`3oe800:`000000:`20
e?l0oooo0?nZE@000000001E0:[oo`3oool0ZUD00000000[P=@00P3oool01@3oojX0E@000000001E
Z_l0e80[00L0000000D0EJ[o0?ooZP1E0000000005FZo`020?ooo`030?ooe020:`00000000@00000
00H002^00=Coo`3oom@0P2/00000001EZ_l20?ooo`030:YE0000000005FZ0080oooo00P0e80[0000
0000EJX0oooo0?ooZP1E0000000005FZo`80oooo00<0e80[0000000000001@0000000`1EZ_l0oooo
0?ooo`060?ooo`0:0?ooZP1E000000000000:`20e?l0oooo0:YE00000000001E0:[oool0oooo2@3o
ool00?l0oooo?`3oool01P3oojX0E@00000000000000000[0820E@80000000`0:h3D0?ooo`3oool0
oooo0?ooZP1E0000000005FZo`3oool0ZUD000000000EJX20?ooo`050=B0:`00000005FZ0?ooo`3o
ZUD01P0000003`0002/0P=Co0?ooe020:`00000005FZo`3oool0oonZ05D000000000EJ[o0?oDP00[
0000000[083Do`090?ooo`040?oDP00[0000000[083Do`80oooo00<0ojYE00000000000010000000
500002/0P=Co0?oDP00[0000000[083Do`3oool0omB002/0000002/0P=Co0?ooo`3oZUD000000000
E@2Zool0oooo0:YE0000000005FZ0P3oool01@3oojX0E@000000:`20e?l0ojYE00H0000000H0000[
083Do`3oojX0E@000000001EZ_l50?ooo`0:0?oDP00[0000000000000000:h00e?oo0?ooe020:`00
000005FZo`80oooo00<0ZUD000000000EJX00P3oool0203DP2/00000001EZP3oool0oonZ05D00000
0000EJ[o0P3oool00`3oZUD0000000000004000000030000:`20e?l0oooo00L0oooo00H0oonZ05D0
0000000000000000:`20P5D20000000302^0e03oool0oooo0?l0oooo203oool00?l0oooo?`3oool0
1@3oojX0E@000000001EP800:`000080000000<002^00=Coo`3oool00P3oool0:@3oojX0E@000000
001EZ_l0oooo0:YE00000000000[083Do`3oom@0P2/000000000EJX0oooo0?oDP00[0000001E0:[o
o`3oool0omB002/0000005D0Z_oo0?ooe020:`00000005FZo`3oool0oonZ05D000000000EJ[o0?oo
ZP1E0000000002^0e03oool0oonZ05D0000002/0P=Co00@0oooo00@0omB002/0000002/0P=Co0P3o
ool03`3oe800:`000000E@2Zool0oooo0?oDP00[0000001E0:[oo`3oe800:`0000000000EJX0oooo
0?nZE@020000000M02^0e03oool0e80[0000000005D0Z_oo0?ooo`2ZE@0000000000:`20e?l0oooo
0=B0:`000000001E0:[oo`3oe800:`000000E@2Zool0oooo0?oDP00[0000001E0:[oo`3oojX0E@00
00000000EJX00P3oool03@3oojX0E@000000E@2Zool0oooo0=B0:`00000002^00=Coo`3oom@0P2/0
0000001EZ_l00P3oool00`2ZE@000000001EZP020?ooo`080=B0:`00000005FZ0?ooo`3oojX0E@00
00000000EJX20?ooo`090?oDP00[0000001E0:[oo`3oool0omB002/0000005D0Z_oo00P0oooo00D0
oonZ05D000000000EH2002/0000200000003000[P03Dool0oooo0?l0oooo2@3oool00?l0oooo?`3o
ool0203oojX0E@000000001EZ_l0ojYE0000000002/0P=Co103oool01P3oojX0E@000000001EZ_l0
oooo0:YE00H0000000@0:h3D0?ooo`3oool0ZUD01@0000000`0[P=@0oooD080[0003000000070000
E@2ZojX0E@000000001EZ_l0oooo0?nZE@0500000003000[P03Dool0oooo00<0oooo00@0omB002/0
000002/0P=Co0`3oool00`2ZE@000000000000030000000402^0e03oool0omB002/000X0000000@0
05FZ0?ooo`3oool0ZUD01P0000001000EJX0oooo0?ooo`2ZE@050000000402^0e03oool0oonZ05D0
00<0000000<002^00=Coo`2ZE@001@0000000`00EJX0oooD080[0003000000050000E@2Zool0ZUD0
00000000EJX00P3oool01P3DP2/00000001EZP3oool0oonZ05D000<0000000<002^00=Coo`2ZE@00
1@0000000`0[P=@0oooo0?ooo`070?ooo`080?ooZP1E0000000005FZo`3oZUD000000000:`20e?oo
0?ooo`/0oooo003o0?ooocl0oooo00T0oonZ05D000000000EJ[o0?ooo`3DP2/000000000:`20e?l0
0`3oool02@3oojX0E@000000001EZ_l0oooo0:YE0000000005FZ0:YE000200000003001EZP3oool0
oooo0080oooo00P0e80[000000000000000002^0e03oool0oooD080[00<0000000D0001E0:[oZP1E
0000000005FZo`020?ooo`060?nZE@000000000000000000:h00e?oo1@3oool0103oe800:`000000
:`20e?l40?ooo`050=B0:`00000000000000000[P=@00P3oool03@3oe800:`000000:`20ZX00:`00
0000000005D0Z_oo0?oDP00[000000000000E@2Zool00P3oool0102ZE@000000001EZP2ZE@020000
0003001EZP3oool0oooo0080oooo00D0e80[000000000000000002^0e0020?ooo`090?ooZP1E0000
000[0820E@000000000[083Do`3oool0ZUD000<0000000@002^00=Coo`3oom@0P2/00`0000001@00
05D0Z_oo0:YE0000000005FZ0080oooo00d0e80[00000000EJX0oooo0?ooZP1E0000000[0820E@00
0000000[083Do`3oool0e80[00<0000000<0:h3D0?ooo`3oool0203oool02@3oojX0E@000000001E
Z_l0oooo0=B0:`000000000[083Do`3o0?ooo`X0oooo003o0?ooocl0oooo00@0oonZ05D000000000
EJ[o0P3oool0102ZE@0000000000:`20e?lI0?ooo`040?ooe020:`00000005FZoa80oooo00@0omB0
02/0000002/0P=Co>`3oool0103oom@0P2/00000001EZ_lR0?ooo`040?ooZP1E0000000005FZo`80
oooo00@0ZUD00000000002/0P=Coo`3oool90?ooo`00o`3ooolo0?ooo`040?ooZP1E0000000005FZ
o`80oooo00X0oooD080[00000000000[083Do`3oool0oonZ05D000000000EJ[o4`3oool02@3oom@0
P2/00000001EZ_l0oooo0?ooZP1E0000000005FZo`0:0?ooo`030:YE00000000000000H0000000<0
:h3D0?ooo`3oool0=P3oool0103oom@0P2/00000001EZ_lR0?ooo`040?ooZP1E0000000005FZo`80
oooo00D0oooD080[00000000000[083Do`3o0?ooo`P0oooo003o0?ooocl0oooo00@0oonZ05D00000
0000EJ[o0`3oool02@3oojX0E@000000000005D0Z_oo0?ooZP1E0000000005FZo`0E0?ooo`070:YE
001EZ_l0oooo0?ooZP1E0000000005FZo`0:0?ooo`030:YE00000000000000H0000000<0:h3D0?oo
o`3oool0>03oool00`2ZE@00EJ[o0?ooo`0Q0?ooo`040?ooZP1E0000000005FZo`<0oooo00D0oonZ
05D000000000001E0:[oo`3o0?ooo`L0oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?oo
o`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo
0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00J@3oool00`3DP2/00000
000000050000000405FZo`3oool0oooo0?nZE@<0000000<0EJ[o0?ooo`3oool00P3oool01@3oZUD0
0000000000000000EJ[o07/0oooo00@0oonZ05D0000002/0P=Co0`3oool01@3oZUD0000000000000
0000EJ[o00@0oooo00D0ojYE000000000000000005FZo`1j0?ooo`050?oDP00[000000000000000[
P=@0103oool01@3oZUD00000000000000000EJ[o00@0oooo00D0ojYE000000000000000005FZo`1j
0?ooo`050:YE00000000000000000000EJX0103oool01@3oZUD00000000000000000EJ[o00@0oooo
00D0ojYE000000000000000005FZo`1f0?ooo`040?ooe020:`00000002^0e0@0oooo00D0ojYE0000
00000000000005FZo`040?ooo`050?nZE@00000000000000001EZ_l0103oool01@3oZUD000000000
00000000EJ[o02D0oooo001Y0?ooo`030?oDP00[0000000000D0000000<0EJ[o0?ooo`3oZUD01@00
0000101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo07P0oooo00@0oonZ05D0000002/0
P=Co0P3oool00`3oZUD00000000000030000000405FZo`3oool0oooo0?nZE@D0000000<0EJ[o0?oo
o`3oool0MP3oool00`3oZUD00000000000030000000402^0e03oool0oooo0?nZE@D0000000@0EJ[o
0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?ooo`1e0?ooo`030?ooe020:`00000000@0000000@0
05FZ0?ooo`3oool0ojYE1@000000101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo07<0
oooo00@0oooD080[00000000:h3D0`3oool00`3oZUD00000000000030000000405FZo`3oool0oooo
0?nZE@D0000000@0EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?ooo`0R0?ooo`00JP3oool0
102ZE@0000000000E@2Zool40?ooo`0B0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo
0?ooe020:`00000002^0e03oool0e80[00000000:h00e?ooM@3oool00`2ZE@000000000000050000
000C001EZP3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0
oooo0=B0:`00000002^00=Coo`1f0?ooo`0K0?ooe020:`00000002^0e03oool0ojYE0000000005D0
Z_oo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo0?ooe020:`00000002^0e03oool0
e80[00000000:h00e?oo07H0oooo01/0omB002/000000000EJ[o0?ooo`3oZUD000000000:`20e?l0
oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0oooD080[00000000:h3D0?ooo`3DP2/0
0000000[P03Dool0M03oool0103oom@0P2/00000000[P=@20?ooo`0K0?ooe020:`00000002^0e03o
ool0e80[00000000:h00e?oo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo0?ooe020
:`00000002^0e03oool0e80[00000000:h00e?oo02<0oooo001Z0?ooo`050?ooe020:`0000000000
E@2Zool00`3oool04P3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000
:`20e?l0oooo0?oDP00[0000001E0:[oogD0oooo00<0ZUD00000000000001@0000004`00EJX0omB0
02/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800:`00
0000E@2Zool0MP3oool06`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`3oe800:`00
0000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E
0:[oo`1f0?ooo`0K0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?oDP00[0000000[
083Do`3oool0omB002/0000005D0Z_oo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo
07@0oooo00@0oooD080[00000000:h3D0P3oool06`3oe800:`000000:`20e?l0oooo0?oDP00[0000
001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0
oooo0?oDP00[0000001E0:[oo`0S0?ooo`00J`3oool01@3oom@0P2/00000000005D0Z_oo0080oooo
0180omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB002/0000005D0Z_oo0?ooo`3o
ojX0E@000000:`20e?me0?ooo`0K0?nZE@00000005FZ0?ooo`3oojX0E@000000:`20e?l0oooo0?oD
P00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0
000002/0P=Co07H0oooo01/0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB002/0
000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000
:`20e?l0MP3oool06`3oojX0E@000000001EZ_l0oooo0?nZE@000000001E0:[oo`3oe800:`000000
E@2Zool0oooo0?ooZP1E0000000[083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083D
o`1d0?ooo`040?ooe020:`00000002^0e080oooo01/0omB002/0000005D0Z_oo0?ooo`3oojX0E@00
0000:`20e?l0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB002/0000005D0Z_oo
0?ooo`3oojX0E@000000:`20e?l08`3oool006`0oooo01P0oooD080[00000000001E0:[oo`3oool0
ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0
E@000000001EZ_me0?ooo`0K0?ooe020:`00000005FZo`3oojX0E@000000:`20e?l0oooo0?nZE@00
0000001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D00000
0000EJ[o07H0oooo01/0ojYE000000000000EJ[o0?ooo`3oZUD000000000E@2Zool0ojYE00000000
05D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001E
Z_l0M`3oool00`3oZUD00000000000030000000D05FZo`3oool0ojYE0000000005D0Z_oo0?ooo`3o
ojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_md0?ooo`040?oo
e020:`00000002^0e080oooo01/0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE
0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@00
0000001EZ_l08`3oool006d0oooo01L0oooD080[0000000005FZ0?ooo`3oZUD000000000E@2Zool0
oooo0?ooZP1E0000000005FZo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`1f0?oo
o`0J0?oDP00[000002^00=CoZP1E0000000[083Do`3oool0ojYE0000000005D0Z_oo0?ooo`3oojX0
E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_mf0?ooo`030?nZE@00
0000000000@0000001@005FZ0?ooo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`3o
ZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZogL0oooo00<0oonZ05D0000000000P000000
5@0005D0Z_oo0?ooo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`3oZUD000000000
E@2Zool0oooo0?ooZP1E0000000005FZo`1d0?ooo`040?ooe020:`00000002^0e080oooo01/0ojYE
0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@00
0000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l08`3oool006h0oooo01H0
omB002/0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000
001E0:[oo`3oool0oonZ05D0000002/0P=CoM`3oool06@3DP2/0000002^0P01E0000000[083Do`3o
ool0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB002/0000005D0Z_oo0?ooo`3o
ojX0E@000000:`20e?l0MP3oool0103oe800:`00000[P020E@020000000E02^0e03oool0oooo0?oD
P00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0
000002/0P=Co07H0oooo01/0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0omB002/0
000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000
:`20e?l0L@3oool01`3oom@0P2/002^0e03oom@0P2/00000000[P=@00P3oool06`3oe800:`000000
E@2Zool0oooo0?ooZP1E0000000[083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083D
o`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`0S0?ooo`00J@3oool06`3oZUD00000
0000E@2Zool0oooo0?ooZP1E0000000005FZo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E
0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`1g0?ooo`0I0?ooe020:`000000
0000000002/0P=Co0?ooo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`00
0000:`20e?l0oooo0?oDP00[0000001E0:[oo`1f0?ooo`040?ooZP1E0000001E0:[oo`D0oooo0180
omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800
:`000000E@2Zoomf0?ooo`0K0?ooZP1E0000000[083Do`3oool0omB002/0000005D0Z_oo0?oDP00[
0000000[083Do`3oool0omB002/0000005D0Z_oo0?oDP00[0000000[083Do`3oool0omB002/00000
05D0Z_oo0740oooo00L0oooD080[00000000000[02/[00000000:h3D0080oooo01/0omB002/00000
02/0P=Co0?ooo`3oe800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Z
ool0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool08`3oool006T0oooo01/0oonZ05D0
00000000EJ[o0?ooo`3oZUD000000000:`20e?l0oooD080[00000000:h3D0?ooo`3DP2/00000000[
P03Dool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0N03oool0603oZUD000000000
000002/0P=Co0?ooo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000
000[P=@0oooo0=B0:`00000002^00=CoogH0oooo01/0oooD080[00000000EJ[o0?ooo`3oZUD00000
0000E@2Zool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0oooD080[00000000:h3D
0?ooo`3DP2/00000000[P03Dool0MP3oool06`3oojX0E@000000000[P=@0oooo0=B0:`000000001E
0:[oo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo
0=B0:`00000002^00=Coo`1c0?ooo`050:YE0000000000000000000[P=@00P3oool06`3oom@0P2/0
0000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^0
0=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`0S0?ooo`00JP3oool00`2ZE@00
00000000000300000004001EZP3oool0oooo0?nZE@D0000000@0EJ[o0?ooo`3oool0ojYE1@000000
0`1EZ_l0oooo0?ooo`1h0?ooo`040:YE00000000000[083Do`80oooo00<0ojYE0000000000000`00
0000101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo07H0oooo00<0omB002/000000000
0`000000100[P=@0oooo0?ooo`3oZUD50000000405FZo`3oool0oooo0?nZE@D0000000<0EJ[o0?oo
o`3oool0MP3oool00`3DP2/00000000000030000000402^0e03oool0oooo0?nZE@D0000000@0EJ[o
0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?ooo`1c0?ooo`040?nZE@000000000002^0e0<0oooo
00<0ojYE0000000000000`000000101EZ_l0oooo0?ooo`3oZUD50000000405FZo`3oool0oooo0?nZ
E@D0000000<0EJ[o0?ooo`3oool08P3oool006/0oooo00D0e80[0000000000000000001EZP040?oo
o`050?nZE@00000000000000001EZ_l0103oool01@3oZUD00000000000000000EJ[o07/0oooo00@0
oonZ05D0000002/0P=Co0`3oool01@3oZUD00000000000000000EJ[o00@0oooo00D0ojYE00000000
0000000005FZo`1j0?ooo`050?oDP00[0000000000000000EJX0103oool01@3oZUD0000000000000
0000EJ[o00@0oooo00D0ojYE000000000000000005FZo`1j0?ooo`050:YE0000000000000000000[
P=@0103oool01@3oZUD00000000000000000EJ[o00@0oooo00D0ojYE000000000000000005FZo`1g
0?ooo`030:YE00000000:h3D00@0oooo00D0ojYE000000000000000005FZo`040?ooo`050?nZE@00
000000000000001EZ_l0103oool01@3oZUD00000000000000000EJ[o02D0oooo003o0?ooool0oooo
l03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0
ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`
0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool005h0ooooo`00003o000006d00000
9@3oool005h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0C0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0:0?ooo`@0o`00503oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08`3oool005h0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1@0?ooo`D0o`00>@3oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo06D0oooo
1P3o003o0?ooood0oooo00<000000?ooo`3oool08`3oool004d0oooo00D0ojYE0000000000000000
05FZo`0<0?ooo`030000003oool0oooo0640oooo203o003o0?ooool0oooo00<000000?ooo`3oool0
8`3oool004`0oooo00<0ojYE0000000000000`0000000`1EZ_l0oooo0?ooo`090?ooo`030000003o
ool0oooo05h0oooo203o003o0?ooool0oooo0`3oool00`000000oooo0?ooo`0S0?ooo`00B`3oool0
2@3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`0:0?ooo`030000003oool0oooo05`0
oooo1P3o003o0?ooool0oooo1`3oool00`000000oooo0?ooo`0S0?ooo`00B`3oool02@3oe800:`00
0000:`20e?l0oooo0?oDP00[0000001E0:[oo`0:0?ooo`030000003oool0oooo05L0oooo203o003o
0?ooool0oooo2P3oool00`000000oooo0?ooo`0S0?ooo`00B`3oool02@3oe800:`000000E@2Zool0
oooo0?ooZP1E0000000[083Do`0:0?ooo`030000003oool0oooo05D0oooo203o003o0?ooool0oooo
303oool00`000000oooo0?ooo`0S0?ooo`00B`3oool02@3oZUD000000000E@2Zool0oooo0?ooZP1E
0000000005FZo`0:0?ooo`D00000D03oool60?l00?l0ooooo`3oool=0?ooo`D000009@3oool004/0
oooo00T0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l02P3oool00`000000oooo0?oo
o`1>0?ooo`P0o`00o`3ooooo0?oooa<0oooo00<000000?ooo`3oool08`3oool004/0oooo00T0omB0
02/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l02P3oool00`000000oooo0?ooo`1;0?ooo`P0
o`00o`3ooooo0?oooaH0oooo00<000000?ooo`3oool08`3oool004/0oooo00T0omB002/0000002/0
P=Co0?ooo`3oe800:`000000E@2Zool02P3oool00`000000oooo0?ooo`190?ooo`H0o`00o`3ooooo
0?oooaX0oooo00<000000?ooo`3oool08`3oool004/0oooo00T0oooD080[00000000:h3D0?ooo`3D
P2/00000000[P03Dool02P3oool00`000000oooo0?ooo`140?ooo`P0o`00o`3ooooo0?oooad0oooo
00<000000?ooo`3oool08`3oool004`0oooo00<0ojYE0000000000000`0000000`1EZ_l0oooo0?oo
o`090?ooo`030000003oool0oooo0480oooo203o003o0?ooool0oooo7`3oool00`000000oooo0?oo
o`0S0?ooo`00C@3oool01@3oZUD00000000000000000EJ[o00`0oooo00<000000?ooo`3oool0@03o
ool50?l00?l0ooooo`3ooolT0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0
oooo03/0oooo203o003o0?ooool0oooo9P3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`00
0000oooo0?ooo`0i0?ooo`P0o`00o`3ooooo0?ooobP0oooo00<000000?ooo`3oool08`3oool005h0
oooo00<000000?ooo`3oool0=03oool80?l00?l0ooooo`3oool]0?ooo`030000003oool0oooo02<0
oooo001N0?ooo`030000003oool0oooo0380oooo203o003o0?ooool0oooo;`3oool00`000000oooo
0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0_0?ooo`H0o`00o`3ooooo0?oooc@0oooo00<0
00000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0:P3oool90?l00?l0ooooo`3ooolf
0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo02P0oooo203o003o0?oo
ool0oooo>@3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0V0?ooo`D0
o`00o`3ooooo0?oooch0oooo00<000000?ooo`3oool08`3oool005h0oooo0`00000Q0?ooo`P0o`00
o`3ooooo0?ooocd0oooo1000000U0?ooo`00GP3oool00`000000oooo0?ooo`0P0?ooo`L0o`00o`3o
oooo0?oood80oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0803oool2
0?l00?l0ooooo`3ooom70?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo
0200oooo0P3o003o0?ooool0ooooA`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000
oooo0?ooo`0P0?ooo`80o`00o`3ooooo0?ooodL0oooo00<000000?ooo`3oool08`3oool005h0oooo
00<000000?ooo`3oool0803oool20?l007H0ooooo`00002]000002<0oooo00<000000?ooo`3oool0
8`3oool005h0oooo00<000000?ooo`3oool0803oool20?l007H0ooooo`00002]000002<0oooo00<0
00000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0803oool20?l007H0ooooo`00002]
000002<0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0803oool20?l0
07H0ooooo`00002]000002<0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3o
ool0803oool20?l007H0ooooo`00002]000002<0oooo00<000000?ooo`3oool08`3oool005h0oooo
00<000000?ooo`3oool0803oool20?l007H0ooooo`00002]000002<0oooo00<000000?ooo`3oool0
8`3oool005h0oooo00<000000?ooo`3oool0803oool20?l007H0ooooo`00002]000002<0oooo00<0
00000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0803oool20?l007H0ooooo`00002]
000002<0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0803oool20?l0
07H0ooooo`00002]000002<0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3o
ool0803oool20?l007H0ooooo`00002]000002<0oooo00<000000?ooo`3oool08`3oool005h0oooo
0`00000P0?ooo`<0o`00M@3ooooo00000:d00000803oool4000002D0oooo001N0?ooo`030000003o
ool0oooo0240oooo0P3o001e0?ooool00000[@00000S0?ooo`030000003oool0oooo02<0oooo001N
0?ooo`030000003oool0oooo0240oooo0P3o001e0?ooool00000[@00000S0?ooo`030000003oool0
oooo02<0oooo001N0?ooo`030000003oool0oooo0240oooo0`3o001d0?ooool00000[@00000S0?oo
o`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo0280oooo0`3o001c0?ooool0
0000[@00000S0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo02<0oooo
0`3o001b0?ooool00000[@00000S0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003o
ool0oooo02@0oooo0P3o001b0?ooool00000[@00000S0?ooo`030000003oool0oooo02<0oooo001N
0?ooo`030000003oool0oooo02D0oooo00<0o`000?ooo`3oool0GP3ooooo00000;l000008`3oool0
0`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0U0?ooo`030?l0003oool0oooo
05h0oooo00<000000?ooo`3oool0o`3ooonZ0?oooa8000008`3oool00`000000oooo0?ooo`0S0?oo
o`00GP3oool00`000000oooo0?ooo`0U0?ooo`80o`00G`3oool00`000000oooo0?ooo`3o0?ooojX0
oooo4P00000S0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo02H0oooo
0P3o001N0?ooo`030000003oool0oooo0?l0ooooZP3ooolB000002<0oooo00<000000?ooo`3oool0
8`3oool005h0oooo00<000000?ooo`3oool09P3oool20?l005h0oooo00<000000?ooo`3oool0o`3o
oonZ0?oooa8000008`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0V
0?ooo`80o`00GP3oool00`000000oooo0?ooo`3o0?ooojX0oooo4P00000S0?ooo`030000003oool0
oooo02<0oooo001N0?ooo`030000003oool0oooo02H0oooo0`3o001M0?ooo`030000003oool0oooo
0?l0ooooZP3ooolB000002<0oooo00<000000?ooo`3oool08`3oool005h0oooo0`00000W0?ooo`80
o`00G@3oool00`000000oooo0?ooo`3o0?ooojX0oooo4P00000P0?ooo`@000009@3oool005h0oooo
00<000000?ooo`3oool0:03oool20?l005`0oooo00<000000?ooo`3oool0o`3ooonZ0?oooa800000
8`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0Y0?ooo`80o`00F`3o
ool00`000000oooo0?ooo`3o0?ooojX0oooo4P00000S0?ooo`030000003oool0oooo02<0oooo001N
0?ooo`030000003oool0oooo02T0oooo0P3o001K0?ooo`030000003oool0oooo0?l0ooooZP3ooolB
000002<0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0:P3oool20?l0
05X0oooo00<000000?ooo`3oool0o`3ooonZ0?oooa8000008`3oool00`000000oooo0?ooo`0S0?oo
o`00GP3oool00`000000oooo0?ooo`0[0?ooo`<0o`00F03oool00`000000oooo0?ooo`3o0?ooojX0
oooo4P00000S0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo02/0oooo
103o001G0?ooo`030000003oool0oooo0?l0ooooZP3ooolB000002<0oooo00<000000?ooo`3oool0
8`3oool005h0oooo00<000000?ooo`3oool0;@3oool30?l005H0oooo00<000000?ooo`3oool0o`3o
oonZ0?oooa8000008`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0^
0?ooo`@0o`00E03oool00`000000oooo0?ooo`3o0?ooojX0oooo4P00000S0?ooo`030000003oool0
oooo02<0oooo001N0?ooo`030000003oool0oooo02l0oooo103o001C0?ooo`030000003oool0oooo
0?l0ooooZP3ooolB000002<0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3o
ool0<@3oool40?l00540oooo00<000000?ooo`3oool0o`3ooonZ0?oooa8000008`3oool00`000000
oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0b0?ooo`@0o`00D03oool00`000000oooo
0?ooo`3o0?ooojX0oooo4P00000S0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003o
ool0oooo03@0oooo0`3o001?0?ooo`030000003oool0oooo0?l0ooooZP3ooolB000002<0oooo00<0
00000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0=@3oool40?l004d0oooo00<00000
0?ooo`3oool0o`3ooonZ0?oooa8000008`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`00
0000oooo0?ooo`0f0?ooo`@0o`00C03oool00`000000oooo0?ooo`3o0?ooojX0oooo4P00000S0?oo
o`030000003oool0oooo02<0oooo001N0?ooo`<00000>03oool30?l004/0oooo00<000000?ooo`3o
ool0o`3ooonZ0?oooa800000803oool4000002D0oooo001N0?ooo`030000003oool0oooo03T0oooo
103o00190?ooo`030000003oool0oooo0?l0ooooZP3ooolB000002<0oooo00<000000?ooo`3oool0
8`3oool005h0oooo00<000000?ooo`3oool0>P3oool40?l004P0oooo00<000000?ooo`3oool0o`3o
oonZ0?oooa8000008`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0l
0?ooo`<0o`00A`3oool00`000000oooo0?ooo`3o0?ooojX0oooo4P00000S0?ooo`030000003oool0
oooo02<0oooo001N0?ooo`030000003oool0oooo03d0oooo103o00150?ooo`030000003oool0oooo
0?l0ooooZP3ooolB000002<0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3o
ool0?P3oool40?l004@0oooo00<000000?ooo`3oool0o`3ooonZ0?oooa8000008`3oool00`000000
oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`100?ooo`<0o`00@`3oool00`000000oooo
0?ooo`3o0?ooo`<0oooo00<0ZUD000000000EJX0@`3oool00`3oom@0P2/[083Do`0;0?ooo`030?oo
ZP1E:h00e?oo0500oooo4P00000S0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003o
ool0oooo0440oooo103o00110?ooo`030000003oool0oooo0?l0oooo0`3oool00`2ZE@000000001E
ZP120?ooo`030?ooe020:b/0P=Co00d0oooo00<0omB002/[P03Dool0C`3ooolB000002<0oooo00<0
00000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0@P3oool40?l00400oooo00<00000
0?ooo`3oool0o`3oool30?ooo`030:YE0000000005FZ0480oooo00<0ZUD0001EZP3oool03P3oool0
0`3DP2/005FZ0?ooo`1>0?oooa8000008`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`00
0000oooo0?ooo`140?ooo`<0o`00?`3oool00`000000oooo0?ooo`2V0?ooo`040?ooZP1E00000000
05FZo`@0oooo00`0ojYE000000000000:h3D0?ooZP1E0000000005FZo`3oool0ZUD000000000EJX2
0?ooo`030=B0:`00000005FZ00<0oooo00D0ZUD0000000000000000002^0e0030?ooo`080?oDP00[
000000000000:`20e:X0E@000000001EZ_l20?ooo`060?nZE@000000000000000000:h00e?oo2P3o
ool0103oe800:`000000:`20e?l40?ooo`050:YE0000000000000000000[P=@00P3oool04`3oe800
:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oool0ojYE0000000005D0Z_oo0?ooo`2ZE@00
0000001EZP2ZE@000P0000000`0[P=@0oooo0?ooo`020?ooo`050:YE0000000000000000000[P=@0
0P3oool0103oojX0E@000000:`20e?l30?ooo`0@0=B0:`0000000000000[P03DojX0E@000000:`20
e?l0oooo0?oDP00[000000000000:`20e?l0oooo0:YE0080000000T002^00:Z0:`00000005FZ0?oo
o`3oojX0E@000000:`20e?l0103oool01@2ZE@000000000000000000:h3D00L0oooo00P0ojYE0000
:`20e?l0oooo0?ooZP1E0000000005FZo`@0oooo00@0ojYE000000000000:h3D0P3oool00`3oe800
:`0005FZo`1>0?oooa8000008`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo
0?ooo`150?ooo`<0o`00?P3oool00`000000oooo0?ooo`2V0?ooo`040?ooZP1E0000000005FZo`<0
oooo00d0oonZ05D00000000002^00=Coo`3oojX0E@000000001EZ_l0oooo0:YE0000000005FZ0080
oooo00<0e80[00000000EJX00P3oool00`2ZE@000000000000030000000402^0e03oool0oooo0:YE
0080000000L0000[083DZP1E0000000005FZo`3oool0ojYE00D0000000<0001E0:[oo`3oool0203o
ool0103oe800:`000000:`20e?l30?ooo`030:YE00000000000000<000000180:h3D0?ooo`3oe800
:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oool0ojYE0000000005D0Z_oo0?ooo`2ZE@06
0000000402^0e03oool0oooo0:YE00D0000000H0:h3D0?ooo`3oojX0E@000000:`20e?l20?ooo`03
0?nZE@000000000000@0000000@002^00=Coo`3oool0ZUD00P0000000`0002/0P=Co0?nZE@060000
0006001EZP3oool0oonZ05D0000002/0P=Co0`3oool00`2ZE@000000000000030000000302^0e03o
ool0oooo00@0oooo00P0ZUD00000E@2Zool0oooo0?ooZP1E0000000005FZo`<0oooo00D0oonZ05D0
0000000002^00=Coo`020?ooo`030?ooZP1E000005FZ04h0oooo4P00000S0?ooo`030000003oool0
oooo02<0oooo00140?ooo`050=B0:`00000000000000000[P=@0103oool01@3oZUD0000000000000
0000EJ[o00`0oooo00<000000?ooo`3oool0AP3oool30?l003d0oooo00<000000?ooo`3oool0YP3o
ool0103oojX0E@000000001EZ_l30?ooo`0=0=B0:`000000000005FZo`3oool0oonZ05D000000000
EJ[o0?ooo`2ZE@000000001EZP020?ooo`0O0=B0:`00000005FZ0?ooo`3oe800:`000000001EZ_l0
oooo0?nZE@000000001E0:[oo`3oom@0P2/00000000[P=@0oooo0?ooZP1E0000000005FZo`3oojX0
E@000000000[P=@0oooo0?ooe020:`00000002^0e0090?ooo`040?oDP00[0000000[083Do`80oooo
02h0omB002/000000000EJ[o0?ooo`3oZUD000000000E@2Zool0omB002/0000002/0P=Co0?ooo`3o
e800:`000000E@2Zool0oooo0?nZE@000000001E0:[oo`3oool0ZUD00000000002/0P=Co0?ooo`3D
P2/000000000E@2Zool0omB002/000000000EJ[o0?ooo`3oZUD000000000E@2Zool0oonZ05D00000
02/0P=Co0P3oool03@3DP2/00000000[P03Dool0oooD080[0000000002^00=Coo`3oom@0P2/00000
000[P=@00P3oool03@2ZE@000000000[P03Dool0oonZ05D00000000005FZ0?ooo`3oojX0E@000000
:`20e?l00P3oool02@3oe800:`000000001EZ_l0oooo0?nZE@000000001E0:[oo`040?ooo`090?oo
ZP1E000002^00=Coo`3oool0oonZ05D000000000EJ[o00<0oooo00@0e80[000000000000EJ[o0`3o
ool0103oom@0P2/00000E@2Zoom=0?oooa8000008`3oool00`000000oooo0?ooo`0S0?ooo`00@`3o
ool00`3DP2/000000000000300000004001EZP3oool0oooo0?nZE@D0000000<0EJ[o0?ooo`3oool0
2@3oool00`000000oooo0?ooo`170?ooo`80o`00?@3oool00`000000oooo0?ooo`2V0?ooo`040?oo
ZP1E0000000005FZo`80oooo00@0omB002/00000000005FZ0P3oool0203oojX0E@000000001EZ_l0
oooo0:YE0000000005FZ0P3oool0203DP2/00000001EZP3oool0e80[00000000:h00e?oo1@3oool0
3@3oom@0P2/00000001EZ_l0oooo0?ooZP1E0000000005FZo`3oe800:`000000:`20e?l03P3oool0
103oe800:`000000:`20e?l20?ooo`040=B0:`00000002^00=Coo`D0oooo0180omB002/0000002/0
P=Co0?ooo`3oe800:`000000E@2Zool0oooo0?nZE@000000001E0:[oo`3oool0ZUD000000000EJX2
0?ooo`080?ooZP1E0000000[083Do`3DP2/00000000[P03Dool50?ooo`040?ooZP1E0000000[083D
o`80oooo00d0ojYE000000000000EJ[o0?ooo`3DP2/00000000[P03Dool0oooD080[00000000EJ[o
0080oooo00<0ZUD000000000EJX00P3oool0202ZE@000000001EZP3oool0oonZ05D0000002/0P=Co
0P3oool0103DP2/00000000[P03Dool90?ooo`090?ooZP1E000002^00=Coo`3oool0oonZ05D00000
0000EJ[o0080oooo00@0omB002/00000000005FZ103oool0103oom@0P2/00000E@2Zoom=0?oooa80
00008`3oool00`000000oooo0?ooo`0S0?ooo`00@P3oool04P3oojX0E@000000000[P=@0oooo0?nZ
E@000000000[083Do`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`X0oooo00<00000
0?ooo`3oool0A`3oool20?l003d0oooo00<000000?ooo`3oool0:`3ooomB0?l002T0oooo00X0oonZ
05D000000000000[083Do`3oool0ZUD00000000005D0Z_oo0P3oool0203oojX0E@000000001EZ_l0
oooo0:YE0000000005FZ0P3oool01@3DP2/00000001EZP3oool0e80[00L0000000h0EJ[o0?ooe020
:`00000005FZo`3oool0oonZ05D000000000EJ[o0?oDP00[0000001E0:[oo`h0oooo00@0omB002/0
000002/0P=Co0P3oool00`3DP2/00000000000050000000C05FZo`3oe800:`000000:`20e?l0oooo
0?oDP00[0000000[083Do`3oool0ojYE0000000005D0Z_oo0?ooo`2ZE@00000002^0e0020?ooo`05
0?ooZP1E0000000005FZo`3DP2/01`0000001@1EZ_l0oonZ05D000000000EJ[o0080oooo00<0oooD
080[00000000100000001P00:h00e?oo0?ooe020:`00000005FZo`80oooo00<0ZUD000000000EJX0
0P3oool0203DP2/00000001EZP3oool0oonZ05D000000000EJ[o0P3oool00`3DP2/0000000000005
0000000305FZo`3oool0oooo0080oooo00l0oonZ05D00000:h00e?oo0?ooo`3oojX0E@0000000000
02/0P=Co0?ooo`2ZE@0000000000E@2Zool0103oool0103oom@0P2/00000E@2Zoom=0?oooa800000
8`3oool00`000000oooo0?ooo`0S0?ooo`00@P3oool04P3oZUD000000000E@2Zool0oooo0?ooe020
:`00000005FZo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`X0oooo00<000000?oo
o`3oool0A`3oool20?l003d0oooo00<000000?ooo`3oool0:`3ooomB0?l002T0oooo00H0oonZ05D0
0000000000000000:`20P5D20000000<02^0e03oool0oooo0?ooo`3oojX0E@000000001EZ_l0oooo
0:YE0000000005FZ0P3oool01@3DP2/00000001EZP3oool0ojYE00H0000000l0000[083Do`3oom@0
P2/00000001EZ_l0oooo0?ooZP1E0000000005FZo`3oe800:`000000:`20e?l03P3oool0103oe800
:`000000:`20e?l20?ooo`030?nZE@000000000000@0000001@0000[083Do`3oe800:`000000:`20
e?l0oooo0?oDP00[0000000[083Do`3oool0ojYE0000000005D0Z_oo0?ooo`2ZE@000000001EZP80
oooo00D0oonZ05D0000002/0P=Co0?nZE@06000000060000:`20e?l0oonZ05D000000000EJ[o1@3o
ool02P3oe800:`0000000000000002^00=Coo`3oom@0P2/00000001EZ_l20?ooo`030:YE00000000
05FZ0080oooo00P0e80[00000000EJX0oooo0?ooZP1E0000000005FZo`80oooo00<0ojYE00000000
0000100000000`0002/0P=Co0?ooo`030?ooo`070?ooZP1E0000001E0:[oo`3oool0oonZ05D00002
000000050000:`20P5D000000000000[P=@01@3oool0103oom@0P2/00000E@2Zoom=0?oooa800000
8`3oool00`000000oooo0?ooo`0S0?ooo`00A`3oool03@3oom@0P2/00000000[P=@0omB002/00000
05D0Z_oo0?ooo`3oojX0E@000000:`20e?l02P3oool5000004D0oooo0P3o000m0?ooo`030000003o
ool0oooo0:H0oooo00D0oonZ05D000000000EH2002/0000200000003000[P03Dool0oooo0080oooo
02T0oonZ05D000000000EJ[o0?ooo`2ZE@0000000000:`20e?l0oooD080[0000000005FZ0?ooo`3o
e800:`000000E@2Zool0oooo0?oDP00[0000001E0:[oo`3oom@0P2/00000001EZ_l0oooo0?ooZP1E
0000000005FZo`3oojX0E@000000000[P=@0oooo0?ooZP1E0000000[083Do`090?ooo`040?oDP00[
0000000[083Do`80oooo00l0omB002/0000005D0Z_oo0?ooo`3oe800:`000000E@2Zool0omB002/0
0000000005FZ0?ooo`3oZUD00P0000007@0[P=@0oooo0=B0:`000000001E0:[oo`3oool0ZUD00000
000002/0P=Co0?ooo`3DP2/000000000E@2Zool0omB002/0000005D0Z_oo0?ooo`3oe800:`000000
E@2Zool0oonZ05D00000000005FZ0080oooo00d0oonZ05D0000005D0Z_oo0?ooo`3DP2/00000000[
P03Dool0oooD080[00000000EJ[o0080oooo00<0ZUD000000000EJX00P3oool0203DP2/00000001E
ZP3oool0oonZ05D00000000005FZ0P3oool02@3oe800:`000000E@2Zool0oooo0?oDP00[0000001E
0:[oo`050?ooo`090:YE000005D0Z_oo0?ooo`3oojX0E@000000001EP800:`000080000000<002^0
0=Coo`3oool0103oool00`3oojX0E@00001EZP1>0?oooa8000007`3oool5000002D0oooo00120?oo
o`060?ooZP1E0000000[083Do`3oool0ojYE0P0000002P1EZ_l0ojYE0000000005D0Z_oo0?ooo`3o
ojX0E@000000001EZ_l:0?ooo`030000003oool0oooo04L0oooo0P3o000m0?ooo`030000003oool0
oooo0:H0oooo00P0oonZ05D000000000EJ[o0?nZE@000000000[083Do`@0oooo00H0oonZ05D00000
0000EJ[o0?ooo`2ZE@060000000402^0e03oool0oooo0:YE00D0000000<0:h3D0?ooe020:`000`00
00001`0005D0Z_nZ05D000000000EJ[o0?ooo`3oZUD01@0000000`00:h00e?oo0?ooo`080?ooo`04
0?oDP00[0000000[083Do`<0oooo00<0ZUD00000000000000`000000100[P=@0oooo0?oDP00[000:
00000004001EZP3oool0oooo0:YE00H0000000@005FZ0?ooo`3oool0ZUD01@000000100[P=@0oooo
0?ooZP1E000300000003000[P03Dool0ZUD000D0000000<005FZ0?ooe020:`000`0000001@0005D0
Z_oo0:YE0000000005FZ0080oooo00H0e80[00000000EJX0oooo0?ooZP1E000300000003000[P03D
ool0ZUD000D0000000<0:h3D0?ooo`3oool0103oool0303oZUD0000[083Do`3oool0oonZ05D00000
0000EJ[o0?nZE@000000000[083Do`H0oooo00<0omB002/0001EZ_l0CP3ooolB000002<0oooo00<0
00000?ooo`3oool08`3oool00480oooo00<0oooD080[00000000100000002`00:h00e?oo0?nZE@00
0000001E0:[oo`3oool0oonZ05D000000000EJ[o00X0oooo00<000000?ooo`3oool0A`3oool20?l0
03d0oooo00<000000?ooo`3oool0YP3oool02@3oojX0E@000000001EZ_l0oooo0=B0:`000000000[
083Do`030?ooo`090?ooZP1E0000000005FZo`3oool0ZUD000000000EJX0ZUD00080000000<005FZ
0?ooo`3oool00P3oool0203DP2/00000000000000000:h3D0?ooo`3oom@0P2/00`0000001@0005D0
Z_nZ05D000000000EJ[o0080oooo00H0ojYE0000000000000000000[P03Dool:0?ooo`040?oDP00[
0000000[083Do`@0oooo00D0e80[000000000000000002^0e0020?ooo`0=0?oDP00[0000000[082Z
P00[000000000000E@2Zool0omB002/000000000001E0:[oo`020?ooo`040:YE0000000005FZ0:YE
0080000000<005FZ0?ooo`3oool00P3oool01@3DP2/00000000000000000:h3D0080oooo00T0oonZ
05D0000002/0P81E0000000002/0P=Co0?ooo`2ZE@000`0000001000:h00e?oo0?ooe020:`030000
00050000E@2Zool0ZUD000000000EJX00P3oool03@3DP2/00000001EZP3oool0oonZ05D0000002/0
P81E0000000002/0P=Co0?ooo`3DP2/00`0000000`0[P=@0oooo0?ooo`060?ooo`0<0:YE0000EJX0
oooo0?ooZP1E0000000005FZo`3oool0e80[0000000002/0P=Co1@3oool00`3DP2/005FZ0?ooo`1>
0?oooa8000008`3oool00`000000oooo0?ooo`0S0?ooo`00@`3oool00`2ZE@000000000000020000
000<001EZP3oool0oooo0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co2P3oool00`00
0000oooo0?ooo`160?ooo`<0o`00?@3oool00`000000oooo0?ooo`2V0?ooo`040?ooZP1E00000000
05FZo`80oooo00@0ZUD00000000002/0P=Co6@3oool0103oom@0P2/00000001EZ_lG0?ooo`040?oD
P00[0000000[083Doc/0oooo00@0oooD080[00000000EJ[o803oool01`3oom@0P2/005FZo`3oojX0
E@000000001EZ_l00P3oool0102ZE@0000000000:`20e?l30?ooo`030?nZE@00:h00e?oo04l0oooo
4P00000S0?ooo`030000003oool0oooo02<0oooo00130?ooo`030=B0:`00000005FZ00D0oooo00T0
omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool02P3oool00`000000oooo0?ooo`140?oo
o`@0o`00?P3oool00`000000oooo0?ooo`2V0?ooo`040?ooZP1E0000000005FZo`80oooo00X0oooD
080[00000000000[083Do`3oool0oonZ05D000000000EJ[o4`3oool02@3oom@0P2/00000001EZ_l0
oooo0?ooZP1E0000000005FZo`0?0?ooo`030:YE00000000000000H0000000<0:h3D0?ooo`3oool0
=P3oool0103oom@0P2/00000001EZ_lR0?ooo`050:YE:`20e:X0E@000000001EZ_l00P3oool0203o
om@0P2/00000000002/0P=Co0?ooo`3oojX0EEFZD@3ooolB000002<0oooo00<000000?ooo`3oool0
8`3oool004<0oooo00@0omB002/00000:h00e?oo103oool02@3oom@0P2/00000000[P=@0oooo0=B0
:`00000002^00=Coo`0:0?ooo`030000003oool0oooo04<0oooo103o000o0?ooo`030000003oool0
oooo0:H0oooo00@0oonZ05D000000000EJ[o0`3oool02@3oojX0E@000000000005D0Z_oo0?ooZP1E
0000000005FZo`0E0?ooo`070:YE001EZ_l0oooo0?ooZP1E0000000005FZo`0?0?ooo`030:YE0000
0000000000H0000000<0:h3D0?ooo`3oool0>03oool00`2ZE@00EJ[o0?ooo`0R0?ooo`040?ooZP1E
0000000005FZo`<0oooo00D0oonZ05D000000000001E0:[oo`1C0?oooa8000008`3oool00`000000
oooo0?ooo`0S0?ooo`00@`3oool00`3oojX0E@0000000003000000040000E@2Zool0oooo0?nZE@D0
000000<0EJ[o0?ooo`3oool02@3oool00`000000oooo0?ooo`120?ooo`<0o`00@@3oool00`000000
oooo0?ooo`3o0?ooojX0oooo4P00000S0?ooo`030000003oool0oooo02<0oooo00130?ooo`030?oo
e020:`00000000<0000000D0001E0:[oo`3oool0oooo0?nZE@030000000305FZo`3oool0oooo00X0
oooo00<000000?ooo`3oool0@03oool40?l00480oooo00<000000?ooo`3oool0o`3ooonZ0?oooa80
00008`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0o0?ooo`@0o`00
@`3oool00`000000oooo0?ooo`3o0?ooojX0oooo4P00000S0?ooo`030000003oool0oooo02<0oooo
001N0?ooo`030000003oool0oooo03h0oooo0`3o00150?ooo`030000003oool0oooo0?l0ooooZP3o
oolB000002<0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0?03oool4
0?l004H0oooo00<000000?ooo`3oool0o`3ooonZ0?oooa8000008`3oool00`000000oooo0?ooo`0S
0?ooo`00GP3oool00`000000oooo0?ooo`0k0?ooo`@0o`00A`3oool00`000000oooo0?ooo`3o0?oo
ojX0oooo4P00000S0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo03X0
oooo0`3o00190?ooo`030000003oool0oooo0?l0ooooZP3ooolB000002<0oooo00<000000?ooo`3o
ool08`3oool005h0oooo00<000000?ooo`3oool0>03oool40?l004X0oooo00<000000?ooo`3oool0
o`3ooonZ0?oooa8000008`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?oo
o`0g0?ooo`@0o`00B`3oool00`000000oooo0?ooo`3o0?ooojX0oooo4P00000S0?ooo`030000003o
ool0oooo02<0oooo001N0?ooo`<00000=P3oool30?l004d0oooo00<000000?ooo`3oool0o`3ooonZ
0?oooa800000803oool4000002D0oooo001N0?ooo`030000003oool0oooo03@0oooo103o001>0?oo
o`030000003oool0oooo0?l0ooooZP3ooolB000002<0oooo00<000000?ooo`3oool08`3oool005h0
oooo00<000000?ooo`3oool0<`3oool40?l004l0oooo00<000000?ooo`3oool0o`3ooonZ0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0
<@3oool40?l00540oooo00<000000?ooo`3oool0o`3ooonZ0?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0<03oool40?l00580oooo00<0
00000?ooo`3oool0o`3ooonZ0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool08`3o
ool005h0oooo00<000000?ooo`3oool0;P3oool40?l005@0oooo00<000000?ooo`3oool0o`3ooonZ
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?oo
o`3oool0;@3oool40?l005D0oooo00<000000?ooo`3oool0o`3ooonZ0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0;03oool30?l005L0
oooo00<000000?ooo`3oool0o`3ooonZ0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool08`3oool005h0oooo00<000000?ooo`3oool0:P3oool40?l005P0oooo00<000000?ooo`3oool0
o`3ooonZ0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool08`3oool005h0oooo00<0
00000?ooo`3oool0:@3oool40?l005T0oooo00<000000?ooo`3oool0o`3ooonZ0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0:03oool3
0?l005/0oooo00<000000?ooo`3oool0o`3ooonZ0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool09`3oool30?l005`0oooo00<000000?oo
o`3oool0o`3ooonZ0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool08`3oool005h0
oooo00<000000?ooo`3oool09@3oool40?l005d0oooo00<000000?ooo`3oool0o`3ooonZ0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0
903oool40?l005h0oooo00<000000?ooo`3oool0o`3ooonZ0?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool08`3oool30?l00600oooo00<0
00000?ooo`3oool0o`3ooonZ0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool08`3o
ool005h0oooo0`00000R0?ooo`<0o`00H@3oool00`000000oooo0?ooo`3o0?ooojX0oooo00<00000
0?ooo`3oool0;`3oool4000002D0oooo001N0?ooo`030000003oool0oooo0240oooo0`3o001R0?oo
o`030000003oool0oooo0?l0ooooZP3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
02<0oooo001N0?ooo`030000003oool0oooo0200oooo0`3o001S0?ooo`030000003oool0oooo0?l0
ooooZP3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000
003oool0oooo01h0oooo103o001T0?ooo`030000003oool0oooo0?l0ooooZP3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo01d0oooo103o
001U0?ooool00000[P00000d0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0
oooo01`0oooo0`3o003o0?ooool0ooooBP3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`00
0000oooo0?ooo`0K0?ooo`<0o`00o`3ooooo0?oood/0oooo00<000000?ooo`3oool08`3oool005h0
oooo00<000000?ooo`3oool06P3oool30?l00?l0ooooo`3ooom<0?ooo`030000003oool0oooo02<0
oooo001N0?ooo`030000003oool0oooo01T0oooo0`3o003o0?ooool0ooooC@3oool00`000000oooo
0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0H0?ooo`<0o`00o`3ooooo0?ooodh0oooo00<0
00000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool05`3oool30?l00?l0ooooo`3ooom?
0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo01L0oooo0P3o003o0?oo
ool0ooooD03oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0F0?ooo`80
o`00o`3ooooo0?oooe40oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0
5@3oool30?l00?l0ooooo`3ooomA0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003o
ool0oooo01@0oooo0`3o003o0?ooool0ooooDP3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool3
000001<0oooo0`3o003o0?ooool0ooooD03oool4000002D0oooo001N0?ooo`030000003oool0oooo
0180oooo0`3o003o0?ooool0ooooE03oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000
oooo0?ooo`0A0?ooo`<0o`00o`3ooooo0?oooeD0oooo00<000000?ooo`3oool08`3oool005h0oooo
00<000000?ooo`3oool0403oool30?l00?l0ooooo`3ooomF0?ooo`030000003oool0oooo02<0oooo
001N0?ooo`030000003oool0oooo00l0oooo0`3o003o0?ooool0ooooE`3oool00`000000oooo0?oo
o`0S0?ooo`00GP3oool00`000000oooo0?ooo`0>0?ooo`<0o`00o`3ooooo0?oooeP0oooo00<00000
0?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool03@3oool30?l00?l0ooooo`3ooomI0?oo
o`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo00`0oooo0`3o003o0?ooool0
ooooFP3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0;0?ooo`<0o`00
o`3ooooo0?oooe/0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool02P3o
ool30?l00?l0ooooo`3ooomL0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0
oooo00X0oooo0P3o003o0?ooool0ooooG@3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`00
0000oooo0?ooo`0:0?ooo`80o`00o`3ooooo0?oooed0oooo00<000000?ooo`3oool08`3oool005h0
oooo00<000000?ooo`3oool02P3oool20?l00?l0ooooo`3ooomM0?ooo`030000003oool0oooo02<0
oooo001N0?ooo`030000003oool0oooo00X0oooo0P3o003o0?ooool0ooooG@3oool00`000000oooo
0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0:0?ooo`80o`00o`3ooooo0?oooed0oooo00<0
00000?ooo`3oool08`3oool005h0oooo0`00000:0?ooo`<0o`00o`3ooooo0?oooeT0oooo1000000U
0?ooo`00;@3oool00`3oZUD0001E0:[oo`0^0?ooo`030000003oool0oooo00/0oooo0P3o003o0?oo
ool0ooooG03oool00`000000oooo0?ooo`0S0?ooo`00:P3oool01P3oe800:`00000000000000001E
0:[oobh0oooo00<000000?ooo`3oool02`3oool20?l00?l0ooooo`3ooomL0?ooo`030000003oool0
oooo02<0oooo000W0?ooo`030?ooZP1E0000000000@0000000<002^00=Coo`3oool0;@3oool00`00
0000oooo0?ooo`0;0?ooo`80o`00o`3ooooo0?oooe`0oooo00<000000?ooo`3oool08`3oool002@0
oooo00<0oooD080[000000001@0000000`1EZ_l0oooo0?ooo`0_0?ooo`030000003oool0oooo00/0
oooo0`3o003o0?ooool0ooooF`3oool00`000000oooo0?ooo`0S0?ooo`008P3oool00`3oojX0E@00
0000000300000005001EZP3oool0ZUD00000001EZ_l0<@3oool00`000000oooo0?ooo`0<0?ooo`80
o`00o`3ooooo0?oooe/0oooo00<000000?ooo`3oool08`3oool00280oooo00@0oonZ05D000000000
05FZ103oool00`2ZE@00000005FZo`0a0?ooo`030000003oool0oooo00`0oooo0P3o003o0?ooool0
ooooF`3oool00`000000oooo0?ooo`0S0?ooo`008P3oool00`3oojX0E@000000000300000005001E
ZP3oool0ZUD00000001EZ_l0<@3oool00`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0?l0
ooooo`3ooomI0?ooo`030000003oool0oooo02<0oooo000T0?ooo`030?ooZP1E0000000000D00000
00<0EJ[o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0=0?ooo`80o`00o`3ooooo0?oooeX0oooo
00<000000?ooo`3oool08`3oool002L0oooo00<0omB002/000000000100000000`00:h00e?oo0?oo
o`0]0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooeP0oooo00<0
00000?ooo`3oool08`3oool002X0oooo00H0ojYE00000000000000000000E@2Zool<0?ooo`040?oo
e020:`00000002^0e0@0oooo00D0ojYE000000000000000005FZo`040?ooo`050?nZE@0000000000
0000001EZ_l0303oool00`000000oooo0?ooo`0>0?ooo`80o`00o`3ooooo0?oooeT0oooo00<00000
0?ooo`3oool08`3oool002d0oooo00<0e80[0000E@2Zool0303oool0103oom@0P2/00000000[P=@3
0?ooo`030?nZE@000000000000<0000000@0EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?oo
o`090?ooo`030000003oool0oooo00l0oooo0P3o003o0?ooool0ooooF03oool00`000000oooo0?oo
o`0S0?ooo`00?03oool0103oom@0P2/00000000[P=@20?ooo`0B0?ooe020:`00000002^0e03oool0
e80[00000000:h00e?oo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo2P3oool00`00
0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo0?l0ooooo`3ooomF0?ooo`030000003oool0oooo
02<0oooo000l0?ooo`040?ooe020:`00000002^0e080oooo0180omB002/0000002/0P=Co0?ooo`3o
e800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool:0?ooo`030000
003oool0oooo0100oooo0P3o003o0?ooool0ooooE`3oool00`000000oooo0?ooo`0S0?ooo`008P3o
ool00`3oojX0E@0000000009000000030000E@2Zool0oooo00/0oooo00@0oooD080[00000000:h3D
0P3oool04P3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`3oe800:`000000E@2Zool0
oooo0?ooZP1E0000000[083Do`X0oooo1@00000?0?ooo`<0o`00o`3ooooo0?oooe40oooo1@00000U
0?ooo`008P3oool00`3oojX0E@0000000009000000030000E@2Zool0oooo00/0oooo00@0oooD080[
00000000:h3D0P3oool04P3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`3oZUD00000
0000E@2Zool0oooo0?ooZP1E0000000005FZo`X0oooo00<000000?ooo`3oool04@3oool50?l00?l0
ooooo`3ooomC0?ooo`030000003oool0oooo02<0oooo000l0?ooo`040?ooe020:`00000002^0e080
oooo0180ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?oo
o`3oojX0E@000000001EZ_l:0?ooo`030000003oool0oooo01<0oooo1P3o003o0?ooool0ooooD03o
ool00`000000oooo0?ooo`0S0?ooo`009@3oool0103oojX0E@00000[P03Dool@0?ooo`070?ooe020
:`00:h3D0?ooe020:`00000002^0e0020?ooo`0B0?oDP00[0000001E0:[oo`3oool0oonZ05D00000
02/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co2P3oool00`000000oooo0?oo
o`0E0?ooo`H0o`00o`3ooooo0?ooodh0oooo00<000000?ooo`3oool08`3oool002<0oooo00<0oooD
080[00000000200000000`1EZ_l0oooo0?ooo`080?ooo`070?ooe020:`0000000000:`0[:`000000
02^0e0020?ooo`0B0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?oDP00[0000000[
083Do`3oool0omB002/0000005D0Z_oo2P3oool00`000000oooo0?ooo`0H0?ooo`D0o`00o`3ooooo
0?oood`0oooo00<000000?ooo`3oool08`3oool002<0oooo00<0e80[000000000000200000000`00
:h00e?oo0?ooo`0:0?ooo`050:YE0000000000000000000[P=@00P3oool04P3oom@0P2/00000000[
P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`X0
oooo00<000000?ooo`3oool06P3oool50?l00?l0ooooo`3ooom:0?ooo`030000003oool0oooo02<0
oooo000U0?ooo`040?ooZP1E000002^00=Coo`<0oooo00@0oooD080[000005D0Z_oo303oool0103o
ZUD000000000000[P=@30?ooo`030?nZE@000000000000<0000000@0EJ[o0?ooo`3oool0ojYE1@00
00000`1EZ_l0oooo0?ooo`090?ooo`030000003oool0oooo01`0oooo1@3o003o0?ooool0ooooB03o
ool00`000000oooo0?ooo`0S0?ooo`009@3oool0103oojX0E@00000[P03Dool30?ooo`040?ooZP1E
000002^00=Coo`d0oooo00<0ZUD00000000[P=@0103oool01@3oZUD00000000000000000EJ[o00@0
oooo00D0ojYE000000000000000005FZo`0<0?ooo`030000003oool0oooo01h0oooo1P3o003o0?oo
ool0ooooA@3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0P0?ooo`H0
o`00o`3ooooo0?oood<0oooo00<000000?ooo`3oool08`3oool00280oooo00D0oonZ05D0000005D0
Z_nZ05D00007000000030000E@2Zool0oooo02d0oooo00<000000?ooo`3oool08`3oool50?l00?l0
ooooo`3ooom10?ooo`030000003oool0oooo02<0oooo000R0?ooo`050?ooZP1E0000001E0:[oZP1E
00001`0000000`0005D0Z_oo0?ooo`0]0?ooo`030000003oool0oooo02D0oooo1@3o003o0?ooool0
oooo?`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`0W0?ooo`D0o`00
o`3ooooo0?ooocd0oooo00<000000?ooo`3oool08`3oool002D0oooo00@0oonZ05D00000:h00e?oo
=@3oool00`000000oooo0?ooo`0Y0?ooo`H0o`00o`3ooooo0?ooocX0oooo00<000000?ooo`3oool0
8`3oool002<0oooo00<0oooD080[00000000200000000`1EZ_l0oooo0?ooo`0]0?ooo`030000003o
ool0oooo02/0oooo1P3o003o0?ooool0oooo>03oool00`000000oooo0?ooo`0S0?ooo`008`3oool0
0`3DP2/000000000000800000003000[P03Dool0oooo02d0oooo00<000000?ooo`3oool0;P3oool5
0?l00?l0ooooo`3ooolf0?ooo`030000003oool0oooo02<0oooo000U0?ooo`040?ooZP1E000002^0
0=Coo`<0oooo00@0oooD080[000005D0Z_oo;P3oool300000300oooo203o003o0?ooool0oooo;P3o
ool4000002D0oooo000U0?ooo`040?ooZP1E000002^00=Coo`<0oooo00@0oonZ05D00000:h00e?oo
;P3oool00`000000oooo0?ooo`0b0?ooo``0o`00o`3ooooo0?ooob/0oooo00<000000?ooo`3oool0
8`3oool005h0oooo00<000000?ooo`3oool0>03oool<0?l00?l0ooooo`3ooolU0?ooo`030000003o
ool0oooo02<0oooo000U0?ooo`030?ooZP1E0000000000D0000000<002^00=Coo`3oool0;P3oool0
0`000000oooo0?ooo`0n0?ooo``0o`00o`3ooooo0?oooal0oooo00<000000?ooo`3oool08`3oool0
02D0oooo00<0oonZ05D0000000001P0000000`00EJX0oooo0?ooo`0]0?ooo`030000003oool0oooo
04@0oooo2`3o003o0?ooool0oooo6P3oool00`000000oooo0?ooo`0S0?ooo`00;03oool0103oe800
:`000000E@2Zool^0?ooo`030000003oool0oooo04X0oooo2`3o003o0?ooool0oooo503oool00`00
0000oooo0?ooo`0S0?ooo`00;@3oool00`2ZE@00001E0:[oo`0^0?ooo`030000003oool0oooo04l0
oooo303o003o0?ooool0oooo3P3oool00`000000oooo0?ooo`0S0?ooo`00;03oool0103oom@0P2/0
000[P03Dool^0?ooo`030000003oool0oooo05D0oooo303o003o0?ooool0oooo203oool00`000000
oooo0?ooo`0S0?ooo`00;03oool00`3oZUD0000005FZo`0_0?ooo`030000003oool0oooo05/0oooo
303o003o0?ooool0oooo0P3oool00`000000oooo0?ooo`0S0?ooo`009@3oool00`3oojX0E@000000
0006000000030000E@2Zool0oooo02d0oooo00<000000?ooo`3oool0H@3oool;0?l00?l0ooooo03o
ool00`000000oooo0?ooo`0S0?ooo`009@3oool00`3oojX0E@0000000006000000030000E@2Zool0
oooo02d0oooo00<000000?ooo`3oool0I`3oool;0?l00?l0oooomP3oool00`000000oooo0?ooo`0S
0?ooo`00GP3oool00`000000oooo0?ooo`1/0?ooo``0o`00o`3oooo`0?ooo`030000003oool0oooo
02<0oooo001N0?ooo`030000003oool0oooo0780oooo303o003o0?ooonX0oooo00<000000?ooo`3o
ool08`3oool002L0oooo00<0oonZ05D0000000000P0000000`0005D0Z_oo0?ooo`0_0?ooo`030000
003oool0oooo07P0oooo303o003o0?ooon@0oooo00<000000?ooo`3oool08`3oool002H0oooo00<0
ojYE0000000000001@0000000`1EZ_l0oooo0?ooo`0]0?ooo`030000003oool0oooo07h0oooo2`3o
003o0?oooml0oooo00<000000?ooo`3oool08`3oool002D0oooo00@0oooD080[00000000:h3D0`3o
ool0103DP2/00000000[P03Dool^0?ooo`<00000Q03oool;0?l00?l0ooooeP3oool4000002D0oooo
000U0?ooo`040?ooZP1E000002^00=Coo`<0oooo00@0oooD080[000005D0Z_oo;P3oool00`000000
oooo0?ooo`290?ooo`/0o`00o`3ooooD0?ooo`030000003oool0oooo02<0oooo000U0?ooo`040?oo
e020:`0002^00=Coo`<0oooo00@0oooD080[0000:h00e?oo;P3oool00`000000oooo0?ooo`2?0?oo
o`X0o`00o`3oooo?0?ooo`030000003oool0oooo02<0oooo000V0?ooo`030?nZE@000000:h3D00<0
oooo00<0e80[0000001EZ_l0;`3oool00`000000oooo0?ooo`2D0?ooo`/0o`00o`3oooo90?ooo`03
0000003oool0oooo02<0oooo000R0?ooo`030?ooZP1E0000000000T0000000<0001E0:[oo`3oool0
;@3oool00`000000oooo0?ooo`2I0?ooo`/0o`00o`3oooo40?ooo`030000003oool0oooo02<0oooo
000R0?ooo`030?ooZP1E0000000000T0000000<0001E0:[oo`3oool0;@3oool00`000000oooo0?oo
o`2O0?ooo`X0o`00o`3ooono0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0
oooo0:@0oooo2P3o003o0?oookX0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?oo
o`3oool0Z@3oool;0?l00?l0oooo]03oool00`000000oooo0?ooo`0S0?ooo`009`3oool00`3oojX0
E@0000000002000000030000:`20e?l0oooo02l0oooo00<000000?ooo`3oool0[P3oool;0?l00?l0
oooo[`3oool00`000000oooo0?ooo`0S0?ooo`009P3oool00`3oZUD00000000000050000000305FZ
o`3oool0oooo02d0oooo00<000000?ooo`3oool0]03oool:0?l00?l0ooooZP3oool00`000000oooo
0?ooo`0S0?ooo`009@3oool02`3oom@0P2/00000001EZ_l0omB002/0:`20e?l0omB002/00000:h00
e?oo02h0oooo00<000000?ooo`3oool0^@3oool:0?l00?l0ooooY@3oool00`000000oooo0?ooo`0S
0?ooo`009@3oool02`3oojX0E@00000[P03Dool0omB002/0:`20e?l0oooo0:YE000005D0Z_oo02h0
oooo00<000000?ooo`3oool0_P3oool;0?l00?l0ooooW`3oool00`000000oooo0?ooo`0S0?ooo`00
9@3oool02`3oom@0P2/00000:`20e?l0omB002/0:`20e?l0oooD080[000005D0Z_oo02h0oooo00<0
00000?ooo`3oool0``3oool;0?l00?l0ooooVP3oool00`000000oooo0?ooo`0S0?ooo`009P3oool0
2@3oZUD00000000000000000000[083Do`2ZE@00000002^0e00_0?ooo`030000003oool0oooo0<T0
oooo2P3o003o0?oooiD0oooo00<000000?ooo`3oool08`3oool002L0oooo00L0oonZ05D000000000
000[083Do`3DP2/0:h3D0300oooo00<000000?ooo`3oool0cP3oool:0?l00?l0ooooT03oool00`00
0000oooo0?ooo`0S0?ooo`00GP3oool300000=<0oooo2P3o003o0?ooohP0oooo1000000U0?ooo`00
;03oool01P3oZUD000000000E@2Zool0ZUD002^0e2`0oooo00<000000?ooo`3oool0f03oool90?l0
0?l0ooooQ`3oool00`000000oooo0?ooo`0S0?ooo`00;03oool01@3oZUD0000000000000000005FZ
02d0oooo00<000000?ooo`3oool0g@3oool80?l00?l0ooooP`3oool00`000000oooo0?ooo`0S0?oo
o`00GP3oool00`000000oooo0?ooo`3Q0?ooo`T0o`00o`3ooomn0?ooo`030000003oool0oooo02<0
oooo001N0?ooo`030000003oool0oooo0>D0oooo2@3o003o0?ooogX0oooo00<000000?ooo`3oool0
8`3oool005h0oooo00<000000?ooo`3oool0jP3oool80?l00?l0ooooMP3oool00`000000oooo0?oo
o`0S0?ooo`00GP3oool00`000000oooo0?ooo`3^0?ooo`T0o`00o`3oooma0?ooo`030000003oool0
oooo02<0oooo001N0?ooo`030000003oool0oooo0?80oooo2@3o003o0?ooofd0oooo00<000000?oo
o`3oool08`3oool005h0oooo00<000000?ooo`3oool0m`3oool80?l00?l0ooooJ@3oool00`000000
oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`3k0?ooo`T0o`00o`3ooomT0?ooo`030000
003oool0oooo02<0oooo000R0?ooo`030?ooZP1E0000000000T0000000<0001E0:[oo`3oool0;@3o
ool00`000000oooo0?ooo`3o0?ooo`T0o`00o`3ooomP0?ooo`030000003oool0oooo02<0oooo000R
0?ooo`030?ooZP1E0000000000T0000000<0001E0:[oo`3oool0;@3oool00`000000oooo0?ooo`3o
0?ooo`D0oooo203o003o0?oooe`0oooo00<000000?ooo`3oool08`3oool002L0oooo00D0oonZ05D0
0000000002^00=Coo`0b0?ooo`030000003oool0oooo0?l0oooo2@3oool90?l00?l0ooooE`3oool0
0`000000oooo0?ooo`0S0?ooo`009P3oool01@3oojX0E@0000000000:h00e?oo03<0oooo00<00000
0?ooo`3oool0o`3oool=0?ooo`T0o`00o`3ooomC0?ooo`030000003oool0oooo02<0oooo000U0?oo
o`050?ooZP1E000000000000000[P=@0=03oool00`000000oooo0?ooo`3o0?oooa80oooo203o003o
0?ooodl0oooo00<000000?ooo`3oool08`3oool002@0oooo00<0omB002/000000000100000000`1E
Z_l0oooo0?ooo`0`0?ooo`<00000o`3ooolF0?ooo`P0o`00o`3ooom80?ooo`@000009@3oool002<0
oooo00H0omB002/000000000001E0:[oo`3DP2/3000000030000:`20e?l0oooo02l0oooo00<00000
0?ooo`3oool0o`3ooolJ0?ooo`P0o`00o`3ooom70?ooo`030000003oool0oooo02<0oooo000R0?oo
o`050?ooZP1E000000000000E@2Zool00P3oool00`3oom@0P2/00000000200000003000[P03Dool0
oooo02d0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`L0o`00o`3ooom40?ooo`030000003oool0
oooo02<0oooo000R0?ooo`040?ooZP1E0000001E0:[oo`D0oooo00D0ojYE000000000000001E0:[o
o`0^0?ooo`030000003oool0oooo0?l0oooo8P3oool70?l00?l0oooo@03oool00`000000oooo0?oo
o`0S0?ooo`008P3oool00`3oojX0E@1E0:[oo`080?ooo`030:YE000005D0Z_oo02h0oooo00<00000
0?ooo`3oool0o`3ooolU0?ooo`L0o`00o`3ooolm0?ooo`030000003oool0oooo02<0oooo001N0?oo
o`030000003oool0oooo0?l0oooo:@3oool70?l00?l0oooo>@3oool00`000000oooo0?ooo`0S0?oo
o`00GP3oool00`000000oooo0?ooo`3o0?ooob`0oooo203o003o0?ooocD0oooo00<000000?ooo`3o
ool08`3oool002D0oooo00<0oonZ05D0000000001P0000000`0005D0Z_oo0?ooo`0]0?ooo`030000
003oool0oooo0?l0oooo<03oool70?l00?l0oooo<P3oool00`000000oooo0?ooo`0S0?ooo`009@3o
ool00`3oojX0E@0000000006000000030000E@2Zool0oooo02d0oooo00<000000?ooo`3oool0o`3o
oold0?ooo`L0o`00o`3oool^0?ooo`030000003oool0oooo02<0oooo000V0?ooo`030?nZE@000000
EJ[o03D0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`L0o`00o`3oool[0?ooo`030000003oool0
oooo02<0oooo000U0?ooo`040?ooe020:`0002^00=Cooa<0oooo00@0oooD080[00000000:h3D103o
ool01@3DP2/00000000000000000:h3D00@0oooo00D0ojYE000000000000000005FZo`0<0?ooo`03
0000003oool0oooo0?l0oooo>`3oool70?l00?l0oooo9`3oool00`000000oooo0?ooo`0S0?ooo`00
9@3oool0103oojX0E@000000E@2ZoolC0?ooo`040?ooe020:`00000002^0e0<0oooo00<0e80[0000
000000000`0000001000EJX0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo00T0oooo00<00000
0?ooo`3oool0o`3oooln0?ooo`P0o`00o`3ooolS0?ooo`030000003oool0oooo02<0oooo000U0?oo
o`030?ooe020:`00000000H0000000<0001E0:[oo`3oool02`3oool0103oom@0P2/00000000[P=@2
0?ooo`0B0?ooZP1E0000000002^0e03oool0ojYE0000000002/0P=Co0?ooe020:`00000002^0e03o
ool0e80[00000000:h00e?oo2P3oool00`000000oooo0?ooo`3o0?oood80oooo1`3o003o0?ooob00
oooo00<000000?ooo`3oool08`3oool002H0oooo00<0oonZ05D0000000001@0000000`0005D0Z_oo
0?ooo`0;0?ooo`040?ooe020:`00000002^0e080oooo0180ojYE0000000005D0Z_oo0?ooo`3oom@0
P2/00000001EZ_l0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool:0?ooo`030000003o
ool0oooo0?l0ooooAP3oool70?l00?l0oooo703oool00`000000oooo0?ooo`0S0?ooo`009P3oool0
0`3oZUD0000005FZo`0C0?ooo`040?ooe020:`00000002^0e0L0oooo00d0oooD080[00000000:h3D
0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co00X0oooo00<000000?ooo`3oool0o`3o
oom90?ooo`L0o`00o`3ooolI0?ooo`030000003oool0oooo02<0oooo000U0?ooo`040?ooe020:`00
02^00=Cooa<0oooo00@0oooD080[00000000:h3D0P3oool01P3oojX0E@000000:`20e?l0oooo0?nZ
E@80000000X0EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o2P3oool500000?l0
ooooB`3oool70?l00?l0oooo4@3oool5000002D0oooo000U0?ooo`040?ooZP1E0000001E0:[ooa<0
oooo00@0oooD080[00000000:h3D0P3oool00`3oom@0P2/0000000040000000;000[P03Dool0ojYE
0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l02P3oool00`000000oooo0?ooo`3o0?oooe00
oooo1`3o003o0?oooa80oooo00<000000?ooo`3oool08`3oool002H0oooo00<0ZUD0000000000000
1@0000000`0005D0Z_oo0?ooo`080?ooo`070?ooe020:`00:h3D0?ooe020:`00000002^0e0030?oo
o`030:YE0000000000000080000000`005FZ0?ooo`3oool0omB002/0000005D0Z_oo0?ooo`3oojX0
E@000000:`20e?l:0?ooo`030000003oool0oooo0?l0ooooD`3oool70?l00?l0oooo3`3oool00`00
0000oooo0?ooo`0S0?ooo`009P3oool00`3oojX0E@0000000005000000030000E@2Zool0oooo00P0
oooo00L0oooD080[00000000000[02/[00000000:h3D00<0oooo00<0e80[00000000EJX01@3oool0
2@3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`0:0?ooo`030000003oool0oooo0?l0
ooooEP3oool70?l00?l0oooo303oool00`000000oooo0?ooo`0S0?ooo`00>`3oool01@2ZE@000000
000000000000:h3D00<0oooo00@0omB002/00000:h00e?oo103oool02@3oom@0P2/00000000[P=@0
oooo0=B0:`00000002^00=Coo`0:0?ooo`030000003oool0oooo0?l0ooooF@3oool70?l00?l0oooo
2@3oool00`000000oooo0?ooo`0S0?ooo`00?03oool0103oZUD000000000000[P=@30?ooo`030?oo
ZP1E0000000000<0000000@0001E0:[oo`3oool0ojYE1@0000000`1EZ_l0oooo0?ooo`090?ooo`03
0000003oool0oooo0?l0ooooG03oool70?l00?l0oooo1P3oool00`000000oooo0?ooo`0S0?ooo`00
?@3oool00`2ZE@00000002^0e0030?ooo`030?ooe020:`00000000<0000000D0001E0:[oo`3oool0
oooo0?nZE@030000000305FZo`3oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooomO0?ooo`L0
o`00o`3oool30?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0oooo
HP3oool70?l00?l0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0o`3o
oomU0?ooo`L0o`00o03oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o
0?ooofP0oooo1`3o003i0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo
0?l0ooooJ`3oool70?l00?H0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3o
ool0o`3ooom^0?ooo`L0o`00l`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo
0?ooo`3o0?ooog40oooo1`3o003`0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003o
ool0oooo0?l0ooooM03oool70?l00>d0oooo00<000000?ooo`3oool08`3oool005h0oooo00<00000
0?ooo`3oool0o`3ooomg0?ooo`L0o`00jP3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool30000
0?l0ooooNP3oool70?l00>@0oooo1000000U0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooogd0
oooo1P3o003U0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0oooo
P03oool60?l00>80oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0o`3o
oon20?ooo`L0o`00g`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o
0?ooohD0oooo1P3o003M0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo
0?l0ooooR03oool60?l00=X0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3o
ool0o`3ooon:0?ooo`H0o`00f03oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo
0?ooo`3o0?ooohd0oooo1P3o003E0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003o
ool0oooo0?l0ooooS`3oool70?l00=80oooo00<000000?ooo`3oool08`3oool005h0oooo00<00000
0?ooo`3oool0o`3ooonB0?ooo`H0o`00d03oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`00
0000oooo0?ooo`3o0?oooiD0oooo1P3o003=0?ooo`030000003oool0oooo02<0oooo001N0?ooo`03
0000003oool0oooo0?l0ooooU`3oool70?l00<X0oooo00<000000?ooo`3oool08`3oool005h0oooo
00<000000?ooo`3oool0o`3ooonJ0?ooo`H0o`00b03oool00`000000oooo0?ooo`0S0?ooo`00GP3o
ool00`000000oooo0?ooo`3o0?oooid0oooo1P3o00350?ooo`030000003oool0oooo02<0oooo001N
0?ooo`<00000o`3ooonO0?ooo`H0o`00`03oool4000002D0oooo001N0?ooo`030000003oool0oooo
0?l0ooooXP3oool50?l00<40oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3o
ool0o`3ooonT0?ooo`D0o`00_`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo
0?ooo`3o0?ooojH0oooo1@3o002m0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003o
ool0oooo0?l0ooooZ03oool50?l00;/0oooo00<000000?ooo`3oool08`3oool005h0oooo00<00000
0?ooo`3oool0o`3ooonZ0?ooo`D0o`00^@3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`00
0000oooo0?ooo`3o0?oooj`0oooo1@3o002g0?ooo`030000003oool0oooo02<0oooo001N0?ooo`03
0000003oool0oooo0?l0oooo[P3oool60?l00;@0oooo00<000000?ooo`3oool08`3oool005h0oooo
00<000000?ooo`3oool0o`3ooon`0?ooo`H0o`00/P3oool00`000000oooo0?ooo`0S0?ooo`00GP3o
ool00`000000oooo0?ooo`3o0?oook<0oooo1@3o002`0?ooo`030000003oool0oooo02<0oooo001N
0?ooo`030000003oool0oooo0?l0oooo]@3oool50?l00:h0oooo00<000000?ooo`3oool08`3oool0
05h0oooo00<000000?ooo`3oool0o`3ooong0?ooo`D0o`00[03oool00`000000oooo0?ooo`0S0?oo
o`00GP3oool00`000000oooo0?ooo`3o0?oookT0oooo1@3o002Z0?ooo`030000003oool0oooo02<0
oooo001N0?ooo`030000003oool0oooo0?l0oooo^`3oool50?l00:P0oooo00<000000?ooo`3oool0
8`3oool005h0oooo00<000000?ooo`3oool0o`3ooonm0?ooo`D0o`00YP3oool00`000000oooo0?oo
o`0S0?ooo`00GP3oool300000?l0oooo_`3oool50?l00:40oooo1000000U0?ooo`00GP3oool00`00
0000oooo0?ooo`3o0?oool40oooo103o002S0?ooo`030000003oool0oooo02<0oooo001N0?ooo`03
0000003oool0oooo0?l0oooo``3oool40?l00:40oooo00<000000?ooo`3oool08`3oool005h0oooo
00<000000?ooo`3oool0o`3oooo40?ooo`D0o`00W`3oool00`000000oooo0?ooo`0S0?ooo`00GP3o
ool00`000000oooo0?ooo`3o0?ooolH0oooo103o002N0?ooo`030000003oool0oooo02<0oooo001N
0?ooo`030000003oool0oooo0?l0oooob03oool40?l009`0oooo00<000000?ooo`3oool08`3oool0
05h0oooo00<000000?ooo`3oool0o`3oooo90?ooo`D0o`00VP3oool00`000000oooo0?ooo`0S0?oo
o`00GP3oool00`000000oooo0?ooo`3o0?oool/0oooo103o002I0?ooo`030000003oool0oooo02<0
oooo001N0?ooo`030000003oool0oooo0?l0ooooc@3oool40?l009L0oooo00<000000?ooo`3oool0
8`3oool005h0oooo00<000000?ooo`3oool0o`3oooo>0?ooo`D0o`00U@3oool00`000000oooo0?oo
o`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooom00oooo103o002D0?ooo`030000003oool0
oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0oooodP3oool40?l00980oooo00<000000?oo
o`3oool08`3oool005h0oooo00<000000?ooo`3oool0o`3ooooC0?ooo`D0o`00T03oool00`000000
oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooomD0oooo103o002?0?ooo`030000
003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0ooooe`3oool40?l008d0oooo00<0
00000?ooo`3oool08`3oool005h0oooo0`00003o0?ooomP0oooo103o00290?ooo`@000009@3oool0
05h0oooo00<000000?ooo`3oool0o`3ooooJ0?ooo`@0o`00RP3oool00`000000oooo0?ooo`0S0?oo
o`00GP3oool00`000000oooo0?ooo`3o0?ooom/0oooo103o00290?ooo`030000003oool0oooo02<0
oooo001N0?ooo`030000003oool0oooo0?l0oooog@3oool40?l008L0oooo00<000000?ooo`3oool0
8`3oool005h0oooo00<000000?ooo`3oool0o`3ooooN0?ooo`@0o`00QP3oool00`000000oooo0?oo
o`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooon00oooo103o00240?ooo`030000003oool0
oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0ooooh@3oool40?l008<0oooo00<000000?oo
o`3oool08`3oool005h0oooo00<000000?ooo`3oool0o`3ooooS0?ooo`@0o`00P@3oool00`000000
oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooon@0oooo103o00200?ooo`030000
003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0ooooiP3oool40?l007h0oooo00<0
00000?ooo`3oool08`3oool003T0oooo00<0e80[0000000000001@000000101EZ_l0oooo0?ooo`3o
ZUD30000000305FZo`3oool0oooo0080oooo00D0ojYE000000000000000005FZo`0<0?ooo`030000
003oool0oooo0?l0ooooi`3oool40?l007d0oooo00<000000?ooo`3oool08`3oool003T0oooo00<0
omB002/0000000001@0000000`1EZ_l0oooo0?nZE@050000000405FZo`3oool0oooo0?nZE@D00000
00<0EJ[o0?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooonT0oooo103o001k0?ooo`030000
003oool0oooo02<0oooo000j0?ooo`040:YE00000000001E0:[oo`@0oooo0180oooD080[00000000
:h3D0?ooo`3DP2/00000000[P03Dool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool:
0?ooo`030000003oool0oooo0?l0oooojP3oool40?l007X0oooo00<000000?ooo`3oool08`3oool0
03X0oooo00D0oooD080[00000000001E0:[oo`030?ooo`0B0?oDP00[0000000[083Do`3oool0omB0
02/0000005D0Z_oo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo2P3oool00`000000
oooo0?ooo`3o0?ooon`0oooo103o001h0?ooo`030000003oool0oooo02<0oooo000k0?ooo`050?oo
e020:`0000000000E@2Zool00P3oool04P3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083D
o`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`X0oooo00<000000?ooo`3oool0o`3o
ooo]0?ooo`@0o`00M`3oool00`000000oooo0?ooo`0S0?ooo`00?03oool0603oom@0P2/000000000
05D0Z_oo0?ooo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`3oZUD000000000E@2Z
ool0oooo0?ooZP1E0000000005FZo`X0oooo1@00003o0?ooond0oooo0`3o001b0?ooo`D000009@3o
ool003d0oooo01L0oooD080[0000000005FZ0?ooo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000
000005FZo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`0:0?ooo`030000003oool0
oooo0?l0ooool03oool30?l007D0oooo00<000000?ooo`3oool08`3oool003h0oooo01H0omB002/0
000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[o
o`3oool0oonZ05D0000002/0P=Co2P3oool00`000000oooo0?ooo`3o0?oooo40oooo0`3o001d0?oo
o`030000003oool0oooo02<0oooo000i0?ooo`0K0?nZE@000000001E0:[oo`3oool0oonZ05D00000
0000EJ[o0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?oDP00[0000000[083Do`3o
ool0omB002/0000005D0Z_oo00X0oooo00<000000?ooo`3oool0o`3oooob0?ooo`@0o`00LP3oool0
0`000000oooo0?ooo`0S0?ooo`00>@3oool06`3oojX0E@000000001EZ_l0oooo0?nZE@000000000[
083Do`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo
0=B0:`00000002^00=Coo`0:0?ooo`030000003oool0oooo0?l0ooool`3oool40?l00740oooo00<0
00000?ooo`3oool08`3oool003X0oooo00<0ZUD00000000000000`0000001000EJX0oooo0?ooo`3o
ZUD50000000405FZo`3oool0oooo0?nZE@D0000000<0EJ[o0?ooo`3oool02@3oool00`000000oooo
0?ooo`3o0?ooooD0oooo0`3o001`0?ooo`030000003oool0oooo02<0oooo000k0?ooo`050=B0:`00
0000000000000000EJX0103oool01@3oZUD00000000000000000EJ[o00@0oooo00D0ojYE00000000
0000000005FZo`0<0?ooo`030000003oool0oooo0?l0oooomP3oool30?l006l0oooo00<000000?oo
o`3oool08`3oool005h0oooo00<000000?ooo`3oool0o`3oooog0?ooo`<0o`00KP3oool00`000000
oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooooP0oooo0`3o001]0?ooo`030000
003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0oooon@3oool30?l006`0oooo00<0
00000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0o`3ooooj0?ooo`<0o`00J`3oool0
0`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o0?oooo/0oooo103o001Y0?oo
o`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0ooooo03oool40?l006P0
oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0o`3oooon0?ooo`<0o`00
I`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooool0oooo0`3o
001V0?ooo`030000003oool0oooo02<0oooo001N0?ooo`<00000o`3ooooo0?ooo`40oooo0`3o001R
0?ooo`@000009@3oool005h0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`80oooo0`3o001T0?oo
o`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0ooooo`3oool30?ooo`<0
o`00H`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooool0oooo
103oool30?l00680oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0o`3o
oooo0?ooo`D0oooo0`3o001Q0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0
oooo0?l0ooooo`3oool60?ooo`<0o`00H03oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`00
0000oooo0?ooo`3o0?ooool0oooo1`3oool30?l005l0oooo00<000000?ooo`3oool08`3oool005h0
oooo00<000000?ooo`3oool0o`3ooooo0?ooo`P0oooo0`3o001N0?ooo`030000003oool0oooo02<0
oooo001N0?ooo`030000003oool0oooo0?l0ooooo`3oool90?ooo`<0o`00G@3oool00`000000oooo
0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooool0oooo2P3oool30?l005`0oooo00<0
00000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`/0oooo0`3o001K
0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0ooooo`3oool<0?oo
o`<0o`00FP3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooool0
oooo3@3oool30?l005T0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0
o`3ooooo0?ooo`h0oooo0`3o001H0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003o
ool0oooo0?l0ooooo`3oool?0?ooo`<0o`00E`3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool3
00000?l0ooooo`3oool@0?ooo`80o`00E03oool4000002D0oooo001N0?ooo`030000003oool0oooo
0?l0ooooo`3ooolA0?ooo`80o`00EP3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000
oooo0?ooo`3o0?ooool0oooo4P3oool20?l005D0oooo00<000000?ooo`3oool08`3oool005h0oooo
00<000000?ooo`3oool0o`3ooooo0?oooa<0oooo0P3o001D0?ooo`030000003oool0oooo02<0oooo
001N0?ooo`030000003oool0oooo0?l0ooooo`3ooolD0?ooo`030?l0003oool0oooo0580oooo00<0
00000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0o`3ooooo0?oooa@0oooo0P3o001C
0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0ooooo`3ooolE0?oo
o`80o`00DP3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooool0
oooo5P3oool20?l00540oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0
o`3ooooo0?oooaL0oooo00<0o`000?ooo`3oool0C`3oool00`000000oooo0?ooo`0S0?ooo`00GP3o
ool00`000000oooo0?ooo`3o0?ooool0oooo5`3oool20?l00500oooo00<000000?ooo`3oool08`3o
ool005h0oooo00<000000?ooo`3oool0o`3ooooo0?oooaP0oooo0P3o001?0?ooo`030000003oool0
oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0ooooo`3ooolI0?ooo`80o`00CP3oool00`00
0000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooool0oooo6P3oool00`3o0000
oooo0?ooo`1<0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0oooo
o`3ooolJ0?ooo`80o`00C@3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?oo
o`3o0?ooool0oooo6`3oool20?l004`0oooo00<000000?ooo`3oool08`3oool005h0oooo0`00003o
0?ooool0oooo703oool20?l004P0oooo1000000U0?ooo`00GP3oool00`000000oooo0?ooo`3o0?oo
ool0oooo7@3oool20?l004X0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooah0oooo00<0o`000?ooo`3oool0B03oool00`000000oooo0?ooo`0S0?ooo`00
GP3oool00`000000oooo0?ooo`3o0?ooool0oooo7P3oool20?l004T0oooo00<000000?ooo`3oool0
8`3oool005h0oooo00<000000?ooo`3oool0o`3ooooo0?oooal0oooo0P3o00180?ooo`030000003o
ool0oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0ooooo`3ooolP0?ooo`80o`00A`3oool0
0`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool00`3o
0000oooo0?ooo`150?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0
ooooo`3ooolQ0?ooo`80o`00AP3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo
0?ooo`3o0?ooool0oooo8P3oool20?l004D0oooo00<000000?ooo`3oool08`3oool005h0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooob<0oooo0P3o00140?ooo`030000003oool0oooo02<0oooo001N
0?ooo`030000003oool0oooo0?l0ooooo`3ooolT0?ooo`030?l0003oool0oooo0480oooo00<00000
0?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0o`3ooooo0?ooob@0oooo0P3o00130?oo
o`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0ooooo`3ooolU0?ooo`80
o`00@P3oool00`000000oooo0?ooo`0S0?ooo`00GP3oool00`000000oooo0?ooo`3o0?ooool0oooo
9P3oool20?l00440oooo00<000000?ooo`3oool08`3oool005h0oooo0`00003o0?ooool0oooo9`3o
ool00`3o0000oooo0?ooo`0l0?ooo`@000009@3oool005h0oooo00<000000?ooo`3oool0o`3ooooo
0?ooobL0oooo0P3o00100?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo
0?l0ooooo`3ooolX0?ooo`030?l0003oool0oooo03h0oooo00<000000?ooo`3oool08`3oool005h0
oooo00<000000?ooo`3oool0o`3ooooo0?ooobP0oooo0P3o000o0?ooo`030000003oool0oooo02<0
oooo001N0?ooo`030000003oool0oooo0?l0ooooo`3ooolY0?ooo`030?l0003oool0oooo03d0oooo
00<000000?ooo`3oool08`3oool005h0oooo00<000000?ooo`3oool0o`3ooooo0?ooobT0oooo0P3o
000n0?ooo`030000003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0ooooo`3ooolZ
0?ooo`030?l0003oool0oooo03`0oooo00<000000?ooo`3oool08`3oool005h0oooo00<000000?oo
o`3oool0o`3ooooo0?ooobX0oooo0P3o000m0?ooo`030000003oool0oooo02<0oooo001N0?ooo`03
0000003oool0oooo0?l0ooooo`3oool[0?ooo`80o`00?03oool00`000000oooo0?ooo`0S0?ooo`00
GP3oool00`000000oooo0?ooo`3o0?ooool0oooo;03oool00`3o0000oooo0?ooo`0j0?ooo`030000
003oool0oooo02<0oooo001N0?ooo`030000003oool0oooo0?l0ooooo`3oool/0?ooo`80o`00>`3o
ool00`000000oooo0?ooo`0S0?ooo`00>@3oool00`3DP2/00000000000050000000405FZo`3oool0
oooo0=B0:`<0000000<0:h3D0?ooo`3oool00P3oool01@3oZUD00000000000000000EJ[o00`0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`1Q0?ooo`030?l0003oool0oooo02X0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0S0?ooo`00>@3oool00`3oe800:`000000
00050000000305FZo`3oool0e80[00D0000000@005FZ0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo
0?ooo`090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0H@3oool20?l002/0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0S0?ooo`00>P3oool0102ZE@0000000000
E@2Zool40?ooo`0B0?ooZP1E0000000002^0e03oool0ojYE0000000002/0P=Co0?ooe020:`000000
02^0e03oool0e80[00000000:h00e?oo2P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0I0?ooo`030?l0003oool0
oooo00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo02<0oooo000j0?ooo`050?ooe020:`0000000000E@2Zool00`3oool04P3oZUD000000000E@2Z
ool0oooo0?ooe020:`00000005FZo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`X0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool06@3oool20?l000H0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo02<0oooo000k0?ooo`050?ooe020:`0000000000E@2Z
ool01`3oool03@3oom@0P2/00000000[P=@0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20
e?l02P3ooooo00000?l00000<P0000000`3o000000000000000h000002D0oooo000l0?ooo`0<0?oo
e020:`0000000000E@2Zool0oooo0?ooZP1E0000000[083Do`3oool0ojYE0P0000002P1EZ_l0ojYE
0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_oo0?ooool0ooooW03oool003d0oooo00L0oooD
080[0000000005FZ0?ooo`3oom@0P2/000D0000000/002^00=Coo`3oZUD000000000E@2Zool0oooo
0?ooZP1E0000000005FZo`3o0?ooool0ooooW03oool003h0oooo00H0omB002/0000002/0P=Co0?oo
o`2ZE@040000000<001EZP3oool0oooo0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co
o`3ooooo0?oooi`0oooo000i0?ooo`0=0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o
0?ooo`3DP2/00000001EZP050?ooo`090?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo
0?l0ooooo`3ooonL0?ooo`00>@3oool03P3oojX0E@000000001EZ_l0oooo0?nZE@000000000[083D
o`3oool0omB002/00000:h00e?oo103oool02@3oom@0P2/00000000[P=@0oooo0=B0:`00000002^0
0=Coo`3o0?ooool0ooooW03oool003X0oooo00<0ZUD00000000000000`0000001@00EJX0oooo0?oo
o`3oojX0E@0000@0000000@0001E0:[oo`3oool0ojYE1@0000000`1EZ_l0oooo0?ooo`3o0?ooool0
ooooV`3oool003/0oooo00D0e80[0000000000000000001EZP030?ooo`030?ooe020:`00000000<0
000000D0001E0:[oo`3oool0oooo0?nZE@030000000305FZo`3oool0oooo0?l0ooooo`3ooonL0?oo
o`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo
0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo
003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0
ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool0
0001\
\>"],
  ImageRangeCache->{{{0, 749}, {462.5, 0}} -> {-1.05093, -0.648943, \
0.00280622, 0.00280622}, {{18.125, 730.813}, {451.438, 11}} -> {36.3622, \
-46.9797, 1.38159, 0.672898}, {{231.938, 659.563}, {355.938, 284.688}} -> \
{-1.92354, -2.1341, 0.00785989, 0.0190883}, {{254.875, 382.125}, {346.5, \
294.063}} -> {-3.44158, -5.69556, 0.0123755, 0.0400478}}]
}, Open  ]],

Cell[BoxData[""], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"lst", "=", 
        RowBox[{"AtmGraphs", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["MeanMolecularWeight",
                    GridBoxOptions->{RowSpacings->0.4,
                    RowLines->False}], ",", "\"\<Molecular Weight\>\""}], 
                "}"}], 
              StyleBox["}",
                GridBoxOptions->{RowSpacings->0.4,
                RowLines->False}]}], 
            StyleBox[",",
              GridBoxOptions->{RowSpacings->0.4,
              RowLines->False}], \(PlotRange -> {\(-7\)\ , 500\ }\)}], 
          StyleBox["]",
            GridBoxOptions->{RowSpacings->0.4,
            RowLines->False}]}]}], 
      StyleBox[";",
        GridBoxOptions->{RowSpacings->0.4,
        RowLines->False}]}], "\[IndentingNewLine]", \(Show[
        LegendGraphs[lst, LegendSize \[Rule] {1.2,  .2}, 
          LegendPosition \[Rule] \ {\(- .6\), \(- .35\)}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        ImageSize \[Rule] 750];\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 750 463.525 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0328815 0.00853301 0.001219 [
[.02381 -0.0125 -6.4375 -20.3125 ]
[.02381 -0.0125 6.4375 0 ]
[.18822 -0.0125 -6.4375 -20.3125 ]
[.18822 -0.0125 6.4375 0 ]
[.35262 -0.0125 -10.875 -20.3125 ]
[.35262 -0.0125 10.875 0 ]
[.51703 -0.0125 -10.875 -20.3125 ]
[.51703 -0.0125 10.875 0 ]
[.68144 -0.0125 -10.875 -20.3125 ]
[.68144 -0.0125 10.875 0 ]
[.84585 -0.0125 -10.875 -20.3125 ]
[.84585 -0.0125 10.875 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -102.313 -40.625 ]
[.5 -0.0125 102.313 -20.3125 ]
[-0.0125 .00853 -12.875 -10.1563 ]
[-0.0125 .00853 0 10.1563 ]
[-0.0125 .13043 -30.625 -10.1563 ]
[-0.0125 .13043 0 10.1563 ]
[-0.0125 .25233 -30.625 -10.1563 ]
[-0.0125 .25233 0 10.1563 ]
[-0.0125 .37423 -30.625 -10.1563 ]
[-0.0125 .37423 0 10.1563 ]
[-0.0125 .49613 -30.625 -10.1563 ]
[-0.0125 .49613 0 10.1563 ]
[-0.0125 .61803 -30.625 -10.1563 ]
[-0.0125 .61803 0 10.1563 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -50.9375 -48.625 ]
[-0.01875 .30902 -30.625 48.625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -67.4375 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.18822 0 m
.18822 .00625 L
s
gsave
.18822 -0.0125 -67.4375 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.35262 0 m
.35262 .00625 L
s
gsave
.35262 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.51703 0 m
.51703 .00625 L
s
gsave
.51703 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.68144 0 m
.68144 .00625 L
s
gsave
.68144 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.84585 0 m
.84585 .00625 L
s
gsave
.84585 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
.05669 0 m
.05669 .00375 L
s
.08957 0 m
.08957 .00375 L
s
.12245 0 m
.12245 .00375 L
s
.15534 0 m
.15534 .00375 L
s
.2211 0 m
.2211 .00375 L
s
.25398 0 m
.25398 .00375 L
s
.28686 0 m
.28686 .00375 L
s
.31974 0 m
.31974 .00375 L
s
.38551 0 m
.38551 .00375 L
s
.41839 0 m
.41839 .00375 L
s
.45127 0 m
.45127 .00375 L
s
.48415 0 m
.48415 .00375 L
s
.54991 0 m
.54991 .00375 L
s
.5828 0 m
.5828 .00375 L
s
.61568 0 m
.61568 .00375 L
s
.64856 0 m
.64856 .00375 L
s
.71432 0 m
.71432 .00375 L
s
.7472 0 m
.7472 .00375 L
s
.78008 0 m
.78008 .00375 L
s
.81297 0 m
.81297 .00375 L
s
.87873 0 m
.87873 .00375 L
s
.91161 0 m
.91161 .00375 L
s
.94449 0 m
.94449 .00375 L
s
.97737 0 m
.97737 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -163.313 -44.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(MolecularWeight) show
190.500 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
199.375 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Kg) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
220.563 19.750 moveto
(\\220) show
226.438 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(kmol) show
263.625 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00853 m
.00625 .00853 L
s
gsave
-0.0125 .00853 -73.875 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13043 m
.00625 .13043 L
s
gsave
-0.0125 .13043 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
0 .25233 m
.00625 .25233 L
s
gsave
-0.0125 .25233 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
0 .37423 m
.00625 .37423 L
s
gsave
-0.0125 .37423 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
0 .49613 m
.00625 .49613 L
s
gsave
-0.0125 .49613 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03291 m
.00375 .03291 L
s
0 .05729 m
.00375 .05729 L
s
0 .08167 m
.00375 .08167 L
s
0 .10605 m
.00375 .10605 L
s
0 .15481 m
.00375 .15481 L
s
0 .17919 m
.00375 .17919 L
s
0 .20357 m
.00375 .20357 L
s
0 .22795 m
.00375 .22795 L
s
0 .27671 m
.00375 .27671 L
s
0 .30109 m
.00375 .30109 L
s
0 .32547 m
.00375 .32547 L
s
0 .34985 m
.00375 .34985 L
s
0 .39861 m
.00375 .39861 L
s
0 .42299 m
.00375 .42299 L
s
0 .44737 m
.00375 .44737 L
s
0 .47175 m
.00375 .47175 L
s
0 .52051 m
.00375 .52051 L
s
0 .54489 m
.00375 .54489 L
s
0 .56927 m
.00375 .56927 L
s
0 .59365 m
.00375 .59365 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -150.406 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
109.625 14.1563 translate
90 rotate
-109.625 -14.1563 translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Altitude) show
121.688 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
130.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Km) show
156.250 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.18822 .61178 m
.18822 .61803 L
s
.35262 .61178 m
.35262 .61803 L
s
.51703 .61178 m
.51703 .61803 L
s
.68144 .61178 m
.68144 .61803 L
s
.84585 .61178 m
.84585 .61803 L
s
.125 Mabswid
.05669 .61428 m
.05669 .61803 L
s
.08957 .61428 m
.08957 .61803 L
s
.12245 .61428 m
.12245 .61803 L
s
.15534 .61428 m
.15534 .61803 L
s
.2211 .61428 m
.2211 .61803 L
s
.25398 .61428 m
.25398 .61803 L
s
.28686 .61428 m
.28686 .61803 L
s
.31974 .61428 m
.31974 .61803 L
s
.38551 .61428 m
.38551 .61803 L
s
.41839 .61428 m
.41839 .61803 L
s
.45127 .61428 m
.45127 .61803 L
s
.48415 .61428 m
.48415 .61803 L
s
.54991 .61428 m
.54991 .61803 L
s
.5828 .61428 m
.5828 .61803 L
s
.61568 .61428 m
.61568 .61803 L
s
.64856 .61428 m
.64856 .61803 L
s
.71432 .61428 m
.71432 .61803 L
s
.7472 .61428 m
.7472 .61803 L
s
.78008 .61428 m
.78008 .61803 L
s
.81297 .61428 m
.81297 .61803 L
s
.87873 .61428 m
.87873 .61803 L
s
.91161 .61428 m
.91161 .61803 L
s
.94449 .61428 m
.94449 .61803 L
s
.97737 .61428 m
.97737 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00853 m
1 .00853 L
s
.99375 .13043 m
1 .13043 L
s
.99375 .25233 m
1 .25233 L
s
.99375 .37423 m
1 .37423 L
s
.99375 .49613 m
1 .49613 L
s
.125 Mabswid
.99625 .03291 m
1 .03291 L
s
.99625 .05729 m
1 .05729 L
s
.99625 .08167 m
1 .08167 L
s
.99625 .10605 m
1 .10605 L
s
.99625 .15481 m
1 .15481 L
s
.99625 .17919 m
1 .17919 L
s
.99625 .20357 m
1 .20357 L
s
.99625 .22795 m
1 .22795 L
s
.99625 .27671 m
1 .27671 L
s
.99625 .30109 m
1 .30109 L
s
.99625 .32547 m
1 .32547 L
s
.99625 .34985 m
1 .34985 L
s
.99625 .39861 m
1 .39861 L
s
.99625 .42299 m
1 .42299 L
s
.99625 .44737 m
1 .44737 L
s
.99625 .47175 m
1 .47175 L
s
.99625 .52051 m
1 .52051 L
s
.99625 .54489 m
1 .54489 L
s
.99625 .56927 m
1 .56927 L
s
.99625 .59365 m
1 .59365 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
.97619 .00244 m
.97619 .00305 L
.97619 .00366 L
.97619 .00427 L
.97619 .00488 L
.97619 .00549 L
.97619 .0061 L
.97619 .0067 L
.97619 .00731 L
.97619 .00792 L
.97619 .00853 L
.97619 .00914 L
.97619 .00975 L
.97619 .01036 L
.97619 .01097 L
.97619 .01158 L
.97619 .01219 L
.97619 .0128 L
.97619 .01341 L
.97619 .01402 L
.97619 .01463 L
.97619 .01524 L
.97619 .01585 L
.97619 .01646 L
.97619 .01707 L
.97619 .01768 L
.97619 .01829 L
.97619 .01889 L
.97619 .0195 L
.97619 .02011 L
.97619 .02072 L
.97619 .02133 L
.97619 .02194 L
.97619 .02255 L
.97619 .02316 L
.97619 .02377 L
.97619 .02438 L
.97619 .02499 L
.97619 .0256 L
.97619 .02621 L
.97619 .02682 L
.97619 .02804 L
.97619 .02926 L
.97619 .03048 L
.97619 .03169 L
.97619 .03291 L
.97619 .03413 L
.97619 .03535 L
.97619 .03657 L
.97619 .03779 L
Mistroke
.97619 .03901 L
.97619 .04023 L
.97619 .04145 L
.97619 .04267 L
.97619 .04388 L
.97619 .0451 L
.97619 .04632 L
.97619 .04754 L
.97619 .04876 L
.97619 .04998 L
.97619 .0512 L
.97619 .05242 L
.97619 .05486 L
.97619 .05729 L
.97619 .05973 L
.97619 .06217 L
.97619 .06461 L
.97619 .06705 L
.97619 .06948 L
.97619 .07192 L
.97619 .07436 L
.97619 .0768 L
.97619 .07924 L
.97619 .08167 L
.97619 .08777 L
.97619 .09386 L
.97619 .09996 L
.97619 .10605 L
.97619 .11215 L
.97619 .11276 L
.97573 .11337 L
.97441 .11824 L
.9685 .12434 L
.95765 .13043 L
.92049 .14262 L
.88531 .15481 L
.86032 .167 L
.83763 .17919 L
.81625 .19138 L
.7962 .20357 L
.7768 .21576 L
.75838 .22795 L
.74096 .24014 L
.72419 .25233 L
.7089 .26452 L
.69361 .27671 L
.66697 .30109 L
.64363 .32547 L
.62357 .34985 L
.6068 .37423 L
Mistroke
.59233 .39861 L
.57984 .42299 L
.56866 .44737 L
.55879 .47175 L
.54926 .49613 L
.52525 .55708 L
.495 .61803 L
Mfstroke
.495 .61803 m
.495 .61803 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.2381 .11854 m
.2381 .21378 L
.80952 .21378 L
.80952 .11854 L
F
1 g
.21429 .14235 m
.21429 .23759 L
.78571 .23759 L
.78571 .14235 L
F
0 g
.001 w
[ ] 0 setdash
.21429 .14235 m
.78571 .14235 L
.78571 .23759 L
.21429 .23759 L
.21429 .14235 L
s
% Start of sub-graphic
p
0.214286 0.14235 0.785714 0.237588 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0122549 0.122549 [
[ 0 0 0 0 ]
[ 1 .16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .16667 L
0 .16667 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0220588 0.35119 0.144608 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .08333 -61 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Molecular) show
142.063 19.750 moveto
(Weight) show
195.125 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{750, 463.5},
  ImageCacheValid->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"lst", "=", 
        RowBox[{"AtmGraphs", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["DynamicViscosity",
                    GridBoxOptions->{RowSpacings->0.4,
                    RowLines->False}], ",", "\"\<Dynamic Viscosity\>\""}], 
                "}"}], 
              StyleBox["}",
                GridBoxOptions->{RowSpacings->0.4,
                RowLines->False}]}], 
            StyleBox[",",
              GridBoxOptions->{RowSpacings->0.4,
              RowLines->False}], \(PlotRange -> {\(-7\)\ , 100\ }\)}], 
          StyleBox["]",
            GridBoxOptions->{RowSpacings->0.4,
            RowLines->False}]}]}], 
      StyleBox[";",
        GridBoxOptions->{RowSpacings->0.4,
        RowLines->False}]}], "\[IndentingNewLine]", \(Show[
        LegendGraphs[lst, LegendSize \[Rule] { .8,  .2}, 
          LegendPosition \[Rule] \ { .1,  .35}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        ImageSize \[Rule] 750];\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 750 463.525 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.73124 0.1394 0.0404321 0.00577602 [
[.08096 -0.0125 -10.875 -20.3125 ]
[.08096 -0.0125 10.875 0 ]
[.22036 -0.0125 -10.875 -20.3125 ]
[.22036 -0.0125 10.875 0 ]
[.35976 -0.0125 -10.875 -20.3125 ]
[.35976 -0.0125 10.875 0 ]
[.49916 -0.0125 -10.875 -20.3125 ]
[.49916 -0.0125 10.875 0 ]
[.63856 -0.0125 -10.875 -20.3125 ]
[.63856 -0.0125 10.875 0 ]
[.77796 -0.0125 -10.875 -20.3125 ]
[.77796 -0.0125 10.875 0 ]
[.91736 -0.0125 -10.875 -20.3125 ]
[.91736 -0.0125 10.875 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -131.469 -40.625 ]
[.5 -0.0125 131.469 -20.3125 ]
[-0.0125 .04043 -12.875 -10.1563 ]
[-0.0125 .04043 0 10.1563 ]
[-0.0125 .15595 -21.75 -10.1563 ]
[-0.0125 .15595 0 10.1563 ]
[-0.0125 .27147 -21.75 -10.1563 ]
[-0.0125 .27147 0 10.1563 ]
[-0.0125 .38699 -21.75 -10.1563 ]
[-0.0125 .38699 0 10.1563 ]
[-0.0125 .50251 -21.75 -10.1563 ]
[-0.0125 .50251 0 10.1563 ]
[-0.0125 .61803 -30.625 -10.1563 ]
[-0.0125 .61803 0 10.1563 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -50.9375 -48.625 ]
[-0.01875 .30902 -30.625 48.625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08096 0 m
.08096 .00625 L
s
gsave
.08096 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
1.000 setlinewidth
grestore
.22036 0 m
.22036 .00625 L
s
gsave
.22036 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
1.000 setlinewidth
grestore
.35976 0 m
.35976 .00625 L
s
gsave
.35976 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.49916 0 m
.49916 .00625 L
s
gsave
.49916 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
1.000 setlinewidth
grestore
.63856 0 m
.63856 .00625 L
s
gsave
.63856 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(17) show
1.000 setlinewidth
grestore
.77796 0 m
.77796 .00625 L
s
gsave
.77796 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
1.000 setlinewidth
grestore
.91736 0 m
.91736 .00625 L
s
gsave
.91736 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(19) show
1.000 setlinewidth
grestore
.125 Mabswid
.10884 0 m
.10884 .00375 L
s
.13672 0 m
.13672 .00375 L
s
.1646 0 m
.1646 .00375 L
s
.19248 0 m
.19248 .00375 L
s
.24824 0 m
.24824 .00375 L
s
.27612 0 m
.27612 .00375 L
s
.304 0 m
.304 .00375 L
s
.33188 0 m
.33188 .00375 L
s
.38764 0 m
.38764 .00375 L
s
.41552 0 m
.41552 .00375 L
s
.4434 0 m
.4434 .00375 L
s
.47128 0 m
.47128 .00375 L
s
.52704 0 m
.52704 .00375 L
s
.55492 0 m
.55492 .00375 L
s
.5828 0 m
.5828 .00375 L
s
.61068 0 m
.61068 .00375 L
s
.66644 0 m
.66644 .00375 L
s
.69432 0 m
.69432 .00375 L
s
.7222 0 m
.7222 .00375 L
s
.75008 0 m
.75008 .00375 L
s
.80584 0 m
.80584 .00375 L
s
.83372 0 m
.83372 .00375 L
s
.8616 0 m
.8616 .00375 L
s
.88948 0 m
.88948 .00375 L
s
.05308 0 m
.05308 .00375 L
s
.0252 0 m
.0252 .00375 L
s
.94524 0 m
.94524 .00375 L
s
.97312 0 m
.97312 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -192.469 -44.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(DynamicViscosity) show
198.688 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
207.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
225.313 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
234.688 19.750 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
245.500 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
258.813 19.750 moveto
(N) show
274.750 19.750 moveto
(s) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
283.625 19.750 moveto
(\\220) show
289.500 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
303.688 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
313.063 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
321.938 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04043 m
.00625 .04043 L
s
gsave
-0.0125 .04043 -73.875 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .15595 m
.00625 .15595 L
s
gsave
-0.0125 .15595 -82.75 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .27147 m
.00625 .27147 L
s
gsave
-0.0125 .27147 -82.75 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .38699 m
.00625 .38699 L
s
gsave
-0.0125 .38699 -82.75 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
0 .50251 m
.00625 .50251 L
s
gsave
-0.0125 .50251 -82.75 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06931 m
.00375 .06931 L
s
0 .09819 m
.00375 .09819 L
s
0 .12707 m
.00375 .12707 L
s
0 .18483 m
.00375 .18483 L
s
0 .21371 m
.00375 .21371 L
s
0 .24259 m
.00375 .24259 L
s
0 .30035 m
.00375 .30035 L
s
0 .32923 m
.00375 .32923 L
s
0 .35811 m
.00375 .35811 L
s
0 .41587 m
.00375 .41587 L
s
0 .44475 m
.00375 .44475 L
s
0 .47363 m
.00375 .47363 L
s
0 .53139 m
.00375 .53139 L
s
0 .56027 m
.00375 .56027 L
s
0 .58915 m
.00375 .58915 L
s
0 .01155 m
.00375 .01155 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -150.406 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
109.625 14.1563 translate
90 rotate
-109.625 -14.1563 translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Altitude) show
121.688 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
130.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Km) show
156.250 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08096 .61178 m
.08096 .61803 L
s
.22036 .61178 m
.22036 .61803 L
s
.35976 .61178 m
.35976 .61803 L
s
.49916 .61178 m
.49916 .61803 L
s
.63856 .61178 m
.63856 .61803 L
s
.77796 .61178 m
.77796 .61803 L
s
.91736 .61178 m
.91736 .61803 L
s
.125 Mabswid
.10884 .61428 m
.10884 .61803 L
s
.13672 .61428 m
.13672 .61803 L
s
.1646 .61428 m
.1646 .61803 L
s
.19248 .61428 m
.19248 .61803 L
s
.24824 .61428 m
.24824 .61803 L
s
.27612 .61428 m
.27612 .61803 L
s
.304 .61428 m
.304 .61803 L
s
.33188 .61428 m
.33188 .61803 L
s
.38764 .61428 m
.38764 .61803 L
s
.41552 .61428 m
.41552 .61803 L
s
.4434 .61428 m
.4434 .61803 L
s
.47128 .61428 m
.47128 .61803 L
s
.52704 .61428 m
.52704 .61803 L
s
.55492 .61428 m
.55492 .61803 L
s
.5828 .61428 m
.5828 .61803 L
s
.61068 .61428 m
.61068 .61803 L
s
.66644 .61428 m
.66644 .61803 L
s
.69432 .61428 m
.69432 .61803 L
s
.7222 .61428 m
.7222 .61803 L
s
.75008 .61428 m
.75008 .61803 L
s
.80584 .61428 m
.80584 .61803 L
s
.83372 .61428 m
.83372 .61803 L
s
.8616 .61428 m
.8616 .61803 L
s
.88948 .61428 m
.88948 .61803 L
s
.05308 .61428 m
.05308 .61803 L
s
.0252 .61428 m
.0252 .61803 L
s
.94524 .61428 m
.94524 .61803 L
s
.97312 .61428 m
.97312 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04043 m
1 .04043 L
s
.99375 .15595 m
1 .15595 L
s
.99375 .27147 m
1 .27147 L
s
.99375 .38699 m
1 .38699 L
s
.99375 .50251 m
1 .50251 L
s
.125 Mabswid
.99625 .06931 m
1 .06931 L
s
.99625 .09819 m
1 .09819 L
s
.99625 .12707 m
1 .12707 L
s
.99625 .18483 m
1 .18483 L
s
.99625 .21371 m
1 .21371 L
s
.99625 .24259 m
1 .24259 L
s
.99625 .30035 m
1 .30035 L
s
.99625 .32923 m
1 .32923 L
s
.99625 .35811 m
1 .35811 L
s
.99625 .41587 m
1 .41587 L
s
.99625 .44475 m
1 .44475 L
s
.99625 .47363 m
1 .47363 L
s
.99625 .53139 m
1 .53139 L
s
.99625 .56027 m
1 .56027 L
s
.99625 .58915 m
1 .58915 L
s
.99625 .01155 m
1 .01155 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
.97619 .01155 m
.95542 .01444 L
.93451 .01733 L
.91346 .02022 L
.89227 .0231 L
.87108 .02599 L
.84975 .02888 L
.82829 .03177 L
.80668 .03466 L
.78493 .03754 L
.76319 .04043 L
.7413 .04332 L
.71928 .04621 L
.69711 .0491 L
.67481 .05198 L
.65236 .05487 L
.62992 .05776 L
.6072 .06065 L
.58448 .06354 L
.56161 .06642 L
.53847 .06931 L
.51533 .0722 L
.49205 .07509 L
.46863 .07798 L
.44508 .08086 L
.42138 .08375 L
.39754 .08664 L
.37356 .08953 L
.34945 .09242 L
.32519 .0953 L
.3008 .09819 L
.27612 .10108 L
.25145 .10397 L
.25047 .10686 L
.25047 .10974 L
.25047 .11263 L
.25047 .11552 L
.25047 .11841 L
.25047 .1213 L
.25047 .12418 L
.25047 .12707 L
.25047 .13285 L
.25047 .13862 L
.25047 .1444 L
.25047 .15018 L
.25047 .15595 L
.25758 .16173 L
.26525 .1675 L
.27278 .17328 L
.28031 .17906 L
Mistroke
.28783 .18483 L
.29536 .19061 L
.30289 .19638 L
.31042 .20216 L
.3178 .20794 L
.32533 .21371 L
.33272 .21949 L
.34011 .22526 L
.35865 .23104 L
.37928 .23682 L
.39977 .24259 L
.42012 .24837 L
.46055 .25992 L
.50042 .27147 L
.54001 .28302 L
.57904 .29458 L
.61779 .30613 L
.64372 .31768 L
.64372 .32923 L
.63243 .34079 L
.5828 .35234 L
.5552 .36389 L
.51603 .37544 L
.47644 .38699 L
.37593 .41587 L
.27292 .44475 L
.18677 .47363 L
.10996 .50251 L
.03176 .53139 L
.02381 .53428 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.57143 .45187 m
.57143 .54711 L
.95238 .54711 L
.95238 .45187 L
F
1 g
.54762 .47568 m
.54762 .57092 L
.92857 .57092 L
.92857 .47568 L
F
0 g
.001 w
[ ] 0 setdash
.54762 .47568 m
.92857 .47568 L
.92857 .57092 L
.54762 .57092 L
.54762 .47568 L
s
% Start of sub-graphic
p
0.547619 0.475684 0.928571 0.570922 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0183824 0.183824 [
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0330882 0.35119 0.216912 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .125 -61 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Dynamic) show
133.500 19.750 moveto
(Viscosity) show
203.125 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{750, 463.5},
  ImageCacheValid->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"lst", "=", 
        RowBox[{"AtmGraphs", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["KinematicViscosity",
                    GridBoxOptions->{RowSpacings->0.4,
                    RowLines->False}], ",", "\"\<\!\(\*
StyleBox[\"Kinematic\",\nGridBoxOptions->{RowSpacings->0.4,\n\
RowLines->False}]\) Viscosity\>\""}], "}"}], 
              StyleBox["}",
                GridBoxOptions->{RowSpacings->0.4,
                RowLines->False}]}], 
            StyleBox[",",
              GridBoxOptions->{RowSpacings->0.4,
              RowLines->False}], \(PlotRange -> {\(-7\)\ , 100\ }\)}], 
          StyleBox["]",
            GridBoxOptions->{RowSpacings->0.4,
            RowLines->False}]}]}], 
      StyleBox[";",
        GridBoxOptions->{RowSpacings->0.4,
        RowLines->False}]}], "\[IndentingNewLine]", \(Show[
        LegendGraphs[lst, LegendSize \[Rule] { .8,  .2}, 
          LegendPosition \[Rule] \ {\(- .6\),  .35}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        ImageSize \[Rule] 750];\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 750 463.525 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.935808 0.182491 0.0404321 0.00577602 [
[.02335 -0.0125 -12.2188 -20.3125 ]
[.02335 -0.0125 12.2188 0 ]
[.20584 -0.0125 -12.2188 -20.3125 ]
[.20584 -0.0125 12.2188 0 ]
[.38833 -0.0125 -12.2188 -20.3125 ]
[.38833 -0.0125 12.2188 0 ]
[.57083 -0.0125 -12.2188 -20.3125 ]
[.57083 -0.0125 12.2188 0 ]
[.75332 -0.0125 -12.2188 -20.3125 ]
[.75332 -0.0125 12.2188 0 ]
[.93581 -0.0125 -6.4375 -20.3125 ]
[.93581 -0.0125 6.4375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -108.469 -40.625 ]
[.5 -0.0125 108.469 -20.3125 ]
[-0.0125 .04043 -12.875 -10.1563 ]
[-0.0125 .04043 0 10.1563 ]
[-0.0125 .15595 -21.75 -10.1563 ]
[-0.0125 .15595 0 10.1563 ]
[-0.0125 .27147 -21.75 -10.1563 ]
[-0.0125 .27147 0 10.1563 ]
[-0.0125 .38699 -21.75 -10.1563 ]
[-0.0125 .38699 0 10.1563 ]
[-0.0125 .50251 -21.75 -10.1563 ]
[-0.0125 .50251 0 10.1563 ]
[-0.0125 .61803 -30.625 -10.1563 ]
[-0.0125 .61803 0 10.1563 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -50.9375 -48.625 ]
[-0.01875 .30902 -30.625 48.625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02335 0 m
.02335 .00625 L
s
gsave
.02335 -0.0125 -73.2188 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.20584 0 m
.20584 .00625 L
s
gsave
.20584 -0.0125 -73.2188 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.38833 0 m
.38833 .00625 L
s
gsave
.38833 -0.0125 -73.2188 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.57083 0 m
.57083 .00625 L
s
gsave
.57083 -0.0125 -73.2188 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.75332 0 m
.75332 .00625 L
s
gsave
.75332 -0.0125 -73.2188 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.93581 0 m
.93581 .00625 L
s
gsave
.93581 -0.0125 -67.4375 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
.05985 0 m
.05985 .00375 L
s
.09635 0 m
.09635 .00375 L
s
.13285 0 m
.13285 .00375 L
s
.16934 0 m
.16934 .00375 L
s
.24234 0 m
.24234 .00375 L
s
.27884 0 m
.27884 .00375 L
s
.31534 0 m
.31534 .00375 L
s
.35184 0 m
.35184 .00375 L
s
.42483 0 m
.42483 .00375 L
s
.46133 0 m
.46133 .00375 L
s
.49783 0 m
.49783 .00375 L
s
.53433 0 m
.53433 .00375 L
s
.60732 0 m
.60732 .00375 L
s
.64382 0 m
.64382 .00375 L
s
.68032 0 m
.68032 .00375 L
s
.71682 0 m
.71682 .00375 L
s
.78981 0 m
.78981 .00375 L
s
.82631 0 m
.82631 .00375 L
s
.86281 0 m
.86281 .00375 L
s
.89931 0 m
.89931 .00375 L
s
.97231 0 m
.97231 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -169.469 -44.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
92.063 19.750 moveto
(@) show
97.813 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
115.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
124.438 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(KinematicViscosity) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
270.188 19.750 moveto
(D) show
275.938 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .04043 m
.00625 .04043 L
s
gsave
-0.0125 .04043 -73.875 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .15595 m
.00625 .15595 L
s
gsave
-0.0125 .15595 -82.75 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .27147 m
.00625 .27147 L
s
gsave
-0.0125 .27147 -82.75 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .38699 m
.00625 .38699 L
s
gsave
-0.0125 .38699 -82.75 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
0 .50251 m
.00625 .50251 L
s
gsave
-0.0125 .50251 -82.75 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .06931 m
.00375 .06931 L
s
0 .09819 m
.00375 .09819 L
s
0 .12707 m
.00375 .12707 L
s
0 .18483 m
.00375 .18483 L
s
0 .21371 m
.00375 .21371 L
s
0 .24259 m
.00375 .24259 L
s
0 .30035 m
.00375 .30035 L
s
0 .32923 m
.00375 .32923 L
s
0 .35811 m
.00375 .35811 L
s
0 .41587 m
.00375 .41587 L
s
0 .44475 m
.00375 .44475 L
s
0 .47363 m
.00375 .47363 L
s
0 .53139 m
.00375 .53139 L
s
0 .56027 m
.00375 .56027 L
s
0 .58915 m
.00375 .58915 L
s
0 .01155 m
.00375 .01155 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -150.406 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
109.625 14.1563 translate
90 rotate
-109.625 -14.1563 translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Altitude) show
121.688 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
130.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Km) show
156.250 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02335 .61178 m
.02335 .61803 L
s
.20584 .61178 m
.20584 .61803 L
s
.38833 .61178 m
.38833 .61803 L
s
.57083 .61178 m
.57083 .61803 L
s
.75332 .61178 m
.75332 .61803 L
s
.93581 .61178 m
.93581 .61803 L
s
.125 Mabswid
.05985 .61428 m
.05985 .61803 L
s
.09635 .61428 m
.09635 .61803 L
s
.13285 .61428 m
.13285 .61803 L
s
.16934 .61428 m
.16934 .61803 L
s
.24234 .61428 m
.24234 .61803 L
s
.27884 .61428 m
.27884 .61803 L
s
.31534 .61428 m
.31534 .61803 L
s
.35184 .61428 m
.35184 .61803 L
s
.42483 .61428 m
.42483 .61803 L
s
.46133 .61428 m
.46133 .61803 L
s
.49783 .61428 m
.49783 .61803 L
s
.53433 .61428 m
.53433 .61803 L
s
.60732 .61428 m
.60732 .61803 L
s
.64382 .61428 m
.64382 .61803 L
s
.68032 .61428 m
.68032 .61803 L
s
.71682 .61428 m
.71682 .61803 L
s
.78981 .61428 m
.78981 .61803 L
s
.82631 .61428 m
.82631 .61803 L
s
.86281 .61428 m
.86281 .61803 L
s
.89931 .61428 m
.89931 .61803 L
s
.97231 .61428 m
.97231 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04043 m
1 .04043 L
s
.99375 .15595 m
1 .15595 L
s
.99375 .27147 m
1 .27147 L
s
.99375 .38699 m
1 .38699 L
s
.99375 .50251 m
1 .50251 L
s
.125 Mabswid
.99625 .06931 m
1 .06931 L
s
.99625 .09819 m
1 .09819 L
s
.99625 .12707 m
1 .12707 L
s
.99625 .18483 m
1 .18483 L
s
.99625 .21371 m
1 .21371 L
s
.99625 .24259 m
1 .24259 L
s
.99625 .30035 m
1 .30035 L
s
.99625 .32923 m
1 .32923 L
s
.99625 .35811 m
1 .35811 L
s
.99625 .41587 m
1 .41587 L
s
.99625 .44475 m
1 .44475 L
s
.99625 .47363 m
1 .47363 L
s
.99625 .53139 m
1 .53139 L
s
.99625 .56027 m
1 .56027 L
s
.99625 .58915 m
1 .58915 L
s
.99625 .01155 m
1 .01155 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
.02381 .01155 m
.02663 .01444 L
.02949 .01733 L
.03238 .02022 L
.03251 .0231 L
.03823 .02599 L
.04119 .02888 L
.0442 .03177 L
.04723 .03466 L
.05029 .03754 L
.05338 .04043 L
.05651 .04332 L
.05967 .04621 L
.06286 .0491 L
.06609 .05198 L
.06935 .05487 L
.07265 .05776 L
.07599 .06065 L
.07937 .06354 L
.08278 .06642 L
.08624 .06931 L
.08973 .0722 L
.09327 .07509 L
.09685 .07798 L
.10047 .08086 L
.10414 .08375 L
.10785 .08664 L
.11162 .08953 L
.11543 .09242 L
.11929 .0953 L
.12321 .09819 L
.12717 .10108 L
.13119 .10397 L
.13734 .10686 L
.14356 .10974 L
.14978 .11263 L
.15601 .11552 L
.16223 .11841 L
.16845 .1213 L
.17467 .12418 L
.18089 .12707 L
.19333 .13285 L
.20576 .13862 L
.21819 .1444 L
.23062 .15018 L
.24304 .15595 L
.25606 .16173 L
.26905 .1675 L
.28198 .17328 L
.29485 .17906 L
Mistroke
.30766 .18483 L
.3204 .19061 L
.33309 .19638 L
.34571 .20216 L
.35828 .20794 L
.37078 .21371 L
.38323 .21949 L
.39561 .22526 L
.40885 .23104 L
.4221 .23682 L
.43519 .24259 L
.44813 .24837 L
.47353 .25992 L
.49834 .27147 L
.52258 .28302 L
.54628 .29458 L
.56947 .30613 L
.59125 .31768 L
.61095 .32923 L
.6298 .34079 L
.64687 .35234 L
.66427 .36389 L
.68204 .37544 L
.70017 .38699 L
.74724 .41587 L
.79702 .44475 L
.85138 .47363 L
.90928 .50251 L
.96996 .53139 L
.97619 .53428 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.2381 .45187 m
.2381 .54711 L
.61905 .54711 L
.61905 .45187 L
F
1 g
.21429 .47568 m
.21429 .57092 L
.59524 .57092 L
.59524 .47568 L
F
0 g
.001 w
[ ] 0 setdash
.21429 .47568 m
.59524 .47568 L
.59524 .57092 L
.21429 .57092 L
.21429 .47568 L
s
% Start of sub-graphic
p
0.214286 0.475684 0.595238 0.570922 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0183824 0.183824 [
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0330882 0.35119 0.216912 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .125 -61 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Kinematic) show
143.563 19.750 moveto
(Viscosity) show
213.188 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{750, 463.5},
  ImageCacheValid->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"lst", "=", 
        RowBox[{"AtmGraphs", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{"{", 
                RowBox[{
                  StyleBox["PressureScaleHeight",
                    GridBoxOptions->{RowSpacings->0.4,
                    RowLines->False}], ",", "\"\<\!\(\*
StyleBox[\"Scale\",\nGridBoxOptions->{RowSpacings->0.4,\n\
RowLines->False}]\)\!\(\*
StyleBox[\" \",\nGridBoxOptions->{RowSpacings->0.4,\n\
RowLines->False}]\)\!\(\*
StyleBox[\"Height\",\nGridBoxOptions->{RowSpacings->0.4,\nRowLines->False}]\)\
\>\""}], "}"}], 
              StyleBox["}",
                GridBoxOptions->{RowSpacings->0.4,
                RowLines->False}]}], 
            StyleBox[",",
              GridBoxOptions->{RowSpacings->0.4,
              
              RowLines->
                False}], \(PlotRange -> {{6000, 10000}, {\(-7\)\ , 25\ }}\)}],
           
          StyleBox["]",
            GridBoxOptions->{RowSpacings->0.4,
            RowLines->False}]}]}], 
      StyleBox[";",
        GridBoxOptions->{RowSpacings->0.4,
        RowLines->False}]}], "\[IndentingNewLine]", \(Show[
        LegendGraphs[lst, LegendSize \[Rule] { .8,  .2}, 
          LegendPosition \[Rule] \ {\(- .1\),  .35}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        ImageSize \[Rule] 750];\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 750 463.525 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.5 0.00025 0.135195 0.0193136 [
[.125 -0.0125 -19.75 -20.3125 ]
[.125 -0.0125 19.75 0 ]
[.25 -0.0125 -19.75 -20.3125 ]
[.25 -0.0125 19.75 0 ]
[.375 -0.0125 -19.75 -20.3125 ]
[.375 -0.0125 19.75 0 ]
[.5 -0.0125 -19.75 -20.3125 ]
[.5 -0.0125 19.75 0 ]
[.625 -0.0125 -19.75 -20.3125 ]
[.625 -0.0125 19.75 0 ]
[.75 -0.0125 -19.75 -20.3125 ]
[.75 -0.0125 19.75 0 ]
[.875 -0.0125 -19.75 -20.3125 ]
[.875 -0.0125 19.75 0 ]
[1 -0.0125 -24.1875 -20.3125 ]
[1 -0.0125 24.1875 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -99.0625 -40.625 ]
[.5 -0.0125 99.0625 -20.3125 ]
[-0.0125 .03863 -24.4375 -10.1563 ]
[-0.0125 .03863 0 10.1563 ]
[-0.0125 .13519 -12.875 -10.1563 ]
[-0.0125 .13519 0 10.1563 ]
[-0.0125 .23176 -12.875 -10.1563 ]
[-0.0125 .23176 0 10.1563 ]
[-0.0125 .32833 -21.75 -10.1563 ]
[-0.0125 .32833 0 10.1563 ]
[-0.0125 .4249 -21.75 -10.1563 ]
[-0.0125 .4249 0 10.1563 ]
[-0.0125 .52147 -21.75 -10.1563 ]
[-0.0125 .52147 0 10.1563 ]
[-0.0125 .61803 -21.75 -10.1563 ]
[-0.0125 .61803 0 10.1563 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -44.75 -50.8438 ]
[-0.01875 .30902 -24.4375 50.8438 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
gsave
.125 -0.0125 -80.75 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6500) show
1.000 setlinewidth
grestore
.25 0 m
.25 .00625 L
s
gsave
.25 -0.0125 -80.75 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7000) show
1.000 setlinewidth
grestore
.375 0 m
.375 .00625 L
s
gsave
.375 -0.0125 -80.75 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7500) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -80.75 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8000) show
1.000 setlinewidth
grestore
.625 0 m
.625 .00625 L
s
gsave
.625 -0.0125 -80.75 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8500) show
1.000 setlinewidth
grestore
.75 0 m
.75 .00625 L
s
gsave
.75 -0.0125 -80.75 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9000) show
1.000 setlinewidth
grestore
.875 0 m
.875 .00625 L
s
gsave
.875 -0.0125 -80.75 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9500) show
1.000 setlinewidth
grestore
1 0 m
1 .00625 L
s
gsave
1 -0.0125 -85.1875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10000) show
1.000 setlinewidth
grestore
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -160.063 -44.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PressureScaleHeight) show
222.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
231.438 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Km) show
257.125 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03863 m
.00625 .03863 L
s
gsave
-0.0125 .03863 -85.4375 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .13519 m
.00625 .13519 L
s
gsave
-0.0125 .13519 -73.875 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .23176 m
.00625 .23176 L
s
gsave
-0.0125 .23176 -73.875 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .32833 m
.00625 .32833 L
s
gsave
-0.0125 .32833 -82.75 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .4249 m
.00625 .4249 L
s
gsave
-0.0125 .4249 -82.75 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .52147 m
.00625 .52147 L
s
gsave
-0.0125 .52147 -82.75 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -82.75 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .05794 m
.00375 .05794 L
s
0 .07725 m
.00375 .07725 L
s
0 .09657 m
.00375 .09657 L
s
0 .11588 m
.00375 .11588 L
s
0 .15451 m
.00375 .15451 L
s
0 .17382 m
.00375 .17382 L
s
0 .19314 m
.00375 .19314 L
s
0 .21245 m
.00375 .21245 L
s
0 .25108 m
.00375 .25108 L
s
0 .27039 m
.00375 .27039 L
s
0 .2897 m
.00375 .2897 L
s
0 .30902 m
.00375 .30902 L
s
0 .34764 m
.00375 .34764 L
s
0 .36696 m
.00375 .36696 L
s
0 .38627 m
.00375 .38627 L
s
0 .40558 m
.00375 .40558 L
s
0 .44421 m
.00375 .44421 L
s
0 .46353 m
.00375 .46353 L
s
0 .48284 m
.00375 .48284 L
s
0 .50215 m
.00375 .50215 L
s
0 .54078 m
.00375 .54078 L
s
0 .56009 m
.00375 .56009 L
s
0 .57941 m
.00375 .57941 L
s
0 .59872 m
.00375 .59872 L
s
0 .01931 m
.00375 .01931 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -146.438 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
111.844 14.1563 translate
90 rotate
-111.844 -14.1563 translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
67.438 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Altitude) show
126.125 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
135.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Km) show
160.688 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.125 .61178 m
.125 .61803 L
s
.25 .61178 m
.25 .61803 L
s
.375 .61178 m
.375 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.625 .61178 m
.625 .61803 L
s
.75 .61178 m
.75 .61803 L
s
.875 .61178 m
.875 .61803 L
s
.125 Mabswid
.025 .61428 m
.025 .61803 L
s
.05 .61428 m
.05 .61803 L
s
.075 .61428 m
.075 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.175 .61428 m
.175 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.225 .61428 m
.225 .61803 L
s
.275 .61428 m
.275 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.325 .61428 m
.325 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.425 .61428 m
.425 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.475 .61428 m
.475 .61803 L
s
.525 .61428 m
.525 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.575 .61428 m
.575 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.675 .61428 m
.675 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.725 .61428 m
.725 .61803 L
s
.775 .61428 m
.775 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.825 .61428 m
.825 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.925 .61428 m
.925 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.975 .61428 m
.975 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03863 m
1 .03863 L
s
.99375 .13519 m
1 .13519 L
s
.99375 .23176 m
1 .23176 L
s
.99375 .32833 m
1 .32833 L
s
.99375 .4249 m
1 .4249 L
s
.99375 .52147 m
1 .52147 L
s
.125 Mabswid
.99625 .05794 m
1 .05794 L
s
.99625 .07725 m
1 .07725 L
s
.99625 .09657 m
1 .09657 L
s
.99625 .11588 m
1 .11588 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .17382 m
1 .17382 L
s
.99625 .19314 m
1 .19314 L
s
.99625 .21245 m
1 .21245 L
s
.99625 .25108 m
1 .25108 L
s
.99625 .27039 m
1 .27039 L
s
.99625 .2897 m
1 .2897 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .34764 m
1 .34764 L
s
.99625 .36696 m
1 .36696 L
s
.99625 .38627 m
1 .38627 L
s
.99625 .40558 m
1 .40558 L
s
.99625 .44421 m
1 .44421 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .48284 m
1 .48284 L
s
.99625 .50215 m
1 .50215 L
s
.99625 .54078 m
1 .54078 L
s
.99625 .56009 m
1 .56009 L
s
.99625 .57941 m
1 .57941 L
s
.99625 .59872 m
1 .59872 L
s
.99625 .01931 m
1 .01931 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .13519 m
1 .13519 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
.84295 .03863 m
.81955 .04828 L
.79613 .05794 L
.7727 .0676 L
.74928 .07725 L
.72585 .08691 L
.7024 .09657 L
.67888 .10622 L
.65553 .11588 L
.63207 .12554 L
.60863 .13519 L
.58518 .14485 L
.56172 .15451 L
.53825 .16417 L
.5148 .17382 L
.49133 .18348 L
.46785 .19314 L
.44438 .20279 L
.4209 .21245 L
.39743 .22211 L
.37393 .23176 L
.35045 .24142 L
.32695 .25108 L
.30345 .26073 L
.27995 .27039 L
.25645 .28005 L
.23293 .2897 L
.20943 .29936 L
.1859 .30902 L
.16238 .31867 L
.13885 .32833 L
.11533 .33799 L
.0918 .34764 L
.09115 .3573 L
.0914 .36696 L
.09165 .37661 L
.0919 .38627 L
.09215 .39593 L
.0924 .40558 L
.09265 .41524 L
.0929 .4249 L
.0934 .44421 L
.0939 .46353 L
.0944 .48284 L
.0949 .50215 L
.0954 .52147 L
.10275 .54078 L
.11058 .56009 L
.1184 .57941 L
.12622 .59872 L
Mistroke
.13405 .61803 L
Mfstroke
.13405 .61803 m
.13405 .61803 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.47619 .45187 m
.47619 .54711 L
.85714 .54711 L
.85714 .45187 L
F
1 g
.45238 .47568 m
.45238 .57092 L
.83333 .57092 L
.83333 .47568 L
F
0 g
.001 w
[ ] 0 setdash
.45238 .47568 m
.83333 .47568 L
.83333 .57092 L
.45238 .57092 L
.45238 .47568 L
s
% Start of sub-graphic
p
0.452381 0.475684 0.833333 0.570922 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0183824 0.183824 [
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0330882 0.35119 0.216912 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .125 -61 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Scale) show
109.188 19.750 moveto
(Height) show
158.625 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{750, 463.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001cb000`400?l00000o`00003oo`3ooooo
0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo
003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0
ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool0
0?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0oooo[`3o
ool00`3oojX0E@00000000030000000305FZo`3oool0oooo00h0oooo00<0oonZ05D0:`20e?l0o`3o
oolW0?ooo`00o`3ooon^0?ooo`030?ooe020:`00000000D0000000<0EJ[o0?ooo`3oool03P3oool0
0`3DP2/002^00=Coo`3o0?ooobH0oooo003o0?oook@0oooo00<0ZUD000000000EJX0403oool00`3o
ojX0E@0[083Do`3o0?ooobH0oooo003o0?ooobH0oooo00@0oonZ05D000000000EJ[o1`3oool0103o
ojX0E@000000:`20e?l40?ooo`050:YE0000000000000000000[P=@00`3oool00`3oom@0P2/00000
000200000006000[P03Dool0oooo0?ooo`3oom@0P2/00`0000000`00:h00e?oo0?ooo`020?ooo`0<
0:YE000000000000000[P02ZP2/00000001EZP3oool0oonZ05D0000002/0P=Co103oool01@2ZE@00
0000000000000000:h3D00D0oooo00<0ojYE0000000000000P0000000`0[P=@0oooo0?ooo`020?oo
o`060?nZE@000000000000000000:h00e?oo0P3oool0303DP2/0000000000000:h00e?nZ05D00000
02/0P=Co0?ooZP1E0000000005FZo`80oooo00D0ZUD0000000000000000002^0e0020?ooo`040?oo
ZP1E0000000005FZo`@0oooo00@0ojYE0000000005D0Z_oo0P3oool01@2ZE@000000000000000000
:h3D0080oooo00@0oonZ05D000000000EJ[o0P3oool01`3DP2/000000000000[P=@0e80[00000000
EJX00P3oool00`2ZE@000000001EZP020?ooo`030=B0:`00000005FZ0080oooo00L0omB002/00000
0000000F01D0000002/0P=Co00@0oooo00@0oonZ05D000000000EJ[o103oool04P3oZUD000000000
000[P=@0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0oooo0?nZE@000000001E0:[o
ool0oooo203oool00?l0oooo9P3oool0103oojX0E@000000001EZ_l70?ooo`040?ooZP1E0000000[
083Do`<0oooo00<0ZUD00000000000000`000000100[P=@0oooo0?ooe020:`0500000004000[P03D
ool0oooD080[00D0000000@002^00=Coo`3oool0ojYE1P0000001P00EJX0oooo0?ooZP1E0000000[
083Do`<0oooo00<0ZUD00000000000000`0000001@0[P=@0oooo0?ooo`3oool0e80[00H0000000@0
:h3D0?ooo`3oool0ojYE1@0000000`0005D0Z_oo0?nZE@0600000008000[P03Dool0oonZ05D00000
0000EJ[o0?ooo`2ZE@050000000602^0e03oool0oonZ05D000000000EJ[o103oool01P3oZUD00000
0000E@2Zool0oooo0:YE00D0000000P0:h3D0?ooo`3oojX0E@000000001EZ_l0oooo0=B0:`@00000
00<0:b/[00000000EJX00P3oool00`2ZE@000000001EZP020?ooo`030=B0:`00000005FZ0080oooo
00L0ZUD0000000000000000F01D0000002/0P=Co00@0oooo00@0oonZ05D000000000EJ[o0`3oool0
4`3oojX0E@0000000000:h00e?oo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?oo
o`3oZUD000000000E@2Zool0o`3oool80?ooo`00o`3ooolV0?ooo`040?ooZP1E0000000005FZo`L0
oooo00@0oonZ05D0000002/0P=Co0P3oool0:@3oe800:`000000001EZ_l0oooo0?nZE@000000001E
0:[oo`3oZUD000000000:`20e?l0oooo0?ooZP1E0000000[083Do`3oZUD000000000:`20e?l0oooo
0?ooZP1E0000000[083Do`3oool0ZUD000000000:h00e?oo0?ooZP1E00000000001EZP3oool0oonZ
05D0000002/0P=Co0080oooo00h0omB002/000000000EJ[o0?ooo`3oZUD000000000E@2Zool0oooo
0?ooZP1E0000000002^0e080oooo02L0e80[0000000005D0Z_oo0?ooZP1E0000000002^0e03oool0
oooD080[00000000:h3D0=B0:`00000002^00=Coo`3oom@0P2/000000000:h00e?oo0?ooZP1E0000
000005FZo`3oe800:`000000001EZ_l0oooo0?nZE@000000001E0:[oo`3oojX0E@000000001EZ_l0
103oool06P3oZUD000000000E@2Zool0omB002/000000000EJ[o0?ooo`3oZUD000000000E@2Zool0
oonZ05D000000000EJ[o0?ooZP1E00000000001EZP3oool0omB002/00000000005FZ0P3oool00`2Z
E@000000001EZP020?ooo`080=B0:`00000005FZ0?ooo`3oom@0P2/00000000[P=@80?ooo`040?oo
ZP1E0000000005FZo`<0oooo01<0e80[000000000000EJ[o0?ooo`3oe800:`000000:`20e?l0oooo
0?oDP00[0000001E0:[oo`3oool0ojYE0000000005D0Z_oo0?l0oooo203oool00?l0oooo9P3oool0
103oojX0E@000000001EZ_l70?ooo`040?ooZP1E0000000[083Do`80oooo00@0e80[00000000:h00
e?oo203oool01P3oZUD00000000000000000000[083Do`<0oooo00X0ojYE00000000000000000000
:`20e?l0oooo0:YE0000000005FZ0P3oool0202ZE@000000001EZP3oool0oonZ05D0000002/0P=Co
0P3oool0103DP2/00000000[P03Dool60?ooo`040?nZE@000000001E0:[oo`80oooo00P0omB002/0
000002/0P=Co0?oDP00[0000000[083Do`D0oooo0140ojYE000000000000EJ[o0?ooo`3DP2/00000
000[P03Dool0oonZ05D000000000EJ[o0=B0:`00000002^00=Coo`050?ooo`040?ooZP1E00000000
05FZo`@0oooo00P0ojYE0000000005D0Z_oo0=B0:`00000002^00=Coo`D0oooo00P0oonZ05D00000
0000EJ[o0?oDP00[0000000[083Do`80oooo00<0e80[00000000EJX00P3oool00`2ZE@000000001E
ZP020?ooo`080=B0:`00000005FZ0?ooo`3oom@0P2/00000001EZ_l80?ooo`040?ooZP1E00000000
05FZo`80oooo00@0omB002/00000000005FZ0P3oool03P3oe800:`000000:`20e?l0oooo0?oDP00[
0000001E0:[oo`3oool0ojYE0000000005D0Z_ooo`3oool80?ooo`00o`3ooolV0?ooo`040?ooZP1E
0000000005FZo`L0oooo00@0oonZ05D000000000EJ[o0P3oool00`3DP2/000000000000500000003
05FZo`3oool0e80[00D0000000@005FZ0?ooo`3oool0e80[1@0000001P00EJX0oooo0?ooo`2ZE@00
0000001EZP80oooo00P0e80[00000000EJX0oooo0?ooZP1E0000000005FZo`80oooo00<0e80[0000
000000001@0000000`1EZ_l0oooo0?ooo`040?ooo`090?ooZP1E000000000000E@2Zool0omB002/0
000005D0Z_oo00D0oooo00<0oooD080[00000000100000001`00:h00e?oo0?ooZP1E0000000005FZ
o`3DP2/01`0000001@1EZ_l0oonZ05D000000000EJ[o00@0oooo00D0ojYE0000000005D0Z_oo0=B0
:`070000000905FZo`3oojX0E@000000001EZ_l0omB002/0000005D0Z_oo0080oooo00<0e80[0000
0000EJX00P3oool00`2ZE@000000001EZP020?ooo`080=B0:`00000005FZ0?ooo`3oom@0P2/00000
001EZ_l80?ooo`0:0?ooZP1E000000000000:`20e?l0oooo0:YE00000000001E0:[oo`80oooo00h0
omB002/0000002/0P=Co0?ooo`3oe800:`000000:`20e?l0oooo0?nZE@000000001E0:[oool0oooo
203oool00?l0oooo9P3oool00`3oojX0E@00000000050000000702^0e03oool0oooo0?ooZP1E0000
000005FZo`020?ooo`030?nZE@000000000000@0000000@0000[083Do`3oojX0E@000`0000001P00
EJX0oooo0?ooo`3oool0oonZ05D000<0000000<005FZ0?ooo`3oool00P3oool00`2ZE@000000001E
ZP020?ooo`080=B0:`00000005FZ0?ooo`3oojX0E@000000001EZ_l20?ooo`030?nZE@0000000000
00@0000000<0000[083Do`3oool00`3oool00`3DP2/00000000000020000000602^0e03oool0omB0
02/0000002/0P=Co203oool02`3oe800:`0000000000000002^00=Coo`3oojX0E@000000001EZ_l0
ojYE00H0000000@0000[083Do`3oojX0E@00200000000`0005D0Z_oo0?nZE@060000000:0000:`20
e?l0oonZ05D000000000EJ[o0?oDP00[0000000[083Do`80oooo00<0e80[00000000EJX00P3oool0
0`2ZE@000000001EZP020?ooo`080=B0:`00000005FZ0?ooo`3oom@0P2/00000001EZ_l80?ooo`06
0?ooZP1E000000000000000002/0P81E0P0000004P0[P=@0oooo0?ooo`3oool0omB002/0000002/0
P=Co0?ooo`3oe800:`000000:`20e?l0oooo0?nZE@000000001E0:[oool0oooo203oool00?l0oooo
9P3oool00`3oojX0E@000000000600000006001EZP3oool0oonZ05D00000000005FZ0P3oool06P3o
e800:`000000E@2Zool0oooo0?oDP00[0000001E0:[oo`3oe800:`000000E@2Zool0oooo0=B0:`00
000005FZ0?ooo`3oe800:`000000E@2Zool0oooo0=B0:`00000005FZ0P3oool00`2ZE@000000001E
ZP020?ooo`080=B0:`00000005FZ0?ooo`3oojX0E@0000000000EJX20?ooo`090?oDP00[0000001E
0:[oo`3oool0omB002/0000005D0Z_oo0080oooo00<0oonZ05D0000000000`000000901EZ_l0oooo
0?ooo`3oojX0E@000000000[P=@0oooo0?ooZP1E0000000[083Do`3oojX0E@000000E@2Zool0oooo
0=B0:`00000002^00=Coo`3oojX0E@000000001EZ_l0omB002/0000005D0Z_oo0?ooo`3oe800:`00
0000E@2Zool0oonZ05D000P0000001P0001E0:[oo`3oe800:`000000E@2Zool0oooo0?oDP00[0000
001E0:[oo`3oojX0E@000000001EZ_l0oonZ05D00000000005FZ0?ooo`3oojX0E@0000000000EJX2
0?ooo`0=0:YE00000000000[083Do`3oom@0P2/000000000EJX0oooo0?ooe020:`00000005FZo`08
0?ooo`050?ooZP1E0000000005F0P00[00000P0000000`00:h00e?oo0?ooo`020?ooo`060?oDP00[
00000000001EZP3oool0ojYE0P0000001P0[P=@0oooo0=B0:`000000001E0:[oool0oooo203oool0
0?l0oooo9P3oool0103oojX0E@000000001EZ_l30?ooo`060=B0:`000000000[083Do`3oojX0E@00
0`0000000`00:h00e?oo0:YE00050000000402^0e03oool0oooD080[00D0000000@0:h3D0?ooo`3o
om@0P2/01@0000001P0[P=@0oooo0?ooo`2ZE@000000001EZP80oooo00H0e80[00000000EJX0oooo
0?ooZP1E000300000003000[P03Dool0ZUD000D0000000D0:h3D0?ooo`3oool0oooo0:YE00020000
00030000E@2Zool0oooo00@0oooo00<0ojYE0000000000000`0000001000:h00e?oo0?ooo`2ZE@05
00000008001EZP3oool0oonZ05D000000000EJ[o0?ooo`2ZE@050000000602^0e03oool0oonZ05D0
00000000EJ[o103oool01P3oZUD000000000E@2Zool0oooo0:YE00D0000000P0:h3D0?ooo`3oojX0
E@000000001EZ_l0oooo0=B0:`H0000000@005FZ0?ooo`3oool0ZUD01P0000000`0[P=@0oooD080[
0003000000030000E@2Zool0oooo00D0oooo00P0oonZ05D000000000EJ[o0?nZE@000000000[083D
o`@0oooo00<0omB002/0000000002@0000000`00EJX0oooo0?ooo`3o0?ooo`L0oooo003o0?ooobH0
oooo00@0oonZ05D000000000EJ[o0`3oool03@3oojX0E@000000001EZ_l0oonZ05D0000002/0P81E
0000000002/0P=Co0?ooo`3DP2/00`0000001P0[P=@0oooo0?ooo`3oool0oonZ05D000<0000000H0
05FZ0?ooo`3oool0oooo0?ooZP1E000300000007001EZP3oool0oooo0?ooo`2ZE@000000001EZP02
0?ooo`0=0=B0:`00000005FZ0?ooo`3oojX0E@000000:`20P5D000000000:`20e?l0oooo0=B0:`03
0000000802^0e03oool0oooo0?ooo`3oom@0P2/00000000[P=@20?ooo`030:YE0000000005FZ00<0
oooo00H0ojYE0000000000000000000[P03Dool30?ooo`0;0:YE00000000000000000000:h00e?oo
0?ooo`3oojX0E@000000001EZ_l00P3oool01@3DP2/00000000000000000:h3D0080oooo00@0oonZ
05D000000000EJ[o103oool0103oZUD000000000E@2Zool20?ooo`050=B0:`00000000000000000[
P=@00P3oool0103oojX0E@000000001EZ_l20?ooo`070=B0:`000000000002^0e03DP2/00000001E
ZP020?ooo`040:YE0000000005FZ0:YE0080000000@005FZ0?ooo`3oom@0P2/00`0000000`0005D0
Z_oo0?ooo`050?ooo`090?ooZP1E0000000005FZo`3oool0e80[0000000002/0P=Co00<0oooo00d0
omB002/0000002/0P:Z002/000000000001E0:[oo`3oe800:`000000000005D0Z_oo0?l0oooo2@3o
ool00?l0oooo9P3oool0103oojX0E@000000001EZ_l30?ooo`040=B0:`000000000[083Doc/0oooo
00T0oooD080[00000000:h3D0?ooo`3oojX0E@000000000[P=@04`3oool0103oojX0E@000000001E
Z_l90?ooo`040?ooZP1E0000000005FZo`@0oooo00@0ojYE0000000005D0Z_oo603oool00`2ZE@00
0000001EZP060?ooo`040?ooe020:`00000005FZo`P0oooo00@0oonZ05D000000000EJ[o0P3oool0
102ZE@0000000000:`20e?oo0?oooaP0oooo003o0?ooobH0oooo00<0oonZ05D0000000001P000000
0`00EJX0oooo0?ooo`0k0?ooo`030=B0:`000000000000<0000000<0001E0:[oo`3oool04P3oool0
103oojX0E@000000001EZ_l90?ooo`040?ooZP1E0000000005FZo`@0oooo00@0ojYE0000000005D0
Z_oo2@3oool0103oojX0E@000000001EZ_l;0?ooo`030:YE0000000005FZ00H0oooo00@0oooD080[
00000000EJ[o203oool0103oojX0E@000000001EZ_l20?ooo`050?ooe020:`0000000000:`20e?l0
o`3ooolG0?ooo`00o`3ooolV0?ooo`030?ooZP1E0000000000D0000000<005FZ0?ooo`3oool0?@3o
ool01P3oZUD00000000000000000001E0:[ooa@0oooo00@0oonZ05D000000000EJ[o2@3oool0103o
ojX0E@000000001EZ_l40?ooo`040?nZE@000000001E0:[oo`T0oooo00@0oonZ05D000000000EJ[o
2`3oool00`2ZE@000000001EZP080?ooo`030:YE001EZ_l0oooo00L0oooo00@0oonZ05D000000000
EJ[o0`3oool01@3oojX0E@000000000005D0Z_oo0?l0oooo5P3oool00?l0ooooo`3oooo`0?ooo`00
o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oo
oo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo002?
0?ooo`050?oDP00[000000000000000[P=@0103oool01@3DP2/00000000000000000:h3D00@0oooo
00D0ojYE000000000000000005FZo`040?ooo`050?nZE@00000000000000001EZ_l0;03oool0103o
om@0P2/00000001EZ_l60?ooo`050?nZE@00000000000000001EZ_l0103oool01@3oZUD000000000
00000000EJ[o00@0oooo00D0ojYE000000000000000005FZo`0/0?ooo`040?ooe020:`00000005FZ
o`H0oooo00D0e80[000000000000000002^0e0040?ooo`050?nZE@00000000000000001EZ_l0103o
ool01@3oZUD00000000000000000EJ[o02d0oooo00D0ZUD00000000000000000001EZP040?ooo`05
0?nZE@00000000000000001EZ_l0103oool01@3oZUD00000000000000000EJ[o00@0oooo00D0ojYE
000000000000000005FZo`0^0?ooo`050:YE00000000000000000000EJX0103oool01@3DP2/00000
000000000000:h3D00@0oooo00D0ojYE000000000000000005FZo`040?ooo`050?nZE@0000000000
0000001EZ_l0;03oool01P3oom@0P2/0000000000000001E0:[oo`@0oooo00D0ojYE000000000000
000005FZo`040?ooo`050?nZE@00000000000000001EZ_l0103oool01@3oZUD00000000000000000
EJ[o02`0oooo00H0oooD080[0000000000000000E@2Zool40?ooo`050=B0:`00000000000000000[
P=@0103oool01@3oZUD00000000000000000EJ[o00@0oooo00D0ojYE000000000000000005FZo`0Z
0?ooo`040?ooe020:`00000002^0e0@0oooo00D0ojYE000000000000000005FZo`040?ooo`050?nZ
E@00000000000000001EZ_l0103oool01@3oZUD00000000000000000EJ[o00@0oooo00D0ojYE0000
00000000000005FZo`0N0?ooo`00SP3oool00`3oZUD00000000000030000000402^0e03oool0oooo
0=B0:`D0000000@005FZ0?ooo`3oool0ojYE1@000000101EZ_l0oooo0?ooo`3oZUD50000000305FZ
o`3oool0oooo02T0oooo00@0oooD080[00000000:h3D1@3oool00`3oZUD000000000000300000004
05FZo`3oool0oooo0?nZE@D0000000@0EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?ooo`0Y
0?ooo`040?ooe020:`00000002^0e0D0oooo00<0e80[0000000000000`0000001000EJX0oooo0?oo
o`3oZUD50000000405FZo`3oool0oooo0?nZE@D0000000<0EJ[o0?ooo`3oool0:03oool00`3oom@0
P2/00000000400000004001EZP3oool0oooo0?nZE@D0000000@0EJ[o0?ooo`3oool0ojYE1@000000
101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo02T0oooo00<0oooD080[000000001000
00001000EJX0oooo0?ooo`3DP2/500000004001EZP3oool0oooo0?nZE@D0000000@0EJ[o0?ooo`3o
ool0ojYE1@0000000`1EZ_l0oooo0?ooo`0X0?ooo`030?ooe020:`00000000<0000000D0000[083D
o`3oool0oooo0?nZE@050000000405FZo`3oool0oooo0?nZE@D0000000@0EJ[o0?ooo`3oool0ojYE
1@0000000`1EZ_l0oooo0?ooo`0X0?ooo`030?ooe020:`00000000<0000000D0000[083Do`3oool0
oooo0=B0:`0500000004001EZP3oool0oooo0?nZE@D0000000@0EJ[o0?ooo`3oool0ojYE1@000000
0`1EZ_l0oooo0?ooo`0W0?ooo`040?ooe020:`00000002^0e0<0oooo00<0ojYE0000000000000`00
0000101EZ_l0oooo0?ooo`3oZUD50000000405FZo`3oool0oooo0?nZE@D0000000@0EJ[o0?ooo`3o
ool0ojYE1@0000000`1EZ_l0oooo0?ooo`0K0?ooo`00S@3oool0903oom@0P2/00000000[P=@0oooo
0?nZE@000000001E0:[oo`3oojX0E@000000000[P=@0oooo0?nZE@000000000[083Do`3oom@0P2/0
0000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^0
0=Coob/0oooo00<0ZUD000000000EJX0103oool06`3oom@0P2/00000000[P=@0oooo0=B0:`000000
02^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0
oooo0=B0:`00000002^00=Coo`0[0?ooo`030:YE0000000005FZ00@0oooo01/0oonZ05D000000000
:h3D0?ooo`3oZUD000000000:`20e?l0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0
oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0:@3oool0903oe800:`000000001EZ_l0
oooo0?nZE@000000000[083Do`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0
P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`000000
02^00=CoobX0oooo02@0omB002/000000000EJ[o0?ooo`3oZUD000000000:`20e?l0oonZ05D00000
0000:h3D0?ooo`3oZUD000000000:`20e?l0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03D
ool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03DoolY0?ooo`0T0?oDP00[0000000[083D
o`3oool0e80[00000000EJX0oooo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo0?oo
e020:`00000002^0e03oool0e80[00000000:h00e?oo0?ooe020:`00000002^0e03oool0e80[0000
0000:h00e?oo:@3oool0903oe800:`000000:`20e?l0oooo0=B0:`00000005FZ0?ooo`3oojX0E@00
0000000[P=@0oooo0?nZE@000000000[083Do`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^0
0=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=CoobP0oooo00@0oooD080[00000000
:h3D0P3oool0903oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[
P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3o
om@0P2/00000000[P=@0oooo0=B0:`00000002^00=Cooa`0oooo002=0?ooo`0T0?oDP00[0000001E
0:[oo`3oool0oonZ05D0000002/0P=Co0?nZE@000000001E0:[oo`3oool0oooD080[00000000EJ[o
0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?oDP00[0000000[083Do`3oool0omB0
02/0000005D0Z_oo:`3oool0103oZUD00000000[P03Dool30?ooo`0K0?oDP00[0000000[083Do`3o
ool0omB002/0000005D0Z_oo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?oDP00[
0000000[083Do`3oool0omB002/0000005D0Z_oo02/0oooo00@0ojYE00000000:h00e?oo0`3oool0
6`3oZUD000000000E@2Zool0oooo0?ooe020:`00000005FZo`3oe800:`000000:`20e?l0oooo0?oD
P00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`0Y0?ooo`0T0?nZ
E@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?oDP00[0000000[083Do`3oool0omB002/0
000005D0Z_oo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?oDP00[0000000[083D
o`3oool0omB002/0000005D0Z_oo:P3oool0903oZUD000000000E@2Zool0oooo0?ooZP1E00000000
05FZo`3oZUD000000000E@2Zool0oooo0?ooe020:`00000005FZo`3oe800:`000000:`20e?l0oooo
0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oobh0oooo01l0
oonZ05D0000005D0Z_oo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?oDP00[0000
000[083Do`3oool0omB002/0000005D0Z_oo0?oDP00[0000000[083Do`3oool0omB002/0000005D0
Z_oo02h0oooo01l0oonZ05D0000005D0Z_oo0?nZE@000000001E0:[oo`3oool0oooD080[00000000
EJ[o0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?oDP00[0000000[083Do`3oool0
omB002/0000005D0Z_oo02P0oooo00@0oooD080[00000000:h3D0P3oool0903oe800:`000000:`20
e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3o
e800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[
0000001E0:[ooa`0oooo002=0?ooo`090?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co
00D0oooo01H0oooD080[00000000:h3D0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co
0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co:`3oool0103oe800:`000000:`20e?l3
0?ooo`0K0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3o
ool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co02/0oooo
00@0omB002/0000002/0P=Co203oool05P3oom@0P2/00000000[P=@0omB002/0000005D0Z_oo0?oo
o`3oojX0E@000000:`20e?l0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?lY0?ooo`0T
0?ooZP1E0000000005FZo`3oool0ojYE0000000005D0Z_oo0?oDP00[0000001E0:[oo`3oool0oonZ
05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E
0:[oo`3oool0oonZ05D0000002/0P=Co:P3oool02@3oojX0E@000000001EZ_l0oooo0?nZE@000000
001E0:[oo`050?ooo`0F0?ooe020:`00000002^0e03oe800:`000000E@2Zool0oooo0?ooZP1E0000
000[083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Dob/0oooo0280ZUD000000000
000005F0080[000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[
0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D00000
02/0P=Co:`3oool01`2ZE@00000000000000EH00P2/00000:`20e?l01@3oool05P3oom@0P2/00000
000[P=@0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB002/0000005D0Z_oo0?oo
o`3oojX0E@000000:`20e?lX0?ooo`040?ooe020:`00000002^0e080oooo02@0omB002/0000005D0
Z_oo0?ooo`3oojX0E@000000:`20e?l0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0
omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB002/0000005D0Z_oo0?ooo`3oojX0
E@000000:`20e?lL0?ooo`00S@3oool03`3oZUD000000000001EZ_l0oooo0?nZE@000000001E0:[o
o`3oojX0E@000000:`20e?l0oooo0?nZE@020000000C05FZo`3oZUD000000000E@2Zool0oooo0?oo
ZP1E0000000005FZo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`0[0?ooo`040?oo
e020:`00000002^0e0<0oooo01/0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE
0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@00
0000001EZ_l0:`3oool0103oom@0P2/00000000[P=@30?ooo`060?ooZP1E0000000[083Do`3oool0
ojYE0P0000004`1EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE00000000
05D0Z_oo0?ooo`3oojX0E@000000001EZ_l0:P3oool00`3oZUD00000000000030000000M05FZo`3o
ool0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3o
ojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0:`3oool00`3o
ZUD00000000000030000000805FZo`3oool0oonZ05D0000002/0P=Co0?ooo`3oZUD20000000C05FZ
o`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`3oZUD000000000E@2Zool0oooo0?oo
ZP1E0000000005FZo`0Y0?ooo`030?ooe020:`00000000D0000001`0EJ[o0?nZE@000000001E0:[o
o`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZ
E@000000001E0:[oo`3oool0oonZ05D000000000EJ[o:@3oool00`3oom@0P2/00000000500000007
05FZo`3oojX0E@000000:`20e?l0oooo0?nZE@020000000C05FZo`3oZUD000000000E@2Zool0oooo
0?ooZP1E0000000005FZo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`0X0?ooo`04
0?ooe020:`00000002^0e080oooo02@0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0
ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0
E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_lL0?ooo`00S@3oool0
0`3oZUD000000000000400000004001EZP3oool0oooD080[00D0000001@002^00=Coo`3oZUD00000
0000E@2Zool0oooo0?ooZP1E0000000005FZo`3oZUD000000000E@2Zool0oooo0?ooZP1E00000000
05FZob`0oooo00@0ojYE0000000005D0Z_oo0P3oool06`3oZUD000000000E@2Zool0oooo0?ooZP1E
0000000005FZo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`3oZUD000000000E@2Z
ool0oooo0?ooZP1E0000000005FZo`0/0?ooo`040?nZE@000000001E0:[oo`80oooo00<0oooD080[
00000000100000005000:h00e?oo0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZ
E@000000001E0:[oo`3oool0oonZ05D000000000EJ[o:P3oool00`3oojX0E@00000000020000000N
0000E@2Zool0oooo0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E
0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o
:`3oool00`3oojX0E@0000000002000000050000E@2Zool0oooo0?ooe020:`001@0000005000:h00
e?oo0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[oo`3oool0
oonZ05D000000000EJ[o:@3oool01P3oZUD000000000:`20e?l0oooo0=B0:`80000001`0EJ[o0?nZ
E@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D0
00000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o:@3oool01P3oZUD00000
0000:`20e?l0oooo0=B0:`80000000<0EJ[o0?ooe020:`001@0000005000:h00e?oo0?nZE@000000
001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D000000000
EJ[o:03oool0103oom@0P2/00000000[P=@20?ooo`0T0?nZE@000000001E0:[oo`3oool0oonZ05D0
00000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[o
o`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o703o
ool008d0oooo00@0omB002/00000:h00P5D00P0000001@0[P=@0oooo0?ooo`3oool0ZUD000@00000
01D005FZ0?ooo`3oool0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB002/00000
05D0Z_oo0?ooo`3oojX0E@000000:`20e?l0;03oool0103oom@0P2/00000000[P=@20?ooo`0K0?oD
P00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0
000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co02`0oooo00@0oooD080[
00000000:h3D0`3oool00`2ZE@000000000000020000000E001EZP3oool0oooo0?oDP00[0000001E
0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co
02T0oooo02@0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0omB002/0000005D0Z_oo
0?ooo`3oojX0E@000000:`20e?l0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB0
02/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?lZ0?ooo`0;0?ooe020:`00000002^0e03oool0
e80[00000000:h00e?oo0?ooo`2ZE@00100000005@00EJX0oooo0?ooo`3oe800:`000000E@2Zool0
oooo0?ooZP1E0000000[083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`0Y0?oo
o`0T0=B0:`00000002^00=Coo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0
oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000
001E0:[oo`3oool0oonZ05D0000002/0P=Co:@3oool02`3DP2/00000000[P03Dool0oooo0?ooZP1E
0000000[083Do`3oool0ZUD000@0000001D005FZ0?ooo`3oool0omB002/0000005D0Z_oo0?ooo`3o
ojX0E@000000:`20e?l0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l09@3oool01`3o
om@0P2/002^0e03oom@0P2/00000000[P=@00P3oool0903oe800:`000000E@2Zool0oooo0?ooZP1E
0000000[083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`3oe800:`000000E@2Z
ool0oooo0?ooZP1E0000000[083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Doa`0
oooo002=0?ooo`040?ooZP1E0000001E0:[oo`H0oooo00<0e80[00000000EJX01@3oool04P3oe800
:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000
001E0:[oobd0oooo0200ojYE0000000005D0Z_oo0?ooo`3oe800:`000000:`20e?l0oooo0?oDP00[
0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20
e?l0oooo0?oDP00[0000001E0:[oobd0oooo00@0ojYE0000000005D0Z_oo0P3oool00`3DP2/00000
001EZP050?ooo`0B0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?oDP00[0000000[
083Do`3oool0omB002/0000005D0Z_oo:@3oool0903oojX0E@000000:`20e?l0oooo0?oDP00[0000
001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0
oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oobX0oooo
00d0oonZ05D0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0oooo0=B0:`00000005FZ00D0oooo
0180omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3o
e800:`000000E@2ZoolY0?ooo`0T0=B0:`00000002^00=Coo`3oool0oonZ05D0000005D0Z_oo0?oD
P00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?oDP00[0000000[083Do`3oool0omB002/0
000005D0Z_oo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo:@3oool03@3DP2/00000
000[P03Dool0oooo0?ooZP1E0000001E0:[oo`3oool0e80[00000000EJX01@3oool04P3oe800:`00
0000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E
0:[oobD0oooo00L0oooD080[00000000000[02/[00000000:h3D0080oooo02@0omB002/0000002/0
P=Co0?ooo`3oe800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0
omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800
:`000000E@2ZoolL0?ooo`00S@3oool03P3oom@0P2/00000001EZ_l0oooo0?nZE@000000001E0:[o
o`3oool0omB002/00000:h00e?oo103oool04P3oom@0P2/00000000[P=@0oooo0=B0:`00000002^0
0=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coobh0oooo01l0ZUD000000000:h00
e?oo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo0?ooe020:`00000002^0e03oool0
e80[00000000:h00e?oo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo02h0oooo00T0
ZUD000000000:h00e?oo0?ooo`3oe800:`00000[P03Dool0103oool04P3oom@0P2/00000000[P=@0
oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=CoobT0oooo
02@0oonZ05D000000000:h3D0?ooo`3DP2/000000000E@2Zool0oooD080[00000000:h3D0?ooo`3D
P2/00000000[P03Dool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0oooD080[0000
0000:h3D0?ooo`3DP2/00000000[P03DoolZ0?ooo`0>0?ooZP1E0000000002^0e03oool0e80[0000
000005D0Z_oo0?ooo`3oe800:`00000[P03Dool40?ooo`0B0?ooe020:`00000002^0e03oool0e80[
00000000:h00e?oo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo:@3oool0903oZUD0
00000000:`20e?l0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`000000
02^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0
oooo0=B0:`00000002^00=CoobT0oooo00h0ojYE0000000002/0P=Co0?ooo`3DP2/00000000[P03D
ool0oooo0?oDP00[000002^00=Coo`@0oooo0180oooD080[00000000:h3D0?ooo`3DP2/00000000[
P03Dool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03DoolW0?ooo`050:YE000000000000
0000000[P=@00P3oool0903oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/0
0000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^0
0=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Cooa`0oooo002>0?ooo`030?oDP00[
0000000000<0000000D0:h3D0?ooo`3oool0oonZ05D00004000000040000E@2Zool0oooo0?nZE@D0
000000@0EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?ooo`0X0?ooo`030?nZE@0000000000
00D0000000<0EJ[o0?ooo`3oZUD01@000000101EZ_l0oooo0?ooo`3oZUD50000000405FZo`3oool0
oooo0?nZE@D0000000<0EJ[o0?ooo`3oool0:03oool00`3oZUD00000000000050000000405FZo`3o
ool0oonZ05D000@0000000@0001E0:[oo`3oool0ojYE1@000000101EZ_l0oooo0?ooo`3oZUD50000
000305FZo`3oool0oooo02T0oooo00<0e80[0000000000000`000000100[P=@0oooo0?ooo`3oZUD5
0000000405FZo`3oool0oooo0?nZE@D0000000@0EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo
0?ooo`0Z0?ooo`030=B0:`000000000000<0000000D0:h3D0?ooo`3oool0oonZ05D0000400000004
0000E@2Zool0oooo0?nZE@D0000000@0EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?ooo`0X
0?ooo`030?ooe020:`00000000<0000000D0000[083Do`3oool0oooo0?nZE@050000000405FZo`3o
ool0oooo0?nZE@D0000000@0EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?ooo`0X0?ooo`03
0?ooe020:`00000000<0000000H0000[083Do`3oool0oooo0?ooZP1E0004000000040000E@2Zool0
oooo0?nZE@D0000000@0EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?ooo`0W0?ooo`040?nZ
E@000000000002^0e0<0oooo00<0ojYE0000000000000`000000101EZ_l0oooo0?ooo`3oZUD50000
000405FZo`3oool0oooo0?nZE@D0000000@0EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?oo
o`0K0?ooo`00S`3oool01@3oe800:`0000000000000005FZ00<0oooo00<0oooD080[000000000`00
00001@0005D0Z_oo0?ooo`3oool0ojYE00<0000000<0EJ[o0?ooo`3oool00P3oool01@3oZUD00000
000000000000EJ[o02/0oooo00<0ojYE0000000000001@000000101EZ_l0oooo0?ooo`3oZUD30000
000305FZo`3oool0oooo0080oooo00D0ojYE000000000000000005FZo`040?ooo`050?nZE@000000
00000000001EZ_l0:`3oool00`3oZUD00000000000050000000405FZo`3oool0oooD080[00@00000
00D0001E0:[oo`3oool0oooo0?nZE@030000000305FZo`3oool0oooo0080oooo00D0ojYE00000000
0000000005FZo`0]0?ooo`050:YE0000000000000000000[P=@0103oool01@3oZUD0000000000000
0000EJ[o00@0oooo00D0ojYE000000000000000005FZo`040?ooo`050?nZE@00000000000000001E
Z_l0;P3oool01@2ZE@000000000000000000:h3D00<0oooo00<0oooD080[000000000`0000001@00
05D0Z_oo0?ooo`3oool0ojYE00<0000000<0EJ[o0?ooo`3oool00P3oool01@3oZUD0000000000000
0000EJ[o02d0oooo00D0ZUD0000000000000000[083Do`040?ooo`050?nZE@00000000000000001E
Z_l0103oool01@3oZUD00000000000000000EJ[o00@0oooo00D0ojYE000000000000000005FZo`0]
0?ooo`050:YE0000000000000000:`20e?l00`3oool00`3oom@0P2/000000003000000050000E@2Z
ool0oooo0?ooo`3oZUD00`0000000`1EZ_l0oooo0?ooo`020?ooo`050?nZE@00000000000000001E
Z_l0:`3oool00`2ZE@00000002^0e0040?ooo`050?nZE@00000000000000001EZ_l0103oool01@3o
ZUD00000000000000000EJ[o00@0oooo00D0ojYE000000000000000005FZo`040?ooo`050?nZE@00
000000000000001EZ_l07P3oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?oo
ool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03o
ool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0oooo
o`3oooo`0?ooo`00D@3ooooo00000?l00000K@00000b0?ooo`00D@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0<03oool00540oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0`0?ooo`00
D@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
<03oool00540oooo00<000000?ooo`3oool0o`3ooooo0?ooofT0oooo00<000000?ooo`3oool0<03o
ool00540oooo00<000000?ooo`3oool0o`3ooooo0?ooofT0oooo00<000000?ooo`3oool0<03oool0
0540oooo00<000000?ooo`3oool0o`3ooooo0?ooofT0oooo00<000000?ooo`3oool0<03oool00540
oooo00<000000?ooo`3oool0o`3ooooo0?ooofT0oooo00<000000?ooo`3oool0<03oool00540oooo
00<000000?ooo`3oool0o`3ooooo0?ooofT0oooo00<000000?ooo`3oool0<03oool00540oooo00<0
00000?ooo`3oool0o`3ooooo0?ooofT0oooo00<000000?ooo`3oool0<03oool00540oooo00<00000
0?ooo`3oool0o`3ooooo0?ooofT0oooo00<000000?ooo`3oool0<03oool00540oooo0`00003o0?oo
ool0ooooI`3oool300000380oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooomY0?ooo`03
0000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooomY0?ooo`030000
003oool0oooo0300oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooomY0?ooo`030000003o
ool0oooo0300oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooomY0?ooo`030000003oool0
oooo0300oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooomY0?ooo`030000003oool0oooo
0300oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooomY0?ooo`030000003oool0oooo0300
oooo001A0?ooo`030000003oool0oooo0?l0ooooo`3ooomY0?ooo`030000003oool0oooo0300oooo
00110?ooo`050=B0:`00000000000000000[P=@02`3oool00`000000oooo0?ooo`3o0?ooool0oooo
J@3oool00`000000oooo0?ooo`0`0?ooo`00@03oool00`3DP2/000000000000300000003001EZP3o
ool0oooo00P0oooo00<000000?ooo`3oool0o`3ooooo0?ooofT0oooo00<000000?ooo`3oool0<03o
ool003l0oooo00T0oonZ05D000000000:h3D0?ooo`3oZUD000000000:`20e?l02@3oool00`000000
oooo0?ooo`3o0?ooool0ooooJ@3oool00`000000oooo0?ooo`0`0?ooo`00<`3oool00`3oojX0E@00
000000060000000<000[P03Dool0oooo0?nZE@000000001E0:[oo`3oool0oooD080[00000000EJ[o
2@3oool00`000000oooo0?ooo`3o0?ooool0oooo203oool00`3o0000oooo0?ooo`1N0?ooo`030000
003oool0oooo0300oooo000c0?ooo`030?ooZP1E0000000000H0000000<002^00=Coo`3oool01@3o
ool0103oom@0P2/00000000[P=@90?ooo`D00000o`3ooooo0?ooo`@0oooo103o001K0?ooo`D00000
<P3oool003l0oooo00H0oonZ05D0000002/0P=Co0?ooo`3oZUD20000000305FZo`3oool0oooo00L0
oooo00<000000?ooo`3oool0o`3ooooo0?ooo`<0oooo1P3o001P0?ooo`030000003oool0oooo0300
oooo000o0?ooo`030?ooe020:`00000000@0000000<002^00=Coo`3oool0203oool00`000000oooo
0?ooo`3o0?ooool0oooo0@3oool60?l00680oooo00<000000?ooo`3oool0<03oool00400oooo00<0
ZUD00000000000000P0000000`00EJX0oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooooP3o
ool50?l006D0oooo00<000000?ooo`3oool0<03oool00400oooo00<0e80[00000000EJX03P3oool0
0`000000oooo0?ooo`3o0?oooo/0oooo1P3o001W0?ooo`030000003oool0oooo0300oooo00100?oo
o`040?oDP00[000002^00=Coo`d0oooo00<000000?ooo`3oool0o`3ooooi0?ooo`H0o`00J@3oool0
0`000000oooo0?ooo`0`0?ooo`00@03oool00`3oojX0E@0000000003000000030000E@2Zool0oooo
00P0oooo00<000000?ooo`3oool0o`3oooof0?ooo`H0o`00K03oool00`000000oooo0?ooo`0`0?oo
o`00@03oool00`3oom@0P2/000000003000000030000E@2Zool0oooo00P0oooo00<000000?ooo`3o
ool0o`3ooood0?ooo`H0o`00KP3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo
0?ooo`3o0?oooo40oooo1P3o001a0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003o
ool0oooo0?l0ooook`3oool60?l007<0oooo00<000000?ooo`3oool0<03oool00540oooo00<00000
0?ooo`3oool0o`3oooo/0?ooo`H0o`00MP3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`00
0000oooo0?ooo`3o0?ooonX0oooo1P3o001h0?ooo`030000003oool0oooo0300oooo001A0?ooo`<0
0000o`3ooooX0?ooo`D0o`00N@3oool300000380oooo001A0?ooo`030000003oool0oooo0?l0oooo
i@3oool60?l007d0oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0o`3o
oooS0?ooo`H0o`00O`3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`3o
0?ooon40oooo1@3o00220?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo
0?l0oooogP3oool60?l008@0oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3o
ool0o`3ooooL0?ooo`H0o`00QP3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo
0?ooo`3o0?ooomT0oooo1P3o00290?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003o
ool0oooo0?l0ooooe`3oool60?l008/0oooo00<000000?ooo`3oool0<03oool00540oooo00<00000
0?ooo`3oool0o`3ooooD0?ooo`H0o`00SP3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`00
0000oooo0?ooo`3o0?ooom80oooo1P3o002@0?ooo`030000003oool0oooo0300oooo001A0?ooo`03
0000003oool0oooo0?l0ooooc`3oool60?l009<0oooo00<000000?ooo`3oool0<03oool00540oooo
00<000000?ooo`3oool0o`3oooo=0?ooo`H0o`00U@3oool00`000000oooo0?ooo`0`0?ooo`00D@3o
ool300000?l0oooob`3oool50?l009H0oooo0`00000b0?ooo`00D@3oool00`000000oooo0?ooo`3o
0?ooolP0oooo1P3o002J0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo
0?l0ooooaP3oool60?l009`0oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3o
ool0o`3oooo40?ooo`D0o`00W`3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo
0?ooo`3o0?oool40oooo1P3o002Q0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003o
ool0oooo0?l0oooo_`3oool60?l00:<0oooo00<000000?ooo`3oool0<03oool00540oooo00<00000
0?ooo`3oool0o`3ooonl0?ooo`H0o`00YP3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`00
0000oooo0?ooo`3o0?oookX0oooo1P3o002X0?ooo`030000003oool0oooo0300oooo001A0?ooo`03
0000003oool0oooo0?l0oooo]`3oool60?l00:/0oooo00<000000?ooo`3oool0<03oool00540oooo
00<000000?ooo`3oool0o`3ooone0?ooo`H0o`00[@3oool00`000000oooo0?ooo`0`0?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?oook80oooo1P3o002`0?ooo`030000003oool0oooo0300oooo001A
0?ooo`030000003oool0oooo0?l0oooo/03oool60?l00;80oooo00<000000?ooo`3oool0<03oool0
0540oooo0`00003o0?ooojh0oooo1@3o002c0?ooo`<00000<P3oool00540oooo00<000000?ooo`3o
ool0o`3ooon[0?ooo`H0o`00]`3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo
0?ooo`3o0?ooojT0oooo1P3o002i0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003o
ool0oooo0?l0ooooY`3oool50?l00;`0oooo00<000000?ooo`3oool0<03oool00540oooo00<00000
0?ooo`3oool0o`3ooonT0?ooo`H0o`00_P3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`00
0000oooo0?ooo`3o0?oooj80oooo1P3o00300?ooo`030000003oool0oooo0300oooo001A0?ooo`03
0000003oool0oooo0?l0ooooW`3oool60?l00<<0oooo00<000000?ooo`3oool0<03oool00540oooo
00<000000?ooo`3oool0o`3ooonM0?ooo`H0o`00a@3oool00`000000oooo0?ooo`0`0?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?oooiX0oooo1P3o00380?ooo`030000003oool0oooo0300oooo001A
0?ooo`030000003oool0oooo0?l0ooooV03oool60?l00<X0oooo00<000000?ooo`3oool0<03oool0
0540oooo00<000000?ooo`3oool0o`3ooonE0?ooo`H0o`00c@3oool00`000000oooo0?ooo`0`0?oo
o`00D@3oool00`000000oooo0?ooo`3o0?oooi<0oooo1P3o003?0?ooo`030000003oool0oooo0300
oooo001A0?ooo`<00000o`3ooonA0?ooo`D0o`00d03oool300000380oooo001A0?ooo`030000003o
ool0oooo0?l0ooooSP3oool60?l00=@0oooo00<000000?ooo`3oool0<03oool00540oooo00<00000
0?ooo`3oool0o`3ooon<0?ooo`H0o`00eP3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`00
0000oooo0?ooo`3o0?ooohX0oooo1@3o003I0?ooo`030000003oool0oooo0300oooo001A0?ooo`03
0000003oool0oooo0?l0ooooQ`3oool60?l00=/0oooo00<000000?ooo`3oool0<03oool00540oooo
00<000000?ooo`3oool0o`3ooon50?ooo`H0o`00g@3oool00`000000oooo0?ooo`0`0?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?oooh80oooo1P3o003P0?ooo`030000003oool0oooo0300oooo0011
0?ooo`050?nZE@00000000000000001EZ_l02`3oool00`000000oooo0?ooo`3o0?oooh00oooo1P3o
003R0?ooo`030000003oool0oooo0300oooo00100?ooo`030?nZE@000000000000<0000000<0EJ[o
0?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooogd0oooo1P3o003U0?ooo`030000003oool0
oooo0300oooo000o0?ooo`090?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo00T0oooo
00<000000?ooo`3oool0o`3ooomk0?ooo`H0o`00i`3oool00`000000oooo0?ooo`0`0?ooo`00?`3o
ool02@3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`090?ooo`030000003oool0oooo
0?l0ooooN03oool60?l00>X0oooo00<000000?ooo`3oool0<03oool003l0oooo00T0omB002/00000
05D0Z_oo0?ooo`3oojX0E@000000:`20e?l02@3oool00`000000oooo0?ooo`3o0?ooogH0oooo1P3o
003/0?ooo`030000003oool0oooo0300oooo000o0?ooo`090?nZE@000000001E0:[oo`3oool0oonZ
05D000000000EJ[o00T0ooooo`00001g000000D0o`00l000000b0?ooo`00?`3oool02@3oZUD00000
0000E@2Zool0oooo0?ooZP1E0000000005FZo`090?ooo`030000003oool0oooo0?l0ooooL@3oool6
0?l00?40oooo00<000000?ooo`3oool0<03oool003l0oooo00T0omB002/0000005D0Z_oo0?ooo`3o
ojX0E@000000:`20e?l02@3oool00`000000oooo0?ooo`3o0?ooofl0oooo1P3o003c0?ooo`030000
003oool0oooo0300oooo000o0?ooo`090?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo
00T0oooo00<000000?ooo`3oool0o`3ooom]0?ooo`D0o`00mP3oool00`000000oooo0?ooo`0`0?oo
o`00?`3oool02@3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`090?ooo`030000003o
ool0oooo0?l0ooooJP3oool60?l00?P0oooo00<000000?ooo`3oool0<03oool00400oooo00<0ojYE
0000000000000`0000000`1EZ_l0oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooJ03oool6
0?l00?X0oooo00<000000?ooo`3oool0<03oool00440oooo00D0ojYE000000000000000005FZo`0;
0?ooo`030000003oool0oooo0?l0ooooI@3oool60?l00?d0oooo00<000000?ooo`3oool0<03oool0
0540oooo00<000000?ooo`3oool0o`3ooomS0?ooo`H0o`00o`3oool00`000000oooo0?ooo`0`0?oo
o`00D@3oool00`000000oooo0?ooo`3o0?ooof00oooo1P3o003o0?ooo`<0oooo00<000000?ooo`3o
ool0<03oool00540oooo00<000000?ooo`3oool0o`3ooomN0?ooo`H0o`00o`3oool50?ooo`030000
003oool0oooo0300oooo001A0?ooo`030000003oool0oooo0?l0ooooF`3oool60?l00?l0oooo203o
ool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooeT0oooo1P3o003o
0?ooo`X0oooo00<000000?ooo`3oool0<03oool00540oooo0`00003o0?oooeL0oooo1@3o003o0?oo
o`/0oooo0`00000b0?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooe@0oooo1P3o003o0?ooo`l0
oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0o`3ooomB0?ooo`H0o`00
o`3ooolA0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo0?l0ooooD03o
ool50?l00?l0oooo503oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`3o
0?ooodd0oooo1P3o003o0?oooaH0oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?oo
o`3oool0o`3ooom;0?ooo`H0o`00o`3ooolH0?ooo`030000003oool0oooo0300oooo001A0?ooo`03
0000003oool0oooo0?l0ooooB03oool60?l00?l0oooo6`3oool00`000000oooo0?ooo`0`0?ooo`00
D@3oool00`000000oooo0?ooo`3o0?ooodH0oooo1P3o003o0?oooad0oooo00<000000?ooo`3oool0
<03oool00540oooo00<000000?ooo`3oool0o`3ooom30?ooo`H0o`00o`3ooolP0?ooo`030000003o
ool0oooo0300oooo001A0?ooo`030000003oool0oooo0?l0oooo@@3oool60?l00?l0oooo8P3oool0
0`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooch0oooo1P3o003o0?oo
obD0oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0o`3oooll0?ooo`H0
o`00o`3ooolW0?ooo`030000003oool0oooo0300oooo001A0?ooo`<00000o`3ooolj0?ooo`D0o`00
o`3ooolX0?ooo`<00000<P3oool00540oooo00<000000?ooo`3oool0o`3ooolg0?ooo`H0o`00o`3o
ool/0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo0?l0oooo=@3oool6
0?l00?l0oooo;P3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`3o0?oo
oc<0oooo1@3o003o0?oooc40oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3o
ool0o`3oool`0?ooo`H0o`00o`3ooolc0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000
003oool0oooo0?l0oooo;P3oool60?l00?l0oooo=@3oool00`000000oooo0?ooo`0`0?ooo`00D@3o
ool00`000000oooo0?ooo`3o0?ooob/0oooo1P3o003o0?ooocP0oooo00<000000?ooo`3oool0<03o
ool00540oooo00<000000?ooo`3oool0o`3ooolY0?ooo`H0o`00o`3ooolj0?ooo`030000003oool0
oooo0300oooo001A0?ooo`030000003oool0oooo0?l0oooo9P3oool60?l00?l0oooo?@3oool00`00
0000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooob@0oooo1P3o003o0?ooocl0
oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`H0o`00
o`3ooom20?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo0?l0oooo7`3o
ool60?l00?l0ooooA03oool00`000000oooo0?ooo`0`0?ooo`00D@3oool300000?l0oooo7@3oool5
0?l00?l0ooooA@3oool300000380oooo001A0?ooo`030000003oool0oooo0?l0oooo6P3oool60?l0
0?l0ooooB@3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`3o0?oooaP0
oooo1P3o003o0?oood/0oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0
o`3ooolF0?ooo`D0o`00o`3ooom>0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003o
ool0oooo0?l0oooo4`3oool60?l00?l0ooooD03oool00`000000oooo0?ooo`0`0?ooo`00D@3oool0
0`000000oooo0?ooo`3o0?oooa40oooo1P3o003o0?oooe80oooo00<000000?ooo`3oool0<03oool0
0540oooo00<000000?ooo`3oool0o`3oool>0?ooo`H0o`00o`3ooomE0?ooo`030000003oool0oooo
0300oooo001A0?ooo`030000003oool0oooo0?l0oooo303oool60?l00?l0ooooE`3oool00`000000
oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo1P3o003o0?oooeX0oooo
00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0o`3oool70?ooo`H0o`00o`3o
oomL0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo0?l0oooo103oool6
0?l00?l0ooooG`3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`3o0?oo
o`80oooo1P3o003o0?ooof40oooo00<000000?ooo`3oool0<03oool00540oooo0`00003o0?ooo`D0
o`00o`3ooomR0?ooo`<00000<P3oool00540oooo00<000000?ooo`3oool0o03oool60?l00?l0oooo
IP3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`3j0?ooo`H0o`00o`3o
oomX0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo0?P0oooo1@3o003o
0?ooof/0oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0m@3oool60?l0
0?l0ooooK@3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`3c0?ooo`H0
o`00o`3ooom_0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo0?00oooo
1P3o003o0?ooog80oooo00<000000?ooo`3oool0<03oool00440oooo00D0e80[0000000000000000
02^0e00;0?ooo`030000003oool0oooo0>h0oooo1P3o003o0?ooog@0oooo00<000000?ooo`3oool0
<03oool00400oooo00<0e80[0000000000000`0000000`00EJX0oooo0?ooo`080?ooo`030000003o
ool0oooo0>/0oooo1P3o003o0?ooogL0oooo00<000000?ooo`3oool0<03oool003l0oooo00T0oonZ
05D000000000:h3D0?ooo`3oZUD000000000:`20e?l02@3oool00`000000oooo0?ooo`3Y0?ooo`H0
o`00o`3ooomi0?ooo`030000003oool0oooo0300oooo000o0?ooo`090?nZE@000000001E0:[oo`3o
ool0oooD080[00000000EJ[o00T0oooo00<000000?ooo`3oool0iP3oool60?l00?l0ooooO03oool0
0`000000oooo0?ooo`0`0?ooo`00A03oool0103oom@0P2/00000000[P=@90?ooo`030000003oool0
oooo0>@0oooo1P3o003o0?ooogh0oooo00<000000?ooo`3oool0<03oool003l0oooo00H0oonZ05D0
000002/0P=Co0?ooo`3oZUD20000000305FZo`3oool0oooo00L0oooo1@00003P0?ooo`D0o`00o`3o
oomm0?ooo`D00000<P3oool003l0oooo00<0oooD080[00000000100000000`00:h00e?oo0?ooo`08
0?ooo`030000003oool0oooo0=l0oooo1P3o003o0?oooh<0oooo00<000000?ooo`3oool0<03oool0
0400oooo00<0ZUD00000000000000P0000000`00EJX0oooo0?ooo`090?ooo`030000003oool0oooo
0=d0oooo1P3o003o0?ooohD0oooo00<000000?ooo`3oool0<03oool00400oooo00<0e80[00000000
EJX03P3oool00`000000oooo0?ooo`3K0?ooo`D0o`00o`3ooon80?ooo`030000003oool0oooo0300
oooo000W0?ooo`030?nZE@0005D0Z_oo01H0oooo00@0omB002/00000:h00e?oo3@3oool00`000000
oooo0?ooo`3H0?ooo`H0o`00o`3ooon:0?ooo`030000003oool0oooo0300oooo000T0?ooo`060?oD
P00[000000000000000005D0Z_oo5P3oool00`3oojX0E@0000000003000000030000E@2Zool0oooo
00P0oooo00<000000?ooo`3oool0eP3oool60?l00?l0ooooS03oool00`000000oooo0?ooo`0`0?oo
o`008@3oool00`3oojX0E@000000000400000003000[P03Dool0oooo01D0oooo00<0oooD080[0000
00000`0000000`0005D0Z_oo0?ooo`080?ooo`030000003oool0oooo0=<0oooo1P3o003o0?ooohl0
oooo00<000000?ooo`3oool0<03oool001h0oooo00<0oooD080[000000001@0000000`1EZ_l0oooo
0?ooo`0X0?ooo`030000003oool0oooo0=40oooo1P3o003o0?oooi40oooo00<000000?ooo`3oool0
<03oool001`0oooo00<0oonZ05D0000000000`0000001@00EJX0oooo0:YE00000000EJ[o02X0oooo
00<000000?ooo`3oool0cP3oool60?l00?l0ooooU03oool00`000000oooo0?ooo`0`0?ooo`00703o
ool0103oojX0E@0000000000EJX40?ooo`030:YE00000000EJ[o02X0oooo00<000000?ooo`3oool0
c03oool60?l00?l0ooooUP3oool00`000000oooo0?ooo`0`0?ooo`00703oool00`3oojX0E@000000
000300000005001EZP3oool0ZUD00000001EZ_l0:P3oool00`000000oooo0?ooo`390?ooo`H0o`00
o`3ooonI0?ooo`030000003oool0oooo0300oooo000N0?ooo`030?ooZP1E0000000000D0000000<0
EJ[o0?ooo`3oool0:03oool00`000000oooo0?ooo`370?ooo`H0o`00o`3ooonK0?ooo`030000003o
ool0oooo0300oooo000Q0?ooo`030?oDP00[0000000000@0000000<002^00=Coo`3oool09P3oool3
00000<D0oooo1@3o003o0?oooi`0oooo0`00000b0?ooo`00903oool01P3oZUD00000000000000000
001E0:[oobL0oooo00<000000?ooo`3oool0`P3oool60?l00?l0ooooX03oool00`000000oooo0?oo
o`0`0?ooo`009`3oool00`3DP2/0001E0:[oo`0W0?ooo`030000003oool0oooo0<00oooo1P3o003o
0?oooj80oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0_P3oool50?l0
0?l0ooooY@3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`2k0?ooo`H0
o`00o`3ooonW0?ooo`030000003oool0oooo0300oooo000L0?ooo`030?ooZP1E0000000000T00000
00<0001E0:[oo`3oool09P3oool00`000000oooo0?ooo`2i0?ooo`H0o`00o`3ooonY0?ooo`030000
003oool0oooo0300oooo000L0?ooo`030?ooZP1E0000000000T0000000<0001E0:[oo`3oool09P3o
ool00`000000oooo0?ooo`2f0?ooo`H0o`00o`3ooon/0?ooo`030000003oool0oooo0300oooo001A
0?ooo`030000003oool0oooo0;@0oooo1P3o003o0?ooojh0oooo00<000000?ooo`3oool0<03oool0
01l0oooo00@0oonZ05D00000:h00e?oo;P3oool00`000000oooo0?ooo`2a0?ooo`H0o`00o`3ooona
0?ooo`030000003oool0oooo0300oooo000M0?ooo`030?ooe020:`00000000P0000000<0EJ[o0?oo
o`3oool09P3oool00`000000oooo0?ooo`2_0?ooo`H0o`00o`3ooonc0?ooo`030000003oool0oooo
0300oooo000M0?ooo`030=B0:`000000000000P0000000<002^00=Coo`3oool09P3oool00`000000
oooo0?ooo`2/0?ooo`H0o`00o`3ooonf0?ooo`030000003oool0oooo0300oooo000O0?ooo`040?oo
ZP1E000002^00=Coo`<0oooo00@0oooD080[000005D0Z_oo9`3oool00`000000oooo0?ooo`2Z0?oo
o`H0o`00o`3ooonh0?ooo`030000003oool0oooo0300oooo000O0?ooo`040?ooZP1E000002^00=Co
o`<0oooo00@0oonZ05D00000:h00e?oo9`3oool300000:L0oooo1P3o003o0?oookT0oooo0`00000b
0?ooo`00D@3oool00`000000oooo0?ooo`2T0?ooo`L0o`00o`3ooonm0?ooo`030000003oool0oooo
0300oooo000L0?ooo`050?ooZP1E0000001E0:[oZP1E00001`0000000`0005D0Z_oo0?ooo`0V0?oo
o`030000003oool0oooo0:80oooo1P3o003o0?oool00oooo00<000000?ooo`3oool0<03oool001`0
oooo00D0oonZ05D0000005D0Z_nZ05D00007000000030000E@2Zool0oooo02H0oooo00<000000?oo
o`3oool0W`3oool60?l00?l0oooo``3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000
oooo0?ooo`2L0?ooo`L0o`00o`3oooo50?ooo`030000003oool0oooo0300oooo000O0?ooo`040?oo
ZP1E000002^00=Coobh0oooo00<000000?ooo`3oool0V@3oool70?l00?l0oooob03oool00`000000
oooo0?ooo`0`0?ooo`007@3oool00`3oom@0P2/0000000080000000305FZo`3oool0oooo02H0oooo
00<000000?ooo`3oool0U`3oool60?l00?l0oooob`3oool00`000000oooo0?ooo`0`0?ooo`007@3o
ool00`3DP2/000000000000800000003000[P03Dool0oooo02H0oooo00<000000?ooo`3oool0U03o
ool60?l00?l0oooocP3oool00`000000oooo0?ooo`0`0?ooo`007`3oool0103oojX0E@00000[P03D
ool30?ooo`040?ooe020:`00001E0:[oobL0oooo00<000000?ooo`3oool0TP3oool60?l00?l0oooo
d03oool00`000000oooo0?ooo`0`0?ooo`007`3oool0103oojX0E@00000[P03Dool30?ooo`040?oo
ZP1E000002^00=CoobL0oooo00<000000?ooo`3oool0S`3oool60?l00?l0ooood`3oool00`000000
oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`2=0?ooo`H0o`00o`3ooooE0?ooo`030000
003oool0oooo0300oooo000O0?ooo`030?ooZP1E0000000000D0000000<002^00=Coo`3oool09`3o
ool3000008X0oooo1P3o003o0?ooomH0oooo0`00000b0?ooo`007`3oool00`3oojX0E@0000000006
00000003001EZP3oool0oooo02H0oooo00<000000?ooo`3oool0R03oool60?l00?l0oooofP3oool0
0`000000oooo0?ooo`0`0?ooo`009P3oool0103oe800:`000000E@2ZoolW0?ooo`030000003oool0
oooo08D0oooo1P3o003o0?ooomd0oooo00<000000?ooo`3oool0<03oool002L0oooo00<0ZUD00000
E@2Zool09`3oool00`000000oooo0?ooo`230?ooo`H0o`00o`3ooooO0?ooo`030000003oool0oooo
0300oooo000V0?ooo`040?ooe020:`0002^00=CoobL0oooo00<000000?ooo`3oool0P03oool60?l0
0?l0oooohP3oool00`000000oooo0?ooo`0`0?ooo`009P3oool00`3oZUD0000005FZo`0X0?ooo`03
0000003oool0oooo07h0oooo1P3o003o0?ooon@0oooo00<000000?ooo`3oool0<03oool001l0oooo
00<0oonZ05D0000000001P0000000`0005D0Z_oo0?ooo`0V0?ooo`030000003oool0oooo07`0oooo
1@3o003o0?ooonL0oooo00<000000?ooo`3oool0<03oool001l0oooo00<0oonZ05D0000000001P00
00000`0005D0Z_oo0?ooo`0V0?ooo`030000003oool0oooo07T0oooo1P3o003o0?ooonT0oooo00<0
00000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0M`3oool60?l00?l0ooooj`3oool0
0`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`1e0?ooo`D0o`00o`3oooo^0?oo
o`030000003oool0oooo0300oooo000Q0?ooo`030?ooZP1E000000000080000000<0001E0:[oo`3o
ool0:03oool00`000000oooo0?ooo`1b0?ooo`H0o`00o`3oooo`0?ooo`030000003oool0oooo0300
oooo000P0?ooo`030?nZE@000000000000D0000000<0EJ[o0?ooo`3oool09P3oool00`000000oooo
0?ooo`1`0?ooo`H0o`00o`3oooob0?ooo`030000003oool0oooo0300oooo000O0?ooo`040?ooe020
:`00000002^0e0<0oooo00@0e80[00000000:h00e?oo9`3oool3000006d0oooo1P3o003o0?oooo<0
oooo0`00000b0?ooo`007`3oool0103oojX0E@00000[P03Dool30?ooo`040?ooe020:`00001E0:[o
obL0oooo00<000000?ooo`3oool0J`3oool60?l00?l0oooom`3oool00`000000oooo0?ooo`0`0?oo
o`007`3oool0103oom@0P2/0000[P03Dool30?ooo`040?ooe020:`0002^00=CoobL0oooo00<00000
0?ooo`3oool0J03oool60?l00?l0oooonP3oool00`000000oooo0?ooo`0`0?ooo`00803oool00`3o
ZUD0000002^0e0030?ooo`030=B0:`000000EJ[o02P0oooo00<000000?ooo`3oool0IP3oool60?l0
0?l0ooooo03oool00`000000oooo0?ooo`0`0?ooo`00703oool00`3oojX0E@000000000900000003
0000E@2Zool0oooo02H0oooo00<000000?ooo`3oool0H`3oool60?l00?l0ooooo`3oool00`000000
oooo0?ooo`0`0?ooo`00703oool00`3oojX0E@0000000009000000030000E@2Zool0oooo02H0oooo
00<000000?ooo`3oool0H@3oool60?l00?l0ooooo`3oool20?ooo`030000003oool0oooo0300oooo
001A0?ooo`030000003oool0oooo05l0oooo1@3o003o0?ooool0oooo1@3oool00`000000oooo0?oo
o`0`0?ooo`00D@3oool00`000000oooo0?ooo`1L0?ooo`H0o`00o`3ooooo0?ooo`L0oooo00<00000
0?ooo`3oool0<03oool00240oooo00<0oonZ05D0000000000P0000000`0002/0P=Co0?ooo`0@0?oo
o`040?ooe020:`00000002^0e0@0oooo00D0ojYE000000000000000005FZo`0;0?ooo`030000003o
ool0oooo05X0oooo1P3o003o0?ooool0oooo2@3oool00`000000oooo0?ooo`0`0?ooo`00803oool0
0`3oZUD00000000000050000000305FZo`3oool0oooo00h0oooo00@0oooD080[00000000:h3D0`3o
ool00`3oZUD00000000000030000000305FZo`3oool0oooo00P0oooo00<000000?ooo`3oool0F03o
ool50?l00?l0ooooo`3oool<0?ooo`030000003oool0oooo0300oooo000O0?ooo`0;0?ooe020:`00
000005FZo`3oe800:`0[083Do`3oe800:`00000[P03Dool03`3oool0103oom@0P2/00000000[P=@2
0?ooo`090?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo00T0oooo00<000000?ooo`3o
ool0E@3oool60?l00?l0ooooo`3oool>0?ooo`030000003oool0oooo0300oooo000O0?ooo`0;0?oo
ZP1E000002^00=Coo`3oe800:`0[083Do`3oool0ZUD00000E@2Zool03`3oool0103oom@0P2/00000
000[P=@20?ooo`090?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo00T0oooo00<00000
0?ooo`3oool0D`3oool60?l00?l0ooooo`3oool@0?ooo`030000003oool0oooo0300oooo000O0?oo
o`0;0?ooe020:`00000[083Do`3oe800:`0[083Do`3oom@0P2/00000E@2Zool03`3oool0103oom@0
P2/00000000[P=@20?ooo`090?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co00T0oooo
1@00001>0?ooo`H0o`00o`3ooooo0?ooo`l0oooo1@00000b0?ooo`00803oool02@3oZUD000000000
00000000000[083Do`2ZE@00000002^0e00@0?ooo`040?ooe020:`00000002^0e080oooo00T0ojYE
0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l02@3oool00`000000oooo0?ooo`1>0?ooo`H0
o`00o`3ooooo0?oooaD0oooo00<000000?ooo`3oool0<03oool00240oooo00L0oonZ05D000000000
000[083Do`3DP2/0:h3D0140oooo00@0oooD080[00000000:h3D0P3oool02@3oZUD000000000E@2Z
ool0oooo0?ooZP1E0000000005FZo`090?ooo`030000003oool0oooo04/0oooo1P3o003o0?ooool0
oooo603oool00`000000oooo0?ooo`0`0?ooo`00=P3oool01`3oom@0P2/002^0e03oom@0P2/00000
000[P=@00P3oool02@3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`090?ooo`030000
003oool0oooo04T0oooo1P3o003o0?ooool0oooo6P3oool00`000000oooo0?ooo`0`0?ooo`00=P3o
ool01`3oom@0P2/00000000002/0:b/00000000[P=@00P3oool02@3oe800:`000000:`20e?l0oooo
0?oDP00[0000001E0:[oo`090?ooo`030000003oool0oooo04H0oooo1P3o003o0?ooool0oooo7@3o
ool00`000000oooo0?ooo`0`0?ooo`009P3oool01P3oZUD000000000E@2Zool0ZUD002^0e0`0oooo
00D0ZUD0000000000000000002^0e0020?ooo`090?ooe020:`00000002^0e03oool0e80[00000000
:h00e?oo00T0oooo00<000000?ooo`3oool0A03oool60?l00?l0ooooo`3ooolO0?ooo`030000003o
ool0oooo0300oooo000V0?ooo`050?nZE@000000000000000000EJX03P3oool0103oZUD000000000
000[P=@30?ooo`030?nZE@000000000000<0000000<0EJ[o0?ooo`3oool0203oool00`000000oooo
0?ooo`120?ooo`D0o`00o`3ooooo0?ooob80oooo00<000000?ooo`3oool0<03oool003X0oooo00<0
ZUD00000000[P=@0103oool01@3oZUD00000000000000000EJ[o00/0oooo00<000000?ooo`3oool0
?`3oool60?l00?l0ooooo`3ooolT0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003o
ool0oooo03d0oooo1P3o003o0?ooool0oooo9P3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool0
0`000000oooo0?ooo`0k0?ooo`D0o`00o`3ooooo0?ooobT0oooo00<000000?ooo`3oool0<03oool0
0540oooo00<000000?ooo`3oool0>03oool60?l00?l0ooooo`3oool[0?ooo`030000003oool0oooo
0300oooo001A0?ooo`030000003oool0oooo03H0oooo1P3o003o0?ooool0oooo;@3oool00`000000
oooo0?ooo`0`0?ooo`00D@3oool3000003D0oooo103o003o0?ooool0oooo;P3oool300000380oooo
001A0?ooo`030000003oool0oooo03D0oooo0P3o003o0?ooool0oooo<P3oool00`000000oooo0?oo
o`0`0?ooo`00703oool00`3oojX0E@0000000009000000030000E@2Zool0oooo02H0oooo00<00000
0?ooo`3oool0=@3oool20?l00?l0ooooo`3ooolb0?ooo`030000003oool0oooo0300oooo000L0?oo
o`030?ooZP1E0000000000T0000000<0001E0:[oo`3oool09P3oool00`000000oooo0?ooo`0e0?oo
o`80o`00o`3ooooo0?oooc80oooo00<000000?ooo`3oool0<03oool00240oooo00D0oonZ05D00000
000002^00=Coo`0[0?ooo`030000003oool0oooo03D0oooo0P3o003o0?ooool0oooo<P3oool00`00
0000oooo0?ooo`0`0?ooo`00803oool01@3oojX0E@0000000000:h00e?oo02`0oooo00<000000?oo
o`3oool0=@3oool20?l00?l0ooooo`3ooolb0?ooo`030000003oool0oooo0300oooo000O0?ooo`05
0?ooZP1E000000000000000[P=@0;@3oool00`000000oooo0?ooo`0d0?ooo`80o`00o`3ooooo0?oo
oc<0oooo00<000000?ooo`3oool0<03oool001h0oooo00<0omB002/000000000100000000`1EZ_l0
oooo0?ooo`0Y0?ooo`030000003oool0oooo03D0oooo0P3o003o0?ooool0oooo<P3oool00`000000
oooo0?ooo`0`0?ooo`007@3oool01P3oe800:`000000000005D0Z_oo0=B0:`<0000000<0000[083D
o`3oool0:03oool00`000000oooo0?ooo`0e0?ooo`80o`00o`3ooooo0?oooc80oooo00<000000?oo
o`3oool0<03oool001`0oooo00D0oonZ05D000000000001E0:[oo`020?ooo`030?ooe020:`000000
0080000000<002^00=Coo`3oool09P3oool00`000000oooo0?ooo`0e0?ooo`80o`00o`3ooooo0?oo
oc80oooo00<000000?ooo`3oool0<03oool001`0oooo00@0oonZ05D0000005D0Z_oo1@3oool01@3o
ZUD000000000000005D0Z_oo02L0oooo00<000000?ooo`3oool0=@3oool20?l00?l0ooooo`3ooolb
0?ooo`030000003oool0oooo0300oooo000L0?ooo`030?ooZP1E05D0Z_oo00P0oooo00<0ZUD00000
E@2Zool09`3oool00`000000oooo0?ooo`0e0?ooo`80o`00o`3ooooo0?oooc80oooo00<000000?oo
o`3oool0<03oool00540oooo0`00000e0?ooo`80o`00o`3ooooo0?oooc00oooo0`00000b0?ooo`00
D@3oool00`000000oooo0?ooo`0e0?ooo`80o`00o`3ooooo0?oooc80oooo00<000000?ooo`3oool0
<03oool001l0oooo00<0oonZ05D0000000001P0000000`0005D0Z_oo0?ooo`0V0?ooo`030000003o
ool0oooo03D0oooo0P3o003o0?ooool0oooo<P3oool00`000000oooo0?ooo`0`0?ooo`007`3oool0
0`3oojX0E@0000000006000000030000E@2Zool0oooo02H0oooo00<000000?ooo`3oool0=@3oool2
0?l00?l0ooooo`3ooolb0?ooo`030000003oool0oooo0300oooo000P0?ooo`030?nZE@000000EJ[o
02h0oooo00<000000?ooo`3oool0=@3oool20?l00?l0ooooo`3ooolb0?ooo`030000003oool0oooo
0300oooo000O0?ooo`040?ooe020:`0002^00=Coobh0oooo00<000000?ooo`3oool0=@3oool20?l0
0?l0ooooo`3ooolb0?ooo`030000003oool0oooo0300oooo000O0?ooo`040?ooZP1E0000001E0:[o
obh0oooo00<000000?ooo`3oool0=@3oool20?l00?l0ooooo`3ooolb0?ooo`030000003oool0oooo
0300oooo000O0?ooo`030?ooe020:`00000000H0000000<0001E0:[oo`3oool09P3oool00`000000
oooo0?ooo`0e0?ooo`80o`00o`3ooooo0?oooc80oooo00<000000?ooo`3oool0<03oool00200oooo
00<0oonZ05D0000000001@0000000`0005D0Z_oo0?ooo`0V0?ooo`030000003oool0oooo03D0oooo
0P3o003o0?ooool0oooo<P3oool00`000000oooo0?ooo`0`0?ooo`00803oool00`3oZUD0000005FZ
o`0^0?ooo`030000003oool0oooo03D0oooo0P3o003o0?ooool0oooo<P3oool00`000000oooo0?oo
o`0`0?ooo`007`3oool0103oom@0P2/0000[P03Dool^0?ooo`030000003oool0oooo03D0oooo0P3o
003o0?ooool0oooo<P3oool00`000000oooo0?ooo`0`0?ooo`007`3oool0103oojX0E@000000E@2Z
ool^0?ooo`030000003oool0oooo03D0oooo0P3o003o0?ooool0oooo<P3oool00`000000oooo0?oo
o`0`0?ooo`00803oool00`2ZE@00000000000005000000030000E@2Zool0oooo02H0oooo0`00000e
0?ooo`80o`00o`3ooooo0?oooc00oooo0`00000b0?ooo`00803oool00`3oojX0E@00000000050000
00030000E@2Zool0oooo02H0oooo00<000000?ooo`3oool0=@3oool20?l00?l0ooooo`3ooolb0?oo
o`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo03D0oooo0P3o003o0?ooool0
oooo<P3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`0e0?ooo`80o`00
o`3ooooo0?oooc80oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0=@3o
ool20?l00?l0ooooo`3ooolb0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0
oooo03D0oooo0P3o003o0?ooool0oooo<P3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`00
0000oooo0?ooo`0e0?ooo`80o`00o`3ooooo0?oooc80oooo00<000000?ooo`3oool0<03oool00540
oooo00<000000?ooo`3oool0=@3oool20?l00?l0ooooo`3ooolb0?ooo`030000003oool0oooo0300
oooo001A0?ooo`030000003oool0oooo03D0oooo0P3o003o0?ooool0oooo<P3oool00`000000oooo
0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`0e0?ooo`80o`00o`3ooooo0?oooc80oooo00<0
00000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0=@3oool20?l00?l0ooooo`3ooolb
0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo03D0oooo0P3o003o0?oo
ool0oooo<P3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool3000003D0oooo0P3o003o0?ooool0
oooo<03oool300000380oooo001A0?ooo`030000003oool0oooo03D0oooo0P3o003o0?ooool0oooo
<P3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`0e0?ooo`80o`00o`3o
oooo0?oooc80oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0=@3oool2
0?l00?l0ooooo`3ooolb0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo
03D0oooo0P3o003o0?ooool0oooo<P3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000
oooo0?ooo`0e0?ooo`80o`00o`3ooooo0?oooc80oooo00<000000?ooo`3oool0<03oool00540oooo
00<000000?ooo`3oool0=@3oool20?l00?l0ooooo`3ooolb0?ooo`030000003oool0oooo0300oooo
000i0?ooo`040?ooe020:`00000002^0e0@0oooo00D0e80[000000000000000002^0e00;0?ooo`03
0000003oool0oooo03D0oooo0P3o003o0?ooool0oooo<P3oool00`000000oooo0?ooo`0`0?ooo`00
>@3oool0103oom@0P2/00000000[P=@30?ooo`030=B0:`000000000000<0000000<005FZ0?ooo`3o
ool0203oool00`000000oooo0?ooo`0e0?ooo`80o`00o`3ooooo0?oooc80oooo00<000000?ooo`3o
ool0<03oool003T0oooo00@0oooD080[00000000:h3D0P3oool02@3oojX0E@000000000[P=@0oooo
0?nZE@000000000[083Do`090?ooo`030000003oool0oooo03D0oooo0P3o003o0?ooool0oooo<P3o
ool00`000000oooo0?ooo`0`0?ooo`00>@3oool0103oom@0P2/00000000[P=@20?ooo`090?nZE@00
0000001E0:[oo`3oool0oooD080[00000000EJ[o00T0oooo00<000000?ooo`3oool0=@3oool20?l0
0?l0ooooo`3ooolb0?ooo`030000003oool0oooo0300oooo000i0?ooo`040?ooe020:`00000002^0
e0L0oooo00@0oooD080[00000000:h3D2@3oool00`000000oooo0?ooo`0e0?ooo`80o`00o`3ooooo
0?oooc80oooo00<000000?ooo`3oool0<03oool003T0oooo00@0oooD080[00000000:h3D0P3oool0
1P3oojX0E@000000:`20e?l0oooo0?nZE@80000000<0EJ[o0?ooo`3oool01`3oool5000003<0oooo
0P3o003o0?ooool0oooo;P3oool500000380oooo000i0?ooo`040?ooe020:`00000002^0e080oooo
00<0oooD080[00000000100000000`00:h00e?oo0?ooo`080?ooo`030000003oool0oooo03H0oooo
0P3o003o0?ooool0oooo<@3oool00`000000oooo0?ooo`0`0?ooo`00=P3oool01`3oom@0P2/002^0
e03oom@0P2/00000000[P=@00`3oool00`2ZE@0000000000000200000003001EZP3oool0oooo00T0
oooo00<000000?ooo`3oool0=P3oool20?l00?l0ooooo`3ooola0?ooo`030000003oool0oooo0300
oooo000f0?ooo`070?ooe020:`0000000000:`0[:`00000002^0e0030?ooo`030=B0:`00000005FZ
00h0oooo00<000000?ooo`3oool0=P3oool20?l00?l0ooooo`3ooola0?ooo`030000003oool0oooo
0300oooo000h0?ooo`050:YE0000000000000000000[P=@00`3oool0103oe800:`00000[P03Dool=
0?ooo`030000003oool0oooo03H0oooo0P3o003o0?ooool0oooo<@3oool00`000000oooo0?ooo`0`
0?ooo`00>@3oool0103oZUD000000000000[P=@30?ooo`030?ooZP1E0000000000<0000000<0001E
0:[oo`3oool0203oool00`000000oooo0?ooo`0f0?ooo`80o`00o`3ooooo0?oooc40oooo00<00000
0?ooo`3oool0<03oool003X0oooo00<0ZUD00000000[P=@00`3oool00`3oom@0P2/0000000030000
00030000E@2Zool0oooo00P0oooo00<000000?ooo`3oool0=P3oool20?l00?l0ooooo`3ooola0?oo
o`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo03H0oooo0P3o003o0?ooool0
oooo<@3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`0f0?ooo`80o`00
o`3ooooo0?oooc40oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0=P3o
ool20?l00?l0ooooo`3ooola0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0
oooo03H0oooo0P3o003o0?ooool0oooo<@3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`00
0000oooo0?ooo`0f0?ooo`80o`00o`3ooooo0?oooc40oooo00<000000?ooo`3oool0<03oool00540
oooo0`00000f0?ooo`80o`00o`3ooooo0?ooobl0oooo0`00000b0?ooo`00D@3oool00`000000oooo
0?ooo`0f0?ooo`80o`00o`3ooooo0?oooc40oooo00<000000?ooo`3oool0<03oool00540oooo00<0
00000?ooo`3oool0=P3oool20?l00?l0ooooo`3ooola0?ooo`030000003oool0oooo0300oooo001A
0?ooo`030000003oool0oooo03H0oooo0P3o003o0?ooool0oooo<@3oool00`000000oooo0?ooo`0`
0?ooo`00D@3oool00`000000oooo0?ooo`0f0?ooo`80o`00o`3ooooo0?oooc40oooo00<000000?oo
o`3oool0<03oool00540oooo00<000000?ooo`3oool0=P3oool20?l00=P0ooooo`00000N000003X0
oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0=P3oool20?l00=P0oooo
o`00000N000003X0oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0=P3o
ool20?l00=P0ooooo`00000N000003X0oooo00<000000?ooo`3oool0<03oool00540oooo00<00000
0?ooo`3oool0=P3oool20?l00=P0ooooo`00000N000003X0oooo00<000000?ooo`3oool0<03oool0
0540oooo00<000000?ooo`3oool0=P3oool20?l00=P0ooooo`00000N000003X0oooo00<000000?oo
o`3oool0<03oool00540oooo00<000000?ooo`3oool0=P3oool20?l00=P0ooooo`00000N000003X0
oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0=P3oool20?l00=P0oooo
o`00000N000003X0oooo00<000000?ooo`3oool0<03oool00540oooo0`00000f0?ooo`80o`00f03o
oooo000001h00000>03oool300000380oooo001A0?ooo`030000003oool0oooo03H0oooo0P3o003H
0?ooool000007P00000j0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo
03H0oooo0P3o003H0?ooool000007P00000j0?ooo`030000003oool0oooo0300oooo001A0?ooo`03
0000003oool0oooo03H0oooo0P3o003H0?ooool000007P00000j0?ooo`030000003oool0oooo0300
oooo001A0?ooo`030000003oool0oooo03H0oooo0P3o003H0?ooool000007P00000j0?ooo`030000
003oool0oooo0300oooo001A0?ooo`030000003oool0oooo03H0oooo0P3o003H0?ooool000007P00
000j0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo03H0oooo0P3o003H
0?ooool000007P00000j0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo
03H0oooo0P3o003H0?ooool000007P00000j0?ooo`030000003oool0oooo0300oooo001A0?ooo`03
0000003oool0oooo03H0oooo0P3o003H0?ooool000007P00000j0?ooo`030000003oool0oooo0300
oooo001A0?ooo`030000003oool0oooo03H0oooo0P3o003H0?ooool000007P00000j0?ooo`030000
003oool0oooo0300oooo001A0?ooo`030000003oool0oooo03H0oooo0P3o00360?ooool00000<000
000j0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo03H0oooo0P3o0036
0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000003X0oooo00<000000?ooo`3oool0<03oool0
0540oooo0`00000f0?ooo`80o`00aP3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000h0?oo
o`<00000<P3oool00540oooo00<000000?ooo`3oool0=`3oool20?l00<D0oooo00<000000?ooo`3o
ool0o`3ooolK0?oooa800000>P3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo
0?ooo`0g0?ooo`80o`00a@3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000j0?ooo`030000
003oool0oooo0300oooo001A0?ooo`030000003oool0oooo03L0oooo0P3o00350?ooo`030000003o
ool0oooo0?l0oooo6`3ooolB000003X0oooo00<000000?ooo`3oool0<03oool00540oooo00<00000
0?ooo`3oool0=`3oool20?l00<D0oooo00<000000?ooo`3oool0o`3ooolK0?oooa800000>P3oool0
0`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`0g0?ooo`80o`00a@3oool00`00
0000oooo0?ooo`3o0?oooa/0oooo4P00000j0?ooo`030000003oool0oooo0300oooo001A0?ooo`03
0000003oool0oooo03L0oooo0P3o00350?ooo`030000003oool0oooo0?l0oooo6`3ooolB000003X0
oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0=`3oool20?l00<D0oooo
00<000000?ooo`3oool0o`3ooolK0?oooa800000>P3oool00`000000oooo0?ooo`0`0?ooo`00D@3o
ool00`000000oooo0?ooo`0g0?ooo`80o`00a@3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00
000j0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo03L0oooo0P3o0035
0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000003X0oooo00<000000?ooo`3oool0<03oool0
0540oooo00<000000?ooo`3oool0=`3oool20?l00<D0oooo00<000000?ooo`3oool0o`3ooolK0?oo
oa800000>P3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`0g0?ooo`80
o`00a@3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000j0?ooo`030000003oool0oooo0300
oooo001A0?ooo`<00000=`3oool20?l00<D0oooo00<000000?ooo`3oool0o`3ooolK0?oooa800000
>03oool300000380oooo001A0?ooo`030000003oool0oooo03L0oooo0P3o00350?ooo`030000003o
ool0oooo0?l0oooo6`3ooolB000003X0oooo00<000000?ooo`3oool0<03oool00540oooo00<00000
0?ooo`3oool0=`3oool20?l00<D0oooo00<000000?ooo`3oool0o`3ooolK0?oooa800000>P3oool0
0`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`0g0?ooo`80o`00a@3oool00`00
0000oooo0?ooo`3o0?oooa/0oooo4P00000j0?ooo`030000003oool0oooo0300oooo001A0?ooo`03
0000003oool0oooo03L0oooo0P3o00350?ooo`030000003oool0oooo0?l0oooo6`3ooolB000003X0
oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0=`3oool20?l00<D0oooo
00<000000?ooo`3oool0o`3ooolK0?oooa800000>P3oool00`000000oooo0?ooo`0`0?ooo`00D@3o
ool00`000000oooo0?ooo`0g0?ooo`80o`00a@3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00
000j0?ooo`030000003oool0oooo0300oooo000f0?ooo`030=B0:`000000000000D0000000@0EJ[o
0?ooo`3oool0ojYE0`0000000`1EZ_l0oooo0?ooo`090?ooo`030000003oool0oooo03L0oooo0P3o
00350?ooo`030000003oool0oooo0?l0oooo6`3ooolB000003X0oooo00<000000?ooo`3oool0<03o
ool003H0oooo00<0omB002/0000000001@0000000`1EZ_l0oooo0?nZE@050000000305FZo`3oool0
oooo00P0oooo00<000000?ooo`3oool0=`3oool20?l00<D0oooo00<000000?ooo`3oool0o`3ooolK
0?oooa800000>P3oool00`000000oooo0?ooo`0`0?ooo`00=`3oool0102ZE@0000000000E@2Zool4
0?ooo`090?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo00T0oooo00<000000?ooo`3o
ool0=`3oool20?l00<D0oooo00<000000?ooo`3oool0o`3ooolK0?oooa800000>P3oool00`000000
oooo0?ooo`0`0?ooo`00=`3oool01@3oom@0P2/00000000005D0Z_oo00<0oooo00T0omB002/00000
02/0P=Co0?ooo`3oe800:`000000E@2Zool02@3oool00`000000oooo0?ooo`0g0?ooo`80o`00a@3o
ool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000j0?ooo`030000003oool0oooo0300oooo000h
0?ooo`050?ooe020:`0000000000E@2Zool00P3oool02@3oe800:`000000E@2Zool0oooo0?ooZP1E
0000000[083Do`090?ooo`030000003oool0oooo03L0oooo0P3o00350?ooo`030000003oool0oooo
0?l0oooo6`3ooolB000003X0oooo00<000000?ooo`3oool0<03oool003T0oooo00l0oooD080[0000
0000001E0:[oo`3oool0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l02@3oool50000
03D0oooo0`3o00340?ooo`030000003oool0oooo0?l0oooo6`3ooolB000003H0oooo1@00000b0?oo
o`00>P3oool03P3oom@0P2/000000000EJX0oooo0?nZE@000000001E0:[oo`3oool0oonZ05D00000
0000EJ[o2@3oool00`000000oooo0?ooo`0h0?ooo`80o`00a03oool00`000000oooo0?ooo`3o0?oo
oa/0oooo4P00000j0?ooo`030000003oool0oooo0300oooo000k0?ooo`0=0?oDP00[0000000[083D
o`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`090?ooo`030000003oool0oooo03P0
oooo0`3o00330?ooo`030000003oool0oooo0;L0oooo00<0oonZ05D0000000000`0000000`1EZ_l0
oooo0?ooo`1J0?oooa800000>P3oool00`000000oooo0?ooo`0`0?ooo`00=P3oool04P3oZUD00000
0000E@2Zool0oooo0?ooZP1E0000000005FZo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E
0:[oo`T0oooo00<000000?ooo`3oool0>@3oool20?l00<<0oooo00<000000?ooo`3oool0]P3oool0
0`3oom@0P2/0000000050000000305FZo`3oool0oooo05T0oooo4P00000j0?ooo`030000003oool0
oooo0300oooo000f0?ooo`0B0?ooZP1E0000000005FZo`3oool0ojYE0000000002/0P=Co0?ooe020
:`00000002^0e03oool0e80[00000000:h00e?oo2@3oool00`000000oooo0?ooo`0i0?ooo`80o`00
``3oool00`000000oooo0?ooo`2l0?ooo`030:YE0000000005FZ05/0oooo4P00000j0?ooo`030000
003oool0oooo0300oooo000g0?ooo`030:YE00000000000000<0000000@005FZ0?ooo`3oool0ojYE
1@0000000`1EZ_l0oooo0?ooo`080?ooo`030000003oool0oooo03T0oooo0`3o00320?ooo`030000
003oool0oooo0740oooo00<0ojYE0000000000000P0000000`0[P=@0oooo0?ooo`020?ooo`060?nZ
E@000000000000000000:h00e?oo0P3oool0303DP2/0000000000000:h00e?nZ05D0000002/0P=Co
0?ooZP1E0000000005FZo`80oooo00D0ZUD0000000000000000002^0e0070?ooo`040?ooZP1E0000
000005FZo`@0oooo00@0ojYE0000000005D0Z_oo0P3oool01@2ZE@000000000000000000:h3D0080
oooo00@0oonZ05D000000000EJ[o0P3oool01`3DP2/000000000000[P=@0e80[00000000EJX00P3o
ool00`2ZE@000000001EZP020?ooo`030=B0:`00000005FZ0080oooo00D0omB002/000000000000[
083Do`1:0?oooa800000>P3oool00`000000oooo0?ooo`0`0?ooo`00>03oool01@3DP2/000000000
0000000005FZ00@0oooo00D0ojYE000000000000000005FZo`0;0?ooo`030000003oool0oooo03X0
oooo0P3o00320?ooo`030000003oool0oooo0700oooo00<0e80[00000000000010000000100[P=@0
oooo0?ooo`3oZUD5000000030000E@2Zool0ojYE00H0000000P002^00=Coo`3oojX0E@000000001E
Z_l0oooo0:YE00D0000000<0:h3D0?ooo`3oool0103oool0103oojX0E@000000001EZ_l40?ooo`06
0?nZE@000000001E0:[oo`3oool0ZUD01@000000200[P=@0oooo0?ooZP1E0000000005FZo`3oool0
e80[100000000`0[:b/00000001EZP020?ooo`030:YE0000000005FZ0080oooo00<0e80[00000000
EJX00P3oool01@2ZE@0000000000000002/0P=Co04X0oooo4P00000j0?ooo`030000003oool0oooo
0300oooo001A0?ooo`030000003oool0oooo03X0oooo0`3o00310?ooo`030000003oool0oooo06l0
oooo00@0oonZ05D000000000:h3D0P3oool08`3DP2/000000000E@2Zool0oonZ05D000000000:h3D
0?ooo`3oom@0P2/00000000[P=@0e80[00000000:h00e?oo0?ooe020:`000000000[P03Dool0oonZ
05D000000000EJ[o0?oDP00[0000000005FZo`3oool0ojYE0000000005D0Z_oo00D0oooo00@0oonZ
05D000000000EJ[o103oool06P3oZUD000000000E@2Zool0omB002/000000000EJ[o0?ooo`3oZUD0
00000000E@2Zool0oonZ05D000000000EJ[o0?ooZP1E00000000001EZP3oool0omB002/000000000
05FZ0P3oool00`2ZE@000000001EZP020?ooo`080=B0:`00000005FZ0?ooo`3oom@0P2/00000000[
P=A<0?oooa800000>P3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`0k
0?ooo`80o`00`@3oool00`000000oooo0?ooo`1_0?ooo`040?nZE@000000001E0:[oo`80oooo00P0
omB002/0000002/0P=Co0?oDP00[0000000[083Do`D0oooo0140ojYE000000000000EJ[o0?ooo`3D
P2/00000000[P03Dool0oonZ05D000000000EJ[o0=B0:`00000002^00=Coo`0:0?ooo`040?ooZP1E
0000000005FZo`@0oooo00P0ojYE0000000005D0Z_oo0=B0:`00000002^00=Coo`D0oooo00P0oonZ
05D000000000EJ[o0?oDP00[0000000[083Do`80oooo00<0e80[00000000EJX00P3oool00`2ZE@00
0000001EZP020?ooo`080=B0:`00000005FZ0?ooo`3oom@0P2/00000001EZ_m<0?oooa800000>P3o
ool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`0k0?ooo`80o`00`@3oool0
0`000000oooo0?ooo`1d0?ooo`090?ooZP1E000000000000E@2Zool0omB002/0000005D0Z_oo00D0
oooo00<0oooD080[00000000100000001`00:h00e?oo0?ooZP1E0000000005FZo`3DP2/01`000000
0`1EZ_l0oooo0?ooo`030?ooo`040?ooZP1E0000000005FZo`@0oooo00D0ojYE0000000005D0Z_oo
0=B0:`070000000905FZo`3oojX0E@000000001EZ_l0omB002/0000005D0Z_oo0080oooo00<0e80[
00000000EJX00P3oool00`2ZE@000000001EZP020?ooo`080=B0:`00000005FZ0?ooo`3oom@0P2/0
0000001EZ_m<0?oooa800000>P3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo
0?ooo`0k0?ooo`<0o`00`03oool00`000000oooo0?ooo`0>0?oooe80o`004P3oool00`3DP2/00000
000000020000000602^0e03oool0omB002/0000002/0P=Co203oool02`3oe800:`00000000000000
02^00=Coo`3oojX0E@000000001EZ_l0ojYE00H0000000<0000[083Do`3oool0103oool00`3oojX0
E@0000000007000000030000E@2Zool0ojYE00H0000000X0000[083Do`3oojX0E@000000001EZ_l0
omB002/0000002/0P=Co0P3oool00`3DP2/00000001EZP020?ooo`030:YE0000000005FZ0080oooo
00P0e80[00000000EJX0oooo0?ooe020:`00000005FZod`0oooo4P00000j0?ooo`030000003oool0
oooo0300oooo001A0?ooo`030000003oool0oooo03`0oooo0P3o00300?ooo`030000003oool0oooo
00h0ooooDP3o000@0?ooo`030?ooZP1E0000000000<000000280EJ[o0?ooo`3oool0oonZ05D00000
0000:h3D0?ooo`3oojX0E@000000:`20e?l0oonZ05D0000005D0Z_oo0?ooo`3DP2/00000000[P03D
ool0oonZ05D000000000EJ[o0?oDP00[0000001E0:[oo`3oool0omB002/0000005D0Z_oo1@3oool0
0`3oojX0E@00000000070000000H0000E@2Zool0omB002/0000005D0Z_oo0?ooo`3oe800:`000000
E@2Zool0oonZ05D000000000EJ[o0?ooZP1E00000000001EZP3oool0oonZ05D00000000005FZ0P3o
ool03@2ZE@0000000000:`20e?l0oooD080[0000000005FZ0?ooo`3oom@0P2/00000001EZ_l0C03o
oolB000003X0oooo00<000000?ooo`3oool0<03oool00540oooo0`00000l0?ooo`<0o`00_`3oool0
0`000000oooo0?ooo`1`0?ooo`050:YE0000000000000000E@2Zool01@3oool00`3oZUD000000000
000300000004000[P03Dool0oooo0:YE00D0000000P005FZ0?ooo`3oojX0E@000000001EZ_l0oooo
0:YE00D0000000<0:h3D0?ooo`3oool0103oool0103oojX0E@000000001EZ_l40?ooo`060?nZE@00
0000001E0:[oo`3oool0ZUD01@000000200[P=@0oooo0?ooZP1E0000000005FZo`3oool0e80[1P00
00001000EJX0oooo0?ooo`2ZE@060000000302^0e03oom@0P2/000<0000000<0001E0:[oo`3oool0
B@3ooolB000003P0oooo0`00000b0?ooo`00D@3oool00`000000oooo0?ooo`0m0?ooo`80o`00_`3o
ool00`000000oooo0?ooo`1_0?ooo`040?ooe020:`00000002^0e080oooo00<0ZUD000000000EJX0
0`3oool01P3oZUD0000000000000000002^00=Coo`<0oooo00/0ZUD00000000000000000000[P03D
ool0oooo0?ooZP1E0000000005FZo`020?ooo`050=B0:`00000000000000000[P=@01`3oool0103o
ojX0E@000000001EZ_l40?ooo`040?nZE@000000001E0:[oo`80oooo00D0e80[0000000000000000
02^0e0020?ooo`040?ooZP1E0000000005FZo`80oooo00L0e80[000000000000:h3D0=B0:`000000
05FZ0080oooo00@0ZUD000000000EJX0ZUD00P0000001000EJX0oooo0?ooe020:`03000000030000
E@2Zool0oooo04T0oooo4P00000j0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003o
ool0oooo03d0oooo0P3o002o0?ooo`030000003oool0oooo06l0oooo00T0oooD080[00000000:h3D
0?ooo`3oojX0E@000000000[P=@04`3oool0103oojX0E@000000001EZ_l>0?ooo`040?ooZP1E0000
000005FZo`@0oooo00@0ojYE0000000005D0Z_oo603oool00`2ZE@000000001EZP060?ooo`040?oo
e020:`00000005FZod`0oooo4P00000j0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000
003oool0oooo03d0oooo0`3o002n0?ooo`030000003oool0oooo0700oooo00<0e80[000000000000
0`0000000`0005D0Z_oo0?ooo`0B0?ooo`040?ooZP1E0000000005FZo`h0oooo00@0oonZ05D00000
0000EJ[o103oool0103oZUD000000000E@2Zool90?ooo`040?ooZP1E0000000005FZo`/0oooo00<0
ZUD000000000EJX01P3oool0103oom@0P2/00000001EZ_m<0?oooa800000>P3oool00`000000oooo
0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`0n0?ooo`80o`00_P3oool00`000000oooo0?oo
o`1a0?ooo`060?nZE@00000000000000000005D0Z_oo503oool0103oojX0E@000000001EZ_l>0?oo
o`040?ooZP1E0000000005FZo`@0oooo00@0ojYE0000000005D0Z_oo2@3oool0103oojX0E@000000
001EZ_l;0?ooo`030:YE0000000005FZ00P0oooo00<0ZUD005FZo`3oool0B`3ooolB000003X0oooo
00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0?P3oool20?l00;h0oooo00<0
00000?ooo`3oool0o`3ooolK0?oooa800000>P3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool0
0`000000oooo0?ooo`0n0?ooo`<0o`00_@3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000j
0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo03l0oooo0P3o002m0?oo
o`030000003oool0oooo0?l0oooo6`3ooolB000003X0oooo00<000000?ooo`3oool0<03oool00540
oooo00<000000?ooo`3oool0?`3oool20?l00;d0oooo00<000000?ooo`3oool0o`3ooolK0?oooa80
0000>P3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?ooo`0o0?ooo`<0o`00
_03oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000j0?ooo`030000003oool0oooo0300oooo
001A0?ooo`030000003oool0oooo0400oooo0P3o002l0?ooo`030000003oool0oooo0?l0oooo6`3o
oolB000003X0oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0@03oool2
0?l00;`0oooo00<000000?ooo`3oool0o`3ooolK0?oooa800000>P3oool00`000000oooo0?ooo`0`
0?ooo`00D@3oool300000440oooo00<0o`000?ooo`3oool0^P3oool00`000000oooo0?ooo`3o0?oo
oa/0oooo4P00000h0?ooo`<00000<P3oool00540oooo00<000000?ooo`3oool0@@3oool20?l00;/0
oooo00<000000?ooo`3oool0o`3ooolK0?oooa800000>P3oool00`000000oooo0?ooo`0`0?ooo`00
D@3oool00`000000oooo0?ooo`120?ooo`030?l0003oool0oooo0;T0oooo00<000000?ooo`3oool0
o`3ooolK0?oooa800000>P3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000oooo0?oo
o`120?ooo`80o`00^P3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00000j0?ooo`030000003o
ool0oooo0300oooo001A0?ooo`030000003oool0oooo04<0oooo00<0o`000?ooo`3oool0^03oool0
0`000000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0`
0?ooo`00D@3oool00`000000oooo0?ooo`130?ooo`030?l0003oool0oooo0;P0oooo00<000000?oo
o`3oool0o`3ooolK0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0<03oool00540
oooo00<000000?ooo`3oool0@`3oool20?l00;T0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0
A03oool00`3o0000oooo0?ooo`2g0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo04@0oooo0P3o
002h0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo0300oooo001A0?ooo`030000003oool0oooo04D0oooo00<0o`000?ooo`3oool0]P3oool0
0`000000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0`
0?ooo`00D@3oool00`000000oooo0?ooo`150?ooo`80o`00]`3oool00`000000oooo0?ooo`3o0?oo
oa/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool3000004H0
oooo0P3o002f0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`170?ooo`<0
0000<P3oool00540oooo00<000000?ooo`3oool0AP3oool20?l00;H0oooo00<000000?ooo`3oool0
o`3ooolK0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0<03oool00540oooo00<0
00000?ooo`3oool0AP3oool30?l00;D0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0A`3oool2
0?l00;D0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0A`3oool20?l00;D0oooo00<000000?oo
o`3oool0o`3ooolK0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0<03oool00540
oooo00<000000?ooo`3oool0A`3oool30?l00;@0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0
B03oool20?l00;@0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0B03oool30?l00;<0oooo00<0
00000?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0<03o
ool00540oooo00<000000?ooo`3oool0B@3oool20?l00;<0oooo00<000000?ooo`3oool0o`3ooolK
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?oo
o`3oool0B@3oool20?l00;<0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0B@3oool30?l00;80
ooooo`00000O000004/0oooo00<000000?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0
BP3oool20?l00?l0ooooo`3ooolM0?ooo`030000003oool0oooo0300oooo001A0?ooo`<00000BP3o
ool30?l00?l0ooooo`3ooolJ0?ooo`<00000<P3oool00540oooo00<000000?ooo`3oool0B`3oool2
0?l00?l0ooooo`3ooolL0?ooo`030000003oool0oooo0300oooo001A0?ooo`030000003oool0oooo
04/0oooo0`3o003o0?ooool0oooo6`3oool00`000000oooo0?ooo`0`0?ooo`00D@3oool00`000000
oooo0?ooo`1<0?ooo`80o`00o`3ooooo0?oooa/0oooo00<000000?ooo`3oool0<03oool00540oooo
00<000000?ooo`3oool0C03oool20?l00?l0ooooo`3ooolK0?ooo`030000003oool0oooo0300oooo
001A0?ooo`030000003oool0oooo04`0oooo0`3o003o0?ooool0oooo6P3oool00`000000oooo0?oo
o`0`0?ooo`00D@3oool00`000000oooo0?ooo`1=0?ooo`80o`00o`3ooooo0?oooaX0oooo00<00000
0?ooo`3oool0<03oool00540oooo00<000000?ooo`3oool0C@3oool30?l00?l0ooooo`3ooolI0?oo
o`030000003oool0oooo0300oooo000f0?ooo`030=B0:`000000000000D0000000@0EJ[o0?ooo`3o
ool0e80[0`0000000`0[P=@0oooo0?ooo`090?ooo`030000003oool0oooo04X0oooo00@000000?oo
o`3oool0oooo0P3o00180?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0300oooo000f0?ooo`030?oDP00[00000000
00D0000000<0EJ[o0?ooo`3DP2/01@0000000`00EJX0oooo0?ooo`080?ooo`030000003oool0oooo
04X0oooo00@000000?ooo`3oool0oooo0P3o00180?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0300oooo000g0?oo
o`040:YE00000000001E0:[oo`@0oooo00T0oonZ05D000000000:h3D0?ooo`3oZUD000000000:`20
e?l02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3o
ool0oooo0`3o00090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<03oool003L0
oooo00D0oooD080[00000000001E0:[oo`030?ooo`090?nZE@000000001E0:[oo`3oool0oooD080[
00000000EJ[o00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0080oooo0P3o00090?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
<03oool003P0oooo00D0oooD080[00000000001E0:[oo`070?ooo`040?ooe020:`00000002^0e0T0
ooooDP0000030?l00?l00000o`00000H00000380oooo000i0?ooo`0<0?ooe020:`0000000000E@2Z
ool0oooo0?ooZP1E0000000[083Do`3oool0ojYE0P0000000`1EZ_l0oooo0?ooo`3o0?ooool0oooo
YP3oool003X0oooo00L0oooD080[0000000005FZ0?ooo`3oom@0P2/000D0000000<002^00=Coo`3o
ool0o`3ooooo0?ooojL0oooo000k0?ooo`060?oDP00[0000000[083Do`3oool0ZUD0100000000`00
EJX0oooo0?ooo`3o0?ooool0ooooZ03oool003H0oooo00d0ojYE0000000005D0Z_oo0?ooo`3oojX0
E@000000001EZ_l0oooo0=B0:`00000005FZ0?l0ooooo`3ooon]0?ooo`00=P3oool03P3oojX0E@00
0000001EZ_l0oooo0?nZE@000000000[083Do`3oool0omB002/00000:h00e?ooo`3ooooo0?oooj`0
oooo000g0?ooo`030:YE00000000000000<0000000D005FZ0?ooo`3oool0oonZ05D0000400000003
0000E@2Zool0oooo0?l0ooooo`3ooonW0?ooo`00>03oool01@3DP2/0000000000000000005FZ00<0
oooo00<0oooD080[000000000`0000000`0005D0Z_oo0?ooo`3o0?ooool0ooooY`3oool00?l0oooo
o`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?oo
o`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo
0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo
003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo0000\
\>"],
  ImageRangeCache->{{{0, 749}, {462.5, 0}} -> {-1.05093, -0.648943, \
0.00280622, 0.00280622}, {{18.125, 730.813}, {451.438, 11}} -> {5472.11, \
-11.978, 6.47274, 0.0837848}, {{338.813, 623.938}, {106.5, 35.25}} -> \
{-4.09522, -6.89529, 0.0117896, 0.0190879}, {{354.125, 438.938}, {97.0625, \
44.625}} -> {-4.4092, -15.6912, 0.0123804, 0.0400637}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"lst", "=", 
        RowBox[{"AtmGraphs", "[", 
          RowBox[{"{", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["NumberDensity",
                  GridBoxOptions->{RowSpacings->0.4,
                  RowLines->False}], ",", "\"\<\!\(\*
StyleBox[\"Number\",\nGridBoxOptions->{RowSpacings->0.4,\nRowLines->False}]\)\
\!\(\*
StyleBox[\" \",\nGridBoxOptions->{RowSpacings->0.4,\n\
RowLines->False}]\)\!\(\*
StyleBox[\"Density\",\nGridBoxOptions->{RowSpacings->0.4,\n\
RowLines->False}]\)\>\""}], "}"}], 
            StyleBox["}",
              GridBoxOptions->{RowSpacings->0.4,
              RowLines->False}]}], 
          StyleBox["]",
            GridBoxOptions->{RowSpacings->0.4,
            RowLines->False}]}]}], 
      StyleBox[";",
        GridBoxOptions->{RowSpacings->0.4,
        RowLines->False}]}], "\[IndentingNewLine]", \(Show[
        LegendGraphs[lst, LegendSize \[Rule] { .8,  .2}, 
          LegendPosition \[Rule] \ {\(- .1\),  .35}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        ImageSize \[Rule] 750];\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 750 463.525 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.782144 0.068675 0.0176435 0.000585675 [
[.04196 -0.0125 -10.875 -20.3125 ]
[.04196 -0.0125 10.875 0 ]
[.17931 -0.0125 -10.875 -20.3125 ]
[.17931 -0.0125 10.875 0 ]
[.31666 -0.0125 -10.875 -20.3125 ]
[.31666 -0.0125 10.875 0 ]
[.45401 -0.0125 -10.875 -20.3125 ]
[.45401 -0.0125 10.875 0 ]
[.59136 -0.0125 -10.875 -20.3125 ]
[.59136 -0.0125 10.875 0 ]
[.72871 -0.0125 -10.875 -20.3125 ]
[.72871 -0.0125 10.875 0 ]
[.86606 -0.0125 -10.875 -20.3125 ]
[.86606 -0.0125 10.875 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -94.25 -40.625 ]
[.5 -0.0125 94.25 -20.3125 ]
[-0.0125 .01764 -12.875 -10.1563 ]
[-0.0125 .01764 0 10.1563 ]
[-0.0125 .13478 -30.625 -10.1563 ]
[-0.0125 .13478 0 10.1563 ]
[-0.0125 .25191 -30.625 -10.1563 ]
[-0.0125 .25191 0 10.1563 ]
[-0.0125 .36905 -30.625 -10.1563 ]
[-0.0125 .36905 0 10.1563 ]
[-0.0125 .48618 -30.625 -10.1563 ]
[-0.0125 .48618 0 10.1563 ]
[-0.0125 .60332 -39.5 -10.1563 ]
[-0.0125 .60332 0 10.1563 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -59.8125 -48.625 ]
[-0.01875 .30902 -39.5 48.625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04196 0 m
.04196 .00625 L
s
gsave
.04196 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.17931 0 m
.17931 .00625 L
s
gsave
.17931 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
1.000 setlinewidth
grestore
.31666 0 m
.31666 .00625 L
s
gsave
.31666 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
1.000 setlinewidth
grestore
.45401 0 m
.45401 .00625 L
s
gsave
.45401 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
1.000 setlinewidth
grestore
.59136 0 m
.59136 .00625 L
s
gsave
.59136 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.72871 0 m
.72871 .00625 L
s
gsave
.72871 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22) show
1.000 setlinewidth
grestore
.86606 0 m
.86606 .00625 L
s
gsave
.86606 -0.0125 -71.875 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
1.000 setlinewidth
grestore
.125 Mabswid
.07629 0 m
.07629 .00375 L
s
.11063 0 m
.11063 .00375 L
s
.14497 0 m
.14497 .00375 L
s
.21364 0 m
.21364 .00375 L
s
.24798 0 m
.24798 .00375 L
s
.28232 0 m
.28232 .00375 L
s
.35099 0 m
.35099 .00375 L
s
.38533 0 m
.38533 .00375 L
s
.41967 0 m
.41967 .00375 L
s
.48834 0 m
.48834 .00375 L
s
.52268 0 m
.52268 .00375 L
s
.55702 0 m
.55702 .00375 L
s
.62569 0 m
.62569 .00375 L
s
.66003 0 m
.66003 .00375 L
s
.69437 0 m
.69437 .00375 L
s
.76304 0 m
.76304 .00375 L
s
.79738 0 m
.79738 .00375 L
s
.83172 0 m
.83172 .00375 L
s
.90039 0 m
.90039 .00375 L
s
.93473 0 m
.93473 .00375 L
s
.96907 0 m
.96907 .00375 L
s
.00762 0 m
.00762 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -155.25 -44.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
92.063 19.750 moveto
(@) show
97.813 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
115.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
124.438 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(NumberDensity) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
241.750 19.750 moveto
(D) show
247.500 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01764 m
.00625 .01764 L
s
gsave
-0.0125 .01764 -73.875 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13478 m
.00625 .13478 L
s
gsave
-0.0125 .13478 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
0 .25191 m
.00625 .25191 L
s
gsave
-0.0125 .25191 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
0 .36905 m
.00625 .36905 L
s
gsave
-0.0125 .36905 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(600) show
1.000 setlinewidth
grestore
0 .48618 m
.00625 .48618 L
s
gsave
-0.0125 .48618 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(800) show
1.000 setlinewidth
grestore
0 .60332 m
.00625 .60332 L
s
gsave
-0.0125 .60332 -100.5 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04693 m
.00375 .04693 L
s
0 .07621 m
.00375 .07621 L
s
0 .10549 m
.00375 .10549 L
s
0 .16406 m
.00375 .16406 L
s
0 .19335 m
.00375 .19335 L
s
0 .22263 m
.00375 .22263 L
s
0 .2812 m
.00375 .2812 L
s
0 .31048 m
.00375 .31048 L
s
0 .33976 m
.00375 .33976 L
s
0 .39833 m
.00375 .39833 L
s
0 .42762 m
.00375 .42762 L
s
0 .4569 m
.00375 .4569 L
s
0 .51547 m
.00375 .51547 L
s
0 .54475 m
.00375 .54475 L
s
0 .57404 m
.00375 .57404 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -159.281 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
109.625 14.1563 translate
90 rotate
-109.625 -14.1563 translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Altitude) show
121.688 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
130.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Km) show
156.250 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.04196 .61178 m
.04196 .61803 L
s
.17931 .61178 m
.17931 .61803 L
s
.31666 .61178 m
.31666 .61803 L
s
.45401 .61178 m
.45401 .61803 L
s
.59136 .61178 m
.59136 .61803 L
s
.72871 .61178 m
.72871 .61803 L
s
.86606 .61178 m
.86606 .61803 L
s
.125 Mabswid
.07629 .61428 m
.07629 .61803 L
s
.11063 .61428 m
.11063 .61803 L
s
.14497 .61428 m
.14497 .61803 L
s
.21364 .61428 m
.21364 .61803 L
s
.24798 .61428 m
.24798 .61803 L
s
.28232 .61428 m
.28232 .61803 L
s
.35099 .61428 m
.35099 .61803 L
s
.38533 .61428 m
.38533 .61803 L
s
.41967 .61428 m
.41967 .61803 L
s
.48834 .61428 m
.48834 .61803 L
s
.52268 .61428 m
.52268 .61803 L
s
.55702 .61428 m
.55702 .61803 L
s
.62569 .61428 m
.62569 .61803 L
s
.66003 .61428 m
.66003 .61803 L
s
.69437 .61428 m
.69437 .61803 L
s
.76304 .61428 m
.76304 .61803 L
s
.79738 .61428 m
.79738 .61803 L
s
.83172 .61428 m
.83172 .61803 L
s
.90039 .61428 m
.90039 .61803 L
s
.93473 .61428 m
.93473 .61803 L
s
.96907 .61428 m
.96907 .61803 L
s
.00762 .61428 m
.00762 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01764 m
1 .01764 L
s
.99375 .13478 m
1 .13478 L
s
.99375 .25191 m
1 .25191 L
s
.99375 .36905 m
1 .36905 L
s
.99375 .48618 m
1 .48618 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04693 m
1 .04693 L
s
.99625 .07621 m
1 .07621 L
s
.99625 .10549 m
1 .10549 L
s
.99625 .16406 m
1 .16406 L
s
.99625 .19335 m
1 .19335 L
s
.99625 .22263 m
1 .22263 L
s
.99625 .2812 m
1 .2812 L
s
.99625 .31048 m
1 .31048 L
s
.99625 .33976 m
1 .33976 L
s
.99625 .39833 m
1 .39833 L
s
.99625 .42762 m
1 .42762 L
s
.99625 .4569 m
1 .4569 L
s
.99625 .51547 m
1 .51547 L
s
.99625 .54475 m
1 .54475 L
s
.99625 .57404 m
1 .57404 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
1 0 0 r
2 Mabswid
.97619 .01472 m
.9749 .01501 L
.97359 .0153 L
.97227 .01559 L
.97093 .01589 L
.96958 .01618 L
.96849 .01647 L
.96684 .01676 L
.96545 .01706 L
.96404 .01735 L
.96262 .01764 L
.96118 .01794 L
.95972 .01823 L
.95825 .01852 L
.95676 .01881 L
.95525 .01911 L
.95373 .0194 L
.95218 .01969 L
.95062 .01999 L
.94904 .02028 L
.94744 .02057 L
.94582 .02086 L
.94418 .02116 L
.94251 .02145 L
.94083 .02174 L
.93912 .02204 L
.93739 .02233 L
.93564 .02262 L
.93386 .02291 L
.93205 .02321 L
.93022 .0235 L
.92837 .02379 L
.92649 .02409 L
.92416 .02438 L
.92182 .02467 L
.91948 .02496 L
.91713 .02526 L
.91479 .02555 L
.91245 .02584 L
.91011 .02614 L
.90777 .02643 L
.90309 .02701 L
.89841 .0276 L
.89373 .02819 L
.88906 .02877 L
.88438 .02936 L
.87959 .02994 L
.87481 .03053 L
.87006 .03111 L
.86533 .0317 L
Mistroke
.86062 .03229 L
.85594 .03287 L
.85127 .03346 L
.84663 .03404 L
.84201 .03463 L
.83742 .03521 L
.83284 .0358 L
.82823 .03639 L
.82357 .03697 L
.81888 .03756 L
.81424 .03814 L
.80965 .03873 L
.80065 .0399 L
.79185 .04107 L
.78325 .04224 L
.77484 .04341 L
.76661 .04458 L
.75874 .04576 L
.75133 .04693 L
.74409 .0481 L
.73718 .04927 L
.73013 .05044 L
.72293 .05161 L
.71558 .05278 L
.69647 .05571 L
.67624 .05864 L
.65448 .06157 L
.63147 .0645 L
.60734 .06743 L
.60486 .06772 L
.60238 .06801 L
.58121 .07035 L
.55464 .07328 L
.52784 .07621 L
.47675 .08207 L
.43396 .08792 L
.40494 .09378 L
.38324 .09964 L
.36575 .10549 L
.35099 .11135 L
.33814 .11721 L
.32669 .12307 L
.31632 .12892 L
.30678 .13478 L
.29942 .14064 L
.28962 .14649 L
.27434 .15821 L
.26037 .16992 L
.2474 .18163 L
.23517 .19335 L
Mistroke
.22353 .20506 L
.21236 .21677 L
.20156 .22849 L
.1911 .2402 L
.18093 .25191 L
.15665 .2812 L
.13404 .31048 L
.11339 .33976 L
.09515 .36905 L
.07966 .39833 L
.06694 .42762 L
.05666 .4569 L
.04823 .48618 L
.0411 .51547 L
.03484 .54475 L
.02913 .57404 L
.02381 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 g
.47619 .45187 m
.47619 .54711 L
.85714 .54711 L
.85714 .45187 L
F
1 g
.45238 .47568 m
.45238 .57092 L
.83333 .57092 L
.83333 .47568 L
F
0 g
.001 w
[ ] 0 setdash
.45238 .47568 m
.83333 .47568 L
.83333 .57092 L
.45238 .57092 L
.45238 .47568 L
s
% Start of sub-graphic
p
0.452381 0.475684 0.833333 0.570922 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0183824 0.183824 [
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0330882 0.35119 0.216912 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .125 -61 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Number) show
127.813 19.750 moveto
(Density) show
184.938 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{750, 463.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001cb000`400?l00000o`00003oo`3ooooo
0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo
003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0
ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool0
0?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooD`3o
ool00`3oojX0E@00000000030000000505FZo`3oool0oooo0?ooo`3DP2/00`0000000`1EZ_l0oooo
0?ooo`0?0?ooo`030?ooZP1E02/0P=Co07@0oooo00D0omB002/000000000001E0:[oo`020?ooo`05
0?nZE@00000000000000000[P=@0n@3oool00?l0ooooDP3oool00`3oom@0P2/00000000500000006
05FZo`3oool0oooo0=B0:`000000:h3D503oool00`3DP2/002^00=Coo`1c0?ooo`050?oDP00[0000
000000000000EJX0103oool00`3DP2/0000002^0e03i0?ooo`00o`3ooomH0?ooo`030:YE00000000
05FZ0080oooo00<0e80[0000000[P=@0503oool00`3oojX0E@0[083Do`1e0?ooo`040?oDP00[0000
000[083Do`<0oooo00<0e80[0000000[P=@0n@3oool00?l0oooo?P3oool00`3oojX0E@0000000006
0000000502^0e03oool0oooo0?ooZP1E00000P0000000`0002/0P=Co0?ooo`030?ooo`070=B0:`00
0000000002^0e03DP2/00000001EZP020?ooo`030=B0:`000000:h3D00@0oooo00@0oooD080[0000
0000:h3D103oool01@3oZUD00000000000000000EJ[o0080oooo00@0omB002/0000002/0P=Co1@3o
ool0103oojX0E@000000001EZ_l30?ooo`040?oDP00[00000000001EZP<0oooo01/0ZUD000000000
000002^00:Z0:`00000005FZ0?ooo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3o
ool0ojYE0000000005D0Z_oo0?ooe020:`00000005FZZP1E00000P0000000`0[P=@0oooo0?ooo`02
0?ooo`050:YE0000000000000000000[P=@00P3oool0103oojX0E@000000:`20e?l20?ooo`030?oo
ZP1E0000000000D0000000<0:h3D0?ooo`3oool00`3oool01@2ZE@000000000000000000:h3D00<0
oooo00<0ZUD000000000EJX00P3oool00`3DP2/00000001EZP020?ooo`030?ooe020:`0000000080
0000018002^00=Coo`3oool0oonZ05D000000000EJ[o0?ooo`3oe800:`000000000002/0P=Co0?oo
o`3oojX0E@000000000[P=@30?ooo`030=B0:`000000:h3D0?T0oooo003o0?oooch0oooo00<0oonZ
05D0000000001P0000000`0[P=@0oooo0?nZE@060000000405FZo`3oool0oooo0=B0:`@0000000<0
:b/[00000000EJX00P3oool00`3DP2/0000002^0e0040?ooo`040?ooe020:`00000002^0e0<0oooo
00<0ojYE0000000000000`0000001P1EZ_l0oooo0?oDP00[0000000[083Do`D0oooo00@0oonZ05D0
00000000EJ[o0`3oool0102ZE@00000000000000EJX20?ooo`030?nZE@000000000000@000000180
05FZ0?ooo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oool0ojYE0000000005D0
Z_oo0?ooe020:`060000000402^0e03oool0oooo0:YE00D0000000H0:h3D0?ooo`3oojX0E@000000
:`20e?l20?ooo`030?ooZP1E0000000000H0000000D002^00=Coo`3oool0oooo0:YE000500000006
02^0e03oool0oooo0:YE0000000005FZ0P3oool01P3DP2/00000001EZP3oool0oooD080[00D00000
00P002^00=Coo`3oojX0E@000000001EZ_l0oooo0:YE0080000000@0000[083Do`3oool0ojYE0P00
00001`00:h00e?oo0?ooo`3oool0e80[0000000[P=@0n@3oool00?l0oooo?P3oool0103oojX0E@00
0000001EZ_l60?ooo`0C0?ooe020:`000000000[P03Dool0oooo0:YE0000000002^00=Coo`3oojX0
E@0000000000EJX0oooo0?oDP00[00000000001EZP020?ooo`030=B0:`000000:h3D00@0oooo00@0
oooD080[00000000:h3D0P3oool02@3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`09
0?ooo`040?ooZP1E0000000005FZo`80oooo00D0ojYE0000000000000000001EZP020?ooo`0^0:YE
0000000002^00=Coo`3oojX0E@0000000000EJX0oooo0?oDP00[0000000[083Do`3oool0omB002/0
000005D0Z_oo0?ooo`3oZUD000000000E@2Zool0oooD080[00000000001E0:[oo`3oool0e80[0000
000005D0Z_oo0?oDP00[0000000005FZo`3oool0ojYE0000000005D0Z_oo0?ooZP1E0000000[083D
o`80oooo00@0oonZ05D000000000EJ[o0`3oool04P3oe800:`000000000[P=@0oooo0?oDP00[0000
000005FZo`3oool0ojYE0000000005D0Z_oo0?ooo`2ZE@000000001EZP80oooo01D0e80[00000000
EJX0oooo0?nZE@000000000[083Do`3oool0oonZ05D0000002/0P=Co0?ooZP1E0000000005FZo`3o
om@0P2/00000000[P=@00`3oool01@2ZE@0000000000000002/0P=Co0080oooo00<0e80[0000000[
P=@0n@3oool00?l0oooo?P3oool0103oojX0E@000000001EZ_l60?ooo`040?oDP00[0000000[083D
o`80oooo00P0oonZ05D0000002/0P=Co0?oDP00[0000000[083Do`80oooo00<0e80[00000000EJX0
0P3oool00`3DP2/0000002^0e0040?ooo`040?ooe020:`00000002^0e080oooo00T0omB002/00000
02/0P=Co0?ooo`3oe800:`000000E@2Zool02@3oool01`3oojX0E@000000001EZ_l0oooo0?ooe020
:`000`0000001P00EJX0oooo0?ooo`2ZE@000000001EZP80oooo01H0ZUD000000000EJX0oooo0?oD
P00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?ooo`3oZUD000000000E@2Zool0oooD080[
00000000:h3D0P3oool0203oojX0E@000000:`20e?l0e80[00000000:h00e?oo1@3oool0103oojX0
E@000000:`20e?l20?ooo`040?ooZP1E0000000005FZo`@0oooo00P0ojYE0000000005D0Z_oo0=B0
:`00000002^00=Coo`H0oooo00<0ZUD000000000EJX00P3oool00`3DP2/00000001EZP040?ooo`0>
0?nZE@00000000000000000002/0P=Co0?ooZP1E0000000005FZo`3oom@0P2/00000001EZ_l20?oo
o`060?oDP00[0000001E0:ZZE@00000005FZ0P3oool00`3DP2/0000002^0e03i0?ooo`00o`3oooln
0?ooo`040?ooZP1E0000000005FZo`H0oooo00@0omB002/0000005D0Z_oo0P3oool0203oojX0E@00
0000001EZ_l0omB002/0000005D0Z_oo0P3oool00`3DP2/00000001EZP020?ooo`030=B0:`000000
:h3D00@0oooo00@0oooD080[00000000:h3D0P3oool02@3oe800:`000000E@2Zool0oooo0?ooZP1E
0000000[083Do`090?ooo`0;0?ooZP1E0000000005FZo`3oool0e80[00000000EJX0ZUD000000000
EJX00P3oool00`2ZE@000000001EZP020?ooo`0F0=B0:`00000005FZ0?ooo`3oe800:`000000:`20
e?l0oooo0?oDP00[0000000[083Do`3oool0ojYE0000000005D0Z_oo0?ooe020:`00000005FZo`80
oooo00D0oonZ05D000000000EJ[o0=B0:`070000000505FZo`3oojX0E@000000001EZ_l00P3oool0
103oojX0E@000000001EZ_l40?ooo`050?oDP00[0000000[083Do`3DP2/01`0000001@1EZ_l0oooo
0:YE0000000005FZ0080oooo00<0e80[00000000EJX00P3oool00`3DP2/00000000000030000000:
001EZP3oool0oonZ05D000000000EJ[o0?ooe020:`00000005FZo`80oooo00/0e80[00000000EJX0
oonZ05D0000005D0Z_oo0?ooo`3DP2/0000002^0e03i0?ooo`00o`3oooln0?ooo`040?ooZP1E0000
000005FZo`H0oooo00@0omB002/0000002/0P=Co0P3oool0203oojX0E@000000:`20e?l0omB002/0
000002/0P=Co0P3oool00`3DP2/00000001EZP020?ooo`030=B0:`000000:h3D00@0oooo00@0oooD
080[00000000:h3D0P3oool02@3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`090?oo
o`0;0?ooZP1E0000000005FZo`3oojX0E@000000:`20e?l0ZUD000000000EJX00P3oool00`2ZE@00
0000001EZP020?ooo`0F0=B0:`00000005FZ0?ooo`3oe800:`000000:`20e?l0oooo0?oDP00[0000
000[083Do`3oool0ojYE0000000005D0Z_oo0?ooe020:`00000005FZo`80oooo00D0oonZ05D00000
02/0P=Co0?nZE@06000000060000:`20e?l0oonZ05D000000000EJ[o0P3oool0103oojX0E@000000
001EZ_l40?ooo`050?ooZP1E0000000[083Do`3oZUD01P0000001P0002/0P=Co0?ooo`2ZE@000000
001EZP80oooo00H0e80[00000000EJX0oooo0?ooZP1E00030000000I001EZP3oool0oooo0?ooo`3o
ojX0E@000000001EZ_l0oooD080[00000000EJ[o0?ooo`3oom@0P2/00000001EZ_l0oooo0:YE0000
0000EJ[o0?ooo`3DP2/0000002^0e03i0?ooo`00o`3oooln0?ooo`040?ooZP1E0000000005FZo`H0
oooo01<0oooD080[0000000002^00=Coo`3oool0ZUD00000000005D0Z_oo0?ooZP1E00000000001E
ZP3oool0oonZ05D00000000005FZ0080oooo00<0e80[0000000[P=@0103oool0103oom@0P2/00000
000[P=@20?ooo`090?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o00T0oooo00/0oonZ
05D000000000EJ[o0=B0:`00000005FZ0?ooo`2ZE@000000001EZP020?ooo`030:YE0000000005FZ
0080oooo00X0e80[00000000EJX0oooo0?oDP00[00000000001EZP3oool0ojYE0P0000007@0[P=@0
oooo0=B0:`000000001E0:[oo`3oom@0P2/000000000:h00e?oo0?ooo`3DP2/000000000E@2Zool0
omB002/0000005D0Z_oo0?ooo`3oe800:`000000E@2Zool0oonZ05D00000000005FZ0080oooo00@0
oonZ05D000000000EJ[o103oool0=@3oojX0E@000000:`20e?l0omB002/0000005D0Z_oo0?ooo`3o
e800:`000000E@2Zool0oooo0:YE00000000000[083Do`3oom@0P2/000000000EJX0oooo0?oDP00[
0000001E0:[oo`3oool0e80[00000000EJX0oooo0?ooZP1E0000000005FZo`3oom@0P2/00000001E
Z_l0oooo0?oDP00[0000001E0:[oo`3oool0ojYE00000000:h00e?oo0=B0:`000000:h3D0?T0oooo
003o0?oooch0oooo00@0oonZ05D000000000EJ[o1`3oool00`3oe800:`00000000040000000405FZ
o`3oool0oooo0=B0:`H0000000h005FZ0?ooo`3oool0e80[0000000[P=@0oooo0?ooe020:`00:h3D
0?ooe020:`00000002^0e080oooo00T0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0
2@3oool02`3oojX0E@000000001EP800:`000000E@2Zool0oooo0:YE0000000005FZ0080oooo00<0
ZUD000000000EJX00P3oool01P3DP2/00000001EZP3oool0omB002/000X0000000@005FZ0?ooo`3o
om@0P2/01P000000100[P=@0oooo0?ooo`2ZE@050000000402^0e03oool0oonZ05D000<0000000D0
02^00=CoZP1E0000000005FZo`040?ooo`060?oDP00[0000000[083Do`3oool0ZUD01@000000100[
P=@0oooo0?ooo`2ZE@060000000402^0e03oool0oooD080[00D0000000L0:h3D0?ooo`3oojX0E@00
0000001EZ]@0P2/000<0000000@0001E0820:`00000005FZ0P3oool01`3oojX0E@000000:`20e?l0
e80[0000000[P=@0n@3oool00?l0oooo?P3oool0103oojX0E@000000001EZ_l80?ooo`060?ooZP1E
000000000000000002/0P=Co103oool01`3DP2/000000000000[P=@0e80[00000000EJX00P3oool0
2`3DP2/0000002^0e03oool0oooD080[00000000000[02/[00000000:h3D0080oooo00T0omB002/0
000002/0P=Co0?ooo`3oe800:`000000E@2Zool02@3oool00`3oojX0E@00000000020000000602^0
e03oool0oooo0:YE0000000005FZ0P3oool00`2ZE@000000001EZP020?ooo`0G0=B0:`00000005FZ
0?ooo`3oe800:`000000:`20ZX00:`000000000005D0Z_oo0?oDP00[000000000000E@2Zool0oooo
0?ooe020:`00000005FZe020:`000P0000000`0[P=@0oooo0?ooo`020?ooo`050=B0:`0000000000
0000000[P=@00P3oool02P3oojX0E@000000:`20P5D000000000:`20e:X0E@000000001EZ_l40?oo
o`040=B0:`000000001E0:[oo`80oooo00D0e80[000000000000000002^0e0030?ooo`040:YE0000
000005FZ0:YE0080000000H005FZ0?ooo`3oool0oooo0?ooZP1E000300000008001EZP3oool0oooo
0?ooZP1E0000000005FZe020:`060000000:05FZo`3oool0oooo0?ooo`2ZE@00000002^0e03DP2/0
000002^0e?T0oooo003o0?oooch0oooo00@0oonZ05D000000000EJ[o6`3oool00`3DP2/0000002^0
e0030?ooo`050:YE0000000000000000000[P=@00P3oool02@3oom@0P2/00000000[P=@0oooo0=B0
:`00000002^00=Coo`090?ooo`060?ooZP1E0000000000000000:h00e?oo0P3oool00`2ZE@000000
001EZP0I0?ooo`040?ooe020:`00000005FZoaD0oooo00@0oonZ05D000000000EJ[o0`3oool0103o
ZUD000000000000[P=@Q0?ooo`040?ooe020:`00000005FZo`X0oooo00<0e80[0000000[P=@0n@3o
ool00?l0oooo?P3oool0103oojX0E@000000001EZ_lK0?ooo`050=B0:`00000000000000001EZ_l0
0P3oool0103oZUD000000000000[P=@30?ooo`030?nZE@000000000000<0000000<0EJ[o0?ooo`3o
ool0203oool01@3oojX0E@00000000000000EJ[o00<0oooo00<0ZUD000000000EJX06@3oool0103o
om@0P2/00000001EZ_lE0?ooo`030?ooZP1E0000000000H0000000<002^00=Coo`3oool0703oool0
203oojX0E@000000001EZ_l0oooD080[00000000EJ[o203oool01@3oZUD00000000000000000:h3D
0?T0oooo003o0?oooch0oooo00@0oonZ05D000000000EJ[o8`3oool00`2ZE@00000002^0e0040?oo
o`050?nZE@00000000000000001EZ_l02`3oool0103oojX0E@0000000000EJX40?ooo`030:YE0000
000005FZ01T0oooo00@0oooD080[00000000EJ[o5@3oool00`3oojX0E@00000000050000000302^0
e03oool0oooo01d0oooo00@0oonZ05D000000000EJ[o0P3oool00`2ZE@00EJ[o0?ooo`3o0?ooo`H0
oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?oo
ool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03o
ool00?l0ooooo`3oooo`0?ooo`00LP3oool0103oom@0P2/00000000[P=@20?ooo`030=B0:`000000
000000D0000000<0EJ[o0?ooo`3oool0AP3oool0103oom@0P2/00000000[P=@60?ooo`040?ooZP1E
0000000[083DodT0oooo00@0oooD080[00000000:h3D103oool01@3oe800:`00000000000000:h3D
04X0oooo00@0oooD080[00000000:h3D103oool01@2ZE@00000000000000000005FZ04L0oooo00<0
e80[0000000000001@000000101EZ_l0oooo0?ooo`3oZUD30000000305FZo`3oool0oooo04D0oooo
00<0e80[0000000000001@0000000`1EZ_l0e80[000000060000000305FZo`3oool0oooo0480oooo
00<0e80[0000000000001@0000000`1EZ_l0oooo0?ooo`020?ooo`040?ooZP1E0000000[083DofD0
oooo001b0?ooo`040?ooe020:`00000002^0e080oooo00<0omB002/0000000001@0000000`1EZ_l0
oooo0?ooo`160?ooo`040?ooe020:`00000002^0e0H0oooo00@0oonZ05D0000002/0P=CoB@3oool0
103oom@0P2/00000000[P=@30?ooo`030?nZE@000000000000<0000000<0:h3D0?ooo`3oool0A`3o
ool0103oom@0P2/00000000[P=@20?ooo`030?ooe020:`00000000@0000000<005FZ0?ooo`3oool0
A03oool00`3oe800:`00000000050000000305FZo`3oool0ojYE00D0000000<0EJ[o0?ooo`3oool0
A03oool00`3oe800:`00000000050000000305FZo`3oe800:`0000H0000000<0EJ[o0?ooo`3oool0
@P3oool00`3oe800:`00000000050000000305FZo`3oool0oooo0080oooo00@0oonZ05D0000002/0
P=CoI@3oool00780oooo00@0oooD080[00000000:h3D0`3oool0102ZE@0000000000E@2Zoom<0?oo
o`040?ooe020:`00000002^0e080oooo00<0ZUD00000000000001@0000000`00EJX0oooo0?ooo`16
0?ooo`040?ooe020:`00000002^0e080oooo00T0oooD080[00000000:h3D0?ooo`3oZUD000000000
E@2Zool0B03oool0103oom@0P2/00000000[P=@20?ooo`090?oDP00[0000000005FZo`3oool0ojYE
0000000002/0P=Co04H0oooo00@0ZUD00000000005D0Z_oo103oool02@3oom@0P2/00000000[P=@0
oooo0=B0:`00000002^00=Coo`160?ooo`040:YE00000000001E0:[oo`D0oooo00@0ZUD000000000
05D0Z_ooB@3oool0102ZE@0000000000E@2Zool40?ooo`030:YE00000000000000D0000000<005FZ
0?ooo`3oool0HP3oool00780oooo00@0oooD080[00000000:h3D0`3oool01@3oom@0P2/000000000
05D0Z_oo04/0oooo00@0oooD080[00000000:h3D0P3oool00`2ZE@0000000000000500000003001E
ZP3oool0oooo04H0oooo00@0oooD080[00000000:h3D0P3oool02@3oe800:`000000E@2Zool0oooo
0?ooZP1E0000000[083Do`180?ooo`040?ooe020:`00000002^0e080oooo00T0ojYE0000000005D0
Z_oo0?ooo`3oojX0E@000000001EZ_l0AP3oool01@3oom@0P2/00000000005D0Z_oo00<0oooo00T0
omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0AP3oool01@3oom@0P2/00000000005D0
Z_oo00@0oooo00D0oooD080[00000000001E0:[oo`180?ooo`050?ooe020:`0000000000E@2Zool0
0`3oool00`2ZE@0000000000000500000003001EZP3oool0oooo0680oooo001b0?ooo`040?ooe020
:`00000002^0e0@0oooo00D0oooD080[00000000001E0:[oo`1:0?ooo`040?ooe020:`00000002^0
e080oooo00P0ojYE00000000EJX0oooo0?ooZP1E0000000[083DodT0oooo00@0oooD080[00000000
:h3D0P3oool02@3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`180?ooo`040?ooe020
:`00000002^0e080oooo00T0oonZ05D000000000EJ[o0?ooo`3oZUD000000000E@2Zool0A`3oool0
1@3oom@0P2/00000000005D0Z_oo0080oooo00T0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000
:`20e?l0A`3oool01@3oom@0P2/00000000005D0Z_oo00@0oooo00D0oooD080[00000000001E0:[o
o`180?ooo`050?ooe020:`0000000000E@2Zool00P3oool0203oZUD00000001EZP3oool0oonZ05D0
000002/0P=CoI@3oool00780oooo00@0oooD080[00000000:h3D1@3oool01@3oom@0P2/000000000
05D0Z_oo04T0oooo00@0oooD080[00000000:h3D0P3oool0203oom@0P2/00000001EZ_l0oonZ05D0
000002/0P=CoB@3oool0103oom@0P2/00000000[P=@20?ooo`090?nZE@000000000005FZo`3oool0
ojYE0000000005D0Z_oo04P0oooo00@0oooD080[00000000:h3D0`3oool00`3oZUD0000000000003
0000000305FZo`3oool0oooo04L0oooo00l0oooD080[00000000001E0:[oo`3oool0ojYE00000000
05D0Z_oo0?ooo`3oojX0E@000000001EZ_l0B03oool01@3oom@0P2/00000000005D0Z_oo00@0oooo
00D0oooD080[00000000001E0:[oo`180?ooo`0>0?ooe020:`0000000000E@2Zool0oooo0?ooe020
:`00000005FZo`3oojX0E@000000:`20e?mU0?ooo`00LP3oool0103oom@0P2/00000000[P=@60?oo
o`040?ooe020:`000000001EZTT0oooo00@0oooD080[00000000:h3D0`3oool01`3oe800:`00000[
P03DojX0E@000000:`20e?l0B@3oool0103oom@0P2/00000000[P=@20?ooo`030?nZE@0000000000
00@0000000<005FZ0?ooo`3oool0A`3oool0103oom@0P2/00000000[P=@30?ooo`030?ooZP1E0000
00000080000000<0001E0:[oo`3oool0B@3oool03P3oom@0P2/000000000EJX0oooo0?nZE@000000
001E0:[oo`3oool0oonZ05D000000000EJ[oB@3oool0103oom@0P2/000000000EJX50?ooo`040?oo
e020:`000000001EZTT0oooo00@0oooD080[0000000005FZ0P3oool01`3oe800:`00000[P03DojX0
E@000000:`20e?l0I@3oool006l0oooo00L0oooD080[000[P=@0oooD080[00000000:h3D00L0oooo
00@0omB002/0000002/0P=CoA@3oool01`3oom@0P2/002^0e03oom@0P2/00000000[P=@0103oool0
1P3DP2/0000002^0P01E0000000[083DodH0oooo00L0oooD080[000[P=@0oooD080[00000000:h3D
0080oooo00@0omB002/00000:h00P5D00P0000000`0[P=@0oooo0?ooo`150?ooo`070?ooe020:`00
:h3D0?ooe020:`00000002^0e0020?ooo`090?ooe020:`00000002^0e03oool0e80[00000000:h00
e?oo04X0oooo00d0omB002/0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0
P=Co04X0oooo00@0omB002/0000002/0P=Co1@3oool0103oe800:`000000:`20e?m90?ooo`040?oD
P00[0000000[083Do`80oooo00H0e80[0000000[P800E@000000:`20e?mU0?ooo`00K`3oool01`3o
om@0P2/00000000002/0:b/00000000[P=@00P3oool02@3oZUD000000000E@2Zool0oooo0?ooZP1E
0000000005FZo`150?ooo`070?ooe020:`0000000000:`0[:`00000002^0e0040?ooo`060?ooe020
:`0000000000000002/0P=CoAP3oool01`3oom@0P2/00000000002/0:b/00000000[P=@00P3oool0
103oojX0E@000000E@2Zoom:0?ooo`070?ooe020:`0000000000:`0[:`00000002^0e0020?ooo`09
0?ooZP1E0000000[083Do`3oool0omB002/0000005D0Z_oo04D0oooo0180ojYE0000000005D0Z_oo
0?ooo`3oojX0E@000000001EZ_l0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zoom50?oo
o`0B0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[oo`3oool0
oonZ05D000000000EJ[oA03oool02@3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`02
0?ooo`060?ooe020:`0000000000000002/0P=CoI@3oool00740oooo00D0ZUD00000000000000000
02^0e0020?ooo`090?ooZP1E0000000005FZo`3oool0ojYE0000000002/0P=Co04L0oooo00D0ZUD0
000000000000000002^0e0050?ooo`050?nZE@00000000000000:`20e?l0B03oool01@2ZE@000000
000000000000:h3D0080oooo00T0oooD080[00000000EJ[o0?ooo`3oZUD000000000E@2Zool0A`3o
ool01@2ZE@000000000000000000:h3D0080oooo00T0oonZ05D000000000:h3D0?ooo`3DP2/00000
0000E@2Zool0A@3oool04P3oojX0E@000000001EZ_l0oooo0?nZE@000000000[083Do`3oom@0P2/0
0000000[P=@0oooo0=B0:`00000002^00=CoodD0oooo0180oonZ05D000000000EJ[o0?ooo`3oZUD0
00000000:`20e?l0oonZ05D000000000EJ[o0?ooo`3oZUD000000000:`20e?m40?ooo`090?ooZP1E
0000000005FZo`3oool0ojYE0000000002/0P=Co00<0oooo00D0ojYE000000000000000[083Do`1U
0?ooo`00LP3oool0103oZUD000000000000[P=@30?ooo`030:YE00000000000000<0000000<005FZ
0?ooo`3oool0A`3oool0103oZUD000000000000[P=@60?ooo`040:YE00000000000[083DodT0oooo
00@0ojYE000000000000:h3D0`3oool00`3oe800:`00000000030000000302^0e03oool0oooo04L0
oooo00@0ojYE000000000000:h3D0`3oool00`3DP2/00000000000030000000302^0e03oool0oooo
04D0oooo00<0ZUD00000000000000`0000001000EJX0oooo0?ooo`3oZUD50000000305FZo`3oool0
oooo04D0oooo00<0ZUD00000000000000`0000001000EJX0oooo0?ooo`2ZE@0500000003001EZP3o
ool0oooo04@0oooo00<0ZUD00000000000000`0000000`00EJX0oooo0?ooo`030?ooo`040:YE0000
0000000[083DofD0oooo001c0?ooo`030:YE00000000:h3D00@0oooo00D0e80[0000000000000000
001EZP1;0?ooo`030:YE00000000:h3D00H0oooo00@0oonZ05D0000002/0P=CoBP3oool00`2ZE@00
000002^0e0040?ooo`050?oDP00[0000000000000000EJX0B`3oool00`2ZE@00000002^0e0040?oo
o`050:YE0000000000000000000[P=@0B@3oool01@3DP2/0000000000000000005FZ00@0oooo00D0
ojYE000000000000000005FZo`190?ooo`050=B0:`000000000000000000EJX0103oool01@3DP2/0
000000000000000005FZ04P0oooo00D0e80[0000000000000000001EZP060?ooo`040?ooZP1E0000
000[083DofD0oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00
oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?oo
ool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03o
ool00?l0ooooo`3oooo`0?ooo`00G@3ooooo00000?l00000O000000G0?ooo`00G@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05@3oool005d0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo001M0?oo
o`030000003oool0oooo0?l0ooooo`3ooomh0?ooo`030000003oool0oooo01D0oooo001=0?ooo`05
0?nZE@00000000000000001EZ_l02`3oool00`000000oooo0?ooo`3o0?ooool0ooooN03oool00`00
0000oooo0?ooo`0E0?ooo`00C03oool00`3oZUD00000000000030000000305FZo`3oool0oooo00P0
oooo00<000000?ooo`3oool0o`3ooooo0?ooogP0oooo00<000000?ooo`3oool05@3oool004/0oooo
00T0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool02@3oool00`000000oooo0?ooo`3o
0?ooool0ooooN03oool00`000000oooo0?ooo`0E0?ooo`00B`3oool02@3oe800:`000000:`20e?l0
oooo0?oDP00[0000001E0:[oo`090?ooo`030000003oool0oooo0?l0ooooo`3ooomV0?ooo`@0o`00
3P3oool00`000000oooo0?ooo`0E0?ooo`00B`3oool02@3oe800:`000000E@2Zool0oooo0?ooZP1E
0000000[083Do`090?ooo`030000003oool0oooo0?l0ooooo`3ooomQ0?ooo`T0o`003P3oool00`00
0000oooo0?ooo`0E0?ooo`00B`3oool02@3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZ
o`090?ooo`D00000o`3ooooo0?oooeX0oooo2`3o000=0?ooo`D000005`3oool004/0oooo00T0ojYE
0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l02@3oool00`000000oooo0?ooo`3o0?ooool0
ooooE`3oool;0?l001H0oooo00<000000?ooo`3oool05@3oool004/0oooo00T0omB002/0000005D0
Z_oo0?ooo`3oojX0E@000000:`20e?l02@3oool00`000000oooo0?ooo`3o0?ooool0ooooDP3oool;
0?l001/0oooo00<000000?ooo`3oool05@3oool004/0oooo00T0omB002/0000002/0P=Co0?ooo`3o
e800:`000000E@2Zool02@3oool00`000000oooo0?ooo`3o0?ooool0ooooB`3oool=0?l00200oooo
00<000000?ooo`3oool05@3oool004/0oooo00T0oooD080[00000000:h3D0?ooo`3DP2/00000000[
P03Dool02@3oool00`000000oooo0?ooo`3o0?ooool0ooooA03oool?0?l002D0oooo00<000000?oo
o`3oool05@3oool004`0oooo00<0ojYE0000000000000`0000000`1EZ_l0oooo0?ooo`080?ooo`03
0000003oool0oooo0?l0ooooo`3ooolk0?oooa40o`00;03oool00`000000oooo0?ooo`0E0?ooo`00
C@3oool01@3oZUD00000000000000000EJ[o00/0oooo00<000000?ooo`3oool0o`3ooooo0?oooc80
oooo4`3o000c0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0?l0oooo
o`3oool/0?oooa00o`00?03oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?oo
o`3o0?ooool0oooo8`3oool@0?l004D0oooo00<000000?ooo`3oool05@3oool005d0oooo00<00000
0?ooo`3oool0o`3ooooo0?oooaX0oooo4`3o001;0?ooo`030000003oool0oooo01D0oooo001M0?oo
o`030000003oool0oooo0?l0ooooo`3ooolD0?oooa00o`00E03oool00`000000oooo0?ooo`0E0?oo
o`00G@3oool00`000000oooo0?ooo`3o0?ooool0oooo2`3oool@0?l005d0oooo00<000000?ooo`3o
ool05@3oool005d0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`<0oooo4P3o001S0?ooo`030000
003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0?l0oooon@3ooolB0?l006`0oooo00<0
00000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0o`3ooooc0?oooa00o`00M03oool0
0`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`3o0?ooonT0oooo403o001n0?oo
o`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0?l0ooooh`3oool@0?l008@0
oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0o`3ooooN0?ooo`/0o`00
SP3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool400000?l0ooooe03oool>0?l00980oooo0`00
000G0?ooo`00G@3oool00`000000oooo0?ooo`3o0?ooom40oooo3@3o002I0?ooo`030000003oool0
oooo01D0oooo001M0?ooo`030000003oool0oooo0?l0ooooc03oool90?l00:80oooo00<000000?oo
o`3oool05@3oool005d0oooo00<000000?ooo`3oool0o`3oooo30?ooo`h0o`00YP3oool00`000000
oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`3o0?oookd0oooo3`3o002[0?ooo`030000
003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0?l0oooo]`3oool<0?l00;@0oooo00<0
00000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0o`3ooona0?ooo``0o`00^P3oool0
0`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`3o0?ooojX0oooo3@3o00300?oo
o`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0?l0ooooX`3oool>0?l00<H0
oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0o`3ooonL0?ooo`h0o`00
c@3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`3o0?ooohh0oooo5@3o
003D0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0?l0ooooQ`3ooolE
0?l00=/0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0o`3ooomo0?oo
o`l0o`00j@3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`3o0?ooog`0
oooo2`3o003`0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0?l0oooo
KP3ooolA0?l00?P0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0o`3o
oomV0?oooaH0o`00n`3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`3o
0?oooed0oooo4@3o003o0?ooo`X0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?oo
o`3oool0o`3ooomE0?oooa40o`00o`3ooolB0?ooo`030000003oool0oooo01D0oooo001M0?ooo`03
0000003oool0oooo0?l0ooooC03ooolA0?l00?l0oooo6`3oool00`000000oooo0?ooo`0E0?ooo`00
G@3oool400000?l0oooo@`3ooolA0?l00?l0oooo8@3oool3000001L0oooo001M0?ooo`030000003o
ool0oooo0?l0oooo?03oool@0?l00?l0oooo;03oool00`000000oooo0?ooo`0E0?ooo`00G@3oool0
0`000000oooo0?ooo`3o0?oooc@0oooo403o003o0?oooc@0oooo00<000000?ooo`3oool05@3oool0
05d0oooo00<000000?ooo`3oool0o`3oool/0?oooa00o`00o`3oooll0?ooo`030000003oool0oooo
01D0oooo001M0?ooo`030000003oool0oooo0?l0oooo8`3ooolA0?l00?l0ooooA03oool00`000000
oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`3o0?oooaX0oooo4P3o003o0?oood`0oooo
00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0o`3ooolA0?oooa80o`00o`3o
oomE0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0?l0oooo3@3oool=
0?l00?l0ooooGP3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`3o0?oo
o`P0oooo2@3o003o0?ooofL0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3o
ool0o`3oool40?ooo`T0o`00o`3ooom[0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000
003oool0oooo0?h0oooo2@3o003o0?ooog00oooo00<000000?ooo`3oool05@3oool005d0oooo00<0
00000?ooo`3oool0n`3oool80?l00?l0ooooM03oool00`000000oooo0?ooo`0E0?ooo`00G@3oool0
0`000000oooo0?ooo`3g0?ooo`L0o`00o`3ooomi0?ooo`030000003oool0oooo01D0oooo001M0?oo
o`030000003oool0oooo0?@0oooo1`3o003o0?ooog`0oooo00<000000?ooo`3oool05@3oool005d0
oooo00<000000?ooo`3oool0l03oool70?l00?l0ooooP03oool00`000000oooo0?ooo`0E0?ooo`00
G@3oool00`000000oooo0?ooo`3]0?ooo`L0o`00o`3ooon30?ooo`030000003oool0oooo01D0oooo
001M0?ooo`030000003oool0oooo0>T0oooo1`3o003o0?ooohL0oooo00<000000?ooo`3oool05@3o
ool005d0oooo00<000000?ooo`3oool0i@3oool80?l00?l0ooooRP3oool00`000000oooo0?ooo`0E
0?ooo`00G@3oool400000>40oooo1`3o003o0?oooh`0oooo0`00000G0?ooo`00G@3oool00`000000
oooo0?ooo`3P0?ooo`H0o`00o`3ooonA0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000
003oool0oooo0=d0oooo1P3o003o0?oooi@0oooo00<000000?ooo`3oool05@3oool005d0oooo00<0
00000?ooo`3oool0f`3oool60?l00?l0ooooUP3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool0
0`000000oooo0?ooo`3I0?ooo`D0o`00o`3ooonI0?ooo`030000003oool0oooo01D0oooo001M0?oo
o`030000003oool0oooo0=L0oooo1@3o003o0?oooi/0oooo00<000000?ooo`3oool05@3oool005d0
oooo00<000000?ooo`3oool0e@3oool50?l00?l0ooooW@3oool00`000000oooo0?ooo`0E0?ooo`00
G@3oool00`000000oooo0?ooo`3C0?ooo`D0o`00o`3ooonO0?ooo`030000003oool0oooo01D0oooo
001M0?ooo`030000003oool0oooo0=40oooo1@3o003o0?oooj40oooo00<000000?ooo`3oool05@3o
ool005d0oooo00<000000?ooo`3oool0cP3oool60?l00?l0ooooX`3oool00`000000oooo0?ooo`0E
0?ooo`00G@3oool00`000000oooo0?ooo`3<0?ooo`H0o`00o`3ooonU0?ooo`030000003oool0oooo
01D0oooo001M0?ooo`030000003oool0oooo0<X0oooo1@3o003o0?ooojP0oooo00<000000?ooo`3o
ool05@3oool005d0oooo00<000000?ooo`3oool0b@3oool40?l00?l0ooooZP3oool00`000000oooo
0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`370?ooo`@0o`00o`3ooon/0?ooo`030000003o
ool0oooo01D0oooo000i0?ooo`030=B0:`000000000000D0000000@0EJ[o0?ooo`3oool0ojYE0`00
00000`1EZ_l0oooo0?ooo`020?ooo`050?nZE@00000000000000001EZ_l02`3oool00`000000oooo
0?ooo`360?ooo`@0o`00o`3ooon]0?ooo`030000003oool0oooo01D0oooo000i0?ooo`030?oDP00[
0000000000D0000000<0EJ[o0?ooo`3oZUD01@000000101EZ_l0oooo0?ooo`3oZUD50000000305FZ
o`3oool0oooo00P0oooo00<000000?ooo`3oool0a03oool40?l00?l0oooo[`3oool00`000000oooo
0?ooo`0E0?ooo`00>P3oool0102ZE@0000000000E@2Zool40?ooo`0B0?ooe020:`00000002^0e03o
ool0e80[00000000:h00e?oo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo2@3oool0
0`000000oooo0?ooo`320?ooo`D0o`00o`3ooon`0?ooo`030000003oool0oooo01D0oooo000j0?oo
o`050?ooe020:`0000000000E@2Zool00`3oool04P3oe800:`000000:`20e?l0oooo0?oDP00[0000
001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`T0oooo00<000000?ooo`3o
ool0`@3oool40?l00?l0oooo/P3oool00`000000oooo0?ooo`0E0?ooo`00>`3oool01@3oom@0P2/0
0000000005D0Z_oo0080oooo0180omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB0
02/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l90?ooo`030000003oool0oooo0;l0oooo103o
003o0?oook@0oooo00<000000?ooo`3oool05@3oool003`0oooo01P0oooD080[00000000001E0:[o
o`3oool0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?oo
o`3oojX0E@000000001EZ_l90?ooo`D00000_03oool40?l00?l0oooo/@3oool5000001L0oooo000m
0?ooo`0G0?ooe020:`000000001EZP3oool0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001E
Z_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l02@3oool00`000000oooo0?ooo`2m
0?ooo`<0o`00o`3ooong0?ooo`030000003oool0oooo01D0oooo000n0?ooo`0F0?oDP00[0000000[
083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`3oe800:`000000E@2Zool0oooo
0?ooZP1E0000000[083Do`T0oooo00<000000?ooo`3oool0_03oool30?l00?l0oooo^03oool00`00
0000oooo0?ooo`0E0?ooo`00>@3oool06`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZ
o`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oD
P00[0000001E0:[oo`090?ooo`030000003oool0oooo0;/0oooo0`3o003o0?oookT0oooo00<00000
0?ooo`3oool05@3oool003T0oooo01/0oonZ05D000000000EJ[o0?ooo`3oZUD000000000:`20e?l0
oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0oooD080[00000000:h3D0?ooo`3DP2/0
0000000[P03Dool02@3oool00`000000oooo0?ooo`2i0?ooo`@0o`00o`3ooonj0?ooo`030000003o
ool0oooo01D0oooo000j0?ooo`030:YE00000000000000<0000000@005FZ0?ooo`3oool0ojYE1@00
0000101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo00P0oooo00<000000?ooo`3oool0
]`3oool50?l00?l0oooo^`3oool00`000000oooo0?ooo`0E0?ooo`00>`3oool01@3DP2/000000000
0000000005FZ00@0oooo00D0ojYE000000000000000005FZo`040?ooo`050?nZE@00000000000000
001EZ_l02`3oool00`000000oooo0?ooo`2e0?ooo`D0o`00o`3ooonm0?ooo`030000003oool0oooo
01D0oooo001M0?ooo`030000003oool0oooo0;@0oooo103o003o0?oookl0oooo00<000000?ooo`3o
ool05@3oool005d0oooo00<000000?ooo`3oool0/P3oool40?l00?l0oooo`@3oool00`000000oooo
0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`2a0?ooo`@0o`00o`3oooo20?ooo`030000003o
ool0oooo01D0oooo001M0?ooo`030000003oool0oooo0;00oooo0`3o003o0?oool@0oooo00<00000
0?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0[`3oool30?l00?l0ooooa@3oool00`00
0000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`2]0?ooo`@0o`00o`3oooo60?ooo`03
0000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0:`0oooo103o003o0?ooolL0oooo
00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0Z`3oool30?l00?l0oooob@3o
ool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`2Z0?ooo`<0o`00o`3oooo:
0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0:P0oooo103o003o0?oo
ol/0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0Y`3oool40?l00?l0
ooooc03oool00`000000oooo0?ooo`0E0?ooo`00G@3oool400000:D0oooo0`3o003o0?oool`0oooo
0`00000G0?ooo`00G@3oool00`000000oooo0?ooo`2U0?ooo`<0o`00o`3oooo?0?ooo`030000003o
ool0oooo01D0oooo001M0?ooo`030000003oool0oooo0:<0oooo103o003o0?ooom00oooo00<00000
0?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0XP3oool40?l00?l0ooood@3oool00`00
0000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`2Q0?ooo`<0o`00o`3ooooC0?ooo`03
0000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0:00oooo0`3o003o0?ooom@0oooo
00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0W`3oool30?l00?l0ooooe@3o
ool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`2N0?ooo`<0o`00o`3ooooF
0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo09d0oooo0`3o003o0?oo
omL0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0W03oool30?l00?l0
oooof03oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`2K0?ooo`<0o`00
o`3ooooI0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo09X0oooo0`3o
003o0?ooomX0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0V@3oool3
0?l00?l0oooof`3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`2H0?oo
o`<0o`00o`3ooooL0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo09L0
oooo0`3o003o0?ooomd0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0
U@3oool40?l00?l0oooogP3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?oo
o`2D0?ooo`@0o`00o`3ooooO0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0
oooo09<0oooo0`3o003o0?ooon40oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?oo
o`3oool0TP3oool30?l00?l0oooohP3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool400000900
oooo0`3o003o0?ooon40oooo0`00000G0?ooo`00G@3oool00`000000oooo0?ooo`2@0?ooo`<0o`00
o`3ooooT0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo08l0oooo0`3o
003o0?ooonD0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0SP3oool3
0?l00?l0ooooiP3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`2=0?oo
o`<0o`00o`3ooooW0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo08`0
oooo0`3o003o0?ooonP0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0
R`3oool30?l00?l0ooooj@3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?oo
o`2:0?ooo`<0o`00o`3ooooZ0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0
oooo08T0oooo0`3o003o0?ooon/0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?oo
o`3oool0R03oool30?l00?l0ooook03oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000
oooo0?ooo`270?ooo`<0o`00o`3oooo]0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000
003oool0oooo08L0oooo0P3o003o0?ooonh0oooo00<000000?ooo`3oool05@3oool005d0oooo00<0
00000?ooo`3oool0QP3oool20?l00?l0ooook`3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool0
0`000000oooo0?ooo`250?ooo`<0o`00o`3oooo_0?ooo`030000003oool0oooo01D0oooo001M0?oo
o`030000003oool0oooo08@0oooo0`3o003o0?oooo00oooo00<000000?ooo`3oool05@3oool005d0
oooo00<000000?ooo`3oool0P`3oool30?l00?l0ooool@3oool00`000000oooo0?ooo`0E0?ooo`00
G@3oool00`000000oooo0?ooo`220?ooo`<0o`00o`3oooob0?ooo`030000003oool0oooo01D0oooo
001M0?ooo`030000003oool0oooo0840oooo0`3o003o0?oooo<0oooo00<000000?ooo`3oool05@3o
ool005d0oooo1000001o0?ooo`<0o`00o`3oooob0?ooo`<000005`3oool005d0oooo00<000000?oo
o`3oool0O`3oool30?l00?l0oooom@3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000
oooo0?ooo`1n0?ooo`<0o`00o`3oooof0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000
003oool0oooo07d0oooo0`3o003o0?ooooL0oooo00<000000?ooo`3oool05@3oool005d0oooo00<0
00000?ooo`3oool0O03oool30?l00?l0oooon03oool00`000000oooo0?ooo`0E0?ooo`00G@3oool0
0`000000oooo0?ooo`1k0?ooo`<0o`00o`3ooooi0?ooo`030000003oool0oooo01D0oooo001M0?oo
o`030000003oool0oooo07X0oooo0`3o003o0?ooooX0oooo00<000000?ooo`3oool05@3oool005d0
oooo00<000000?ooo`3oool0N@3oool30?l00?l0oooon`3oool00`000000oooo0?ooo`0E0?ooo`00
G@3oool00`000000oooo0?ooo`1i0?ooo`80o`00o`3ooool0?ooo`030000003oool0oooo01D0oooo
001M0?ooo`030000003oool0oooo07P0oooo0P3o003o0?ooood0oooo00<000000?ooo`3oool05@3o
ool002<0oooo00<0ojYE0000E@2Zool0=`3oool00`000000oooo0?ooo`1g0?ooo`<0o`00o`3oooom
0?ooo`030000003oool0oooo01D0oooo000P0?ooo`060?oDP00[000000000000000005D0Z_oo=`3o
ool00`000000oooo0?ooo`1f0?ooo`<0o`00o`3oooon0?ooo`030000003oool0oooo01D0oooo000M
0?ooo`030?ooZP1E0000000000@0000000<002^00=Coo`3oool0=P3oool00`000000oooo0?ooo`1e
0?ooo`<0o`00o`3ooooo0?ooo`030000003oool0oooo01D0oooo000J0?ooo`030?ooe020:`000000
00D0000000<0EJ[o0?ooo`3oool0>03oool00`000000oooo0?ooo`1d0?ooo`<0o`00o`3ooooo0?oo
o`40oooo00<000000?ooo`3oool05@3oool001P0oooo00<0oonZ05D0000000000`0000001@00EJX0
oooo0:YE00000000EJ[o01X0oooo00@0oonZ05D0000002/0P=Co0`3oool01@3oZUD0000000000000
0000EJ[o00@0oooo00D0ojYE000000000000000005FZo`0;0?ooo`030000003oool0oooo07<0oooo
0`3o003o0?ooool0oooo0P3oool00`000000oooo0?ooo`0E0?ooo`00603oool0103oojX0E@000000
0000EJX40?ooo`030:YE00000000EJ[o01X0oooo00@0oonZ05D0000002/0P=Co0P3oool00`3oZUD0
0000000000030000000405FZo`3oool0oooo0?nZE@D0000000<0EJ[o0?ooo`3oool0203oool00`00
0000oooo0?ooo`1c0?ooo`80o`00o`3ooooo0?ooo`<0oooo00<000000?ooo`3oool05@3oool001P0
oooo00<0oonZ05D0000000000`0000001@00EJX0oooo0:YE00000000EJ[o01H0oooo00<0ZUD00000
000000001@0000004`00EJX0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0oooD080[
00000000:h3D0?ooo`3DP2/00000000[P03Dool02@3oool00`000000oooo0?ooo`1b0?ooo`80o`00
o`3ooooo0?ooo`@0oooo00<000000?ooo`3oool05@3oool001X0oooo00<0oonZ05D0000000001@00
00000`1EZ_l0oooo0?ooo`0D0?ooo`030:YE00000000000000D0000001<005FZ0?oDP00[0000000[
083Do`3oool0omB002/0000005D0Z_oo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo
00T0oooo00<000000?ooo`3oool0L@3oool30?l00?l0ooooo`3oool40?ooo`030000003oool0oooo
01D0oooo000M0?ooo`030?oDP00[0000000000@0000000<002^00=Coo`3oool04P3oool06`3oZUD0
0000001EZP3oool0oonZ05D0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0oooo0?ooZP1E0000
000[083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`090?ooo`030000003oool0
oooo0700oooo0`3o003o0?ooool0oooo1@3oool00`000000oooo0?ooo`0E0?ooo`00803oool01P3o
ZUD00000000000000000001E0:[ooa<0oooo01/0oooD080[00000000EJ[o0?ooZP1E0000000[083D
o`3oool0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?oo
o`3oojX0E@000000001EZ_l02@3oool5000006d0oooo0`3o003o0?ooool0oooo0P3oool5000001L0
oooo000S0?ooo`030=B0:`0005D0Z_oo01@0oooo01X0omB002/00000:h00e?nZ05D0000002/0P=Co
0?ooo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`3oZUD000000000E@2Zool0oooo
0?ooZP1E0000000005FZo`T0oooo00<000000?ooo`3oool0KP3oool30?l00?l0ooooo`3oool70?oo
o`030000003oool0oooo01D0oooo000k0?ooo`0I0=B0:`000000:h2005D0000002/0P=Co0?ooo`3o
e800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E
0000000[083Do`090?ooo`030000003oool0oooo06d0oooo0`3o003o0?ooool0oooo203oool00`00
0000oooo0?ooo`0E0?ooo`00>`3oool06@3oom@0P2/0000000000000000[083Do`3oool0omB002/0
000002/0P=Co0?ooo`3oe800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800:`000000
E@2Zool02@3oool00`000000oooo0?ooo`1]0?ooo`80o`00o`3ooooo0?ooo`T0oooo00<000000?oo
o`3oool05@3oool001P0oooo00<0oonZ05D0000000002@0000000`0005D0Z_oo0?ooo`0E0?ooo`0H
0?nZE@00000000000000:`20e?l0oooo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo
0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo2@3oool00`000000oooo0?ooo`1/0?oo
o`80o`00o`3ooooo0?ooo`X0oooo00<000000?ooo`3oool05@3oool001P0oooo00<0oonZ05D00000
00002@0000000`0005D0Z_oo0?ooo`0F0?ooo`040:YE00000000000[083Do`80oooo00<0ojYE0000
000000000`000000101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo00P0oooo00<00000
0?ooo`3oool0J`3oool30?l00?l0ooooo`3oool:0?ooo`030000003oool0oooo01D0oooo000m0?oo
o`040?ooZP1E0000000[083Do`<0oooo00D0ojYE000000000000000005FZo`040?ooo`050?nZE@00
000000000000001EZ_l02`3oool00`000000oooo0?ooo`1Z0?ooo`<0o`00o`3ooooo0?ooo`/0oooo
00<000000?ooo`3oool05@3oool001/0oooo00@0oonZ05D00000:h00e?oo?P3oool00`000000oooo
0?ooo`1Y0?ooo`<0o`00o`3ooooo0?ooo``0oooo00<000000?ooo`3oool05@3oool001T0oooo00<0
oooD080[00000000200000000`1EZ_l0oooo0?ooo`0f0?ooo`030000003oool0oooo06P0oooo0`3o
003o0?ooool0oooo3@3oool00`000000oooo0?ooo`0E0?ooo`006@3oool00`3DP2/0000000000008
00000003000[P03Dool0oooo03H0oooo00<000000?ooo`3oool0J03oool20?l00?l0ooooo`3oool>
0?ooo`030000003oool0oooo01D0oooo000K0?ooo`040?ooZP1E000002^00=Coo`<0oooo00@0oooD
080[000005D0Z_oo=`3oool00`000000oooo0?ooo`1W0?ooo`80o`00o`3ooooo0?ooo`l0oooo00<0
00000?ooo`3oool05@3oool001/0oooo00@0oonZ05D00000:h00e?oo0`3oool0103oojX0E@00000[
P03Doolg0?ooo`030000003oool0oooo06H0oooo0`3o003o0?ooool0oooo3`3oool00`000000oooo
0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`1U0?ooo`<0o`00o`3ooooo0?oooa00oooo00<0
00000?ooo`3oool05@3oool001P0oooo00D0oonZ05D0000005D0Z_nZ05D00007000000030000E@2Z
ool0oooo03H0oooo00<000000?ooo`3oool0I03oool30?l00?l0ooooo`3ooolA0?ooo`030000003o
ool0oooo01D0oooo000H0?ooo`050?ooZP1E0000001E0:[oZP1E00001`0000000`0005D0Z_oo0?oo
o`0f0?ooo`030000003oool0oooo06<0oooo0`3o003o0?ooool0oooo4P3oool00`000000oooo0?oo
o`0E0?ooo`00G@3oool00`000000oooo0?ooo`1S0?ooo`80o`00o`3ooooo0?oooa<0oooo00<00000
0?ooo`3oool05@3oool001/0oooo00@0oonZ05D00000:h00e?oo?P3oool00`000000oooo0?ooo`1R
0?ooo`80o`00o`3ooooo0?oooa@0oooo00<000000?ooo`3oool05@3oool001T0oooo00<0oooD080[
00000000200000000`1EZ_l0oooo0?ooo`0f0?ooo`030000003oool0oooo0640oooo0`3o003o0?oo
ool0oooo503oool00`000000oooo0?ooo`0E0?ooo`006@3oool00`3DP2/000000000000800000003
000[P03Dool0oooo03H0oooo00<000000?ooo`3oool0H03oool30?l00?l0ooooo`3ooolE0?ooo`03
0000003oool0oooo01D0oooo000K0?ooo`040?ooZP1E000002^00=Coo`<0oooo00@0oooD080[0000
05D0Z_oo=`3oool4000005l0oooo0P3o003o0?ooool0oooo503oool3000001L0oooo000K0?ooo`04
0?ooZP1E000002^00=Coo`<0oooo00@0oonZ05D00000:h00e?oo=`3oool00`000000oooo0?ooo`1O
0?ooo`80o`00o`3ooooo0?oooaL0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?oo
o`3oool0GP3oool20?l00?l0ooooo`3ooolH0?ooo`030000003oool0oooo01D0oooo000K0?ooo`03
0?ooZP1E0000000000D0000000<002^00=Coo`3oool0=`3oool00`000000oooo0?ooo`1M0?ooo`80
o`00o`3ooooo0?oooaT0oooo00<000000?ooo`3oool05@3oool001/0oooo00<0oonZ05D000000000
1P0000000`00EJX0oooo0?ooo`0f0?ooo`030000003oool0oooo05`0oooo0P3o003o0?ooool0oooo
6P3oool00`000000oooo0?ooo`0E0?ooo`008P3oool0103oe800:`000000E@2Zoolg0?ooo`030000
003oool0oooo05`0oooo00<0o`000?ooo`3oool0o`3ooooo0?oooaT0oooo00<000000?ooo`3oool0
5@3oool002<0oooo00<0ZUD00000E@2Zool0=`3oool00`000000oooo0?ooo`1K0?ooo`80o`00o`3o
oooo0?oooa/0oooo00<000000?ooo`3oool05@3oool00280oooo00@0oooD080[0000:h00e?oo=`3o
ool00`000000oooo0?ooo`1J0?ooo`80o`00o`3ooooo0?oooa`0oooo00<000000?ooo`3oool05@3o
ool00280oooo00<0ojYE0000001EZ_l0>03oool00`000000oooo0?ooo`1I0?ooo`80o`00o`3ooooo
0?oooad0oooo00<000000?ooo`3oool05@3oool001/0oooo00<0oonZ05D0000000001P0000000`00
05D0Z_oo0?ooo`0f0?ooo`030000003oool0oooo05T0oooo00<0o`000?ooo`3oool0o`3ooooo0?oo
oa`0oooo00<000000?ooo`3oool05@3oool001/0oooo00<0oonZ05D0000000001P0000000`0005D0
Z_oo0?ooo`0f0?ooo`030000003oool0oooo05P0oooo0P3o003o0?ooool0oooo7P3oool00`000000
oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`1G0?ooo`80o`00o`3ooooo0?oooal0oooo
00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0EP3oool20?l00?l0ooooo`3o
oolP0?ooo`030000003oool0oooo01D0oooo000M0?ooo`030?ooZP1E000000000080000000<0001E
0:[oo`3oool0>03oool00`000000oooo0?ooo`1E0?ooo`80o`00o`3ooooo0?ooob40oooo00<00000
0?ooo`3oool05@3oool001`0oooo00<0ojYE0000000000001@0000000`1EZ_l0oooo0?ooo`0f0?oo
o`030000003oool0oooo05D0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooob00oooo00<000000?oo
o`3oool05@3oool001/0oooo00@0oooD080[00000000:h3D0`3oool0103DP2/00000000[P03Doolg
0?ooo`030000003oool0oooo05@0oooo0P3o003o0?ooool0oooo8P3oool00`000000oooo0?ooo`0E
0?ooo`006`3oool0103oojX0E@00000[P03Dool30?ooo`040?ooe020:`00001E0:[oocL0oooo00<0
00000?ooo`3oool0D`3oool20?l00?l0ooooo`3ooolS0?ooo`030000003oool0oooo01D0oooo000K
0?ooo`040?ooe020:`0002^00=Coo`<0oooo00@0oooD080[0000:h00e?oo=`3oool00`000000oooo
0?ooo`1B0?ooo`80o`00o`3ooooo0?ooob@0oooo00<000000?ooo`3oool05@3oool001`0oooo00<0
ojYE0000000[P=@00`3oool00`3DP2/0000005FZo`0h0?ooo`@00000D@3oool00`3o0000oooo0?oo
o`3o0?ooool0oooo8@3oool3000001L0oooo000H0?ooo`030?ooZP1E0000000000T0000000<0001E
0:[oo`3oool0=P3oool00`000000oooo0?ooo`1A0?ooo`80o`00o`3ooooo0?ooobD0oooo00<00000
0?ooo`3oool05@3oool001P0oooo00<0oonZ05D0000000002@0000000`0005D0Z_oo0?ooo`0f0?oo
o`030000003oool0oooo0500oooo0P3o003o0?ooool0oooo9P3oool00`000000oooo0?ooo`0E0?oo
o`00G@3oool00`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo0?l0ooooo`3ooolU0?ooo`03
0000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo04l0oooo0P3o003o0?ooool0oooo
9`3oool00`000000oooo0?ooo`0E0?ooo`007@3oool00`3oojX0E@0000000002000000030000:`20
e?l0oooo03P0oooo00<000000?ooo`3oool0CP3oool20?l00?l0ooooo`3ooolX0?ooo`030000003o
ool0oooo01D0oooo000L0?ooo`030?nZE@000000000000D0000000<0EJ[o0?ooo`3oool0=P3oool0
0`000000oooo0?ooo`1>0?ooo`030?l0003oool0oooo0?l0ooooo`3ooolW0?ooo`030000003oool0
oooo01D0oooo000K0?ooo`0;0?ooe020:`00000005FZo`3oe800:`0[083Do`3oe800:`00000[P03D
ool0=`3oool00`000000oooo0?ooo`1=0?ooo`80o`00o`3ooooo0?ooobT0oooo00<000000?ooo`3o
ool05@3oool001/0oooo00/0oonZ05D00000:h00e?oo0?oDP00[02/0P=Co0?ooo`2ZE@00001E0:[o
o`0g0?ooo`030000003oool0oooo04`0oooo0P3o003o0?ooool0oooo:P3oool00`000000oooo0?oo
o`0E0?ooo`006`3oool02`3oom@0P2/00000:`20e?l0omB002/0:`20e?l0oooD080[000005D0Z_oo
03L0oooo00<000000?ooo`3oool0B`3oool20?l00?l0ooooo`3oool[0?ooo`030000003oool0oooo
01D0oooo000L0?ooo`090?nZE@00000000000000000002/0P=Co0:YE00000000:h3D03P0oooo00<0
00000?ooo`3oool0B`3oool00`3o0000oooo0?ooo`3o0?ooool0oooo:P3oool00`000000oooo0?oo
o`0E0?ooo`007@3oool01`3oojX0E@000000000002/0P=Co0=B0:`0[P=@0>@3oool00`000000oooo
0?ooo`1:0?ooo`80o`00o`3ooooo0?ooob`0oooo00<000000?ooo`3oool05@3oool005d0oooo00<0
00000?ooo`3oool0B@3oool20?l00?l0ooooo`3oool]0?ooo`030000003oool0oooo01D0oooo000R
0?ooo`060?nZE@000000001E0:[oo`2ZE@00:h3D=@3oool00`000000oooo0?ooo`190?ooo`030?l0
003oool0oooo0?l0ooooo`3oool/0?ooo`030000003oool0oooo01D0oooo000R0?ooo`050?nZE@00
0000000000000000EJX0=P3oool00`000000oooo0?ooo`180?ooo`80o`00o`3ooooo0?ooobh0oooo
00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0A`3oool20?l00?l0ooooo`3o
ool_0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo04L0oooo00<0o`00
0?ooo`3oool0o`3ooooo0?ooobh0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?oo
o`3oool0AP3oool20?l00?l0ooooo`3oool`0?ooo`030000003oool0oooo01D0oooo001M0?ooo`03
0000003oool0oooo04D0oooo0P3o003o0?ooool0oooo<@3oool00`000000oooo0?ooo`0E0?ooo`00
G@3oool4000004@0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooobh0oooo0`00000G0?ooo`00G@3o
ool00`000000oooo0?ooo`140?ooo`80o`00o`3ooooo0?oooc80oooo00<000000?ooo`3oool05@3o
ool005d0oooo00<000000?ooo`3oool0@`3oool20?l00?l0ooooo`3ooolc0?ooo`030000003oool0
oooo01D0oooo000H0?ooo`030?ooZP1E0000000000T0000000<0001E0:[oo`3oool0=P3oool00`00
0000oooo0?ooo`130?ooo`030?l0003oool0oooo0?l0ooooo`3ooolb0?ooo`030000003oool0oooo
01D0oooo000H0?ooo`030?ooZP1E0000000000T0000000<0001E0:[oo`3oool0=P3oool00`000000
oooo0?ooo`120?ooo`80o`00o`3ooooo0?oooc@0oooo00<000000?ooo`3oool05@3oool001d0oooo
00D0oonZ05D00000000002^00=Coo`0k0?ooo`030000003oool0oooo0480oooo00<0o`000?ooo`3o
ool0o`3ooooo0?oooc<0oooo00<000000?ooo`3oool05@3oool001`0oooo00D0oonZ05D000000000
02^00=Coo`0l0?ooo`030000003oool0oooo0440oooo0P3o003o0?ooool0oooo=@3oool00`000000
oooo0?ooo`0E0?ooo`006`3oool01@3oojX0E@00000000000000:h3D03d0oooo00<000000?ooo`3o
ool0@03oool20?l00?l0ooooo`3ooolf0?ooo`030000003oool0oooo01D0oooo000J0?ooo`030?oD
P00[0000000000@0000000<0EJ[o0?ooo`3oool0>@3oool00`000000oooo0?ooo`100?ooo`030?l0
003oool0oooo0?l0ooooo`3ooole0?ooo`030000003oool0oooo01D0oooo000I0?ooo`060?oDP00[
000000000000E@2Zool0e80[0`0000000`0002/0P=Co0?ooo`0h0?ooo`030000003oool0oooo03l0
oooo0P3o003o0?ooool0oooo=`3oool00`000000oooo0?ooo`0E0?ooo`00603oool01@3oojX0E@00
0000000005D0Z_oo0080oooo00<0oooD080[000000000P0000000`00:h00e?oo0?ooo`0f0?ooo`03
0000003oool0oooo03l0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooocH0oooo00<000000?ooo`3o
ool05@3oool001P0oooo00@0oonZ05D0000005D0Z_oo1@3oool01@3oZUD000000000000005D0Z_oo
03L0oooo00<000000?ooo`3oool0?P3oool20?l00?l0ooooo`3ooolh0?ooo`030000003oool0oooo
01D0oooo000H0?ooo`030?ooZP1E05D0Z_oo00P0oooo00<0ZUD00000E@2Zool0=`3oool00`000000
oooo0?ooo`0m0?ooo`80o`00o`3ooooo0?ooocT0oooo00<000000?ooo`3oool05@3oool005d0oooo
00<000000?ooo`3oool0?@3oool00`3o0000oooo0?ooo`3o0?ooool0oooo>03oool00`000000oooo
0?ooo`0E0?ooo`00>`3oool01@3oe800:`00000000000000:h3D00@0oooo00D0ojYE000000000000
000005FZo`040?ooo`050?nZE@00000000000000001EZ_l02`3oool00`000000oooo0?ooo`0l0?oo
o`80o`00o`3ooooo0?ooocX0oooo00<000000?ooo`3oool05@3oool001/0oooo00<0oonZ05D00000
00001P0000000`0005D0Z_oo0?ooo`0C0?ooo`030?nZE@000000000000<0000000@0:h3D0?ooo`3o
ool0ojYE1@000000101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo00P0oooo00<00000
0?ooo`3oool0?03oool00`3o0000oooo0?ooo`3o0?ooool0oooo>@3oool00`000000oooo0?ooo`0E
0?ooo`006`3oool00`3oojX0E@0000000006000000030000E@2Zool0oooo0180oooo01/0oooD080[
00000000:h3D0?ooo`3oZUD000000000E@2Zool0oooD080[00000000:h3D0?ooo`3DP2/00000000[
P03Dool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool02@3oool00`000000oooo0?oo
o`0k0?ooo`80o`00o`3ooooo0?oooc/0oooo00<000000?ooo`3oool05@3oool001`0oooo00<0ojYE
0000001EZ_l06P3oool06`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`3oe800:`00
0000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E
0:[oo`090?ooo`030000003oool0oooo03X0oooo0P3o003o0?ooool0oooo?03oool00`000000oooo
0?ooo`0E0?ooo`006`3oool0103oom@0P2/0000[P03DoolJ0?ooo`0K0?oDP00[0000001E0:[oo`3o
ool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[
0000001E0:[oo`3oool0oonZ05D0000002/0P=Co00T0oooo1@00000h0?ooo`030?l0003oool0oooo
0?l0ooooo`3ooolg0?ooo`D000005`3oool001/0oooo00@0oonZ05D0000005D0Z_oo6P3oool06`3o
ZUD000000000001EZ_l0oooo0?nZE@000000001E0:[oo`3oZUD000000000E@2Zool0oooo0?ooZP1E
0000000005FZo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`090?ooo`030000003o
ool0oooo03T0oooo0P3o003o0?ooool0oooo?@3oool00`000000oooo0?ooo`0E0?ooo`006`3oool0
0`3oom@0P2/000000006000000030000E@2Zool0oooo0180oooo00<0ojYE00000000000010000000
5000EJX0oooo0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[o
o`3oool0oonZ05D000000000EJ[o2@3oool00`000000oooo0?ooo`0i0?ooo`030?l0003oool0oooo
0?l0ooooo`3oooll0?ooo`030000003oool0oooo01D0oooo000L0?ooo`030?ooZP1E0000000000D0
000000<0001E0:[oo`3oool04P3oool0103oe800:`00000[P020E@020000000E02^0e03oool0oooo
0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ
05D0000002/0P=Co00T0oooo00<000000?ooo`3oool0>03oool20?l00?l0ooooo`3oooln0?ooo`03
0000003oool0oooo01D0oooo000L0?ooo`030?nZE@000000EJ[o01X0oooo00@0oonZ05D0000005D0
Z_oo1@3oool04P3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20
e?l0oooo0?oDP00[0000001E0:[oo`T0oooo00<000000?ooo`3oool0>03oool00`3o0000oooo0?oo
o`3o0?ooool0oooo?@3oool00`000000oooo0?ooo`0E0?ooo`006`3oool0103oom@0P2/0000[P03D
oolJ0?ooo`0K0?ooe020:`00000005FZo`3oool0ojYE0000000005D0Z_oo0?ooe020:`00000002^0
e03oool0e80[00000000:h00e?oo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo00T0
oooo00<000000?ooo`3oool0=`3oool20?l00?l0ooooo`3ooolo0?ooo`030000003oool0oooo01D0
oooo000K0?ooo`040?ooZP1E0000001E0:[ooa/0oooo00<0omB002/0000000000`000000100[P=@0
oooo0?ooo`3oZUD50000000405FZo`3oool0oooo0?nZE@D0000000<0EJ[o0?ooo`3oool0203oool0
0`000000oooo0?ooo`0g0?ooo`030?l0003oool0oooo0?l0ooooo`3oooln0?ooo`030000003oool0
oooo01D0oooo000L0?ooo`030:YE00000000000000D0000000<0001E0:[oo`3oool0503oool01@3o
e800:`0000000000000005FZ00@0oooo00D0ojYE000000000000000005FZo`040?ooo`050?nZE@00
000000000000001EZ_l02`3oool00`000000oooo0?ooo`0f0?ooo`80o`00o`3ooooo0?oood00oooo
00<000000?ooo`3oool05@3oool001`0oooo00<0oonZ05D0000000001@0000000`0005D0Z_oo0?oo
o`0f0?ooo`030000003oool0oooo03H0oooo00<0o`000?ooo`3oool0o`3ooooo0?ooocl0oooo00<0
00000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0=@3oool20?l00?l0ooooo`3ooom1
0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo03@0oooo0P3o003o0?oo
ool0oooo@P3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`0d0?ooo`03
0?l0003oool0oooo0?l0ooooo`3ooom10?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000
003oool0oooo03<0oooo0P3o003o0?ooool0oooo@`3oool00`000000oooo0?ooo`0E0?ooo`00G@3o
ool00`000000oooo0?ooo`0c0?ooo`030?l0003oool0oooo0?l0ooooo`3ooom20?ooo`030000003o
ool0oooo01D0oooo001M0?ooo`030000003oool0oooo0380oooo0P3o003o0?ooool0ooooA03oool0
0`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`0b0?ooo`030?l0003oool0oooo
0?l0ooooo`3ooom30?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0340
oooo0P3o003o0?ooool0ooooA@3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo
0?ooo`0a0?ooo`030?l0003oool0oooo0?l0ooooo`3ooom40?ooo`030000003oool0oooo01D0oooo
001M0?ooo`030000003oool0oooo0300oooo0P3o003o0?ooool0ooooAP3oool00`000000oooo0?oo
o`0E0?ooo`00G@3oool4000002l0oooo00<0o`000?ooo`3oool0o`3ooooo0?oood<0oooo0`00000G
0?ooo`00G@3oool00`000000oooo0?ooo`0_0?ooo`80o`00o`3ooooo0?ooodL0oooo00<000000?oo
o`3oool05@3oool005d0oooo00<000000?ooo`3oool0;`3oool00`3o0000oooo0?ooo`3o0?ooool0
ooooAP3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`0^0?ooo`80o`00
o`3ooooo0?ooodP0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0;P3o
ool00`3o0000oooo0?ooo`3o0?ooool0ooooA`3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool0
0`000000oooo0?ooo`0^0?ooo`030?l0003oool0oooo0?l0ooooo`3ooom70?ooo`030000003oool0
oooo01D0oooo001M0?ooo`030000003oool0oooo02d0oooo0P3o003o0?ooool0ooooB@3oool00`00
0000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`0]0?ooo`030?l0003oool0oooo0?l0
ooooo`3ooom80?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo02`0oooo
0P3o003o0?ooool0ooooBP3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?oo
o`0/0?ooo`030?l0003oool0oooo0?l0ooooo`3ooom90?ooo`030000003oool0oooo01D0oooo001M
0?ooo`030000003oool0oooo02/0oooo0P3o003o0?ooool0ooooB`3oool00`000000oooo0?ooo`0E
0?ooo`00G@3oool00`000000oooo0?ooo`0[0?ooo`030?l0003oool0oooo0?l0ooooo`3ooom:0?oo
o`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo02X0oooo0P3o003o0?ooool0
ooooC03oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`0Z0?ooo`030?l0
003oool0oooo0?l0ooooo`3ooom;0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003o
ool0oooo02X0oooo00<0o`000?ooo`3oool0o`3ooooo0?oood/0oooo00<000000?ooo`3oool05@3o
ool005d0oooo00<000000?ooo`3oool0:@3oool20?l00?l0ooooo`3ooom=0?ooo`030000003oool0
oooo01D0oooo001M0?ooo`030000003oool0oooo02T0oooo00<0o`000?ooo`3oool0o`3ooooo0?oo
od`0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0:03oool20?l00?l0
ooooo`3ooom>0?ooo`030000003oool0oooo01D0oooo001M0?ooo`@000009`3oool00`3o0000oooo
0?ooo`3o0?ooool0ooooB`3oool3000001L0oooo001M0?ooo`030000003oool0oooo02L0oooo0P3o
003o0?ooool0ooooC`3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`0W
0?ooo`80o`00o`3ooooo0?ooodl0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?oo
o`3oool09P3oool30?l00?l0ooooo`3ooom?0?ooo`030000003oool0oooo01D0oooo001M0?ooo`03
0000003oool0oooo02H0oooo0P3o003o0?ooool0ooooD03oool00`000000oooo0?ooo`0E0?ooo`00
G@3oool00`000000oooo0?ooo`0V0?ooo`80o`00o`3ooooo0?oooe00oooo00<000000?ooo`3oool0
5@3oool005d0oooo00<000000?ooo`3oool09@3oool20?l00?l0ooooo`3ooomA0?ooo`030000003o
ool0oooo01D0oooo001M0?ooo`030000003oool0oooo02D0oooo0P3o003o0?ooool0ooooD@3oool0
0`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`0T0?ooo`<0o`00o`3ooooo0?oo
oe40oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0903oool20?l00=h0
ooooo`00000N000005D0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0
903oool20?l00=h0ooooo`00000N000005D0oooo00<000000?ooo`3oool05@3oool005d0oooo00<0
00000?ooo`3oool08`3oool30?l00=h0ooooo`00000N000005D0oooo00<000000?ooo`3oool05@3o
ool005d0oooo00<000000?ooo`3oool08`3oool20?l00=l0ooooo`00000N000005D0oooo00<00000
0?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool08`3oool20?l00=l0ooooo`00000N0000
05D0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool08P3oool30?l00=l0
ooooo`00000N000005D0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0
8P3oool20?l00>00ooooo`00000N000005D0oooo00<000000?ooo`3oool05@3oool005d0oooo00<0
00000?ooo`3oool08@3oool30?l00>00ooooo`00000N000005D0oooo00<000000?ooo`3oool05@3o
ool005d0oooo00<000000?ooo`3oool08@3oool20?l00>40ooooo`00000N000005D0oooo00<00000
0?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool08@3oool20?l00>40ooooo`00000N0000
05D0oooo00<000000?ooo`3oool05@3oool005d0oooo1000000O0?ooo`<0o`00h@3ooooo000001h0
0000D`3oool3000001L0oooo001M0?ooo`030000003oool0oooo0200oooo0P3o003R0?ooool00000
7P00001E0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0200oooo0P3o
003R0?ooool000007P00001E0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0
oooo0200oooo0P3o003R0?ooool000007P00001E0?ooo`030000003oool0oooo01D0oooo001M0?oo
o`030000003oool0oooo01l0oooo0`3o003R0?ooool000007P00001E0?ooo`030000003oool0oooo
01D0oooo001M0?ooo`030000003oool0oooo01l0oooo0P3o003S0?ooool000007P00001E0?ooo`03
0000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo01l0oooo0P3o003S0?ooool00000
7P00001E0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo01h0oooo0`3o
003A0?ooool00000<000001E0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0
oooo01h0oooo0P3o003B0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000005D0oooo00<00000
0?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool07P3oool20?l00=80oooo00<000000?oo
o`3oool0o`3ooolK0?oooa800000E@3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000
oooo0?ooo`0N0?ooo`80o`00dP3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00001E0?ooo`03
0000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo01d0oooo0`3o003B0?ooo`030000
003oool0oooo0?l0oooo6`3ooolB000005D0oooo00<000000?ooo`3oool05@3oool005d0oooo00<0
00000?ooo`3oool07@3oool20?l00=<0oooo00<000000?ooo`3oool0o`3ooolK0?oooa800000E@3o
ool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`0M0?ooo`80o`00d`3oool0
0`000000oooo0?ooo`3o0?oooa/0oooo4P00001E0?ooo`030000003oool0oooo01D0oooo000k0?oo
o`050:YE00000000000000000000EJX0103oool01@3oZUD00000000000000000EJ[o00@0oooo00D0
ojYE000000000000000005FZo`0;0?ooo`030000003oool0oooo01`0oooo0`3o003C0?ooo`030000
003oool0oooo0?l0oooo6`3ooolB000005D0oooo00<000000?ooo`3oool05@3oool003T0oooo00<0
oooD080[00000000100000001000EJX0oooo0?ooo`3oZUD50000000405FZo`3oool0oooo0?nZE@D0
000000<0EJ[o0?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`80o`00e03oool00`000000
oooo0?ooo`3o0?oooa/0oooo4P00001E0?ooo`030000003oool0oooo01D0oooo000i0?ooo`0K0?oD
P00[0000000005FZo`3oool0ojYE0000000002/0P=Co0?ooe020:`00000002^0e03oool0e80[0000
0000:h00e?oo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo00T0oooo00<000000?oo
o`3oool0703oool20?l00=@0oooo00<000000?ooo`3oool0o`3ooolK0?oooa800000E@3oool00`00
0000oooo0?ooo`0E0?ooo`00>@3oool06`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZ
o`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oD
P00[0000001E0:[oo`090?ooo`030000003oool0oooo01`0oooo0P3o003D0?ooo`030000003oool0
oooo0?l0oooo6`3ooolB000005D0oooo00<000000?ooo`3oool05@3oool003T0oooo01/0oonZ05D0
00000000EJ[o0?ooo`3oZUD000000000E@2Zool0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000
:`20e?l0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l02@3oool5000001T0oooo0`3o
003D0?ooo`030000003oool0oooo0?l0oooo6`3ooolB00000540oooo1@00000G0?ooo`00>P3oool0
0`3oZUD00000000000030000000D05FZo`3oool0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000
001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l90?ooo`030000003oool0oooo
01/0oooo0P3o003E0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000005D0oooo00<000000?oo
o`3oool05@3oool003X0oooo00<0oonZ05D0000000000P0000005@0005D0Z_oo0?ooo`3oZUD00000
0000E@2Zool0oooo0?ooZP1E0000000005FZo`3oZUD000000000E@2Zool0oooo0?ooZP1E00000000
05FZo`090?ooo`030000003oool0oooo01/0oooo0P3o003E0?ooo`030000003oool0oooo0?l0oooo
6`3ooolB000005D0oooo00<000000?ooo`3oool05@3oool003T0oooo01/0oooD080[00000000:h3D
0?ooo`3DP2/00000000[P03Dool0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB0
02/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l02@3oool00`000000oooo0?ooo`0K0?ooo`80
o`00e@3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00001E0?ooo`030000003oool0oooo01D0
oooo000i0?ooo`0K0?ooZP1E0000000[083Do`3oool0omB002/0000005D0Z_oo0?oDP00[0000000[
083Do`3oool0omB002/0000005D0Z_oo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo
00T0oooo00<000000?ooo`3oool06P3oool30?l00=D0oooo00<000000?ooo`3oool0o`3ooolK0?oo
oa800000E@3oool00`000000oooo0?ooo`0E0?ooo`00>@3oool06`3oojX0E@000000000[P=@0oooo
0=B0:`000000001E0:[oo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/0
0000000[P=@0oooo0=B0:`00000002^00=Coo`090?ooo`030000003oool0oooo01X0oooo0P3o003F
0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000005D0oooo00<000000?ooo`3oool05@3oool0
03X0oooo00<0e80[0000000000000`000000100[P=@0oooo0?ooo`3oZUD50000000405FZo`3oool0
oooo0?nZE@D0000000<0EJ[o0?ooo`3oool0203oool00`000000oooo0?ooo`0J0?ooo`80o`00eP3o
ool00`000000oooo0?ooo`3o0?oooa/0oooo4P00001E0?ooo`030000003oool0oooo01D0oooo000k
0?ooo`050:YE0000000000000000000[P=@0103oool01@3oZUD00000000000000000EJ[o00@0oooo
00D0ojYE000000000000000005FZo`0;0?ooo`030000003oool0oooo01X0oooo0P3o003F0?ooo`03
0000003oool0oooo0?l0oooo6`3ooolB000005D0oooo00<000000?ooo`3oool05@3oool005d0oooo
00<000000?ooo`3oool06@3oool30?l00=H0oooo00<000000?ooo`3oool0o`3ooolK0?oooa800000
E@3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`0I0?ooo`80o`00e`3o
ool00`000000oooo0?ooo`3o0?oooa/0oooo4P00001E0?ooo`030000003oool0oooo01D0oooo001M
0?ooo`030000003oool0oooo01T0oooo0P3o003G0?ooo`030000003oool0oooo0?l0oooo6`3ooolB
000005D0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool0603oool30?l0
0=L0oooo00<000000?ooo`3oool0o`3ooolK0?oooa800000E@3oool00`000000oooo0?ooo`0E0?oo
o`00G@3oool00`000000oooo0?ooo`0H0?ooo`80o`00f03oool00`000000oooo0?ooo`3o0?oooa/0
oooo4P00001E0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo01P0oooo
0P3o003H0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000005D0oooo00<000000?ooo`3oool0
5@3oool005d0oooo00<000000?ooo`3oool0603oool20?l00=P0oooo00<000000?ooo`3oool0o`3o
oolK0?oooa800000E@3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`0G
0?ooo`<0o`00f03oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00001E0?ooo`030000003oool0
oooo01D0oooo001M0?ooo`030000003oool0oooo01L0oooo0P3o003I0?ooo`030000003oool0oooo
0?l0oooo6`3ooolB000005D0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3o
ool05`3oool20?l00=T0oooo00<000000?ooo`3oool0h03oool01@3oe800:`000000000005D0Z_oo
03D0oooo4P00001E0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo01L0
oooo0P3o003I0?ooo`030000003oool0oooo0>00oooo00D0omB002/0000000000000001EZP0e0?oo
oa800000E@3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool4000001D0oooo0`3o003I0?ooo`03
0000003oool0oooo0>80oooo00@0omB002/0000002/0P=Co=03ooolB000005<0oooo0`00000G0?oo
o`00G@3oool00`000000oooo0?ooo`0F0?ooo`80o`00fP3oool00`000000oooo0?ooo`1^0?ooo`04
0?ooZP1E0000000005FZo`<0oooo00@0omB002/00000000005FZ0`3oool06`2ZE@00000000000000
:h00ZX0[00000000EJX0oooo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?ooo`3o
ZUD000000000E@2Zool0oooD080[00000000EJZZ05D000020000000302^0e03oool0oooo0080oooo
00D0ZUD0000000000000000002^0e0020?ooo`040?ooZP1E0000000[083Do`H0oooo00<0oonZ05D0
000000001@0000000`0[P=@0oooo0?ooo`030?ooo`050:YE0000000000000000000[P=@00`3oool0
0`2ZE@000000001EZP020?ooo`030=B0:`00000005FZ0080oooo00<0oooD080[000000000P000000
4P00:h00e?oo0?ooo`3oojX0E@000000001EZ_l0oooo0?oDP00[000000000000:`20e?l0oooo0?oo
ZP1E0000000002^0e3@0oooo4P00001E0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000
003oool0oooo01H0oooo0P3o003J0?ooo`030000003oool0oooo06h0oooo00@0oonZ05D000000000
EJ[o0`3oool0102ZE@00000000000000EJX20?ooo`030?nZE@000000000000@00000018005FZ0?oo
o`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oool0ojYE0000000005D0Z_oo0?oo
e020:`060000000402^0e03oool0oooo0:YE00D0000000H0:h3D0?ooo`3oojX0E@000000:`20e?l6
0?ooo`030?ooZP1E0000000000H0000000D002^00=Coo`3oool0oooo0:YE00050000000602^0e03o
ool0oooo0:YE0000000005FZ0P3oool01P3DP2/00000001EZP3oool0oooD080[00D0000000P002^0
0=Coo`3oojX0E@000000001EZ_l0oooo0:YE0080000000@0000[083Do`3oool0ojYE0P0000000`00
:h00e?oo0?ooo`0b0?oooa800000E@3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000
oooo0?ooo`0F0?ooo`80o`00fP3oool00`000000oooo0?ooo`1^0?ooo`040?ooZP1E0000000005FZ
o`80oooo00D0ojYE0000000000000000001EZP020?ooo`0^0:YE0000000002^00=Coo`3oojX0E@00
00000000EJX0oooo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?ooo`3oZUD00000
0000E@2Zool0oooD080[00000000001E0:[oo`3oool0e80[0000000005D0Z_oo0?oDP00[00000000
05FZo`3oool0ojYE0000000005D0Z_oo0?ooZP1E0000000[083Do`H0oooo00@0oonZ05D000000000
EJ[o0`3oool04P3oe800:`000000000[P=@0oooo0?oDP00[0000000005FZo`3oool0ojYE00000000
05D0Z_oo0?ooo`2ZE@000000001EZP80oooo01D0e80[00000000EJX0oooo0?nZE@000000000[083D
o`3oool0oonZ05D0000002/0P=Co0?ooZP1E0000000005FZo`3oom@0P2/00000000[P=@00`3oool0
1@2ZE@0000000000000002/0P=Co03<0oooo4P00001E0?ooo`030000003oool0oooo01D0oooo001M
0?ooo`030000003oool0oooo01D0oooo0`3o003J0?ooo`030000003oool0oooo06h0oooo00L0oonZ
05D000000000EJ[o0?ooo`3oom@0P2/000<0000000H005FZ0?ooo`3oool0ZUD000000000EJX20?oo
o`0F0:YE0000000005FZ0?ooo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oool0
ojYE0000000005D0Z_oo0?ooe020:`00000002^0e080oooo00P0oonZ05D0000002/0P=Co0=B0:`00
000002^00=Coo`D0oooo00@0oonZ05D0000002/0P=Co1P3oool0103oojX0E@000000001EZ_l40?oo
o`080?nZE@000000001E0:[oo`3DP2/00000000[P03Dool60?ooo`030:YE0000000005FZ0080oooo
00<0e80[00000000EJX0103oool03P3oZUD00000000000000000000[083Do`3oojX0E@000000001E
Z_l0oooD080[00000000EJ[o0P3oool01P3oe800:`000000E@2ZZUD00000001EZS<0oooo4P00001E
0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo01D0oooo0P3o003K0?oo
o`030000003oool0oooo06h0oooo00/0oonZ05D000000000EJ[o0?ooo`3DP2/00000001EZP2ZE@00
0000001EZP020?ooo`030:YE0000000005FZ0080oooo01H0e80[00000000EJX0oooo0?oDP00[0000
000[083Do`3oool0omB002/0000002/0P=Co0?ooo`3oZUD000000000E@2Zool0oooD080[00000000
EJ[o0P3oool01@3oojX0E@000000001EZ_l0e80[00L0000000D0EJ[o0?ooZP1E0000000005FZo`06
0?ooo`040?ooZP1E0000000005FZo`@0oooo00D0omB002/0000002/0P=Co0=B0:`070000000505FZ
o`3oool0ZUD000000000EJX00P3oool00`3DP2/00000001EZP020?ooo`030=B0:`000000000000<0
000000X005FZ0?ooo`3oojX0E@000000001EZ_l0oooD080[00000000EJ[o0P3oool01`3DP2/00000
001EZP3oojX0E@000000E@2Zool0<P3ooolB000005D0oooo00<000000?ooo`3oool05@3oool005d0
oooo00<000000?ooo`3oool05@3oool20?l00=/0oooo00<000000?ooo`3oool03P3ooomB0?l000h0
oooo00/0oonZ05D000000000EJ[o0?ooZP1E0000000[083Do`2ZE@000000001EZP020?ooo`030:YE
0000000005FZ0080oooo01H0e80[00000000EJX0oooo0?oDP00[0000000[083Do`3oool0omB002/0
000002/0P=Co0?ooo`3oZUD000000000E@2Zool0oooD080[00000000EJ[o0P3oool01@3oojX0E@00
0000:`20e?l0ojYE00H0000000H0000[083Do`3oojX0E@000000001EZ_l60?ooo`040?ooZP1E0000
000005FZo`@0oooo00D0oonZ05D0000002/0P=Co0?nZE@06000000060000:`20e?l0oooo0:YE0000
000005FZ0P3oool01P3DP2/00000001EZP3oool0oonZ05D000<0000001D005FZ0?ooo`3oool0oooo
0?ooZP1E0000000005FZo`3oom@0P2/00000001EZ_l0oooo0?ooe020:`00000005FZo`3oool0ZUD0
0000001EZ_l0<P3ooolB000005D0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?oo
o`3oool05@3oool20?l00=/0oooo00<000000?ooo`3oool03P3ooomB0?l000h0oooo00/0oonZ05D0
00000000EJ[o0=B0:`00000005FZ0?ooo`2ZE@000000001EZP020?ooo`030:YE0000000005FZ0080
oooo00X0e80[00000000EJX0oooo0?oDP00[00000000001EZP3oool0ojYE0P0000007@0[P=@0oooo
0=B0:`000000001E0:[oo`3oom@0P2/000000000:h00e?oo0?ooo`3DP2/000000000E@2Zool0omB0
02/0000005D0Z_oo0?ooo`3oe800:`000000E@2Zool0oonZ05D00000000005FZ00H0oooo00@0oonZ
05D000000000EJ[o103oool0<P3oojX0E@000000:`20e?l0omB002/0000005D0Z_oo0?ooo`3oe800
:`000000E@2Zool0oooo0:YE00000000000[083Do`3oom@0P2/000000000EJX0oooo0?oDP00[0000
001E0:[oo`3oool0e80[00000000EJX0oooo0?ooZP1E0000000005FZo`3oom@0P2/00000001EZ_l0
oooo0?oDP00[0000001E0:[oo`3oool0ojYE00000000:h00e?oo<@3ooolB000005D0oooo00<00000
0?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool05@3oool20?l00=/0oooo00<000000?oo
o`3oool0KP3oool02`3oojX0E@000000001EP800:`000000E@2Zool0oooo0:YE0000000005FZ0080
oooo00<0ZUD000000000EJX00P3oool01P3DP2/00000001EZP3oool0omB002/000X0000000@005FZ
0?ooo`3oom@0P2/01P000000100[P=@0oooo0?ooo`2ZE@050000000402^0e03oool0oonZ05D000<0
000000<002^00=Coo`3oool00P3oool0103oojX0E@000000001EZ_l40?ooo`060?oDP00[0000000[
083Do`3oool0ZUD01@000000100[P=@0oooo0?ooo`2ZE@060000000402^0e03oool0oooD080[00D0
000000L0:h3D0?ooo`3oojX0E@000000001EZ]@0P2/000<0000000@0001E0820:`00000005FZ0P3o
ool0103oojX0E@000000:`20e?la0?oooa800000E@3oool00`000000oooo0?ooo`0E0?ooo`00G@3o
ool00`000000oooo0?ooo`0D0?ooo`<0o`00f`3oool00`000000oooo0?ooo`1^0?ooo`030?ooZP1E
000000000080000000H0:h3D0?ooo`3oool0ZUD000000000EJX20?ooo`030:YE0000000005FZ0080
oooo01L0e80[00000000EJX0oooo0?oDP00[0000000[082ZP00[000000000000E@2Zool0omB002/0
00000000001E0:[oo`3oool0oooD080[00000000EJ[D080[00020000000302^0e03oool0oooo0080
oooo00D0e80[000000000000000002^0e0020?ooo`070?ooZP1E0000000[0820E@000000000[083D
o`030?ooo`040?ooZP1E0000000005FZo`@0oooo00@0e80[0000000005D0Z_oo0P3oool01@3DP2/0
0000000000000000:h3D00<0oooo00@0ZUD000000000EJX0ZUD00P0000001P00EJX0oooo0?ooo`3o
ool0oonZ05D000<0000000P005FZ0?ooo`3oool0oonZ05D000000000EJ[D080[00H0000000L0EJ[o
0?ooo`3oool0oooo0:YE00000000:h3D0340oooo4P00001E0?ooo`030000003oool0oooo01D0oooo
001M0?ooo`030000003oool0oooo01@0oooo0P3o003L0?ooo`030000003oool0oooo06h0oooo00H0
oonZ05D0000000000000000[P03Dool20?ooo`030:YE0000000005FZ01T0oooo00@0oooD080[0000
0000EJ[o6@3oool0103oojX0E@000000001EZ_l30?ooo`040?nZE@000000000002^0e240oooo00@0
oooD080[00000000EJ[o>`3ooolB000005D0oooo00<000000?ooo`3oool05@3oool005d0oooo00<0
00000?ooo`3oool0503oool20?l00=`0oooo00<000000?ooo`3oool0KP3oool01@3oojX0E@000000
00000000EJ[o00<0oooo00<0ZUD000000000EJX06@3oool0103oom@0P2/00000001EZ_lI0?ooo`03
0?ooZP1E0000000000H0000000<002^00=Coo`3oool0703oool0203oojX0E@000000001EZ_l0oooD
080[00000000EJ[o>`3ooolB000005D0oooo00<000000?ooo`3oool05@3oool005d0oooo00<00000
0?ooo`3oool0503oool20?l00=`0oooo00<000000?ooo`3oool0KP3oool0103oojX0E@0000000000
EJX40?ooo`030:YE0000000005FZ01T0oooo00@0oooD080[00000000EJ[o6@3oool00`3oojX0E@00
000000050000000302^0e03oool0oooo01d0oooo00@0oonZ05D000000000EJ[o0P3oool00`2ZE@00
EJ[o0?ooo`0j0?oooa800000E@3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo
0?ooo`0C0?ooo`<0o`00g03oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00001E0?ooo`030000
003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo01<0oooo0P3o003M0?ooo`030000003o
ool0oooo0?l0oooo6`3ooolB000005D0oooo00<000000?ooo`3oool05@3oool005d0oooo00<00000
0?ooo`3oool04`3oool20?l00=d0oooo00<000000?ooo`3oool0o`3ooolK0?oooa800000E@3oool0
0`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`0C0?ooo`80o`00g@3oool00`00
0000oooo0?ooo`3o0?oooa/0oooo4P00001E0?ooo`030000003oool0oooo01D0oooo001M0?ooo`03
0000003oool0oooo01<0oooo0P3o003M0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000005D0
oooo00<000000?ooo`3oool05@3oool005d0oooo1000000A0?ooo`<0o`00g@3oool00`000000oooo
0?ooo`3o0?oooa/0oooo4P00001C0?ooo`<000005`3oool005d0oooo00<000000?ooo`3oool04P3o
ool20?l00=h0oooo00<000000?ooo`3oool0o`3ooolK0?oooa800000E@3oool00`000000oooo0?oo
o`0E0?ooo`00G@3oool00`000000oooo0?ooo`0B0?ooo`80o`00gP3oool00`000000oooo0?ooo`3o
0?oooa/0oooo4P00001E0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo
0180oooo0P3o003N0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000005D0oooo00<000000?oo
o`3oool05@3oool005d0oooo00<000000?ooo`3oool04P3oool20?l00=h0oooo00<000000?ooo`3o
ool0o`3ooolK0?oooa800000E@3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo
0?ooo`0B0?ooo`80o`00gP3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P00001E0?ooo`030000
003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0180oooo0P3o003N0?ooo`030000003o
ool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo01D0oooo001M
0?ooo`030000003oool0oooo0140oooo0P3o003O0?ooo`030000003oool0oooo0?l0oooo6`3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo
0140oooo0P3o003O0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`1T0?oo
o`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0140oooo0P3o003O0?ooo`03
0000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo01D0
oooo001M0?ooo`030000003oool0oooo0140oooo0P3o003O0?ooo`030000003oool0oooo0?l0oooo
6`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003o
ool0oooo0140oooo0P3o003O0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0140oooo0P3o003O
0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo01D0oooo001M0?ooo`030000003oool0oooo0100oooo0P3o003P0?ooo`030000003oool0oooo
0?l0oooo6`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo01D0oooo001M0?ooo`03
0000003oool0oooo0100oooo0P3o003P0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000
oooo0?ooo`1T0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0100oooo
0P3o003P0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo0100oooo0P3o003P0?ooo`030000003o
ool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo01D0oooo001M
0?ooo`030000003oool0oooo0100oooo0P3o003P0?ooo`030000003oool0oooo0?l0oooo6`3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo
0100oooo0P3o003P0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`1T0?oo
o`030000003oool0oooo01D0oooo001M0?ooo`@000003P3oool20?l00>40oooo00<000000?ooo`3o
ool0o`3ooolK0?ooo`030000003oool0oooo0680oooo0`00000G0?ooo`00G@3oool00`000000oooo
0?ooo`0?0?ooo`80o`00h@3oool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`0?0?ooo`80o`00h@3o
ool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`0E0?ooo`00G@3oool00`000000oooo0?ooo`0?0?ooo`80o`00h@3oool00`000000oooo0?ooo`3o
0?oooa/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`00
0000oooo0?ooo`0?0?ooo`80o`00h@3ooooo000001l00000IP3oool00`000000oooo0?ooo`0E0?oo
o`00G@3oool00`000000oooo0?ooo`0>0?ooo`<0o`00o`3ooooo0?ooofL0oooo00<000000?ooo`3o
ool05@3oool005d0oooo00<000000?ooo`3oool03P3oool20?l00?l0ooooo`3ooomX0?ooo`030000
003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo00h0oooo0P3o003o0?ooool0ooooJ03o
ool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`0>0?ooo`80o`00o`3ooooo
0?ooofP0oooo00<000000?ooo`3oool05@3oool005d0oooo00<000000?ooo`3oool03@3oool30?l0
0?l0ooooo`3ooomX0?ooo`030000003oool0oooo01D0oooo001M0?ooo`030000003oool0oooo00d0
oooo0P3o003o0?ooool0ooooJ@3oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo
0?ooo`0=0?ooo`80o`00o`3ooooo0?ooofT0oooo00<000000?ooo`3oool05@3oool005d0oooo00<0
00000?ooo`3oool03@3oool20?l00?l0ooooo`3ooomY0?ooo`030000003oool0oooo01D0oooo001M
0?ooo`030000003oool0oooo00d0oooo0P3o003o0?ooool0ooooJ@3oool00`000000oooo0?ooo`0E
0?ooo`00<`3oool0103oom@0P2/00000000[P=@40?ooo`050?nZE@00000000000000001EZ_l0103o
ool01@3oZUD00000000000000000EJ[o00@0oooo00D0ojYE000000000000000005FZo`0;0?ooo`03
0000003oool0oooo00`0oooo0`3o003o0?ooool0ooooJ@3oool00`000000oooo0?ooo`0E0?ooo`00
<`3oool0103oom@0P2/00000000[P=@30?ooo`030?nZE@000000000000<0000000@0EJ[o0?ooo`3o
ool0ojYE1@000000101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo00P0oooo00<00000
0?ooo`3oool0303oool20?l00?l0ooooo`3ooomZ0?ooo`030000003oool0oooo01D0oooo000c0?oo
o`040?ooe020:`00000002^0e080oooo01/0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03D
ool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0oooD080[00000000:h3D0?ooo`3D
P2/00000000[P03Dool02@3oool00`000000oooo0?ooo`0<0?ooo`80o`00o`3ooooo0?ooofX0oooo
00<000000?ooo`3oool05@3oool003<0oooo00@0oooD080[00000000:h3D0P3oool06`3oe800:`00
0000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E
0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`090?ooo`030000003oool0oooo
00`0oooo0P3o003o0?ooool0ooooJP3oool00`000000oooo0?ooo`0E0?ooo`00<`3oool0103oom@0
P2/00000000[P=@20?ooo`0K0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[
0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D00000
02/0P=Co00T0oooo1@0000090?ooo`<0o`00o`3ooooo0?ooofH0oooo1@00000G0?ooo`00<`3oool0
103oom@0P2/00000000[P=@20?ooo`0K0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o
0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ
05D000000000EJ[o00T0oooo00<000000?ooo`3oool0303oool00`3o0000oooo0?ooo`3o0?ooool0
ooooJ@3oool00`000000oooo0?ooo`0E0?ooo`00<`3oool0103oom@0P2/00000000[P=@20?ooo`0K
0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ
05D000000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o00T0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooogP0oooo00<000000?ooo`3oool05@3oool00300oooo00L0oooD080[
000[P=@0oooD080[00000000:h3D0080oooo01/0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000
:`20e?l0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB002/0000005D0Z_oo0?oo
o`3oojX0E@000000:`20e?l02@3oool00`000000oooo0?ooo`3o0?ooool0ooooN03oool00`000000
oooo0?ooo`0E0?ooo`00<03oool01`3oom@0P2/00000000002/0:b/00000000[P=@00P3oool06`3o
e800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[
0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`090?ooo`030000003o
ool0oooo0?l0ooooo`3ooomh0?ooo`030000003oool0oooo01D0oooo000b0?ooo`050:YE00000000
00000000000[P=@00P3oool06`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0
P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`000000
02^00=Coo`090?ooo`030000003oool0oooo0?l0ooooo`3ooomh0?ooo`030000003oool0oooo01D0
oooo000c0?ooo`040?nZE@000000000002^0e0<0oooo00<0ojYE0000000000000`000000101EZ_l0
oooo0?ooo`3oZUD50000000405FZo`3oool0oooo0?nZE@D0000000<0EJ[o0?ooo`3oool0203oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05@3oool0
03@0oooo00<0ZUD00000000[P=@0103oool01@3oZUD00000000000000000EJ[o00@0oooo00D0ojYE
000000000000000005FZo`040?ooo`050?nZE@00000000000000001EZ_l02`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0E0?ooo`00G@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0E
0?ooo`00G@3ooooo00000?l00000O000000G0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0oooo
l03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0
ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`
0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00001\
\>"],
  ImageRangeCache->{{{0, 749}, {462.5, 0}} -> {-1.05093, -0.648943, \
0.00280622, 0.00280622}, {{18.125, 730.813}, {451.438, 11}} -> {9.22868, \
-190.951, 0.0230132, 2.69848}, {{338.813, 623.938}, {106.5, 35.25}} -> \
{-4.09522, -6.89529, 0.0117896, 0.0190879}, {{354.125, 438.938}, {97.0625, \
44.625}} -> {-4.4092, -15.6912, 0.0123804, 0.0400637}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["NumberDensity",
        GridBoxOptions->{RowSpacings->0.4,
        RowLines->False}], "[", \(5000\ Meter\), "]"}]], "Input"],

Cell[BoxData[
    \(1.5312`*^25\/Meter\^3\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{
      RowBox[{"lst", "=", 
        RowBox[{"AtmGraphs", "[", 
          RowBox[{
            RowBox[{"{", 
              
              RowBox[{\({Pressure, "\<Pressure (hPa)\>"}\), 
                ",", \({MeanDensity, \*"\"\<Density (kg/\!\(m\^3\)\>\""}\), 
                ",", 
                RowBox[{"{", 
                  StyleBox[\(MeanFreePath, "\<M.F.P.L (m)\>"\),
                    GridBoxOptions->{RowSpacings->0.4,
                    RowLines->False}], 
                  StyleBox["}",
                    GridBoxOptions->{RowSpacings->0.4,
                    RowLines->False}]}]}], 
              StyleBox["}",
                GridBoxOptions->{RowSpacings->0.4,
                RowLines->False}]}], 
            StyleBox[",",
              GridBoxOptions->{RowSpacings->0.4,
              RowLines->False}], \(PlotRange -> {\(-7\)\ , 500\ }\), 
            ",", \(AtmGraphStyles \[Rule] {{Red, 
                  AbsoluteThickness[2]}, {Yellow, 
                  AbsoluteThickness[2]}, {Green, AbsoluteThickness[2]}}\), 
            ",", "\[IndentingNewLine]", \(FrameLabel \[Rule] \
{"\<Log[10,Value]\>", "\<Altitude, km\>"}\)}], 
          StyleBox["]",
            GridBoxOptions->{RowSpacings->0.4,
            RowLines->False}]}]}], 
      StyleBox[";",
        GridBoxOptions->{RowSpacings->0.4,
        RowLines->False}]}], "\[IndentingNewLine]", \(Show[
        LegendGraphs[lst, LegendSize \[Rule] { .8,  .2}, 
          LegendPosition \[Rule] \ {\(- .1\),  .35}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        ImageSize \[Rule] 750];\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 750 463.525 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.680951 0.0454819 0.00853301 0.001219 [
[.22613 -0.0125 -16.6563 -20.3125 ]
[.22613 -0.0125 16.6563 0 ]
[.45354 -0.0125 -12.2188 -20.3125 ]
[.45354 -0.0125 12.2188 0 ]
[.68095 -0.0125 -6.4375 -20.3125 ]
[.68095 -0.0125 6.4375 0 ]
[.90836 -0.0125 -6.4375 -20.3125 ]
[.90836 -0.0125 6.4375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -54.6563 -40.625 ]
[.5 -0.0125 54.6563 -20.3125 ]
[-0.0125 .00853 -12.875 -10.1563 ]
[-0.0125 .00853 0 10.1563 ]
[-0.0125 .13043 -30.625 -10.1563 ]
[-0.0125 .13043 0 10.1563 ]
[-0.0125 .25233 -30.625 -10.1563 ]
[-0.0125 .25233 0 10.1563 ]
[-0.0125 .37423 -30.625 -10.1563 ]
[-0.0125 .37423 0 10.1563 ]
[-0.0125 .49613 -30.625 -10.1563 ]
[-0.0125 .49613 0 10.1563 ]
[-0.0125 .61803 -30.625 -10.1563 ]
[-0.0125 .61803 0 10.1563 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -50.9375 -47.3125 ]
[-0.01875 .30902 -30.625 47.3125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.22613 0 m
.22613 .00625 L
s
gsave
.22613 -0.0125 -77.6563 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.45354 0 m
.45354 .00625 L
s
gsave
.45354 -0.0125 -73.2188 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
74.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.68095 0 m
.68095 .00625 L
s
gsave
.68095 -0.0125 -67.4375 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.90836 0 m
.90836 .00625 L
s
gsave
.90836 -0.0125 -67.4375 -24.3125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.0442 0 m
.0442 .00375 L
s
.08969 0 m
.08969 .00375 L
s
.13517 0 m
.13517 .00375 L
s
.18065 0 m
.18065 .00375 L
s
.27161 0 m
.27161 .00375 L
s
.3171 0 m
.3171 .00375 L
s
.36258 0 m
.36258 .00375 L
s
.40806 0 m
.40806 .00375 L
s
.49902 0 m
.49902 .00375 L
s
.54451 0 m
.54451 .00375 L
s
.58999 0 m
.58999 .00375 L
s
.63547 0 m
.63547 .00375 L
s
.72643 0 m
.72643 .00375 L
s
.77191 0 m
.77191 .00375 L
s
.8174 0 m
.8174 .00375 L
s
.86288 0 m
.86288 .00375 L
s
.95384 0 m
.95384 .00375 L
s
.99932 0 m
.99932 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -115.656 -44.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
92.063 19.750 moveto
(@) show
97.813 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
115.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
120.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Value) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
162.563 19.750 moveto
(D) show
168.313 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00853 m
.00625 .00853 L
s
gsave
-0.0125 .00853 -73.875 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13043 m
.00625 .13043 L
s
gsave
-0.0125 .13043 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
0 .25233 m
.00625 .25233 L
s
gsave
-0.0125 .25233 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
0 .37423 m
.00625 .37423 L
s
gsave
-0.0125 .37423 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
0 .49613 m
.00625 .49613 L
s
gsave
-0.0125 .49613 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
0 .61803 m
.00625 .61803 L
s
gsave
-0.0125 .61803 -91.625 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03291 m
.00375 .03291 L
s
0 .05729 m
.00375 .05729 L
s
0 .08167 m
.00375 .08167 L
s
0 .10605 m
.00375 .10605 L
s
0 .15481 m
.00375 .15481 L
s
0 .17919 m
.00375 .17919 L
s
0 .20357 m
.00375 .20357 L
s
0 .22795 m
.00375 .22795 L
s
0 .27671 m
.00375 .27671 L
s
0 .30109 m
.00375 .30109 L
s
0 .32547 m
.00375 .32547 L
s
0 .34985 m
.00375 .34985 L
s
0 .39861 m
.00375 .39861 L
s
0 .42299 m
.00375 .42299 L
s
0 .44737 m
.00375 .44737 L
s
0 .47175 m
.00375 .47175 L
s
0 .52051 m
.00375 .52051 L
s
0 .54489 m
.00375 .54489 L
s
0 .56927 m
.00375 .56927 L
s
0 .59365 m
.00375 .59365 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -149.094 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
108.313 14.1563 translate
90 rotate
-108.313 -14.1563 translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Altitude) show
121.688 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
130.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(km) show
153.625 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.22613 .61178 m
.22613 .61803 L
s
.45354 .61178 m
.45354 .61803 L
s
.68095 .61178 m
.68095 .61803 L
s
.90836 .61178 m
.90836 .61803 L
s
.125 Mabswid
.0442 .61428 m
.0442 .61803 L
s
.08969 .61428 m
.08969 .61803 L
s
.13517 .61428 m
.13517 .61803 L
s
.18065 .61428 m
.18065 .61803 L
s
.27161 .61428 m
.27161 .61803 L
s
.3171 .61428 m
.3171 .61803 L
s
.36258 .61428 m
.36258 .61803 L
s
.40806 .61428 m
.40806 .61803 L
s
.49902 .61428 m
.49902 .61803 L
s
.54451 .61428 m
.54451 .61803 L
s
.58999 .61428 m
.58999 .61803 L
s
.63547 .61428 m
.63547 .61803 L
s
.72643 .61428 m
.72643 .61803 L
s
.77191 .61428 m
.77191 .61803 L
s
.8174 .61428 m
.8174 .61803 L
s
.86288 .61428 m
.86288 .61803 L
s
.95384 .61428 m
.95384 .61803 L
s
.99932 .61428 m
.99932 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00853 m
1 .00853 L
s
.99375 .13043 m
1 .13043 L
s
.99375 .25233 m
1 .25233 L
s
.99375 .37423 m
1 .37423 L
s
.99375 .49613 m
1 .49613 L
s
.125 Mabswid
.99625 .03291 m
1 .03291 L
s
.99625 .05729 m
1 .05729 L
s
.99625 .08167 m
1 .08167 L
s
.99625 .10605 m
1 .10605 L
s
.99625 .15481 m
1 .15481 L
s
.99625 .17919 m
1 .17919 L
s
.99625 .20357 m
1 .20357 L
s
.99625 .22795 m
1 .22795 L
s
.99625 .27671 m
1 .27671 L
s
.99625 .30109 m
1 .30109 L
s
.99625 .32547 m
1 .32547 L
s
.99625 .34985 m
1 .34985 L
s
.99625 .39861 m
1 .39861 L
s
.99625 .42299 m
1 .42299 L
s
.99625 .44737 m
1 .44737 L
s
.99625 .47175 m
1 .47175 L
s
.99625 .52051 m
1 .52051 L
s
.99625 .54489 m
1 .54489 L
s
.99625 .56927 m
1 .56927 L
s
.99625 .59365 m
1 .59365 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
.82876 .00244 m
.8277 .00305 L
.82663 .00366 L
.82555 .00427 L
.82446 .00488 L
.82335 .00549 L
.82224 .0061 L
.82111 .0067 L
.81997 .00731 L
.81882 .00792 L
.81766 .00853 L
.81648 .00914 L
.81529 .00975 L
.81408 .01036 L
.81287 .01097 L
.81163 .01158 L
.81039 .01219 L
.80912 .0128 L
.80785 .01341 L
.80655 .01402 L
.80524 .01463 L
.80392 .01524 L
.80257 .01585 L
.80121 .01646 L
.79984 .01707 L
.79844 .01768 L
.79702 .01829 L
.79559 .01889 L
.79414 .0195 L
.79266 .02011 L
.79116 .02072 L
.78965 .02133 L
.78811 .02194 L
.78655 .02255 L
.7849 .02316 L
.78345 .02377 L
.7819 .02438 L
.78035 .02499 L
.7788 .0256 L
.77725 .02621 L
.7757 .02682 L
.7726 .02804 L
.7695 .02926 L
.7664 .03048 L
.76331 .03169 L
.76021 .03291 L
.75712 .03413 L
.75405 .03535 L
.75099 .03657 L
.74795 .03779 L
Mistroke
.74492 .03901 L
.7419 .04023 L
.7389 .04145 L
.73591 .04267 L
.73294 .04388 L
.72998 .0451 L
.72704 .04632 L
.72411 .04754 L
.7212 .04876 L
.71833 .04998 L
.71549 .0512 L
.71268 .05242 L
.70717 .05486 L
.70179 .05729 L
.69652 .05973 L
.69137 .06217 L
.68634 .06461 L
.6814 .06705 L
.67649 .06948 L
.67158 .07192 L
.66659 .07436 L
.6615 .0768 L
.65631 .07924 L
.65101 .08167 L
.63722 .08777 L
.62263 .09386 L
.60718 .09996 L
.591 .10605 L
.57402 .11215 L
.57228 .11276 L
.57053 .11337 L
.55651 .11824 L
.53908 .12434 L
.52201 .13043 L
.49227 .14262 L
.47194 .15481 L
.45796 .167 L
.44706 .17919 L
.43795 .19138 L
.43002 .20357 L
.42291 .21576 L
.41643 .22795 L
.41041 .24014 L
.40479 .25233 L
.39948 .26452 L
.39443 .27671 L
.38496 .30109 L
.37616 .32547 L
.36788 .34985 L
.35999 .37423 L
Mistroke
.35242 .39861 L
.34512 .42299 L
.33804 .44737 L
.33116 .47175 L
.32446 .49613 L
.30842 .55708 L
.29347 .61803 L
Mfstroke
.29347 .61803 m
.29347 .61803 L
s
1 1 0 r
.69395 .00244 m
.69309 .00305 L
.69223 .00366 L
.69135 .00427 L
.69047 .00488 L
.68957 .00549 L
.68867 .0061 L
.68776 .0067 L
.68684 .00731 L
.6859 .00792 L
.68496 .00853 L
.68401 .00914 L
.68304 .00975 L
.68207 .01036 L
.68108 .01097 L
.68008 .01158 L
.67907 .01219 L
.67805 .0128 L
.67702 .01341 L
.67597 .01402 L
.67491 .01463 L
.67383 .01524 L
.67275 .01585 L
.67165 .01646 L
.67053 .01707 L
.6694 .01768 L
.66825 .01829 L
.66709 .01889 L
.66591 .0195 L
.66472 .02011 L
.66351 .02072 L
.66228 .02133 L
.66103 .02194 L
.65949 .02255 L
.65794 .02316 L
.65639 .02377 L
.65484 .02438 L
.65329 .02499 L
.65174 .0256 L
.65019 .02621 L
.64864 .02682 L
.64554 .02804 L
.64244 .02926 L
.63934 .03048 L
.63624 .03169 L
.63315 .03291 L
.62997 .03413 L
.62681 .03535 L
.62366 .03657 L
.62053 .03779 L
Mistroke
.61741 .03901 L
.61431 .04023 L
.61122 .04145 L
.60815 .04267 L
.60509 .04388 L
.60204 .0451 L
.59901 .04632 L
.596 .04754 L
.59287 .04876 L
.58976 .04998 L
.58669 .0512 L
.58366 .05242 L
.57769 .05486 L
.57187 .05729 L
.56617 .05973 L
.5606 .06217 L
.55515 .06461 L
.54994 .06705 L
.54503 .06948 L
.54024 .07192 L
.53566 .07436 L
.53099 .0768 L
.52622 .07924 L
.52135 .08167 L
.5087 .08777 L
.4953 .09386 L
.48089 .09996 L
.46565 .10605 L
.44967 .11215 L
.44803 .11276 L
.44638 .11337 L
.43233 .11824 L
.41461 .12434 L
.39662 .13043 L
.36199 .14262 L
.33287 .15481 L
.31306 .167 L
.29814 .17919 L
.28604 .19138 L
.27575 .20357 L
.26674 .21576 L
.25867 .22795 L
.25133 .24014 L
.24455 .25233 L
.23824 .26452 L
.23231 .27671 L
.22137 .30109 L
.21139 .32547 L
.20216 .34985 L
.19349 .37423 L
Mistroke
.18528 .39861 L
.17745 .42299 L
.16991 .44737 L
.16262 .47175 L
.15553 .49613 L
.1385 .55708 L
.12231 .61803 L
Mfstroke
.12231 .61803 m
.12231 .61803 L
s
0 1 0 r
.34548 .00244 m
.34634 .00305 L
.3472 .00366 L
.34808 .00427 L
.34896 .00488 L
.34986 .00549 L
.35058 .0061 L
.35167 .0067 L
.35259 .00731 L
.35353 .00792 L
.35447 .00853 L
.35542 .00914 L
.35639 .00975 L
.35736 .01036 L
.35835 .01097 L
.35935 .01158 L
.36036 .01219 L
.36138 .0128 L
.36241 .01341 L
.36346 .01402 L
.36452 .01463 L
.36559 .01524 L
.36668 .01585 L
.36778 .01646 L
.3689 .01707 L
.37003 .01768 L
.37118 .01829 L
.37234 .01889 L
.37352 .0195 L
.37471 .02011 L
.37592 .02072 L
.37715 .02133 L
.3784 .02194 L
.37994 .02255 L
.38149 .02316 L
.38304 .02377 L
.38459 .02438 L
.38614 .02499 L
.38769 .0256 L
.38924 .02621 L
.39079 .02682 L
.39389 .02804 L
.39699 .02926 L
.40009 .03048 L
.40319 .03169 L
.40628 .03291 L
.40946 .03413 L
.41262 .03535 L
.41577 .03657 L
.4189 .03779 L
Mistroke
.42202 .03901 L
.42512 .04023 L
.42821 .04145 L
.43128 .04267 L
.43434 .04388 L
.43739 .0451 L
.44042 .04632 L
.44343 .04754 L
.44656 .04876 L
.44967 .04998 L
.45274 .0512 L
.45577 .05242 L
.46174 .05486 L
.46756 .05729 L
.47326 .05973 L
.47883 .06217 L
.48428 .06461 L
.48949 .06705 L
.4944 .06948 L
.49919 .07192 L
.50377 .07436 L
.50844 .0768 L
.51321 .07924 L
.51808 .08167 L
.53073 .08777 L
.54413 .09386 L
.55854 .09996 L
.57378 .10605 L
.58976 .11215 L
.5914 .11276 L
.59309 .11337 L
.60703 .11824 L
.62468 .12434 L
.6424 .13043 L
.67624 .14262 L
.70459 .15481 L
.72391 .167 L
.73804 .17919 L
.75002 .19138 L
.75937 .20357 L
.768 .21576 L
.77552 .22795 L
.7824 .24014 L
.78921 .25233 L
.7955 .26452 L
.80026 .27671 L
.81035 .30109 L
.81928 .32547 L
.82788 .34985 L
.83627 .37423 L
Mistroke
.84377 .39861 L
.85143 .42299 L
.85847 .44737 L
.86476 .47175 L
.87216 .49613 L
.88818 .55708 L
.9032 .61803 L
Mfstroke
.9032 .61803 m
.9032 .61803 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.47619 .45187 m
.47619 .54711 L
.85714 .54711 L
.85714 .45187 L
F
1 g
.45238 .47568 m
.45238 .57092 L
.83333 .57092 L
.83333 .47568 L
F
0 g
.001 w
[ ] 0 setdash
.45238 .47568 m
.83333 .47568 L
.83333 .57092 L
.45238 .57092 L
.45238 .47568 L
s
% Start of sub-graphic
p
0.452381 0.475684 0.833333 0.570922 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.00679348 0.0679348 [
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0122283 0.35119 0.080163 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .0462 -61 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
76.313 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
80.750 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(F) show
90.438 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
94.875 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
105.563 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
110.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(L) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
124.125 19.750 moveto
(H) show
129.625 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
143.813 19.750 moveto
(L) show
149.313 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.0910326 0.35119 0.158967 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 1 0 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .125 -61 -14.5313 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 29.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 20.500 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 20.500 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Density) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
124.563 20.500 moveto
(H) show
130.063 20.500 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(kg) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
148.625 20.500 moveto
(\\220) show
154.500 20.500 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
168.688 13.125 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 11.375 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
175.563 20.500 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.169837 0.35119 0.237772 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .2038 -61 -14.1563 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28.3125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Pressure) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.813 19.750 moveto
(H) show
141.313 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(hPa) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
170.563 19.750 moveto
(L) show
176.063 19.750 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 16.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{750, 463.5},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0001cb000`400?l00000o`00003oo`3ooooo
0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo
003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0
ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool0
0?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooM`3o
ool00`3oojX0E@00000000030000000405FZo`3oool0oooo0=B0:`<0000000<0EJ[o0?ooo`3oool0
3`3oool00`3oojX0E@0[083Do`0/0?ooo`050?nZE@00000000000000000[P=@0o`3ooolV0?ooo`00
o`3ooomf0?ooo`030?ooe020:`00000000D0000000D0EJ[o0?ooo`3DP2/0000002^0e00D0?ooo`03
0=B0:`00:h00e?oo02d0oooo00<0e80[0000000[P=@0o`3ooolV0?ooo`00o`3oooml0?ooo`070:YE
0000000005FZ0?ooo`3DP2/0000002^0e00D0?ooo`030?ooZP1E02/0P=Co02d0oooo00<0e80[0000
000[P=@0o`3ooolV0?ooo`00o`3ooomR0?ooo`030?ooZP1E0000000000H0000000D0:h3D0?ooo`3o
ool0oonZ05D00002000000030000:`20e?l0oooo00<0oooo00/0e80[000000000000:h3D0=B0:`00
000005FZ0?ooo`3DP2/0000002^0e0040?ooo`040?ooe020:`00000002^0e0@0oooo00D0ojYE0000
00000000000005FZo`020?ooo`040?oDP00[0000000[083Do`@0oooo00D0omB002/000000000001E
0:[oo`040?ooo`0<0=B0:`0000000000000[P03DojX0E@000000:`20e?l0oonZ05D000000000EJ[o
0P3oool01`2ZE@00000000000000:h00ZX0[00000000EJX00`3oool01@2ZE@000000000000000000
:h3D00<0oooo00<0e80[0000000[P=@0o`3ooolV0?ooo`00o`3ooomR0?ooo`030?ooZP1E00000000
00H0000000<0:h3D0?ooo`3oZUD01P000000101EZ_l0oooo0?ooo`3DP2/40000000702/[:`000000
05FZ0?ooo`3DP2/0000002^0e0040?ooo`040?ooe020:`00000002^0e0<0oooo00<0ojYE00000000
00000`0000001P1EZ_l0oooo0?oDP00[0000000[083Do`@0oooo00D0e80[000000000000000005FZ
o`030?ooo`030?nZE@000000000000@0000000P002^00=Coo`3oojX0E@000000001EZ_l0oooo0?nZ
E@H0000000@005FZ0?ooo`3oool0ZUD01@0000001P0[P=@0oooo0?ooo`3DP2/0000002^0e?l0oooo
9P3oool00?l0ooooHP3oool0103oojX0E@000000001EZ_l60?ooo`0G0?ooe020:`000000000[P03D
ool0oooo0:YE0000000002^00=Coo`3oojX0E@0000000000EJX0oooo0?oDP00[00000000001EZP3o
ool0e80[0000000[P=@0103oool0103oom@0P2/00000000[P=@20?ooo`090?ooe020:`00000002^0
e03oool0e80[00000000:h00e?oo00L0oooo00H0oooD080[00000000EEEE00000000EJX30?ooo`0T
0=B0:`00000002^00=Coo`3oom@0P2/000000000:h00e?oo0?ooZP1E0000000005FZo`3oool0ZUD0
00000000:h00e?oo0?ooZP1E00000000001EZP3oool0omB002/000000000EJ[o0?ooo`3oZUD00000
0000E@2Zool0oooo0=B0:`000000:h3Do`3ooolV0?ooo`00o`3ooomR0?ooo`040?ooZP1E00000000
05FZo`H0oooo00@0omB002/0000002/0P=Co0P3oool0203oojX0E@000000:`20e?l0omB002/00000
02/0P=Co0P3oool01`3DP2/00000001EZP3oool0e80[0000000[P=@0103oool0103oom@0P2/00000
000[P=@20?ooo`090?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo00L0oooo00L0omB0
02/0000005D0Z_nZ05D0000005D0Z_oo0080oooo0140ojYE000000000000EJ[o0?ooo`3DP2/00000
000[P03Dool0oonZ05D000000000EJ[o0?ooo`2ZE@000000001EZP020?ooo`080:YE0000000005FZ
0?ooo`3DP2/00000000[P03Dool60?ooo`030=B0:`000000:h3D0?l0oooo9P3oool00?l0ooooHP3o
ool0103oojX0E@000000001EZ_l60?ooo`040?oDP00[0000001E0:[oo`80oooo00P0oonZ05D00000
0000EJ[o0?oDP00[0000001E0:[oo`80oooo00L0e80[00000000EJX0oooo0=B0:`000000:h3D00@0
oooo00@0oooD080[00000000:h3D0P3oool02@3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[
083Do`070?ooo`070=B0:`00000002^00=Coo`2ZE@00000005FZo`020?ooo`030?ooe020:`000000
00@0000000X002^00=Coo`3oojX0E@000000001EZ_l0oooo0:YE0000000005FZ0P3oool01@3DP2/0
0000001EZP3oool0e80[00L0000000D0EJ[o0?ooo`3DP2/0000002^0e03o0?ooobH0oooo003o0?oo
of80oooo00@0oonZ05D000000000EJ[o1P3oool0103oe800:`000000:`20e?l20?ooo`080?ooZP1E
0000000[083Do`3oe800:`000000:`20e?l20?ooo`070=B0:`00000005FZ0?ooo`3DP2/0000002^0
e0040?ooo`040?ooe020:`00000002^0e080oooo00T0ojYE0000000005D0Z_oo0?ooo`3oojX0E@00
0000001EZ_l01P3oool0203oom@0P2/00000000[P=@0oooo0=B0:`00000005FZ1@3oool03P3oe800
:`0000000000000002^00=Coo`3oojX0E@000000001EZ_l0oooo0:YE0000000005FZ0P3oool01@3D
P2/00000001EZP3oool0ojYE00H0000000H0000[083Do`3oool0e80[0000000[P=Co0?ooobH0oooo
003o0?ooof80oooo00@0oonZ05D000000000EJ[o1P3oool05`3oom@0P2/000000000:h00e?oo0?oo
o`2ZE@0000000000E@2Zool0oonZ05D00000000005FZ0?ooo`3oojX0E@0000000000EJX0oooo0=B0
:`000000:h3D00@0oooo00@0oooD080[00000000:h3D0P3oool02@3oZUD000000000E@2Zool0oooo
0?ooZP1E0000000005FZo`060?ooo`0K0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo
0?ooo`3oojX0E@000000E@2Zool0oooo0=B0:`00000002^00=Coo`3oojX0E@000000001EZ_l0oooo
0:YE0000000005FZ0080oooo0140e80[00000000EJX0oooo0?oDP00[0000001E0:[oo`3oool0omB0
02/0000005D0Z_oo0?ooo`3DP2/0000002^0e03o0?ooobH0oooo003o0?ooof80oooo00@0oonZ05D0
00000000EJ[o1`3oool00`3oe800:`00000000040000000405FZo`3oool0oooo0=B0:`H0000000d0
05FZ0?ooo`3DP2/0000002^0e03oool0oooD080[000[P=@0oooD080[00000000:h3D0080oooo00T0
omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l01P3oool02@3DP2/00000000[P03Dool0
oooo0?ooe020:`00000005FZo`020?ooo`030:YE00000000000000<0000000X005FZ0?ooo`3oojX0
E@000000001EZ_l0oooo0:YE0000000005FZ0P3oool00`3DP2/00000001EZP020?ooo`030:YE0000
0000000000<0000000H0:h3D0?ooo`3oool0e80[0000000[P=Co0?ooobH0oooo003o0?ooof80oooo
00@0oonZ05D000000000EJ[o203oool01P3oojX0E@00000000000000000[083Do`@0oooo01<0e80[
000000000000:h3D0=B0:`00000005FZ0?ooo`3DP2/0000002^0e03oool0oooD080[00000000000[
02/[00000000:h3D0080oooo00T0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool01@3o
ool0103oom@0P2/00000000[P=@30?ooo`040=B0:`00000002^00=Coo`80oooo00l0ZUD000000000
00000000000[P03Dool0oooo0?ooZP1E0000000005FZo`3oool0ZUD000000000EJX00P3oool00`3D
P2/00000001EZP030?ooo`050=B0:`00000000000000000[P=@00`3oool00`3DP2/0000002^0e03o
0?ooobH0oooo003o0?ooof80oooo00@0oonZ05D000000000EJ[o6P3oool00`3DP2/0000002^0e003
0?ooo`050:YE0000000000000000000[P=@00P3oool02@3oom@0P2/00000000[P=@0oooo0=B0:`00
000002^00=Coo`050?ooo`040?oDP00[0000000005FZo`<0oooo00@0omB002/0000002/0P=Co2@3o
ool0103oojX0E@000000001EZ_lD0?ooo`030=B0:`000000:h3D0?l0oooo9P3oool00?l0ooooHP3o
ool0103oojX0E@000000001EZ_lJ0?ooo`050=B0:`00000000000000001EZ_l00P3oool0103oZUD0
00000000000[P=@30?ooo`030?nZE@000000000000<0000000<0EJ[o0?ooo`3oool0103oool0103D
P2/000000000E@2Zool30?ooo`040?ooe020:`00000002^0e0T0oooo00@0oonZ05D000000000EJ[o
4P3oool01@3oZUD00000000000000000:h3D0?l0oooo9P3oool00?l0ooooHP3oool0103oojX0E@00
0000001EZ_lR0?ooo`030:YE00000000:h3D00@0oooo00D0ojYE000000000000000005FZo`060?oo
o`040?ooe020:`000000001EZPD0oooo00@0ZUD000000000:h00e?oo203oool0103oojX0E@000000
001EZ_oo0?ooocd0oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oo
oo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o
0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00k03oool0103oom@0P2/00000000[P=@40?oo
o`050?nZE@00000000000000001EZ_l0P`3oool01@3DP2/00000000000000000:h3D0880oooo00D0
ojYE000000000000000005FZo`270?ooo`050=B0:`00000000000000000[P=@0FP3oool00>`0oooo
00@0oooD080[00000000:h3D0`3oool00`3oZUD00000000000030000000305FZo`3oool0oooo07l0
oooo00<0e80[0000000000000`0000000`00EJX0oooo0?ooo`1n0?ooo`030?nZE@000000000000<0
000000<0EJ[o0?ooo`3oool0P`3oool00`3DP2/000000000000300000003001EZP3oool0oooo05L0
oooo003/0?ooo`040?ooe020:`00000002^0e080oooo00T0oooD080[00000000:h3D0?ooo`3DP2/0
0000000[P03Dool0O`3oool02@3oojX0E@000000000[P=@0oooo0?nZE@000000000[083Do`1n0?oo
o`090?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo08<0oooo00T0oonZ05D000000000
:h3D0?ooo`3oZUD000000000:`20e?l0F03oool00=d0oooo00<0oonZ05D0000000001P0000000`00
:h00e?oo0?ooo`030?ooo`040?ooe020:`00000002^0e080oooo00T0omB002/0000002/0P=Co0?oo
o`3oe800:`000000E@2Zool0L`3oool00`3oojX0E@00000000060000000<000[P03Dool0oooo0?nZ
E@000000001E0:[oo`3oool0oooD080[00000000EJ[oOP3oool02@3oe800:`000000:`20e?l0oooo
0?oDP00[0000001E0:[oo`230?ooo`090?nZE@000000001E0:[oo`3oool0oooD080[00000000EJ[o
05P0oooo003M0?ooo`030?ooZP1E0000000000H0000000<002^00=Coo`3oool00`3oool0103oom@0
P2/00000000[P=@20?ooo`090?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co07<0oooo
00<0oonZ05D0000000001P0000000`00:h00e?oo0?ooo`050?ooo`040?ooe020:`00000002^0e7h0
oooo00T0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0R03oool0103oom@0P2/00000
000[P=AH0?ooo`00k03oool0103oom@0P2/00000000[P=@20?ooo`090?nZE@000000001E0:[oo`3o
ool0oonZ05D000000000EJ[o07l0oooo00H0oonZ05D0000002/0P=Co0?ooo`3oZUD20000000305FZ
o`3oool0oooo07`0oooo00T0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0P`3oool0
1P3oojX0E@000000:`20e?l0oooo0?nZE@80000000<0EJ[o0?ooo`3oool0EP3oool00>`0oooo00@0
oooD080[00000000:h3D0P3oool02@3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`1o
0?ooo`030?ooe020:`00000000@0000000<002^00=Coo`3oool0O@3oool02@3oZUD000000000E@2Z
ool0oooo0?ooZP1E0000000005FZo`230?ooo`030?ooe020:`00000000@0000000<002^00=Coo`3o
ool0E`3oool00>T0oooo00L0oooD080[000[P=@0oooD080[00000000:h3D0080oooo00T0omB002/0
000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0P03oool00`2ZE@0000000000000200000003001E
ZP3oool0oooo07h0oooo00T0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0Q03oool0
0`2ZE@0000000000000200000003001EZP3oool0oooo05P0oooo003Y0?ooo`070?ooe020:`000000
0000:`0[:`00000002^0e0020?ooo`090?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo
0800oooo00<0e80[00000000EJX0P`3oool02@3oe800:`000000:`20e?l0oooo0?oDP00[0000001E
0:[oo`240?ooo`030=B0:`00000005FZ05d0oooo003[0?ooo`050:YE0000000000000000000[P=@0
0P3oool02@3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`200?ooo`040?oDP00[0000
02^00=Cooh80oooo00T0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0Q03oool0103o
e800:`00000[P03DoomL0?ooo`00k03oool0103oZUD000000000000[P=@30?ooo`030?nZE@000000
000000<0000000<0EJ[o0?ooo`3oool0O`3oool00`3oojX0E@0000000003000000030000E@2Zool0
oooo07h0oooo00<0ojYE0000000000000`0000000`1EZ_l0oooo0?ooo`230?ooo`030?ooZP1E0000
000000<0000000<0001E0:[oo`3oool0E`3oool00>d0oooo00<0ZUD00000000[P=@0103oool01@3o
ZUD00000000000000000EJ[o0880oooo00<0oooD080[000000000`0000000`0005D0Z_oo0?ooo`1o
0?ooo`050?nZE@00000000000000001EZ_l0QP3oool00`3oom@0P2/000000003000000030000E@2Z
ool0oooo05L0oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00
oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?oo
ool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03o
ool00600ooooo`00003o000006d000008`3oool00500oooo00D0ojYE000000000000000005FZo`0;
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool00`00o`00oooo0?ooo`07
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0B
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo0240oooo001?0?ooo`030?nZE@000000000000<0000000<0EJ[o0?oo
o`3oool0203oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo0`00o`080?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool30?oo01<0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00<0oooo0`3o000C0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0240oooo001>0?ooo`090?ooe020:`00000002^0e03oool0e80[00000000
:h00e?oo00T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`<00?l01`3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080oooo103oo`0C0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`3oool40?l001@0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool08@3oool004h0oooo00T0omB002/0000002/0P=Co0?ooo`3oe800:`000000
E@2Zool02@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo04P0oooo1000o`0m0?oo
o`030000003oool0oooo08X0oooo00@000000?ooo`3oool0oooo103oo`1>0?ooo`D0o`00<P3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0240oooo001>0?ooo`090?oDP00[0000001E
0:[oo`3oool0oonZ05D0000002/0P=Co00T0oooo00<000000?ooo`3oool0e03oool5003o0</0oooo
103oo`1>0?ooo`D0o`00K03oool00`000000oooo0?ooo`0Q0?ooo`00CP3oool02@3oZUD000000000
E@2Zool0oooo0?ooZP1E0000000005FZo`090?ooo`D00000e@3oool4003o0<L0oooo1@3oo`1=0?oo
o`H0o`00J@3oool5000002<0oooo001>0?ooo`090?nZE@000000001E0:[oo`3oool0oonZ05D00000
0000EJ[o00T0oooo00<000000?ooo`3oool0e`3oool5003o0<D0oooo103oo`1>0?ooo`@0o`00L03o
ool00`000000oooo0?ooo`0Q0?ooo`00CP3oool02@3oe800:`000000E@2Zool0oooo0?ooZP1E0000
000[083Do`090?ooo`030000003oool0oooo0=X0oooo1000o`310?ooo`D0ool0C03oool50?l00780
oooo00<000000?ooo`3oool08@3oool004h0oooo00T0omB002/0000002/0P=Co0?ooo`3oe800:`00
0000E@2Zool02@3oool00`000000oooo0?ooo`3J0?ooo`H00?l0_@3oool50?oo04`0oooo1P3o001c
0?ooo`030000003oool0oooo0240oooo001>0?ooo`090?ooe020:`00000002^0e03oool0e80[0000
0000:h00e?oo00T0oooo00<000000?ooo`3oool0g03oool5003o0;/0oooo1@3oo`1;0?ooo`D0o`00
MP3oool00`000000oooo0?ooo`0Q0?ooo`00C`3oool00`3oZUD00000000000030000000305FZo`3o
ool0oooo00P0oooo00<000000?ooo`3oool0g`3oool5003o0;H0oooo1@3oo`1;0?ooo`D0o`00N03o
ool00`000000oooo0?ooo`0Q0?ooo`00D03oool01@3oZUD00000000000000000EJ[o00/0oooo00<0
00000?ooo`3oool0g`3oool7003o0;80oooo1@3oo`1:0?ooo`H0o`00NP3oool00`000000oooo0?oo
o`0Q0?ooo`00H03oool00`000000oooo0?ooo`3S0?ooo`@00?l0[`3oool50?oo04X0oooo1P3o001l
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0>D0oooo1@00o`2Z0?oo
o`D0ool0B@3oool60?l007l0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3o
ool0iP3oool7003o0:@0oooo1P3oo`180?ooo`L0o`00P@3oool00`000000oooo0?ooo`0Q0?ooo`00
H03oool00`000000oooo0?ooo`3Y0?ooo`H00?l0X03oool60?oo04P0oooo1P3o00240?ooo`030000
003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0>`0oooo1P00o`2J0?ooo`H0ool0B@3o
ool50?l008L0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0kP3oool7
003o09<0oooo203oo`170?ooo`P0o`00R03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`00
0000oooo0?ooo`3a0?ooo`H00?l0S`3oool70?oo04P0oooo1`3o002;0?ooo`030000003oool0oooo
0240oooo001P0?ooo`030000003oool0oooo0?@0oooo1@00o`2;0?ooo`D0ool0BP3oool50?l008l0
oooo00<000000?ooo`3oool08@3oool00600oooo0`00003f0?ooo`D00?l0Q`3oool50?oo04X0oooo
1@3o002?0?ooo`<000008`3oool00600oooo00<000000?ooo`3oool0n03oool7003o0800oooo1P3o
o`180?ooo`L0o`00T`3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3j
0?ooo`L00?l0O03oool60?oo04P0oooo1`3o002E0?ooo`030000003oool0oooo0240oooo001P0?oo
o`030000003oool0oooo0?h0oooo1@00o`1h0?ooo`D0ool0BP3oool40?l009T0oooo00<000000?oo
o`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3oool10?ooo`L00?l0L03oool70?oo04P0
oooo1P3o002K0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo
0`3oool7003o06`0oooo1`3oo`180?ooo`L0o`00W03oool00`000000oooo0?ooo`0Q0?ooo`00H03o
ool00`000000oooo0?ooo`3o0?ooo`L0oooo1@00o`1X0?ooo`D0ool0BP3oool50?l00:00oooo00<0
00000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3oool90?ooo`H00?l0H@3oool7
0?oo04P0oooo1`3o002R0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo
0?l0oooo2`3oool6003o05d0oooo1`3oo`190?ooo`H0o`00Y03oool00`000000oooo0?ooo`0Q0?oo
o`00H03oool00`000000oooo0?ooo`3o0?ooo`h0oooo1@00o`1J0?ooo`@0ool0B`3oool40?l00:P0
oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3oool@0?ooo`L00?l0
DP3oool60?oo04T0oooo1`3o002Y0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003o
ool0oooo0?l0oooo4P3oool7003o04h0oooo1`3oo`190?ooo`H0o`00Z`3oool00`000000oooo0?oo
o`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?oooaH0oooo1P00o`170?ooo`L0ool0B@3oool6
0?l00:l0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooolH0?oo
o`H00?l0@`3oool60?oo04X0oooo1P3o002a0?ooo`030000003oool0oooo0240oooo001P0?ooo`03
0000003oool0oooo0?l0oooo703oool4003o0400oooo103oo`1<0?ooo`@0o`00]03oool00`000000
oooo0?ooo`0Q0?ooo`00H03oool300000?l0oooo7@3oool6003o03T0oooo1P3oo`1;0?ooo`D0o`00
]03oool3000002<0oooo001P0?ooo`030000003oool0oooo0?l0oooo7`3oool6003o03D0oooo1P3o
o`1;0?ooo`H0o`00]`3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o
0?ooob<0oooo1000o`0b0?ooo`@0ool0C03oool50?l00;X0oooo00<000000?ooo`3oool08@3oool0
0600oooo00<000000?ooo`3oool0o`3ooolT0?ooo`H00?l0:`3oool60?oo04/0oooo1P3o002l0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo9P3oool6003o02L0
oooo1P3oo`1;0?ooo`H0o`00_P3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo
0?ooo`3o0?ooobT0oooo1@00o`0T0?ooo`@0ool0C@3oool40?l00<40oooo00<000000?ooo`3oool0
8@3oool00600oooo00<000000?ooo`3oool0o`3oool[0?ooo`H00?l07P3oool50?oo04`0oooo1@3o
00330?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo;@3oool5
003o01/0oooo1P3oo`1;0?ooo`H0o`00a03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`00
0000oooo0?ooo`3o0?oooc00oooo1000o`0H0?ooo`@0ool0C@3oool40?l00<L0oooo00<000000?oo
o`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooola0?ooo`H00?l04P3oool50?oo04`0
oooo1@3o00390?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo
<`3oool5003o00l0oooo1P3oo`1;0?ooo`H0o`00bP3oool00`000000oooo0?ooo`0Q0?ooo`00H03o
ool00`000000oooo0?ooo`3o0?ooocH0oooo0`00o`0=0?ooo`@0ool0C@3oool40?l00<d0oooo00<0
00000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3ooolg0?ooo`D00?l01`3oool5
0?oo04`0oooo1@3o003?0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo
0?l0oooo>03oool5003o00@0oooo1P3oo`1;0?ooo`H0o`00d03oool00`000000oooo0?ooo`0Q0?oo
o`00H03oool00`000000oooo0?ooo`3o0?oooc/0oooo1000o`000`3oool0ool00?oo00020?oo04`0
oooo1@3o003C0?ooo`030000003oool0oooo0240oooo001P0?ooo`<00000o`3oooll0?ooo`D00?l0
00<0ool00?ooo`3oool0BP3oool50?l00=<0oooo0`00000S0?ooo`00H03oool00`000000oooo0?oo
o`3o0?oooc`0oooo0P3oo`05003o04T0oooo1@3o003G0?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo0?l0oooo>`3oool40?oo00030?ooo`00o`000?l000<00?l0A@3oool5
0?l00=T0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3oooli0?oo
o`@0ool01@3oool5003o0440oooo1@3o003K0?ooo`030000003oool0oooo0240oooo001P0?ooo`03
0000003oool0oooo0?l0oooo=P3oool60?oo00P0oooo1P00o`0k0?ooo`H0o`00g@3oool00`000000
oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?oooc<0oooo1`3oo`0<0?ooo`H00?l0
=P3oool70?l00=l0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0o`3o
ool`0?ooo`L0ool04P3oool6003o0300oooo1`3o003R0?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo0?l0oooo;P3oool60?oo01L0oooo1P00o`0[0?ooo`L0o`00i@3oool0
0`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooob/0oooo1P3oo`0M0?oo
o`D00?l09`3oool60?l00>P0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3o
ool0o`3ooolY0?ooo`H0ool08@3oool6003o0240oooo1P3o003[0?ooo`030000003oool0oooo0240
oooo001P0?ooo`030000003oool0oooo0?l0oooo9`3oool50?oo02H0oooo1P00o`0M0?ooo`H0o`00
k@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooobD0oooo1@3o
o`0[0?ooo`D00?l0603oool60?l00?00oooo00<000000?ooo`3oool08@3oool00600oooo00<00000
0?ooo`3oool0o`3ooolR0?ooo`H0ool0;`3oool6003o01<0oooo1P3o003b0?ooo`030000003oool0
oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo803oool60?oo03<0oooo1P00o`0>0?oo
o`H0o`00m@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?oooah0
oooo1@3oo`0i0?ooo`H00?l02@3oool60?l00?L0oooo00<000000?ooo`3oool08@3oool00600oooo
0`00003o0?oooa/0oooo1P3oo`0m0?ooo`H00?l0103oool60?l00?P0oooo0`00000S0?ooo`00H03o
ool00`000000oooo0?ooo`3o0?oooaT0oooo1P3oo`120?ooo`H00?l01@3o003l0?ooo`030000003o
ool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo5P3oool60?oo04L0oooo1P00o`3o
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo503oool60?oo
04L0oooo1@3o0006003o0?`0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3o
ool0o`3oool?0?ooo`P0ool0A@3oool80?l000@0oooo2@00o`3g0?ooo`030000003oool0oooo0240
oooo001P0?ooo`030000003oool0oooo0?l0oooo303oool90?oo04@0oooo2@3o00090?ooo`P00?l0
m@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooo`T0oooo1`3o
o`160?ooo`L0o`004`3oool6003o0?80oooo00<000000?ooo`3oool08@3oool00600oooo00<00000
0?ooo`3oool0o`3oool60?ooo`L0ool0AP3oool70?l001P0oooo1`00o`3_0?ooo`030000003oool0
oooo0240oooo001P0?ooo`030000003oool0oooo0?l0oooo0`3oool70?oo04H0oooo1`3o000N0?oo
o`H00?l0k@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3o0?ooo`40
oooo1P3oo`170?ooo`H0o`00903oool6003o0>X0oooo00<000000?ooo`3oool08@3oool003l0oooo
00@0oooD080[00000000:h3D103oool01@3oZUD00000000000000000EJ[o00@0oooo00D0ojYE0000
00000000000005FZo`0;0?ooo`030000003oool0oooo0?d0oooo1P3oo`170?ooo`H0o`00:@3oool7
003o0>L0oooo00<000000?ooo`3oool08@3oool003l0oooo00@0oooD080[00000000:h3D0`3oool0
0`3oZUD00000000000030000000405FZo`3oool0oooo0?nZE@D0000000<0EJ[o0?ooo`3oool0203o
ool00`000000oooo0?ooo`3j0?ooo`L0ool0AP3oool70?l002h0oooo1`00o`3T0?ooo`030000003o
ool0oooo0240oooo000o0?ooo`040?ooe020:`00000002^0e080oooo0180oooD080[00000000:h3D
0?ooo`3DP2/00000000[P03Dool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool90?oo
o`030000003oool0oooo0?L0oooo1`3oo`170?ooo`H0o`00=03oool6003o0>80oooo00<000000?oo
o`3oool08@3oool003l0oooo00@0oooD080[00000000:h3D0P3oool04P3oe800:`000000:`20e?l0
oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`T0oooo
00<000000?ooo`3oool0m@3oool60?oo04L0oooo1P3o000j0?ooo`H00?l0g`3oool00`000000oooo
0?ooo`0Q0?ooo`00?`3oool0103oom@0P2/00000000[P=@20?ooo`0B0?oDP00[0000001E0:[oo`3o
ool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co2@3oool0
0`000000oooo0?ooo`3b0?ooo`H0ool0B03oool60?l003h0oooo1`00o`3L0?ooo`030000003oool0
oooo0240oooo000o0?ooo`040?ooe020:`00000002^0e080oooo0180ojYE0000000005D0Z_oo0?oo
o`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l90?ooo`D0
0000k@3oool70?oo04P0oooo1@3o00140?ooo`L00?l0e@3oool5000002<0oooo000o0?ooo`040?oo
e020:`00000002^0e080oooo0180ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l0ojYE
0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l90?ooo`030000003oool0oooo0>d0oooo1P3o
o`180?ooo`H0o`00B@3oool6003o0=L0oooo00<000000?ooo`3oool08@3oool003`0oooo00L0oooD
080[000[P=@0oooD080[00000000:h3D0080oooo0180omB002/0000005D0Z_oo0?ooo`3oojX0E@00
0000:`20e?l0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l90?ooo`030000003oool0
oooo0>X0oooo1P3oo`190?ooo`H0o`00CP3oool6003o0=@0oooo00<000000?ooo`3oool08@3oool0
03`0oooo00L0oooD080[00000000000[02/[00000000:h3D0080oooo0180omB002/0000002/0P=Co
0?ooo`3oe800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool90?oo
o`030000003oool0oooo0>L0oooo1`3oo`180?ooo`H0o`00D`3oool6003o0=80oooo00<000000?oo
o`3oool08@3oool003h0oooo00D0ZUD0000000000000000002^0e0020?ooo`0B0?ooe020:`000000
02^0e03oool0e80[00000000:h00e?oo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo
2@3oool00`000000oooo0?ooo`3U0?ooo`H0ool0B@3oool60?l005P0oooo1P00o`3?0?ooo`030000
003oool0oooo0240oooo000o0?ooo`040?nZE@000000000002^0e0<0oooo00<0ojYE000000000000
0`000000101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo00P0oooo00<000000?ooo`3o
ool0hP3oool60?oo04X0oooo1@3o001M0?ooo`L00?l0c03oool00`000000oooo0?ooo`0Q0?ooo`00
@03oool00`2ZE@00000002^0e0040?ooo`050?nZE@00000000000000001EZ_l0103oool01@3oZUD0
0000000000000000EJ[o00/0oooo00<000000?ooo`3oool0h03oool60?oo04T0oooo1P3o001R0?oo
o`H00?l0bP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3M0?ooo`H0
ool0BP3oool60?l006L0oooo1P00o`370?ooo`030000003oool0oooo0240oooo001P0?ooo`030000
003oool0oooo0=X0oooo1`3oo`1:0?ooo`D0o`00K03oool7003o0<@0oooo00<000000?ooo`3oool0
8@3oool00600oooo00<000000?ooo`3oool0f03oool60?oo04`0oooo103o001a0?ooo`H00?l0`P3o
ool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3E0?ooo`H0ool0C@3oool4
0?l007H0oooo1P00o`2o0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo
0=<0oooo1P3oo`1=0?ooo`D0o`00N@3oool6003o0;d0oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0d03oool60?oo04h0oooo1@3o001n0?ooo`H00?l0^P3oool00`000000
oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`3>0?ooo`H0ool0C`3oool40?l00880oooo
1P00o`2h0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0</0oooo1P3o
o`1@0?ooo`@0o`00Q`3oool6003o0;D0oooo00<000000?ooo`3oool08@3oool00600oooo0`000039
0?ooo`H0ool0D@3oool40?l008X0oooo1@00o`2b0?ooo`<000008`3oool00600oooo00<000000?oo
o`3oool0b03oool40?oo05<0oooo0`3o002?0?ooo`@00?l0/P3oool00`000000oooo0?ooo`0Q0?oo
o`00H03oool00`000000oooo0?ooo`360?ooo`@0ool0E03oool30?l00940oooo1000o`2a0?ooo`03
0000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0<D0oooo103oo`1C0?ooo`@0o`00
U03oool4003o0:l0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0``3o
ool40?oo05@0oooo103o002F0?ooo`@00?l0[P3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool0
0`000000oooo0?ooo`320?ooo`@0ool0E03oool30?l009X0oooo1000o`2/0?ooo`030000003oool0
oooo0240oooo001P0?ooo`030000003oool0oooo0<00oooo103oo`1E0?ooo`<0o`00W03oool4003o
0:/0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0_`3oool40?oo05D0
oooo0`3o002O0?ooo`@00?l0Z@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo
0?ooo`2n0?ooo`<0ool0EP3oool30?l00:40oooo1000o`2X0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo0;`0oooo103oo`1F0?ooo`<0o`00Y03oool3003o0:L0oooo00<0
00000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0^`3oool40?oo05H0oooo0`3o002V
0?ooo`<00?l0YP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2i0?oo
o`@0ool0E`3oool30?l00:P0oooo1000o`2T0?ooo`030000003oool0oooo0240oooo001P0?ooo`03
0000003oool0oooo0;P0oooo103oo`1G0?ooo`<0o`00ZP3oool4003o0:<0oooo00<000000?ooo`3o
ool08@3oool00600oooo00<000000?ooo`3oool0]P3oool40?oo05P0oooo0`3o002]0?ooo`<00?l0
XP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2e0?ooo`@0ool0F03o
ool30?l00:l0oooo0`00o`2Q0?ooo`030000003oool0oooo0240oooo001P0?ooo`<00000]03oool3
0?oo05X0oooo0P3o002a0?ooo`<00?l0WP3oool3000002<0oooo001P0?ooo`030000003oool0oooo
0;<0oooo0`3oo`1J0?ooo`80o`00/`3oool3003o09l0oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0/P3oool30?oo05X0oooo0P3o002e0?ooo`<00?l0WP3oool00`000000
oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2a0?ooo`<0ool0F`3oool00`3o0000oooo
0?ooo`2e0?ooo`<00?l0W@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?oo
o`2a0?ooo`80ool0F`3oool20?l00;P0oooo0`00o`2L0?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo0;00oooo0P3oo`1L0?ooo`030?l0003oool0oooo0;P0oooo0`00o`2K
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0:l0oooo0`3oo`1K0?oo
o`80o`00^`3oool3003o09X0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3o
ool0[P3oool30?oo05/0oooo0P3o002m0?ooo`<00?l0V@3oool00`000000oooo0?ooo`0Q0?ooo`00
H03oool00`000000oooo0?ooo`2]0?ooo`<0ool0G03oool00`3o0000oooo0?ooo`2m0?ooo`800?l0
V@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2/0?ooo`<0ool0G03o
ool20?l00<00oooo0P00o`2H0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo0:/0oooo0`3oo`1L0?ooo`80o`00`P3oool2003o09L0oooo00<000000?ooo`3oool08@3oool0
0600oooo00<000000?ooo`3oool0Z`3oool20?oo05`0oooo0P3o00340?ooo`03003o003oool0oooo
09D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0ZP3oool20?oo05d0
oooo00<0o`000?ooo`3oool0``3oool2003o09H0oooo00<000000?ooo`3oool08@3oool00600oooo
00<000000?ooo`3oool0Z@3oool30?oo05`0oooo0P3o00360?ooo`800?l0U@3oool00`000000oooo
0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2X0?ooo`<0ool0G03oool20?l00<P0oooo0P00
o`2D0?ooo`030000003oool0oooo0240oooo001P0?ooo`<00000Z03oool20?oo05d0oooo00<0o`00
0?ooo`3oool0b03oool00`00o`00oooo0?ooo`2@0?ooo`<000008`3oool00600oooo00<000000?oo
o`3oool0Y`3oool20?oo05d0oooo0P3o003:0?ooo`800?l0T`3oool00`000000oooo0?ooo`0Q0?oo
o`00H03oool00`000000oooo0?ooo`2V0?ooo`80ool0GP3oool00`3o0000oooo0?ooo`3:0?ooo`80
0?l0TP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2U0?ooo`80ool0
GP3oool20?l00<d0oooo0P00o`2A0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003o
ool0oooo0:D0oooo00<0ool00?ooo`3oool0G@3oool00`3o0000oooo0?ooo`3=0?ooo`03003o003o
ool0oooo08l0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0Y03oool2
0?oo05h0oooo0P3o003?0?ooo`800?l0T03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`00
0000oooo0?ooo`2S0?ooo`80ool0G`3oool00`3o0000oooo0?ooo`3?0?ooo`800?l0S`3oool00`00
0000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2R0?ooo`80ool0G`3oool20?l00=80
oooo0P00o`2>0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0:80oooo
00<0ool00?ooo`3oool0GP3oool00`3o0000oooo0?ooo`3B0?ooo`03003o003oool0oooo08`0oooo
00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0X@3oool20?oo05l0oooo0P3o
003D0?ooo`800?l0S@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2P
0?ooo`80ool0H03oool00`3o0000oooo0?ooo`3D0?ooo`03003o003oool0oooo08/0oooo00<00000
0?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0W`3oool20?oo0600oooo0P3o003F0?oo
o`800?l0S03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`2O0?ooo`03
0?oo003oool0oooo05h0oooo0P3o003H0?ooo`800?l0R`3oool00`000000oooo0?ooo`0Q0?ooo`00
H03oool00`000000oooo0?ooo`2N0?ooo`80ool0H03oool00`3o0000oooo0?ooo`3H0?ooo`03003o
003oool0oooo08T0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0W@3o
ool20?oo0600oooo0P3o003J0?ooo`800?l0RP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool3
000009d0oooo00<0ool00?ooo`3oool0G`3oool00`3o0000oooo0?ooo`3J0?ooo`03003o003oool0
oooo08H0oooo0`00000S0?ooo`00H03oool00`000000oooo0?ooo`2L0?ooo`80ool0H03oool20?l0
0=`0oooo0P00o`290?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo09/0
oooo0P3oo`1Q0?ooo`030?l0003oool0oooo0=`0oooo0P00o`280?ooo`030000003oool0oooo0240
oooo001P0?ooo`030000003oool0oooo09/0oooo00<0ool00?ooo`3oool0G`3oool20?l00=l0oooo
00<00?l00?ooo`3oool0QP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?oo
o`2J0?ooo`80ool0H@3oool00`3o0000oooo0?ooo`3N0?ooo`800?l0Q`3oool00`000000oooo0?oo
o`0Q0?ooo`00H03oool00`000000oooo0?ooo`2J0?ooo`030?oo003oool0oooo05l0oooo0P3o003Q
0?ooo`03003o003oool0oooo08D0oooo00<000000?ooo`3oool08@3oool002l0oooo00<0ojYE0000
E@2Zool0;P3oool00`000000oooo0?ooo`2I0?ooo`80ool0H@3oool00`3o0000oooo0?ooo`3P0?oo
o`800?l0QP3oool00`000000oooo0?ooo`0Q0?ooo`00;03oool01P3oe800:`00000000000000001E
0:[oobh0oooo00<000000?ooo`3oool0V03oool20?oo0640oooo0P3o003S0?ooo`800?l0Q@3oool0
0`000000oooo0?ooo`0Q0?ooo`00:@3oool00`3oojX0E@000000000400000003000[P03Dool0oooo
02d0oooo00<000000?ooo`3oool0V03oool00`3oo`00oooo0?ooo`1P0?ooo`030?l0003oool0oooo
0><0oooo00<00?l00?ooo`3oool0P`3oool00`000000oooo0?ooo`0Q0?ooo`009P3oool00`3oom@0
P2/0000000050000000305FZo`3oool0oooo02l0oooo00<000000?ooo`3oool0U`3oool20?oo0640
oooo0P3o003U0?ooo`800?l0Q03oool00`000000oooo0?ooo`0Q0?ooo`00903oool00`3oojX0E@00
0000000300000005001EZP3oool0ZUD00000001EZ_l0<@3oool00`000000oooo0?ooo`2G0?ooo`03
0?oo003oool0oooo0600oooo00<0o`000?ooo`3oool0i@3oool00`00o`00oooo0?ooo`220?ooo`03
0000003oool0oooo0240oooo000T0?ooo`040?ooZP1E00000000001EZP@0oooo00<0ZUD00000001E
Z_l03@3oool00`3DP2/00000000000050000000405FZo`3oool0oooo0?nZE@<0000000<0EJ[o0?oo
o`3oool00P3oool01@3oZUD00000000000000000EJ[o00/0oooo00<000000?ooo`3oool0UP3oool2
0?oo0640oooo0P3o003W0?ooo`800?l0P`3oool00`000000oooo0?ooo`0Q0?ooo`00903oool00`3o
ojX0E@000000000300000005001EZP3oool0ZUD00000001EZ_l03@3oool00`3oe800:`0000000005
0000000305FZo`3oool0ojYE00D0000000@0EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?oo
o`080?ooo`030000003oool0oooo09D0oooo0P3oo`1Q0?ooo`80o`00j@3oool2003o0880oooo00<0
00000?ooo`3oool08@3oool002H0oooo00<0oonZ05D0000000001@0000000`1EZ_l0oooo0?ooo`0<
0?ooo`040:YE00000000001E0:[oo`@0oooo0180oooD080[00000000:h3D0?ooo`3DP2/00000000[
P03Dool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool90?ooo`030000003oool0oooo
09D0oooo00<0ool00?ooo`3oool0H03oool00`3o0000oooo0?ooo`3Y0?ooo`03003o003oool0oooo
0800oooo00<000000?ooo`3oool08@3oool002T0oooo00<0omB002/000000000100000000`00:h00
e?oo0?ooo`0:0?ooo`050?ooe020:`0000000000E@2Zool00`3oool04P3oe800:`000000:`20e?l0
oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`T0oooo
00<000000?ooo`3oool0U03oool20?oo0640oooo0P3o003[0?ooo`800?l0P@3oool00`000000oooo
0?ooo`0Q0?ooo`00;03oool01P3oZUD00000000000000000001E0:[oo``0oooo00D0oooD080[0000
0000001E0:[oo`020?ooo`0B0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[
0000001E0:[oo`3oool0oonZ05D0000002/0P=Co2@3oool500000980oooo00<0ool00?ooo`3oool0
H03oool00`3o0000oooo0?ooo`3[0?ooo`03003o003oool0oooo07/0oooo1@00000S0?ooo`00;`3o
ool00`3DP2/0001E0:[oo`0=0?ooo`0H0?ooe020:`0000000000E@2Zool0oooo0?nZE@000000001E
0:[oo`3oool0oonZ05D000000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o
2@3oool00`000000oooo0?ooo`2C0?ooo`80ool0H@3oool20?l00>d0oooo0P00o`200?ooo`030000
003oool0oooo0240oooo00100?ooo`0G0?ooe020:`000000001EZP3oool0ojYE0000000005D0Z_oo
0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l02@3o
ool00`000000oooo0?ooo`2C0?ooo`030?oo003oool0oooo0600oooo0P3o003^0?ooo`03003o003o
ool0oooo07h0oooo00<000000?ooo`3oool08@3oool00440oooo01H0omB002/0000002/0P=Co0?oD
P00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0
000002/0P=Co2@3oool00`000000oooo0?ooo`2B0?ooo`80ool0H@3oool30?l00>h0oooo0P00o`1o
0?ooo`030000003oool0oooo0240oooo000T0?ooo`030?ooZP1E0000000000T0000000<0001E0:[o
o`3oool02@3oool06`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`3oe800:`000000
:`20e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[o
o`090?ooo`030000003oool0oooo0980oooo00<0ool00?ooo`3oool0H03oool20?l00?00oooo00<0
0?l00?ooo`3oool0O@3oool00`000000oooo0?ooo`0Q0?ooo`00903oool00`3oojX0E@0000000009
000000030000E@2Zool0oooo00T0oooo01/0oonZ05D000000000EJ[o0?ooo`3oZUD000000000:`20
e?l0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool0oooD080[00000000:h3D0?ooo`3D
P2/00000000[P03Dool02@3oool00`000000oooo0?ooo`2A0?ooo`80ool0H@3oool30?l00?00oooo
0P00o`1n0?ooo`030000003oool0oooo0240oooo000m0?ooo`030:YE00000000000000<0000000@0
05FZ0?ooo`3oool0ojYE1@000000101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo00P0
oooo00<000000?ooo`3oool0T@3oool00`3oo`00oooo0?ooo`1P0?ooo`80o`00lP3oool00`00o`00
oooo0?ooo`1l0?ooo`030000003oool0oooo0240oooo000W0?ooo`040?ooZP1E000002^00=Cooa<0
oooo00D0e80[0000000000000000001EZP040?ooo`050?nZE@00000000000000001EZ_l0103oool0
1@3oZUD00000000000000000EJ[o00/0oooo00<000000?ooo`3oool0T03oool20?oo0680oooo0P3o
003b0?ooo`800?l0O@3oool00`000000oooo0?ooo`0Q0?ooo`009@3oool00`3oom@0P2/000000008
0000000305FZo`3oool0oooo02d0oooo00<000000?ooo`3oool0T03oool00`3oo`00oooo0?ooo`1P
0?ooo`<0o`00l`3oool00`00o`00oooo0?ooo`1k0?ooo`030000003oool0oooo0240oooo000U0?oo
o`030=B0:`000000000000P0000000<002^00=Coo`3oool0;@3oool00`000000oooo0?ooo`2?0?oo
o`80ool0HP3oool20?l00?@0oooo0P00o`1l0?ooo`030000003oool0oooo0240oooo000W0?ooo`04
0?ooZP1E000002^00=Coo`<0oooo00@0oooD080[000005D0Z_oo;P3oool00`000000oooo0?ooo`2?
0?ooo`80ool0H@3oool30?l00?@0oooo0P00o`1l0?ooo`030000003oool0oooo0240oooo000W0?oo
o`040?ooZP1E000002^00=Coo`<0oooo00@0oonZ05D00000:h00e?oo;P3oool00`000000oooo0?oo
o`2>0?ooo`80ool0HP3oool20?l00?H0oooo0P00o`1k0?ooo`030000003oool0oooo0240oooo001P
0?ooo`030000003oool0oooo08h0oooo0P3oo`1R0?ooo`80o`00mP3oool2003o07/0oooo00<00000
0?ooo`3oool08@3oool002@0oooo00D0oonZ05D0000005D0Z_nZ05D00007000000030000E@2Zool0
oooo02d0oooo00<000000?ooo`3oool0S@3oool30?oo0640oooo0`3o003f0?ooo`<00?l0NP3oool0
0`000000oooo0?ooo`0Q0?ooo`00903oool01@3oojX0E@000000E@2ZojX0E@0000L0000000<0001E
0:[oo`3oool0;@3oool00`000000oooo0?ooo`2=0?ooo`80ool0HP3oool20?l00?P0oooo0P00o`1j
0?ooo`030000003oool0oooo0240oooo001P0?ooo`<00000S@3oool20?oo0640oooo0`3o003h0?oo
o`<00?l0M`3oool3000002<0oooo000W0?ooo`040?ooZP1E000002^00=CoocD0oooo00<000000?oo
o`3oool0S03oool20?oo0680oooo0P3o003j0?ooo`800?l0N@3oool00`000000oooo0?ooo`0Q0?oo
o`009@3oool00`3oom@0P2/0000000080000000305FZo`3oool0oooo02d0oooo00<000000?ooo`3o
ool0S03oool00`3oo`00oooo0?ooo`1P0?ooo`<0o`00nP3oool2003o07T0oooo00<000000?ooo`3o
ool08@3oool002D0oooo00<0e80[000000000000200000000`00:h00e?oo0?ooo`0]0?ooo`030000
003oool0oooo08/0oooo0P3oo`1R0?ooo`80o`00n`3oool3003o07P0oooo00<000000?ooo`3oool0
8@3oool002L0oooo00@0oonZ05D00000:h00e?oo0`3oool0103oom@0P2/00000E@2Zool^0?ooo`03
0000003oool0oooo08/0oooo00<0ool00?ooo`3oool0H@3oool20?l00?`0oooo0P00o`1h0?ooo`03
0000003oool0oooo0240oooo000W0?ooo`040?ooZP1E000002^00=Coo`<0oooo00@0oonZ05D00000
:h00e?oo;P3oool00`000000oooo0?ooo`2:0?ooo`80ool0HP3oool30?l00?`0oooo0`00o`1g0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo08X0oooo00<0ool00?ooo`3o
ool0H@3oool20?l00?h0oooo0P00o`1g0?ooo`030000003oool0oooo0240oooo000W0?ooo`030?oo
ZP1E0000000000D0000000<002^00=Coo`3oool0;P3oool00`000000oooo0?ooo`290?ooo`80ool0
HP3oool30?l00?h0oooo0P00o`1g0?ooo`030000003oool0oooo0240oooo000W0?ooo`030?ooZP1E
0000000000H0000000<005FZ0?ooo`3oool0;@3oool00`000000oooo0?ooo`290?ooo`030?oo003o
ool0oooo0640oooo0P3o003o0?ooo`<00?l0MP3oool00`000000oooo0?ooo`0Q0?ooo`00;P3oool0
103oe800:`000000E@2Zool^0?ooo`030000003oool0oooo08T0oooo00<0ool00?ooo`3oool0H@3o
ool20?l00?l0oooo0@3oool2003o07H0oooo00<000000?ooo`3oool08@3oool002l0oooo00<0ZUD0
0000E@2Zool0;P3oool00`000000oooo0?ooo`280?ooo`80ool0HP3oool30?l00?l0oooo0@3oool3
003o07D0oooo00<000000?ooo`3oool08@3oool002h0oooo00@0oooD080[0000:h00e?oo;P3oool0
0`000000oooo0?ooo`280?ooo`030?oo003oool0oooo0640oooo0P3o003o0?ooo`<0oooo0P00o`1e
0?ooo`030000003oool0oooo0240oooo000^0?ooo`030?nZE@000000EJ[o02l0oooo00<000000?oo
o`3oool0Q`3oool20?oo0680oooo0`3o003o0?ooo`<0oooo0P00o`1e0?ooo`030000003oool0oooo
0240oooo000W0?ooo`030?ooZP1E0000000000H0000000<0001E0:[oo`3oool0;@3oool00`000000
oooo0?ooo`270?ooo`030?oo003oool0oooo0640oooo0P3o003o0?ooo`@0oooo0`00o`1d0?ooo`03
0000003oool0oooo0240oooo000W0?ooo`030?ooZP1E0000000000H0000000<0001E0:[oo`3oool0
;@3oool00`000000oooo0?ooo`260?ooo`80ool0H`3oool20?l00?l0oooo1@3oool2003o07@0oooo
00<000000?ooo`3oool08@3oool00600oooo0`0000260?ooo`030?oo003oool0oooo0640oooo0`3o
003o0?ooo`D0oooo0`00o`1a0?ooo`<000008`3oool00600oooo00<000000?ooo`3oool0Q@3oool2
0?oo06<0oooo0P3o003o0?ooo`L0oooo0P00o`1c0?ooo`030000003oool0oooo0240oooo000Y0?oo
o`030?ooZP1E000000000080000000<0001E0:[oo`3oool0;`3oool00`000000oooo0?ooo`250?oo
o`80ool0H`3oool20?l00?l0oooo1`3oool2003o07<0oooo00<000000?ooo`3oool08@3oool002P0
oooo00<0ojYE0000000000001@0000000`1EZ_l0oooo0?ooo`0]0?ooo`030000003oool0oooo08@0
oooo0`3oo`1R0?ooo`<0o`00o`3oool70?ooo`<00?l0LP3oool00`000000oooo0?ooo`0Q0?ooo`00
9`3oool0103oom@0P2/00000000[P=@30?ooo`040=B0:`00000002^00=Coobh0oooo00<000000?oo
o`3oool0Q03oool20?oo06<0oooo0P3o003o0?ooo`T0oooo0P00o`1b0?ooo`030000003oool0oooo
0240oooo000W0?ooo`040?ooZP1E000002^00=Coo`<0oooo00@0oooD080[000005D0Z_oo;P3oool0
0`000000oooo0?ooo`230?ooo`<0ool0H`3oool20?l00?l0oooo2@3oool2003o0780oooo00<00000
0?ooo`3oool08@3oool002L0oooo00@0oooD080[0000:h00e?oo0`3oool0103oom@0P2/0000[P03D
ool^0?ooo`030000003oool0oooo08<0oooo0P3oo`1S0?ooo`<0o`00o`3oool90?ooo`<00?l0L@3o
ool00`000000oooo0?ooo`0Q0?ooo`00:03oool00`3oZUD0000002^0e0030?ooo`030=B0:`000000
EJ[o02l0oooo00<000000?ooo`3oool0P`3oool20?oo06<0oooo0P3o003o0?ooo`/0oooo0P00o`1a
0?ooo`030000003oool0oooo0240oooo000T0?ooo`030?ooZP1E0000000000T0000000<0001E0:[o
o`3oool0;@3oool00`000000oooo0?ooo`220?ooo`<0ool0H`3oool20?l00?l0oooo2`3oool2003o
0740oooo00<000000?ooo`3oool08@3oool002@0oooo00<0oonZ05D0000000002@0000000`0005D0
Z_oo0?ooo`0]0?ooo`030000003oool0oooo0880oooo0P3oo`1T0?ooo`80o`00o`3oool;0?ooo`80
0?l0L@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`220?ooo`80ool0
H`3oool30?l00?l0oooo2`3oool3003o0700oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool0P@3oool30?oo06<0oooo0P3o003o0?ooo`d0oooo0P00o`1`0?ooo`030000003o
ool0oooo0240oooo000Y0?ooo`030?ooZP1E000000000080000000<0000[083Do`3oool0;`3oool0
0`000000oooo0?ooo`210?ooo`80ool0I03oool20?l00?l0oooo3@3oool2003o0700oooo00<00000
0?ooo`3oool08@3oool002P0oooo00<0ojYE0000000000001@0000000`1EZ_l0oooo0?ooo`0]0?oo
o`030000003oool0oooo0800oooo0`3oo`1S0?ooo`<0o`00o`3oool=0?ooo`<00?l0K`3oool00`00
0000oooo0?ooo`0Q0?ooo`009`3oool02`3oom@0P2/00000001EZ_l0omB002/0:`20e?l0omB002/0
0000:h00e?oo02h0oooo00<000000?ooo`3oool0P03oool20?oo06@0oooo0P3o003o0?ooo`l0oooo
0P00o`1_0?ooo`030000003oool0oooo0240oooo000W0?ooo`0;0?ooZP1E000002^00=Coo`3oe800
:`0[083Do`3oool0ZUD00000E@2Zool0;P3oool00`000000oooo0?ooo`200?ooo`80ool0I03oool2
0?l00?l0oooo3`3oool2003o06l0oooo00<000000?ooo`3oool08@3oool002L0oooo00/0oooD080[
000002/0P=Co0?oDP00[02/0P=Co0?ooe020:`00001E0:[oo`0^0?ooo`<00000O`3oool30?oo06<0
oooo0`3o003o0?ooo`l0oooo0`00o`1/0?ooo`<000008`3oool002P0oooo00T0ojYE000000000000
00000000:`20e?l0ZUD00000000[P=@0;`3oool00`000000oooo0?ooo`1o0?ooo`80ool0I03oool2
0?l00?l0oooo4@3oool2003o06h0oooo00<000000?ooo`3oool08@3oool002T0oooo00L0oonZ05D0
00000000000[083Do`3DP2/0:h3D0300oooo00<000000?ooo`3oool0OP3oool30?oo06@0oooo0P3o
003o0?oooa40oooo0P00o`1^0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo07h0oooo0P3oo`1T0?ooo`<0o`00o`3ooolA0?ooo`<00?l0K@3oool00`000000oooo0?ooo`0Q
0?ooo`00H03oool00`000000oooo0?ooo`1n0?ooo`80ool0I03oool20?l00?l0oooo4`3oool2003o
06d0oooo00<000000?ooo`3oool08@3oool002h0oooo00H0ojYE0000000005D0Z_oo0:YE000[P=@/
0?ooo`030000003oool0oooo07d0oooo0`3oo`1T0?ooo`80o`00o`3ooolC0?ooo`<00?l0K03oool0
0`000000oooo0?ooo`0Q0?ooo`00;P3oool01@3oZUD0000000000000000005FZ02d0oooo00<00000
0?ooo`3oool0O@3oool20?oo06@0oooo0`3o003o0?oooa@0oooo0P00o`1/0?ooo`030000003oool0
oooo0240oooo001P0?ooo`030000003oool0oooo07`0oooo0`3oo`1T0?ooo`80o`00o`3ooolE0?oo
o`800?l0K03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1l0?ooo`80
ool0I@3oool20?l00?l0oooo5@3oool3003o06/0oooo00<000000?ooo`3oool08@3oool00600oooo
00<000000?ooo`3oool0O03oool20?oo06@0oooo0`3o003o0?oooaH0oooo0P00o`1[0?ooo`030000
003oool0oooo0240oooo001P0?ooo`030000003oool0oooo07/0oooo0`3oo`1T0?ooo`80o`00o`3o
oolG0?ooo`<00?l0JP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1k
0?ooo`80ool0I@3oool20?l00?l0oooo603oool2003o06X0oooo00<000000?ooo`3oool08@3oool0
0600oooo00<000000?ooo`3oool0NP3oool30?oo06@0oooo0`3o003o0?oooaP0oooo0P00o`1Z0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo07X0oooo0P3oo`1U0?ooo`80
o`00o`3ooolI0?ooo`<00?l0J@3oool00`000000oooo0?ooo`0Q0?ooo`00903oool00`3oojX0E@00
00000009000000030000E@2Zool0oooo02d0oooo00<000000?ooo`3oool0NP3oool20?oo06D0oooo
0P3o003o0?oooaX0oooo0P00o`1Y0?ooo`030000003oool0oooo0240oooo000T0?ooo`030?ooZP1E
0000000000T0000000<0001E0:[oo`3oool0;@3oool3000007T0oooo0`3oo`1T0?ooo`<0o`00o`3o
oolJ0?ooo`<00?l0IP3oool3000002<0oooo000Z0?ooo`040=B0:`0000000000001EZS80oooo00<0
00000?ooo`3oool0N@3oool20?oo06D0oooo0P3o003o0?oooa`0oooo0P00o`1X0?ooo`030000003o
ool0oooo0240oooo000Y0?ooo`050:YE0000000000000000001EZ_l0<P3oool00`000000oooo0?oo
o`1i0?ooo`80ool0I@3oool20?l00?l0oooo703oool2003o06P0oooo00<000000?ooo`3oool08@3o
ool002L0oooo00<0oonZ05D000000000100000000`0002/0P=Co0?ooo`0_0?ooo`030000003oool0
oooo07P0oooo0`3oo`1T0?ooo`<0o`00o`3ooolL0?ooo`<00?l0I`3oool00`000000oooo0?ooo`0Q
0?ooo`009`3oool01`3oojX0E@000000001EZ_l0oooo0?ooZP1E00000P0000000`0005D0Z_oo0?oo
o`0]0?ooo`030000003oool0oooo07P0oooo0P3oo`1U0?ooo`80o`00o`3ooolN0?ooo`800?l0I`3o
ool00`000000oooo0?ooo`0Q0?ooo`009`3oool00`3oojX0E@0[083Do`040?ooo`040?ooZP1E0000
001E0:[oobh0oooo00<000000?ooo`3oool0N03oool20?oo06D0oooo0P3o003o0?oooah0oooo0P00
o`1W0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo07L0oooo0`3oo`1T
0?ooo`<0o`00o`3ooolN0?ooo`<00?l0IP3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`00
0000oooo0?ooo`1g0?ooo`80ool0I@3oool20?l00?l0oooo803oool2003o06H0oooo00<000000?oo
o`3oool08@3oool002L0oooo00<0oonZ05D0000000001P0000000`0005D0Z_oo0?ooo`0]0?ooo`03
0000003oool0oooo07L0oooo0P3oo`1U0?ooo`80o`00o`3ooolP0?ooo`800?l0IP3oool00`000000
oooo0?ooo`0Q0?ooo`009`3oool00`3oojX0E@0000000006000000030000E@2Zool0oooo02d0oooo
00<000000?ooo`3oool0MP3oool30?oo06@0oooo0`3o003o0?ooob00oooo0`00o`1U0?ooo`030000
003oool0oooo0240oooo000X0?ooo`030?nZE@000000EJ[o01<0oooo00D0e80[0000000000000000
05FZo`040?ooo`050?nZE@00000000000000001EZ_l0103oool01@3oZUD00000000000000000EJ[o
00/0oooo00<000000?ooo`3oool0MP3oool20?oo06D0oooo0P3o003o0?ooob80oooo0P00o`1U0?oo
o`030000003oool0oooo0240oooo000W0?ooo`040?ooe020:`0002^00=Cooa80oooo00<0e80[0000
000000000`000000100[P=@0oooo0?ooo`3oZUD50000000405FZo`3oool0oooo0?nZE@D0000000<0
EJ[o0?ooo`3oool0203oool00`000000oooo0?ooo`1f0?ooo`80ool0I@3oool20?l00?l0oooo8P3o
ool2003o06D0oooo00<000000?ooo`3oool08@3oool002L0oooo00@0oonZ05D0000005D0Z_oo4@3o
ool06`3oe800:`000000000[P=@0oooo0=B0:`000000001E0:[oo`3oom@0P2/00000000[P=@0oooo
0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`090?ooo`03
0000003oool0oooo07D0oooo0`3oo`1T0?ooo`<0o`00o`3ooolR0?ooo`<00?l0I03oool00`000000
oooo0?ooo`0Q0?ooo`009`3oool00`3oom@0P2/000000006000000030000E@2Zool0oooo00T0oooo
01/0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l0omB002/0000002/0P=Co0?ooo`3o
e800:`000000E@2Zool0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool02@3oool00`00
0000oooo0?ooo`1e0?ooo`80ool0I@3oool20?l00?l0oooo903oool2003o06@0oooo00<000000?oo
o`3oool08@3oool002P0oooo00<0oonZ05D0000000001@0000000`0005D0Z_oo0?ooo`0>0?ooo`0F
0?ooZP1E0000000[083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`3oe800:`00
0000E@2Zool0oooo0?ooZP1E0000000[083Do`T0oooo00<000000?ooo`3oool0M@3oool20?oo06D0
oooo0P3o003o0?ooob@0oooo0P00o`1T0?ooo`030000003oool0oooo0240oooo000X0?ooo`030?nZ
E@000000EJ[o01H0oooo01H0ojYE0000000005D0Z_oo0?nZE@000000001E0:[oo`3oool0oonZ05D0
00000000EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o2@3oool500000780oooo
0`3oo`1T0?ooo`<0o`00o`3ooolT0?ooo`<00?l0G`3oool5000002<0oooo000W0?ooo`040?ooe020
:`0002^00=Cooa@0oooo01P0omB002/000000000000[083Do`3oool0ojYE0000000005D0Z_oo0?oo
o`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l90?ooo`03
0000003oool0oooo07@0oooo0P3oo`1U0?ooo`80o`00o`3ooolV0?ooo`800?l0H`3oool00`000000
oooo0?ooo`0Q0?ooo`009`3oool0103oojX0E@000000E@2ZoolD0?ooo`0H0?oDP00[00000000000[
P03Dool0oooo0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[o
o`3oool0oonZ05D0000002/0P=Co2@3oool00`000000oooo0?ooo`1d0?ooo`80ool0I@3oool20?l0
0?l0oooo9P3oool2003o06<0oooo00<000000?ooo`3oool08@3oool002P0oooo00<0ZUD000000000
00001@0000000`0005D0Z_oo0?ooo`0>0?ooo`0F0:YE0000000005FZ0?ooo`3oe800:`000000:`20
e?l0oooo0?oDP00[0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oo`T0
oooo00<000000?ooo`3oool0L`3oool30?oo06@0oooo0`3o003o0?ooobH0oooo0`00o`1R0?ooo`03
0000003oool0oooo0240oooo000X0?ooo`030?ooZP1E0000000000D0000000<0001E0:[oo`3oool0
2@3oool06`3oojX0E@000000001EZ_l0oooo0:YE0000000005FZ0?ooo`3oom@0P2/00000000[P=@0
oooo0=B0:`00000002^00=Coo`3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`090?oo
o`030000003oool0oooo07<0oooo0P3oo`1U0?ooo`80o`00o`3ooolX0?ooo`800?l0HP3oool00`00
0000oooo0?ooo`0Q0?ooo`00?@3oool00`2ZE@000000000000030000000405FZo`3oool0oooo0?nZ
E@D0000000@0EJ[o0?ooo`3oool0ojYE1@0000000`1EZ_l0oooo0?ooo`080?ooo`030000003oool0
oooo07<0oooo0P3oo`1U0?ooo`80o`00o`3ooolX0?ooo`800?l0HP3oool00`000000oooo0?ooo`0Q
0?ooo`00?P3oool01@2ZE@000000000000000000EJ[o00@0oooo00D0ojYE000000000000000005FZ
o`040?ooo`050?nZE@00000000000000001EZ_l02`3oool00`000000oooo0?ooo`1b0?ooo`<0ool0
I03oool30?l00?l0oooo:03oool3003o0640oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool0LP3oool20?oo06D0oooo0P3o003o0?ooobX0oooo0P00o`1Q0?ooo`030000003o
ool0oooo0240oooo001P0?ooo`030000003oool0oooo0780oooo0P3oo`1U0?ooo`80o`00o`3ooolZ
0?ooo`800?l0H@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1a0?oo
o`<0ool0I03oool30?l00?l0oooo:P3oool3003o0600oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0L@3oool20?oo06D0oooo0P3o003o0?ooob`0oooo0P00o`1P0?ooo`03
0000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0740oooo0P3oo`1U0?ooo`80o`00
o`3oool/0?ooo`800?l0H03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?oo
o`1`0?ooo`<0ool0I03oool30?l00?l0oooo;03oool3003o05l0oooo00<000000?ooo`3oool08@3o
ool00600oooo00<000000?ooo`3oool0L03oool20?oo06D0oooo0P3o003o0?ooobh0oooo0P00o`1O
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0700oooo0P3oo`1U0?oo
o`80o`00o`3oool^0?ooo`800?l0G`3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool3000006l0
oooo0`3oo`1T0?ooo`<0o`00o`3oool^0?ooo`<00?l0G03oool3000002<0oooo001P0?ooo`030000
003oool0oooo06l0oooo0P3oo`1U0?ooo`80o`00o`3oool`0?ooo`800?l0GP3oool00`000000oooo
0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1_0?ooo`80ool0I@3oool20?l00?l0oooo<03o
ool2003o05h0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0KP3oool3
0?oo06@0oooo0`3o003o0?oooc00oooo0P00o`1N0?ooo`030000003oool0oooo0240oooo001P0?oo
o`030000003oool0oooo06h0oooo0P3oo`1U0?ooo`80o`00o`3ooola0?ooo`<00?l0G@3oool00`00
0000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1^0?ooo`80ool0I@3oool20?l00?l0
oooo<P3oool2003o05d0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0
K@3oool30?oo06@0oooo0`3o003o0?oooc80oooo0P00o`1M0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo06d0oooo0P3oo`1U0?ooo`80o`00o`3ooolc0?ooo`800?l0G@3o
ool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1]0?ooo`80ool0I@3oool2
0?l00?l0oooo<`3oool3003o05`0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?oo
o`3oool0K03oool30?oo06@0oooo0`3o003o0?oooc@0oooo0P00o`1L0?ooo`030000003oool0oooo
0240oooo001P0?ooo`030000003oool0oooo06`0oooo0P3oo`1U0?ooo`80o`00o`3ooole0?ooo`80
0?l0G03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1/0?ooo`80ool0
I@3oool20?l00?l0oooo=@3oool3003o05/0oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool0J`3oool30?oo06@0oooo0`3o003o0?ooocH0oooo0P00o`1K0?ooo`030000003o
ool0oooo0240oooo001P0?ooo`030000003oool0oooo06/0oooo0P3oo`1U0?ooo`80o`00o`3ooolg
0?ooo`800?l0F`3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1[0?oo
o`80ool0I@3oool20?l00?l0oooo=`3oool2003o05/0oooo00<000000?ooo`3oool08@3oool00600
oooo0`00001Z0?ooo`<0ool0I03oool30?l00?l0oooo=`3oool3003o05P0oooo0`00000S0?ooo`00
H03oool00`000000oooo0?ooo`1Z0?ooo`80ool0I@3oool20?l00?l0oooo>@3oool2003o05X0oooo
00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0JP3oool20?oo06D0oooo0P3o
003o0?ooocT0oooo0P00o`1J0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo06T0oooo0`3oo`1U0?ooo`80o`00o`3oooli0?ooo`<00?l0F@3oool00`000000oooo0?ooo`0Q
0?ooo`00H03oool00`000000oooo0?ooo`1Y0?ooo`80ool0I@3oool30?l00?l0oooo>P3oool2003o
05T0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0J@3oool20?oo06D0
oooo0P3o003o0?oooc/0oooo0P00o`1I0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000
003oool0oooo06P0oooo0`3oo`1U0?ooo`80o`00o`3ooolk0?ooo`<00?l0F03oool00`000000oooo
0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1X0?ooo`80ool0I@3oool30?l00?l0oooo?03o
ool2003o05P0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0J03oool2
0?oo06D0oooo0P3o003o0?ooocd0oooo0P00o`1H0?ooo`030000003oool0oooo0240oooo001P0?oo
o`030000003oool0oooo06L0oooo0`3oo`1U0?ooo`80o`00o`3ooolm0?ooo`<00?l0E`3oool00`00
0000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1W0?ooo`80ool0IP3oool20?l00?l0
oooo?P3oool2003o05L0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0
I`3oool20?oo06D0oooo0`3o003o0?oooch0oooo0P00o`1G0?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo06H0oooo0`3oo`1U0?ooo`80o`00o`3ooolo0?ooo`<00?l0EP3o
ool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1V0?ooo`80ool0IP3oool2
0?l00?l0oooo@03oool2003o05H0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?oo
o`3oool0IP3oool20?oo06H0oooo0P3o003o0?oood00oooo0P00o`1F0?ooo`030000003oool0oooo
0240oooo001P0?ooo`<00000I@3oool30?oo06D0oooo0`3o003o0?oood00oooo0`00o`1C0?ooo`<0
00008`3oool00600oooo00<000000?ooo`3oool0I@3oool20?oo06H0oooo0P3o003o0?oood80oooo
0P00o`1E0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo06D0oooo0P3o
o`1V0?ooo`80o`00o`3ooom20?ooo`800?l0E@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool0
0`000000oooo0?ooo`1U0?ooo`80ool0IP3oool20?l00380ooooo`00000N000004T0oooo00<00000
0?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0I03oool30?oo06D0oooo0`3o000b0?oo
ool000007P0000190?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo06@0
oooo0P3oo`1V0?ooo`80o`00<`3ooooo000001h00000B@3oool00`000000oooo0?ooo`0Q0?ooo`00
H03oool00`000000oooo0?ooo`1T0?ooo`80ool0IP3oool20?l003<0ooooo`00000N000004T0oooo
00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0H`3oool30?oo06D0oooo0`3o
000c0?ooool000007P0000190?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo06<0oooo0P3oo`1V0?ooo`80o`00=03ooooo000001h00000B@3oool00`000000oooo0?ooo`0Q
0?ooo`00H03oool00`000000oooo0?ooo`1S0?ooo`80ool0IP3oool20?l003@0ooooo`00000N0000
04T0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0H`3oool20?oo06H0
oooo0P3o000d0?ooool000007P0000190?ooo`030000003oool0oooo0240oooo001P0?ooo`030000
003oool0oooo0680oooo0`3oo`1U0?ooo`<0o`00=03ooooo000001h00000B@3oool00`000000oooo
0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1R0?ooo`80ool0IP3oool20?l003D0ooooo`00
000N000004T0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0HP3oool2
0?oo06H0oooo0P3o000e0?ooool000007P0000190?ooo`030000003oool0oooo0240oooo001P0?oo
o`030000003oool0oooo0680oooo0P3oo`1V0?ooo`80o`00=@3ooooo000001h00000B@3oool00`00
0000oooo0?ooo`0Q0?ooo`00H03oool300000640oooo0`3oo`1U0?ooo`<0o`00=@3ooooo000001h0
0000A`3oool3000002<0oooo001P0?ooo`030000003oool0oooo0640oooo0P3oo`1V0?ooo`80o`00
=P3ooooo000001h00000B@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?oo
o`1Q0?ooo`80ool0IP3oool20?l003H0ooooo`00000N000004T0oooo00<000000?ooo`3oool08@3o
ool00600oooo00<000000?ooo`3oool0H03oool30?oo06H0oooo0P3o000f0?ooool000007P000019
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0600oooo0P3oo`1V0?oo
o`<0o`00=P3ooooo000001h00000B@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000
oooo0?ooo`1P0?ooo`80ool0IP3oool20?l002D0ooooo`00000`000004T0oooo00<000000?ooo`3o
ool08@3oool00600oooo00<000000?ooo`3oool0G`3oool30?oo06H0oooo0P3o000U0?ooo`030000
003oool0oooo0?l0oooo6`3ooolB000004T0oooo00<000000?ooo`3oool08@3oool00600oooo00<0
00000?ooo`3oool0G`3oool20?oo06H0oooo0`3o000U0?ooo`030000003oool0oooo0?l0oooo6`3o
oolB000004T0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0G`3oool2
0?oo06H0oooo0P3o000V0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000004T0oooo00<00000
0?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0GP3oool30?oo06H0oooo0P3o000V0?oo
o`030000003oool0oooo0?l0oooo6`3ooolB000004T0oooo00<000000?ooo`3oool08@3oool00400
oooo00@0oonZ05D0000002/0P=Co0`3oool01@3oZUD00000000000000000EJ[o00@0oooo00D0ojYE
000000000000000005FZo`0;0?ooo`030000003oool0oooo05h0oooo0P3oo`1W0?ooo`80o`009P3o
ool00`000000oooo0?ooo`3o0?oooa/0oooo4P0000190?ooo`030000003oool0oooo0240oooo0010
0?ooo`040?ooZP1E0000000[083Do`80oooo00<0ojYE0000000000000`000000101EZ_l0oooo0?oo
o`3oZUD50000000305FZo`3oool0oooo00P0oooo00<000000?ooo`3oool0GP3oool20?oo06H0oooo
0`3o000V0?ooo`030000003oool0oooo0:l0oooo00<0oooD080[:`20e?l03@3oool00`3oojX0EB^0
0=Coo`1H0?oooa800000B@3oool00`000000oooo0?ooo`0Q0?ooo`00?03oool00`2ZE@0000000000
00050000000C001EZP3oom@0P2/00000000[P=@0oooo0=B0:`00000002^00=Coo`3oom@0P2/00000
000[P=@0oooo0=B0:`00000002^00=Coo`090?ooo`030000003oool0oooo05d0oooo0`3oo`1V0?oo
o`80o`009`3oool00`000000oooo0?ooo`2^0?ooo`030?ooe020:b/0P=Co00l0oooo00<0omB002/[
P03Dool0E`3ooolB000004T0oooo00<000000?ooo`3oool08@3oool003`0oooo00<0ZUD000000000
00001@0000004`00EJX0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0omB002/00000
02/0P=Co0?ooo`3oe800:`000000E@2Zool02@3oool00`000000oooo0?ooo`1M0?ooo`80ool0I`3o
ool20?l002L0oooo00<000000?ooo`3oool0[P3oool00`2ZE@0005FZ0?ooo`0@0?ooo`030=B0:`00
EJX0oooo05H0oooo4P0000190?ooo`030000003oool0oooo0240oooo000l0?ooo`0K0?nZE@000000
05FZ0?ooo`3oojX0E@000000:`20e?l0oooo0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0
P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co00T0oooo00<000000?ooo`3oool0
G@3oool20?oo06L0oooo0P3o000W0?ooo`030000003oool0oooo06h0oooo01H0oonZ05D000000000
EJ[o0?ooo`2ZE@000000001EZP3oool0ojYE0000000005D0Z_oo0?ooo`3oe800:`000000:`20e?l0
oonZ05D000000000EJ[o1P3oool0203oe800:`000000:`20e?l0oonZ05D000000000EJ[o1`3oool0
1P3oe800:`000000:`20e?l0oonZ05D000L0000000<0:h3D0?ooo`3oool0103oool04P3oZUD0000[
083Do`3oool0omB002/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0oooo0?nZE@000000001E
0:[oo`80oooo00<0omB002/0001EZ_l0EP3ooolB000004T0oooo00<000000?ooo`3oool08@3oool0
03`0oooo01/0oooD080[00000000EJ[o0?ooZP1E0000000[083Do`3oool0ojYE0000000005D0Z_oo
0?ooo`3oojX0E@000000001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_l02@3o
ool5000005X0oooo0`3oo`1V0?ooo`<0o`009`3oool00`000000oooo0?ooo`1^0?ooo`0F0?ooZP1E
0000000005FZo`3oom@0P2/000000000:h00e?oo0?nZE@000000001E0:[oo`3oool0omB002/00000
02/0P=Co0?ooZP1E0000000005FZo`H0oooo00P0omB002/0000002/0P=Co0?ooZP1E0000000005FZ
o`L0oooo00H0omB002/0000002/0P=Co0?ooZP1E00070000000302^0e03oool0oooo00@0oooo0180
ZUD00000E@2Zool0oooo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?ooo`3oZUD0
00000000E@2Zool20?ooo`030?ooZP1E000005FZ05H0oooo4P0000150?ooo`D000008`3oool003d0
oooo01X0omB002/00000:h00e?nZ05D0000002/0P=Co0?ooo`3oZUD000000000E@2Zool0oooo0?oo
ZP1E0000000005FZo`3oZUD000000000E@2Zool0oooo0?ooZP1E0000000005FZo`T0oooo00<00000
0?ooo`3oool0G03oool20?oo06L0oooo0P3o000X0?ooo`030000003oool0oooo06h0oooo00d0oonZ
05D000000000EJ[o0?ooZP1E000000000000E@2Zool0ojYE0000000005D0Z_oo00D0oooo00@0oonZ
05D000000000EJ[o2P3oool0103oojX0E@000000001EZ_l;0?ooo`040?ooZP1E0000000005FZo`/0
oooo01<0oonZ05D00000:h00e?oo0?ooo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[o
o`3oool0ojYE0000000005D0Z_oo0080oooo00@0oooD080[000005D0Z_ooE@3ooolB000004T0oooo
00<000000?ooo`3oool08@3oool003h0oooo01T0e80[0000000[P800E@000000:`20e?l0oooo0?oD
P00[0000001E0:[oo`3oool0oonZ05D0000002/0P=Co0?oDP00[0000001E0:[oo`3oool0oonZ05D0
000002/0P=Co00T0oooo00<000000?ooo`3oool0G03oool20?oo06L0oooo0P3o000X0?ooo`030000
003oool0oooo06h0oooo00d0oonZ05D000000000EJ[o0?nZE@0002/0P81E0000001EZ_l0ojYE0000
000005D0Z_oo00D0oooo00@0oonZ05D000000000EJ[o2P3oool0103oojX0E@000000001EZ_l;0?oo
o`040?ooZP1E0000000005FZo`/0oooo01<0oonZ05D00000:h00e?oo0?ooo`3oe800:`000000:`20
e?l0oooo0?oDP00[0000001E0:[oo`3oool0ojYE0000000005D0Z_oo0080oooo00@0oooD080[0000
05D0Z_ooE@3ooolB000004T0oooo00<000000?ooo`3oool08@3oool003h0oooo01T0oooD080[0000
000000000000:`20e?l0oooo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo0?oDP00[
0000000[083Do`3oool0omB002/0000005D0Z_oo00T0oooo00<000000?ooo`3oool0G03oool20?oo
06L0oooo0P3o000X0?ooo`030000003oool0oooo02L0oooo8000o`0W0?ooo`0=0?ooZP1E00000000
05FZo`3DP2/0001E0:[oZP1E0000:h3D0?nZE@000000001E0:[oo`050?ooo`040?ooZP1E00000000
05FZo`X0oooo00@0oonZ05D000000000EJ[o2`3oool0103oojX0E@000000001EZ_l;0?ooo`0C0?oo
ZP1E000002^00=Coo`3oool0omB002/0000002/0P=Co0?ooo`3oe800:`000000:`20e?l0oooo0?nZ
E@000000001E0:[oo`020?ooo`040?ooe020:`00001E0:[ooeD0oooo4P0000190?ooo`030000003o
ool0oooo0240oooo000o0?ooo`0H0?nZE@00000000000000:`20e?l0oooo0?ooe020:`00000002^0
e03oool0e80[00000000:h00e?oo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?oo2@3o
ool00`000000oooo0?ooo`1K0?ooo`<0ool0IP3oool30?l002P0oooo00<000000?ooo`3oool09`3o
oolP003o02L0oooo00d0oonZ05D000000000EJ[o0:YE0000:h00e?oD080[0000EJX0ojYE00000000
05D0Z_oo00D0oooo00<0oonZ05D0000000001@0000000`0[P=@0oooo0?ooo`030?ooo`030?ooZP1E
0000000000D0000000<0:h3D0?ooo`3oool0103oool0103oojX0E@000000001EZ_l;0?ooo`0C0?oo
ZP1E0000001E0:[oo`3oool0omB002/0000002/0P=Co0?ooo`3oe800:`000000:`20e?l0oooo0?nZ
E@000000001E0:[oo`020?ooo`040?ooe020:`00001E0:[ooeD0oooo4P0000190?ooo`030000003o
ool0oooo0240oooo00100?ooo`040:YE00000000000[083Do`80oooo00<0ojYE0000000000000`00
0000101EZ_l0oooo0?ooo`3oZUD50000000305FZo`3oool0oooo00P0oooo00<000000?ooo`3oool0
F`3oool20?oo06L0oooo0P3o000Y0?ooo`030000003oool0oooo06h0oooo00d0oonZ05D000000000
EJ[D080[0000EJX0oooo0:YE0000:h00e:YE0000000005D0Z_oo00D0oooo00<0oonZ05D000000000
1@0000000`0[P=@0oooo0?ooo`030?ooo`030?ooZP1E0000000000H0000000<005FZ0?ooo`3oool0
0`3oool0103oojX0E@000000001EZ_l<0?ooo`0:0:YE000005D0Z_oo0?ooo`3oe800:`0000000000
EJX0oooo0?nZE@80000000H0:h3D0?ooo`3DP2/000000000E@2Zool20?ooo`030?ooZP1E000005FZ
05H0oooo4P0000190?ooo`030000003oool0oooo0240oooo00100?ooo`040?ooZP1E0000000[083D
o`<0oooo00D0ojYE000000000000000005FZo`040?ooo`050?nZE@00000000000000001EZ_l02`3o
ool00`000000oooo0?ooo`1K0?ooo`80ool0I`3oool20?l002T0oooo00<000000?ooo`3oool0KP3o
ool03@3oojX0E@000000001EZZX0E@0002^0e03oool0e80[0000E@2ZZUD000000000E@2Zool01@3o
ool0103oojX0E@000000001EZ_l:0?ooo`040?ooZP1E0000000005FZo`<0oooo00@0e80[00000000
02/0P=Co103oool0103oojX0E@000000001EZ_l<0?ooo`060?nZE@0002/0P=Co0?ooo`3oe800:`00
2P0000001`00EJX0oooo0?ooo`3oool0omB002/0001EZ_l0EP3ooolB000004T0oooo00<000000?oo
o`3oool08@3oool00600oooo00<000000?ooo`3oool0F`3oool20?oo06L0oooo0P3o000Y0?ooo`03
0000003oool0oooo06h0oooo00d0oonZ05D000000000EEEE0000:`20e?l0oooo0?nZE@000000EEEE
0000000005D0Z_oo00D0oooo00@0oonZ05D000000000EJ[o2P3oool0103oojX0E@000000001EZ_l3
0?ooo`040?ooZP1E0000000005FZo`@0oooo00@0oonZ05D000000000EJ[o3@3oool0402ZE@0005FZ
0?ooo`3oe800:`000000:`20ZX00:`000000000005D0Z_oo0?oDP00[000000000000E@2Zool30?oo
o`030=B0:`00EJX0oooo05H0oooo4P0000190?ooo`030000003oool0oooo0240oooo001P0?ooo`03
0000003oool0oooo05X0oooo0`3oo`1V0?ooo`<0o`00:@3oool00`000000oooo0?ooo`1^0?ooo`0=
0?ooZP1E0000000002/[:`0005D0Z_oo0?ooo`3oojX0E@0002/[:`000000001E0:[oo`050?ooo`04
0?ooZP1E0000000005FZo`X0oooo00@0oonZ05D000000000EJ[o0`3oool0103DP2/000000000:`20
e?l40?ooo`040?ooZP1E0000000005FZo`d0oooo00<0oooD080[001EZ_l03`3oool00`3oZUD002^0
0=Coo`1G0?oooa800000B@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?oo
o`1J0?ooo`80ool0I`3oool20?l002X0oooo00<000000?ooo`3oool0KP3oool02@3oojX0E@000000
0000000002^00=Coo`3oool0oooD080[0002000000030000E@2Zool0oooo00@0oooo00<0oonZ05D0
000000001@0000000`0002/0P=Co0?ooo`030?ooo`030?ooZP1E0000000000H0000000<005FZ0?oo
o`3oool00`3oool0103oojX0E@000000001EZ_l?0?ooo`030:YE:`20e?l0oooo00`0oooo00<0oonZ
05EEZP3oool0F03ooolB000004T0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?oo
o`3oool0FP3oool20?oo06L0oooo0P3o000Z0?ooo`030000003oool0oooo06h0oooo00D0oonZ05D0
000000000000001EZP030?ooo`050:YE0000000000000000E@2Zool01@3oool00`3oojX0E@000000
0005000000030000:`20e?l0oooo00<0oooo00<0oonZ05D0000000001@0000000`00EJX0oooo0?oo
o`040?ooo`040?ooZP1E0000000005FZogT0oooo4P0000190?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo05T0oooo0`3oo`1V0?ooo`<0o`00:P3oool00`000000oooo0?oo
o`3o0?oooa/0oooo4P0000190?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo05T0oooo0P3oo`1W0?ooo`80o`00:`3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P000019
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo05T0oooo0P3oo`1W0?oo
o`80o`00:`3oool00`000000oooo0?ooo`3o0?oooa/0oooo4P0000190?ooo`030000003oool0oooo
0240oooo001P0?ooo`030000003oool0oooo05T0oooo0P3oo`1W0?ooo`80o`00:`3oool00`000000
oooo0?ooo`3o0?oooa/0oooo4P0000190?ooo`030000003oool0oooo0240oooo001P0?ooo`<00000
F03oool30?oo06H0oooo0`3o000[0?ooo`030000003oool0oooo0?l0oooo6`3ooolB000004L0oooo
0`00000S0?ooo`00H03oool00`000000oooo0?ooo`1H0?ooo`80ool0I`3oool20?l002`0oooo00<0
00000?ooo`3oool0o`3ooolK0?oooa800000B@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool0
0`000000oooo0?ooo`1H0?ooo`80ool0I`3oool20?l002`0oooo00<000000?ooo`3oool0o`3ooolK
0?oooa800000B@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1H0?oo
o`80ool0I`3oool20?l002`0oooo00<000000?ooo`3oool0W`3oool01@3oe800:`000000000005D0
Z_oo00/0oooo00<0oooD080[:`20e?l02P3oool00`3oojX0E@00000000030000000405FZo`3oom@0
P2/002^0e5@0oooo4P0000190?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo05L0oooo0`3oo`1V0?ooo`<0o`00;03oool00`000000oooo0?ooo`2O0?ooo`050?oDP00[0000
000000000000EJX02P3oool00`3oom@0P2/[083Do`0:0?ooo`030?ooe020:`00000000D0000000@0
EJ[o0=B0:`00:h00e?ooD`3ooolB00000003003o003oool0oooo04H0oooo00<000000?ooo`3oool0
8@3oool00600oooo00<000000?ooo`3oool0E`3oool20?oo06L0oooo0P3o000]0?ooo`030000003o
ool0oooo0:40oooo00@0omB002/0000002/0P=Co2@3oool00`2ZE@0005FZ0?ooo`0@0?ooo`060:YE
0000000005FZ0?oDP00[02/0P=CoD`3ooolB00000003003o003oool0oooo04H0oooo00<000000?oo
o`3oool08@3oool00600oooo00<000000?ooo`3oool0E`3oool20?oo06L0oooo0P3o000]0?ooo`03
0000003oool0oooo06h0oooo00<0oonZ05D0000000001@0000000`0[P=@0oooo0?ooo`030?ooo`05
0:YE0000000000000000000[P=@00`3oool00`2ZE@000000001EZP020?ooo`030=B0:`00000005FZ
0080oooo00<0oooD080[000000000P0000004P00:h00e?oo0?ooo`3oojX0E@000000001EZ_l0oooo
0?oDP00[000000000000:`20e?l0oooo0?ooZP1E0000000002^0e0P0oooo00<0ojYE0000:`20e?l0
0`3oool00`2ZE@000000001EZP020?ooo`030:YE0000000005FZ0080oooo00X0e80[000000000000
:h3D0=B0:`00000005FZ0?ooe020:`00:h3D0`3oool03P3oe800:`000000:`20e?l0oooo0?oDP00[
0000001E0:[oo`3oool0ojYE0000000005D0Z_oo@P3ooolB00000003003o003oool0oooo04H0oooo
00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0E`3oool20?oo06L0oooo0P3o
000]0?ooo`030000003oool0oooo06h0oooo00<0oonZ05D0000000001P0000001@00:h00e?oo0?oo
o`3oool0ZUD000D0000000H0:h3D0?ooo`3oool0ZUD000000000EJX20?ooo`060=B0:`00000005FZ
0?ooo`3oom@0P2/01@0000002000:h00e?oo0?ooZP1E0000000005FZo`3oool0ZUD00P0000001000
02/0P=Co0?ooo`3oZUD200000003000[P03Dool0oooo00H0oooo00<0ZUD00000E@2Zool00`3oool0
2P2ZE@000000001EZP3oool0omB002/0000005D0Z_oo0?ooo`3DP2/40000000702/[:`00000005FZ
0?ooo`3DP2/002^00=Coo`020?ooo`0>0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo
0?ooo`3oZUD000000000E@2Zoom20?oooa80000000<00?l00?ooo`3oool0AP3oool00`000000oooo
0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1F0?ooo`<0ool0IP3oool30?l002d0oooo00<0
00000?ooo`3oool0KP3oool0103oojX0E@000000001EZ_l30?ooo`0B0?oDP00[0000000002^0e03o
ool0omB002/000000000EJ[o0?ooo`3oZUD000000000E@2Zool0oooo0:YE0000000005FZ0P3oool0
5@3DP2/00000001EZP3oool0ojYE0000000002/0P=Co0?ooo`3oojX0E@000000:`20e?l0oonZ05D0
00000000EJ[o0?ooe020:`00000002^0e0030?ooo`050:YE0000000000000000:`20e?l01P3oool0
103oojX0E@00000[P03Dool30?ooo`0E0:YE0000000005FZ0?ooe020:`00000002^0e03oool0oonZ
05D00000000005FZ0?ooo`3oe800:`0000000000EJX0oooo0?oDP00[02/0P=Co0080oooo00h0omB0
02/0000002/0P=Co0?ooo`3oe800:`000000E@2Zool0oooo0?nZE@000000001E0:[ood80oooo4P00
0002003o04L0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0EP3oool2
0?oo06L0oooo0P3o000^0?ooo`030000003oool0oooo06h0oooo00@0oonZ05D000000000EJ[o103o
ool0203oZUD000000000E@2Zool0e80[00000000:h00e?oo1P3oool00`2ZE@000000001EZP020?oo
o`030=B0:`00000005FZ00@0oooo00h0ojYE00000000000000000000:`20e?l0oonZ05D000000000
EJ[o0?ooe020:`00000005FZo`80oooo00H0omB002/0000005D0ZZYE00000000EJX60?ooo`040?oo
ZP1E000002^00=Coo`<0oooo00`0ZUD00000000002/0P81E0000000005D0Z_oo0?ooo`3oe800:`00
0000:`20e?l20?ooo`070=B0:`00000005FZ0?ooo`3oom@0P2/002^0e0020?ooo`0>0?oDP00[0000
000[083Do`3oool0omB002/0000005D0Z_oo0?ooo`3oZUD000000000E@2Zoom20?oooa8000000P00
o`170?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo05H0oooo0P3oo`1W
0?ooo`80o`00;P3oool00`000000oooo0?ooo`1^0?ooo`040?ooZP1E0000000005FZo`@0oooo00D0
omB002/0000002/0P=Co0=B0:`070000000505FZo`3oool0ZUD000000000EJX00P3oool00`3DP2/0
0000001EZP020?ooo`030=B0:`000000000000<0000000X005FZ0?ooo`3oojX0E@000000001EZ_l0
oooD080[00000000EJ[o0P3oool01`3DP2/00000001EZP3oojX0E@000000E@2Zool01@3oool0103o
ojX0E@00000[P03Dool30?ooo`030:YE0000000000000080000000L0EJ[o0?ooo`3oool0omB002/0
000005D0Z_oo0080oooo00<0e80[00000000EJX00P3oool04P3DP2/002^00=Coo`3oool0omB002/0
000002/0P=Co0?ooo`3oe800:`000000:`20e?l0oooo0?nZE@000000001E0:[ood80oooo4P000002
003o04L0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0EP3oool20?oo
06L0oooo0P3o000^0?ooo`030000003oool0oooo02L0oooo803oo`0W0?ooo`040?ooZP1E00000000
05FZo`@0oooo00D0oonZ05D0000002/0P=Co0?nZE@06000000060000:`20e?l0oooo0:YE00000000
05FZ0P3oool01P3DP2/00000001EZP3oool0oonZ05D000<0000001D005FZ0?ooo`3oool0oooo0?oo
ZP1E0000000005FZo`3oom@0P2/00000001EZ_l0oooo0?ooe020:`00000005FZo`3oool0ZUD00000
001EZ_l01@3oool0103oojX0E@000000E@2Zool30?ooo`060:YE0000000005EE05D00000:h00e?oo
0P3oool0103oe800:`000000:`20e?l20?ooo`030=B0:`00000005FZ0080oooo0180omB002/0:`20
e?l0oooo0?oDP00[0000000[083Do`3oool0omB002/0000002/0P=Co0?ooo`3oZUD000000000E@2Z
oom20?oooa8000000P00o`170?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo05D0oooo0`3oo`1V0?ooo`<0o`00;P3oool00`000000oooo0?ooo`0W0?ooob00ool09`3oool0
103oojX0E@000000001EZ_l40?ooo`0b0?ooZP1E0000000[083Do`3oe800:`000000E@2Zool0oooo
0?oDP00[0000001E0:[oo`3oool0ZUD00000000002/0P=Co0?ooe020:`000000001EZP3oool0omB0
02/0000005D0Z_oo0?ooo`3DP2/00000001EZP3oool0oonZ05D000000000EJ[o0?ooe020:`000000
05FZo`3oool0omB002/0000005D0Z_oo0?ooo`3oZUD00000000[P03Dool50?ooo`030:YE000005D0
Z_oo00<0oooo00H0ZUD000000000EJX0e80[00000000EJX20?ooo`090?ooZP1E00000000001EZP3o
ool0oonZ05D00000000005FZ0080oooo00X0oooD080[000[P=@0oooo0?oDP00[00000000001EZP3o
ool0ojYE0P0000001P0[P=@0oooo0=B0:`000000001E0:[ood80oooo4P000003003o04H0oooo00<0
00000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0E@3oool20?oo06L0oooo0P3o000_
0?ooo`030000003oool0oooo06h0oooo00@0oonZ05D000000000EJ[o103oool01P3oe800:`000000
:`20e?l0oooo0:YE00D0000000@0:h3D0?ooo`3oool0ZUD01P000000100[P=@0oooo0?ooe020:`05
0000000702^0e03oool0oonZ05D000000000EJ[D080[0003000000040000E@20P2/00000001EZP80
oooo00@0oonZ05D0000002/0P=Co1@3oool00`3oZUD0000[083Do`030?ooo`070:YE0000000005FZ
0?ooe020:`00000002^0e0020?ooo`030=B0:`000000000000@0000000T005FZ0?ooo`3oool0oooo
0=B0:`00:h00e?oo0?oDP00[00002P0000001000EJX0oooo0?ooe020:`020000000302^0e03oool0
oooo03/0oooo4P0000000`3oool00?l0003o00160?ooo`030000003oool0oooo0240oooo001P0?oo
o`030000003oool0oooo05D0oooo0P3oo`1W0?ooo`80o`00;`3oool00`000000oooo0?ooo`1^0?oo
o`040?ooZP1E0000000005FZo`@0oooo00@0e80[0000000005D0Z_oo0P3oool01@3DP2/000000000
00000000:h3D00<0oooo00@0ZUD000000000EJX0ZUD00P0000001P00EJX0oooo0?ooo`3oool0oonZ
05D000<0000000P005FZ0?ooo`3oool0oonZ05D000000000EJ[D080[00H0000000L0EJ[o0?ooo`3o
ool0oooo0:YE00000000:h3D00H0oooo00<0ZUD0001EZP3oool00P3oool0202ZE@000000001EZP3o
ool0omB002/000000000EJ[o0P3oool01`3DP2/000000000000[P=@0e80[00000000EJX00`3oool0
5`3oe800:`0[083Do`3oe800:`000000:`20ZX00:`000000000005D0Z_oo0?oDP00[000000000000
E@2Zool0oooo0=B0:`0002/0P=Co0?nZE@000000EJ[o03`0oooo4P0000000`3oool00?l0003o0016
0?ooo`030000003oool0oooo0240oooo001P0?ooo`<00000E03oool30?oo06H0oooo0`3o000_0?oo
o`030000003oool0oooo06h0oooo00@0oonZ05D000000000EJ[o0`3oool0103oZUD000000000000[
P=@Q0?ooo`040?ooe020:`00000005FZoa00oooo00<0oooD080[001EZ_l00P3oool00`2ZE@000000
001EZP0A0?ooo`030?ooe020:`00:h3D0140oooo00<0oonZ05D0000[P=@0?03ooolB000000040?oo
o`00o`000?l0003o04<0oooo0`00000S0?ooo`00H03oool00`000000oooo0?ooo`1D0?ooo`80ool0
I`3oool20?l00300oooo00<000000?ooo`3oool0KP3oool00`3oojX0E@000000000600000003000[
P03Dool0oooo01`0oooo00P0oonZ05D000000000EJ[o0?ooe020:`00000005FZoa80oooo00H0ZUD[
083Do`3oool0ZUD000000000EJXB0?ooo`030=B0:`00:h00e?oo0100oooo00<0omB002/0001EZ_l0
?03ooolB00000080oooo0P00o`150?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003o
ool0oooo05@0oooo0P3oo`1W0?ooo`80o`00<03oool00`000000oooo0?ooo`1^0?ooo`030?ooZP1E
0000000000D0000000<0:h3D0?ooo`3oool07@3oool0103oojX0E@000000001EZ_l20?ooo`030:YE
001EZ_l0oooo01@0oooo00<0ZUD000000000EJX0903oool00`3oZUD0001E0:[oo`0m0?oooa800000
0P3oool2003o04D0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0E03o
ool20?oo06L0oooo0P3o000`0?ooo`030000003oool0oooo0=/0oooo00<0e80[0000E@2Zool0?03o
oolB00000080oooo0P00o`150?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0
oooo05<0oooo0`3oo`1V0?ooo`<0o`00<03oool00`000000oooo0?ooo`3H0?ooo`060?nZE@000000
EJ[o0=B0:`0002/0P=Co?03ooolB00000080oooo0`00o`140?ooo`030000003oool0oooo0240oooo
001P0?ooo`030000003oool0oooo05<0oooo0P3oo`1W0?ooo`80o`00<@3oool00`000000oooo0?oo
o`3I0?ooo`040:YE00000000000002^0e3d0oooo4P0000030?ooo`800?l0A03oool00`000000oooo
0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1C0?ooo`80ool0I`3oool20?l00340oooo00<0
00000?ooo`3oool0o`3ooolK0?oooa8000000`3oool2003o04@0oooo00<000000?ooo`3oool08@3o
ool00600oooo00<000000?ooo`3oool0D`3oool20?oo06L0oooo0P3o000a0?ooo`030000003oool0
oooo0?l0oooo6`3ooolB000000<0oooo0P00o`140?ooo`030000003oool0oooo0240oooo001P0?oo
o`030000003oool0oooo0580oooo0`3oo`1V0?ooo`<0o`00<@3oool00`000000oooo0?ooo`3o0?oo
oa/0oooo4P0000030?ooo`<00?l0@`3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000
oooo0?ooo`1B0?ooo`80ool0I`3oool20?l00380oooo00<000000?ooo`3oool0o`3ooolK0?oooa80
0000103oool2003o04<0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0
DP3oool20?oo06L0oooo0P3o000b0?ooo`030000003oool0oooo0;X0oooo00<0oooD080[:`20e?l0
7@3oool00`3oojX0EB^00=Coo`0m0?oooa800000103oool2003o04<0oooo00<000000?ooo`3oool0
8@3oool00600oooo00<000000?ooo`3oool0DP3oool20?oo06L0oooo0P3o000b0?ooo`030000003o
ool0oooo0;T0oooo00<0oooD080[:`20e?l07`3oool00`3oe800:b^00=Coo`0l0?oooa800000103o
ool2003o04<0oooo00<000000?ooo`3oool08@3oool00600oooo00<000000?ooo`3oool0D@3oool3
0?oo06H0oooo0`3o000b0?ooo`030000003oool0oooo0;T0oooo00<0ZUD0001EZP3oool0803oool0
0`3DP2/005FZ0?ooo`0k0?oooa800000103oool3003o0480oooo00<000000?ooo`3oool08@3oool0
0600oooo00<000000?ooo`3oool0D@3oool20?oo06L0oooo0P3o000c0?ooo`030000003oool0oooo
06h0oooo00@0oonZ05D000000000EJ[o1`3oool0103oojX0E@000000:`20e?l40?ooo`050:YE0000
000000000000000[P=@00`3oool00`3oom@0P2/00000000200000006000[P03Dool0oooo0?ooo`3o
om@0P2/00`0000000`00:h00e?oo0?ooo`020?ooo`0<0:YE000000000000000[P02ZP2/00000001E
ZP3oool0oonZ05D0000002/0P=Co103oool01@2ZE@000000000000000000:h3D00L0oooo00<0ojYE
0000:`20e?l00`3oool00`2ZE@000000001EZP020?ooo`080=B0:`00000005FZ0?ooo`3oojX0E@00
0000001EZ_l80?ooo`0<0=B0:`0000000000000[P03DojX0E@000000:`20e?l0oooo0?oDP00[0000
EJ[o>`3ooolB000000D0oooo0P00o`120?ooo`030000003oool0oooo0240oooo001P0?ooo`030000
003oool0oooo0540oooo0P3oo`1W0?ooo`80o`00<`3oool00`000000oooo0?ooo`1^0?ooo`040?oo
ZP1E0000000005FZo`L0oooo00@0oonZ05D0000002/0P=Co0`3oool00`2ZE@000000000000030000
000402^0e03oool0oooD080[00D0000000@002^00=Coo`3oom@0P2/01@0000001000:h00e?oo0?oo
o`3oZUD600000006001EZP3oool0oonZ05D0000002/0P=Co0`3oool00`2ZE@000000000000030000
000302^0e03oool0oooo00@0oooo00<0ZUD00000E@2Zool00`3oool00`2ZE@000000001EZP020?oo
o`080=B0:`00000005FZ0?ooo`3oojX0E@000000001EZ_l70?ooo`030?nZE@000000000000@00000
00H002^00=Coo`3oool0oonZ05D00000EJXk0?ooo`030000003oool0oooo01@0oooo0P00o`120?oo
o`030000003oool0oooo0240oooo001P0?ooo`<00000D03oool30?oo06L0oooo0P3o000c0?ooo`03
0000003oool0oooo06h0oooo00@0oonZ05D000000000EJ[o1`3oool0103oojX0E@000000:`20e?l2
0?ooo`0Y0?oDP00[0000000005FZo`3oool0ojYE0000000005D0Z_oo0?nZE@000000000[083Do`3o
ool0oonZ05D0000002/0P=Co0?nZE@000000000[083Do`3oool0oonZ05D0000002/0P=Co0?ooo`2Z
E@000000000[P03Dool0oonZ05D00000000005FZ0?ooo`3oojX0E@000000:`20e?l00P3oool02@3o
e800:`000000001EZ_l0oooo0?nZE@000000001E0:[oo`040?ooo`040?ooZP1E000002^00=Coo`<0
oooo00<0ZUD000000000EJX00P3oool0203DP2/00000001EZP3oool0oonZ05D000000000EJ[o1`3o
ool03P3DP2/00000000[P03Dool0oooD080[0000000002^00=Coo`3oool0oooD080[000005D0Z_oo
>P3oool00`000000oooo0?ooo`0D0?ooo`800?l0@03oool3000002<0oooo001P0?ooo`030000003o
ool0oooo0500oooo0P3oo`1W0?ooo`<0o`00<`3oool00`000000oooo0?ooo`1^0?ooo`040?ooZP1E
0000000005FZo`L0oooo00@0oonZ05D0000002/0P=Co0P3oool0103DP2/00000000[P03Dool80?oo
o`060?nZE@00000000000000000002/0P=Co0`3oool02P3oZUD00000000000000000000[083Do`3o
ool0ZUD000000000EJX20?ooo`080:YE0000000005FZ0?ooo`3oojX0E@000000:`20e?l20?ooo`04
0=B0:`00000002^00=Coo`T0oooo00@0oonZ05D00000:h00e?oo0`3oool00`2ZE@000000001EZP02
0?ooo`080=B0:`00000005FZ0?ooo`3oojX0E@000000001EZ_l70?ooo`0>0?nZE@000000000005FZ
o`3oool0e80[00000000:h00e?oo0?ooo`3oom@0P2/00000E@2Zoolj0?ooo`030000003oool0oooo
01@0oooo0`00o`110?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0500
oooo0P3oo`1W0?ooo`80o`00=03oool00`000000oooo0?ooo`1^0?ooo`040?ooZP1E0000000005FZ
o`L0oooo00@0oonZ05D000000000EJ[o0P3oool00`3DP2/00000000000050000000305FZo`3oool0
e80[00D0000000@005FZ0?ooo`3oool0e80[1@0000001P00EJX0oooo0?ooo`2ZE@000000001EZP80
oooo00P0e80[00000000EJX0oooo0?ooZP1E0000000005FZo`80oooo00<0e80[0000000000001@00
00000`1EZ_l0oooo0?ooo`020?ooo`040?ooZP1E000002^00=Coo`<0oooo00<0ZUD000000000EJX0
0P3oool0203DP2/00000001EZP3oool0oonZ05D000000000EJ[o1`3oool00`3oom@0P2/000000004
00000007000[P03Dool0oooo0?ooe020:`00001E0:[oo`0j0?ooo`030000003oool0oooo01D0oooo
0P00o`110?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo0500oooo0P3o
o`1W0?ooo`80o`00=03oool00`000000oooo0?ooo`0W0?ooob00o`009`3oool00`3oojX0E@000000
00050000000702^0e03oool0oooo0?ooZP1E0000000005FZo`020?ooo`030?nZE@000000000000@0
000000@0000[083Do`3oojX0E@000`0000001P00EJX0oooo0?ooo`3oool0oonZ05D000<0000000<0
05FZ0?ooo`3oool00P3oool00`2ZE@000000001EZP020?ooo`080=B0:`00000005FZ0?ooo`3oojX0
E@000000001EZ_l20?ooo`030?nZE@000000000000@0000000<0000[083Do`3oool00`3oool0103o
ojX0E@000000E@2Zool30?ooo`030:YE0000000005FZ0080oooo00H0e80[00000000EJX0oooo0?oo
ZP1E00060000000302^0e03oool0oooo00<0oooo00/0omB002/0000000000000000[P03Dool0oooo
0?ooe020:`00001E0:[oo`0j0?ooo`030000003oool0oooo01D0oooo0P00o`110?ooo`030000003o
ool0oooo0240oooo001P0?ooo`030000003oool0oooo04l0oooo0`3oo`1W0?ooo`80o`00=03oool0
0`000000oooo0?ooo`0W0?ooob00o`009`3oool00`3oojX0E@000000000600000006001EZP3oool0
oonZ05D00000000005FZ0P3oool06P3oe800:`000000E@2Zool0oooo0?oDP00[0000001E0:[oo`3o
e800:`000000E@2Zool0oooo0=B0:`00000005FZ0?ooo`3oe800:`000000E@2Zool0oooo0=B0:`00
000005FZ0P3oool00`2ZE@000000001EZP020?ooo`080=B0:`00000005FZ0?ooo`3oojX0E@000000
0000EJX20?ooo`090?oDP00[0000001E0:[oo`3oool0omB002/0000005D0Z_oo00D0oooo00<0ZUD0
0000E@2Zool00`3oool02`2ZE@0000000000:`20e?l0oooD080[0000000005FZ0?ooo`3oojX0E@00
00L0000000l005FZ0?ooo`3oojX0E@000000E@2Zool0oooo0=B0:`00000002^00=Coo`3oool0oonZ
05D00000EJX0>`3oool00`000000oooo0?ooo`0E0?ooo`800?l0@@3oool00`000000oooo0?ooo`0Q
0?ooo`00H03oool00`000000oooo0?ooo`1?0?ooo`80ool0I`3oool30?l003@0oooo00<000000?oo
o`3oool0KP3oool0103oojX0E@000000001EZ_l30?ooo`060=B0:`000000000[083Do`3oojX0E@00
0`0000000`00:h00e?oo0:YE00050000000402^0e03oool0oooD080[00D0000000@0:h3D0?ooo`3o
om@0P2/01@0000001P0[P=@0oooo0?ooo`2ZE@000000001EZP80oooo00H0e80[00000000EJX0oooo
0?ooZP1E000300000003000[P03Dool0ZUD000D0000000<0:h3D0?ooo`3oool0103oool00`3oZUD0
000[083Do`030?ooo`030:YE00000000000000@0000000H0:h3D0?ooo`3oojX0E@000000001EZ_l3
0?ooo`060=B0:`000000000[083Do`3oool0ZUD01@0000001P00EJX0oooo0?ooo`3oe800:`0005FZ
oc/0oooo00<000000?ooo`3oool05@3oool3003o0400oooo00<000000?ooo`3oool08@3oool00600
oooo00<000000?ooo`3oool0C`3oool20?oo06L0oooo0P3o000e0?ooo`030000003oool0oooo06h0
oooo00@0oonZ05D000000000EJ[o0`3oool03@3oojX0E@000000001EZ_l0oonZ05D0000002/0P81E
0000000002/0P=Co0?ooo`3DP2/00`0000001P0[P=@0oooo0?ooo`3oool0oonZ05D000<0000000H0
05FZ0?ooo`3oool0oooo0?ooZP1E000300000007001EZP3oool0oooo0?ooo`2ZE@000000001EZP02
0?ooo`0=0=B0:`00000005FZ0?ooo`3oojX0E@000000:`20P5D000000000:`20e?l0oooo0=B0:`03
0000000302^0e03oool0oooo00H0oooo00<0ZUD0001EZP3oool00P3oool0102ZE@000000001EZP2Z
E@0200000007001EZP3oool0oooo0?ooZP1E0000000005FZo`030?ooo`040?ooZP1E0000000005FZ
o`80oooo00H0ZUD00000000000000000000[P03Dool20?ooo`030=B0:`00EJX0oooo03/0oooo00<0
00000?ooo`3oool05P3oool2003o0400oooo00<000000?ooo`3oool08@3oool00600oooo00<00000
0?ooo`3oool0C`3oool20?oo06L0oooo0P3o000e0?ooo`030000003oool0oooo06h0oooo00@0oonZ
05D000000000EJ[o0`3oool0103DP2/000000000:`20e?m00?ooo`030?ooe020:`00EJ[o0080oooo
00<0ZUD000000000EJX01P3oool0103oojX0E@000000001EZ_l30?ooo`040=B0:`000000000[083D
o`T0oooo00<0ojYE000[P03Dool0?03oool00`000000oooo0?ooo`0F0?ooo`800?l0@03oool00`00
0000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1>0?ooo`<0ool0I`3oool20?l003D0
oooo00<000000?ooo`3oool0KP3oool00`3oojX0E@000000000600000003001EZP3oool0oooo0440
oooo00H0ZUD[083Do`3oool0ZUD000000000EJX60?ooo`030?ooZP1E0000000000H0000000<005FZ
0?ooo`3oool01`3oool00`3oojX0EEFZ0?ooo`0m0?ooo`030000003oool0oooo01H0oooo0P00o`10
0?ooo`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo04h0oooo0P3oo`1W0?oo
o`<0o`00=@3oool00`000000oooo0?ooo`1^0?ooo`030?ooZP1E0000000000D0000000<005FZ0?oo
o`3oool0A@3oool00`2ZE@000000001EZP060?ooo`030?ooZP1E0000000000D0000000<005FZ0?oo
o`3oool0B03oool00`000000oooo0?ooo`0F0?ooo`<00?l0?`3oool00`000000oooo0?ooo`0Q0?oo
o`00H03oool00`000000oooo0?ooo`1>0?ooo`80ool0I`3oool20?l003H0oooo00<000000?ooo`3o
ool0o`3ooolK0?ooo`030000003oool0oooo01L0oooo0P00o`0o0?ooo`030000003oool0oooo0240
oooo001P0?ooo`030000003oool0oooo04h0oooo0P3oo`1W0?ooo`80o`00=P3oool00`000000oooo
0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool05`3oool2003o03l0oooo00<000000?ooo`3oool0
8@3oool00600oooo00<000000?ooo`3oool0C@3oool30?oo06L0oooo0P3o000f0?ooo`030000003o
ool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0G0?ooo`800?l0?`3oool00`000000oooo0?oo
o`0Q0?ooo`00H03oool00`000000oooo0?ooo`1=0?ooo`80ool0J03oool20?l003H0oooo00<00000
0?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo01L0oooo0P00o`0o0?ooo`030000003oool0
oooo0240oooo001P0?ooo`030000003oool0oooo04d0oooo0P3oo`1W0?ooo`<0o`00=P3oool00`00
0000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool05`3oool3003o03h0oooo00<000000?oo
o`3oool08@3oool00600oooo0`00001<0?ooo`<0ool0I`3oool20?l003L0oooo00<000000?ooo`3o
ool0o`3ooolK0?ooo`030000003oool0oooo01P0oooo0P00o`0l0?ooo`<000008`3oool00600oooo
00<000000?ooo`3oool0C03oool20?oo06P0oooo0P3o000g0?ooool000007`00000J0?ooo`800?l0
?P3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1<0?ooo`80ool0J03o
ool20?l00?l0ooooL03oool2003o03h0oooo00<000000?ooo`3oool08@3oool00600oooo00<00000
0?ooo`3oool0C03oool20?oo06L0oooo0`3o003o0?ooog00oooo0`00o`0m0?ooo`030000003oool0
oooo0240oooo001P0?ooo`030000003oool0oooo04/0oooo0`3oo`1W0?ooo`80o`00o`3ooomb0?oo
o`800?l0?@3oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1;0?ooo`80
ool0J03oool20?l00?l0ooooLP3oool2003o03d0oooo00<000000?ooo`3oool08@3oool00600oooo
00<000000?ooo`3oool0B`3oool20?oo06P0oooo0P3o003o0?ooog80oooo0P00o`0m0?ooo`030000
003oool0oooo0240oooo001P0?ooo`030000003oool0oooo04/0oooo0P3oo`1W0?ooo`<0o`00o`3o
oomb0?ooo`<00?l0?03oool00`000000oooo0?ooo`0Q0?ooo`00H03oool00`000000oooo0?ooo`1:
0?ooo`<0ool0I`3oool20?l00?l0ooooM03oool2003o03`0oooo00<000000?ooo`3oool08@3oool0
0600oooo00<000000?ooo`3oool0BP3oool20?oo06P0oooo0P3o003o0?ooog@0oooo0P00o`0l0?oo
o`030000003oool0oooo0240oooo001P0?ooo`030000003oool0oooo04X0oooo0P3oo`1X0?ooo`80
o`00o`3ooomd0?ooo`800?l0?03oool00`000000oooo0?ooo`0Q0?ooo`00?P3oool01@3DP2/00000
000000000000:h3D00@0oooo00D0ojYE000000000000000005FZo`040?ooo`050?nZE@0000000000
0000001EZ_l02`3oool00`000000oooo0?ooo`190?ooo`<0ool0?@3oool00`000000oooo0?ooo`0W
0?ooo`<0o`00G`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08@0oooo0`00o`03
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool08@3oool003d0oooo00<0e80[0000
000000000`0000001000EJX0oooo0?ooo`3oZUD50000000405FZo`3oool0oooo0?nZE@D0000000<0
EJ[o0?ooo`3oool0203oool00`000000oooo0?ooo`190?ooo`80ool0?P3oool00`000000oooo0?oo
o`0W0?ooo`80o`00H03oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08D0oooo0P00
o`030?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool08@3oool003`0oooo01/0oonZ
05D000000000:h3D0?ooo`3oZUD000000000:`20e?l0oooD080[00000000:h3D0?ooo`3DP2/00000
000[P03Dool0oooD080[00000000:h3D0?ooo`3DP2/00000000[P03Dool02@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool04@3oool20?oo00H0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool02`3oool20?l000`0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool05@3oool2003o00<0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0240oooo
000l0?ooo`0K0?nZE@000000001E0:[oo`3oool0oooD080[00000000EJ[o0?oDP00[0000000[083D
o`3oool0omB002/0000005D0Z_oo0?oDP00[0000000[083Do`3oool0omB002/0000005D0Z_oo00T0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0140
oooo0P3oo`060?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo0P3o000<0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01D0
oooo0P00o`030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0Q0?ooo`00@@3oool05P3oom@0P2/00000000[P=@0omB002/0000005D0Z_oo0?ooo`3o
ojX0E@000000:`20e?l0omB002/0000005D0Z_oo0?ooo`3oojX0E@000000:`20e?l90?oood/00000
0`3oo`1W000000<0o`00o`00001f000000<00?l0>`00000S0?ooo`00?03oool01P3oojX0E@000000
:`20e?l0oooo0?nZE@80000001<0EJ[o0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o
0?nZE@000000001E0:[oo`3oool0oonZ05D000000000EJ[o0?l0ooooo`3ooonI0?ooo`00?03oool0
0`3oom@0P2/0000000040000000D000[P03Dool0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000
001EZ_l0ojYE0000000005D0Z_oo0?ooo`3oojX0E@000000001EZ_oo0?ooool0ooooV@3oool003d0
oooo00<0ZUD00000000000000P0000005@00EJX0oooo0?ooo`3oe800:`000000E@2Zool0oooo0?oo
ZP1E0000000[083Do`3oe800:`000000E@2Zool0oooo0?ooZP1E0000000[083Do`3o0?ooool0oooo
V@3oool003d0oooo00<0e80[00000000EJX01@3oool04P3oe800:`000000:`20e?l0oooo0?oDP00[
0000001E0:[oo`3oe800:`000000:`20e?l0oooo0?oDP00[0000001E0:[oool0ooooo`3ooonI0?oo
o`00?@3oool0103oe800:`00000[P03Dool40?ooo`0B0?ooe020:`00000002^0e03oool0e80[0000
0000:h00e?oo0?ooe020:`00000002^0e03oool0e80[00000000:h00e?ooo`3ooooo0?oooiT0oooo
000m0?ooo`030?ooZP1E0000000000<0000000@0001E0:[oo`3oool0ojYE1@000000101EZ_l0oooo
0?ooo`3oZUD50000000305FZo`3oool0oooo0?l0ooooo`3ooonH0?ooo`00?@3oool00`3oom@0P2/0
00000003000000050000E@2Zool0oooo0?ooo`3oZUD00`0000000`1EZ_l0oooo0?ooo`020?ooo`05
0?nZE@00000000000000001EZ_l0o`3ooooo0?oooi/0oooo003o0?ooool0ooool03oool00?l0oooo
o`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?oo
o`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo
0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo
003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 749}, {462.5, 0}} -> {-1.05093, -0.648943, \
0.00280622, 0.00280622}, {{18.125, 730.813}, {451.438, 11}} -> {-18.4117, \
-85.8705, 0.0355787, 1.32747}, {{338.813, 623.938}, {106.5, 35.25}} -> \
{-4.09522, -18.4873, 0.0117896, 0.0516496}, {{354.125, 438.938}, {103, \
83.625}} -> {-12.7812, -40.0153, 0.0334936, 0.108387}, {{354.125, 438.938}, \
{80.5, 61.1875}} -> {-12.8242, -42.588, 0.033602, 0.108738}, {{354.125, \
438.938}, {58.0625, 38.6875}} -> {-12.7812, -44.886, 0.0334936, 0.108387}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 1005}},
ScreenStyleEnvironment->"Presentation",
WindowSize->{1111, 903},
WindowMargins->{{51, Automatic}, {-9, Automatic}},
ShowSelection->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 28, 0, 77, "Section"],
Cell[1807, 55, 265, 4, 84, "Input"],
Cell[2075, 61, 1971, 34, 613, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4083, 100, 27, 0, 49, "Section"],
Cell[4113, 102, 1557, 37, 132, "Input"],

Cell[CellGroupData[{
Cell[5695, 143, 248, 5, 61, "Input"],
Cell[5946, 150, 120276, 2734, 472, 34743, 1675, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[126271, 2890, 30, 0, 77, "Section"],

Cell[CellGroupData[{
Cell[126326, 2894, 1101, 27, 86, "Input"],
Cell[127430, 2923, 109239, 2398, 472, 29178, 1406, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[236706, 5326, 1329, 32, 84, "Input"],
Cell[238038, 5360, 101400, 2092, 472, 23529, 1127, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[339453, 7455, 26, 0, 38, "Input"],

Cell[CellGroupData[{
Cell[339504, 7459, 1100, 27, 84, "Input"],
Cell[340607, 7488, 25359, 1247, 472, 25306, 1245, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[366003, 8740, 1088, 27, 84, "Input"],
Cell[367094, 8769, 27031, 1297, 472, 26978, 1295, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[394162, 10071, 1160, 28, 84, "Input"],
Cell[395325, 10101, 25750, 1216, 472, 25697, 1214, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[421112, 11322, 1373, 35, 84, "Input"],
Cell[422488, 11359, 112078, 2433, 472, 27663, 1388, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[534603, 13797, 1126, 28, 84, "Input"],
Cell[535732, 13827, 104714, 2233, 472, 26308, 1262, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[640483, 16065, 167, 4, 38, "Input"],
Cell[640653, 16071, 55, 1, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[640745, 16077, 1619, 37, 178, "Input"],
Cell[642367, 16116, 119812, 2728, 472, 34765, 1675, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

